(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   7631422,     168122]*)
(*NotebookOutlinePosition[   7690588,     169267]*)
(*  CellTagsIndexPosition[   7688747,     169227]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Periodic Phenomena", "Title"],

Cell["\<\

Let's begin by \"looking\" at a familiar periodic phenomena:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Cfreq = 261.6;\)\), "\[IndentingNewLine]", 
    \(\(Dfreq\  = \ 293.7;\)\), "\[IndentingNewLine]", 
    \(\(Efreq\  = \ 329.6;\)\), "\[IndentingNewLine]", 
    \(\(Ffreq = \ 349.2;\)\), "\[IndentingNewLine]", 
    \(\(Gfreq = 392.0;\)\), "\[IndentingNewLine]", 
    \(\(Afreq = \ 440.0;\)\), "\[IndentingNewLine]", 
    \(\(\(Bfreq = \ 493.9;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Note[freq_]\  := \ Sin[\ 2\ Pi\ freq\ t];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(CNote\  = \ Note[Cfreq];\)\), "\[IndentingNewLine]", 
    \(\(DNote\  = \ Note[Dfreq];\)\), "\[IndentingNewLine]", 
    \(\(ENote\  = \ Note[Efreq];\)\), "\[IndentingNewLine]", 
    \(\(FNote\  = \ Note[Ffreq];\)\), "\[IndentingNewLine]", 
    \(\(GNote\  = \ Note[Gfreq];\)\), "\[IndentingNewLine]", 
    \(\(ANote\  = \ Note[Afreq];\)\), "\[IndentingNewLine]", 
    \(\(BNote\  = \ 
        Note[Bfreq];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Csound\  = \ Play[{CNote, DNote}, {t, 0, 2}]\)}], "Input",
  CellTags->{
  "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", "mmtag:17:Play[]", 
    "mmtag:17:sound_generation"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 16384 8
{ currentfile 1 index readhexstring pop }
 false 2 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003oool0003o
o`0004;o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_l0
00001ooonfX2o`0000Kooo]Z1?l00005oookJP?o00001_oonfX3o`0000Oooo]Z0_l00007oookJP;o
00001_oonfX2o`0000Oooo]Z0_l00007oookJP?o00001_oonfX3o`0000Gooo]Z0ol00007oookJP;o
00001ooonfX2o`0000Oooo]Z0_l00006oookJP?o00001_oonfX3o`0000Kooo]Z0ol00006oookJP?o
00001_oonfX2o`0000Oooo]Z0_l00007oookJP;o00001ooonfX3o`0000Gooo]Z0ol00006oookJP?o
00001ooonfX2o`0000Oooo]Z0_l00006oookJP;o00001ooonfX2o`0000Oooo]Z0ol00006oookJP?o
00001OoonfX4o`0000Kooo]Z0_l00007oookJP;o00001ooonfX2o`0000Kooo]Z0ol00006oookJP?o
00001_oonfX3o`0000Kooo]Z0ol00006oookJP?o00001_oonfX2o`0000Oooo]Z0_l00007oookJP?o
00001OoonfX4o`0000Gooo]Z0ol00006oookJP?o00001ooonfX2o`0000Kooo]Z0ol00006oookJP;o
00001ooonfX3o`0000Kooo]Z0ol00006oookJP?o00001OoonfX3o`0000Oooo]Z0_l00007oookJP;o
00001ooonfX2o`0000Kooo]Z0ol00006oookJP?o00001_oonfX3o`0000Oooo]Z0_l00006oookJP;o
00001ooonfX2o`0000Oooo]Z0ol00006oookJP?o00001OoonfX3o`0000;ooo]Z0Ol000000004o`00
0?oonf[o0000o`0000Gooo]Z1?l00004oookJPGo00001?oonfX4o`0000Kooo]Z1?l00005oookJPCo
00001?oonfX5o`0000Cooo]Z1?l00005oookJPCo00001OoonfX4o`0000Gooo]Z1?l00005oookJPCo
00001OoonfX4o`0000Gooo]Z1?l00005oookJPCo00001?oonfX4o`0000Gooo]Z1?l00006oookJPCo
00001OoonfX4o`0000Cooo]Z1?l00005oookJPCo00001OoonfX4o`0000Gooo]Z1?l00004oookJPGo
00001OoonfX4o`0000Gooo]Z1?l00005oookJPCo00001?oonfX5o`0000Cooo]Z1?l00005oookJPCo
00001OoonfX4o`0000Gooo]Z1Ol00004oookJPCo00001OoonfX4o`0000Gooo]Z1?l00004oookJPGo
00001?oonfX4o`0000Gooo]Z1Ol00005oookJPCo00001?oonfX5o`0000Cooo]Z1?l00005oookJPCo
00001OoonfX4o`0000Cooo]Z1Ol00005oookJPCo00001OoonfX4o`0000Gooo]Z1?l00004oookJPGo
00001?oonfX4o`0000Gooo]Z1?l00005oookJPCo00001OoonfX5o`0000Cooo]Z1?l00005oookJPCo
00001OoonfX4o`0000Gooo]Z1?l00004oookJPCo00001_oonfX4o`0000Gooo]Z1?l00005oookJPCo
00001?oonfX4o`0000Gooo]Z1?l00005oookJPCo00001OoonfX5o`0000Cooo]Z1?l00001oookJP7o
000000001?l0003ooo]Zo`000?l00005oookJPGo00000ooonfX6o`0000?ooo]Z0ol000000ooonf[o
0000oookJP03oookJPGo00001?oonfX5o`0000?ooo]Z1_l00004oookJPCo00001OoonfX5o`0000Co
oo]Z1Ol00003oookJP?o000000?ooo]Zo`000?l000000ooonfX5o`0000Cooo]Z1Ol00005oookJPCo
00001?oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000?ooo]Z1Ol00004oookJPGo00001?oonfX5
o`0000Cooo]Z1Ol00003oookJPKo00001?oonfX4o`0000Gooo]Z1Ol00004oookJPGo00000ooonfX6
o`0000?ooo]Z1Ol00004oookJPGo00001?oonfX5o`0000Cooo]Z1Ol00004oookJPGo00001?oonfX5
o`0000Cooo]Z1Ol00003oookJPKo00000ooonfX3o`000003oookJ_l0003ooo]Z00?ooo]Z1Ol00005
oookJPGo00000ooonfX2o`000004oookJ_l0003o0000o`0000?ooo]Z1Ol00004oookJPGo00001?oo
nfX5o`0000?ooo]Z0ol000000ooonf[o0000o`000004oookJPCo00001OoonfX5o`0000Cooo]Z1Ol0
0003oookJPKo00000ooonfX5o`0000Cooo]Z1Ol00004oookJPGo00001?oonfX5o`0000Cooo]Z1Ol0
0004oookJPGo00001?oonfX00ol0003ooo]Zo`000002o`0000?ooo]Z1_l00003oookJPGo00001?oo
nfX5o`0000Gooo]Z1Ol00003oookJP?o000000?ooo]Zo`000?l000000ooonfX3o`000003oookJ_l0
003ooo]Z00?ooo]Z1Ol00004oookJPGo00001?oonfX2o`000003oookJ_l0003o000000Cooo]Z0_l0
00000ooonf[o0000o`000004oookJPGo00001?oonfX5o`0000Cooo]Z1Ol00003oookJPGo00000Ooo
nfX1o`00000000?o0000oookJ_l000000_l00003oookJPKo00000_oonfX7o`0000?ooo]Z1Ol00004
oookJPKo00000ooonfX6o`0000;ooo]Z1ol00002oookJPKo00000ooonfX6o`0000?ooo]Z1_l00003
oookJPKo00000ooonfX3o`000003oookJ_l0003o000000?ooo]Z1_l00003oookJPKo00000_oonfX7
o`0000;ooo]Z0ol000001?oonf[o0000o`000?l00002oookJPKo00001?oonfX6o`0000;ooo]Z1ol0
0002oookJPOo00000_oonfX6o`0000?ooo]Z1_l00003oookJPKo00000_oonfX7o`0000?ooo]Z1_l0
0003oookJPKo00000ooonfX6o`0000;ooo]Z1ol00002oookJPKo00000ooonfX6o`0000Cooo]Z0_l0
00000ooonf[o0000o`000003oookJPOo00000_oonfX6o`0000?ooo]Z1_l00003oookJPKo00000_oo
nfX7o`0000;ooo]Z1_l00004oookJPGo00001?oonfX6o`0000;ooo]Z1ol00002oookJPKo00000ooo
nfX6o`0000?ooo]Z1_l00002oookJPOo00000ooonfX6o`0000?ooo]Z1_l00003oookJPKo00000_oo
nfX7o`0000;ooo]Z1_l00003oookJPKo00001?oonfX5o`0000?ooo]Z1ol00002oookJP;o000000Co
oo]Zo`000?l0003o00000ooonfX6o`0000?ooo]Z1_l00002oookJPOo00000_oonfX7o`0000?ooo]Z
1Ol00004oookJPKo00000_oonfX7o`0000;ooo]Z1ol00002oookJPKo00000ooonfX6o`0000?ooo]Z
0_l000001?oonf[o0000o`000?l00003oookJPGo00000OoonfX1o`00000000?o0000oookJ_l00000
0_l00003oookJPKo00000_oonfX3o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?oonfX0
1Ol00002oookJP?o000000Cooo]Zo`000?oonf[o00000_oonfX4o`000003oookJ_l0003o000000;o
oo]Z1ol00002oookJPCo000000?ooo]Zo`000?oonfX00_oonfX2o`000003oookJ_l0003o000000;o
00000_oonfX2o`000003oookJ_l0003o000000;o000000Gooo]Zo`000?l0003o0000oookJP04o`00
0003oookJ_l0003o000000Go00000_oonfX7o`0000?ooo]Z1_l00002oookJPGo000000Cooo]Zo`00
0?oonf[ooo]Z1?l000000ooonf[o0000o`000002oookJP;o000000?ooo]Zo`000?l000000_l00002
oookJP;o000000?ooo]Zo`000?l000000_l00002oookJPOo00000_oonfX3o`000004oookJ_l0003o
0000o`0000;ooo]Z1_l00003oookJPKo00000_oonfX4o`0000;ooo]Z0_l000000ooonf[o0000o`00
0006o`000004oookJ_l0003o0000oookJPCo00000_oonfX7o`0000;ooo]Z0ol000001?oonf[o0000
o`000?l00002oookJPOo00000_oonfX7o`0000;ooo]Z1?l000000ooonf[o0000o`000002oookJP;o
000000?ooo]Zo`000?oonfX00_l000001Ooonf[o0000o`000?l0003ooo]Z00Co000000?ooo]Zo`00
0?l000001Ol00003oookJP;o000000Cooo]Zo`000?l0003o00000ooonfX6o`0000;ooo]Z2?l00000
0ooonf[o0000o`000002o`000003oookJ_l0003o000000;ooo]Z0_l000000ooonf[o0000oookJP02
o`0000;ooo]Z0_l000000ooonf[o0000o`000002o`0000;ooo]Z1ol00002oookJPKo00000ooonfX6
o`0000?ooo]Z1ol000000ooonf[o0000o`000002o`000005oookJ_l0003o0000o`000?oonfX01?l0
00000ooonf[o0000o`000002oookJPOo00000ooonfX6o`0000;ooo]Z0ol000001?oonf[o0000o`00
0?l00002oookJP?o000000?ooo]Zo`000?l000000ooonfX3o`000004oookJ_l0003o0000o`0000;o
oo]Z1ol000000ooonf[o0000o`000006o`000004oookJ_l0003o0000oookJPGo00000_oonfX6o`00
00?ooo]Z0_l000001?oonf[o0000o`000?l00002oookJP?o000000?ooo]Zo`000?l000000_l00000
0ooonf[o0000o`000005o`0000;ooo]Z1?l00002oookJP03o`000?oonf[ooo]Z00Oo00000_oonfX4
o`000003oookJ_l0003o000000;ooo]Z00?o0000oookJ_l000001?l00002oookJPKo00000ooonfX7
o`0000;ooo]Z1ol000000ooonf[o0000oookJP02o`000003oookJ_l0003ooo]Z007o000000000ol0
003ooo]Zo`000003o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000001_l000000ooo
nf[o0000o`000006o`000003oookJ_l0003o000000Go00000_oonfXEo`000005oookJ_l0003o0000
o`000?oonfX02?l00002oookJPOo000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000006
o`000003oookJ_l0003o000000?o000000Cooo]Zo`000?l0003ooo]Z6_l000000ooonf[o0000o`00
0005o`0000;ooo]Z1ol000000ooonf[o0000o`00000?o`000003oookJ_l0003o000000Ko000000?o
oo]Zo`000?l000001_l000000ooonf[o0000o`000006o`000003oookJ_l0003o000000Ko000000?o
oo]Zo`000?l000001Ol00002oookJPSo000000?ooo]Zo`000?l000005ol00002oookJPOo000000?o
oo]Zo`000?l000001_l000000ooonf[o0000o`000006o`000003oookJ_l0003o000000Ko000000?o
oo]Zo`000?l000001_l000001?oonf[o0000o`000?oonfX>o`000003oookJ_l0003o000000Go0000
0_oonfX7o`0000;ooo]Z1ol000000ooonf[o0000o`00000?o`000003oookJ_l0003o000000Ko0000
00?ooo]Zo`000?l000001_l000000ooonf[o0000o`000006o`000003oookJ_l0003o000000Go0000
0_oonfX8o`000003oookJ_l0003o0000017o000000?ooo]Zo`000?l000001?l000000ooonf[o0000
o`000005o`0000;ooo]Z1ol000000ooonf[o0000o`000006o`000003oookJ_l0003o000000Ko0000
00?ooo]Zo`000?l000001_l000000ooonf[o0000o`000006o`000006oookJ_l0003o0000oookJ_l0
003ooo]Z0ol000000ooonf[o0000o`000006o`000003oookJ_l0003o000000Go00000_oonfX7o`00
0003oookJ_l0003o000000_o000000?ooo]Zo`000?l000002_l00002oookJPOo000000?ooo]Zo`00
0?l000001_l000000ooonf[o0000o`000003o`0000;ooo]Z0Ol000000003o`000?oonf[o000000?o
000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000006o`0000;ooo]Z3_l000000ooonf[o
0000oookJP03o`000003oookJ_l0003o000001;o000000?ooo]Zo`000?l000001ol000001Ooonf[o
0000o`000?l0003ooo]Z00Co000000?ooo]Zo`000?l000004ol000000ooonf[o0000o`000006o`00
0003oookJ_l0003ooo]Z01co000000?ooo]Zo`000?oonfX01ol000000ooonf[o0000o`000007o`00
0003oookJ_l0003o000000;o000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`000002o`00
0003oookJ_l0003o000000Ko000000Cooo]Zo`000?l0003ooo]Z2ol000000ooonf[o0000o`000009
o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`00000=
o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000_l000001Ooonf[o0000o`000?l0
003ooo]Z00Co000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000006o`000005oookJ_l0
003o0000o`000?oonfX02?l000001Ooonf[o0000o`000?l0003ooo]Z01[o000000?ooo]Zo`000?l0
00001_l00002oookJQ3o000000Gooo]Zo`000?l0003o0000oookJP08o`000005oookJ_l0003o0000
o`000?oonfX04Ol000000ooonf[o0000o`000002o`000005oookJ_l0003o0000o`000?oonfX01?l0
00000ooonf[o0000o`000002o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000001_l0
00000ooonf[o0000o`000003o`000003oookJ_l0003ooo]Z00ko000000?ooo]Zo`000?l000004Ol0
00001Ooonf[o0000o`000?l0003ooo]Z00Co000000?ooo]Zo`000?oonfX01ol000000ooonf[o0000
o`000002o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000000ol000001?oonf[o0000
o`000?oonfXKo`000005oookJ_l0003ooo]Zo`000?oonfX02?l000000ooonf[o0000o`000004o`00
0003oookJ_l0003o000000Ko00000OoonfX1o`00000000?o0000oookJ_l000001ol000000ooonf[o
0000o`00000?o`000003oookJ_l0003o0000013o000000?ooo]Zo`000?l000006?l000000ooonf[o
0000o`000004o`000004oookJ_l0003o0000oookJQGo000000?ooo]Zo`000?l000002Ol000000ooo
nf[o0000o`00000Fo`000003oookJ_l0003o000002;o000000?ooo]Zo`000?l00000Eol000000ooo
nf[o0000o`00000Fo`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000003?l000001?oo
nf[o0000o`000?oonfX?o`000003oookJ_l0003o000002;o000000?ooo]Zo`000?l000001_l00000
0ooonf[o0000o`000004o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000002Ol00000
0ooonf[o0000o`00000=o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l00000>ol00000
0ooonf[o0000o`00000=o`000004oookJ_l0003o0000oookJPoo000000?ooo]Zo`000?l000001_l0
00000ooonf[o0000o`00000Ko`00007ooo]Z0Ol000000003o`000?oonf[o000000So000000?ooo]Z
o`000?l000000ol000001?oonf[o0000o`000?oonfX6o`000003oookJ_l0003ooo]Z00oo000000?o
oo]Zo`000?l000001_l000000ooonf[o0000o`000007o`000003oookJ_l0003o000001Ko000000?o
oo]Zo`000?oonfX01_l000001?oonf[o0000o`000?oonfXHo`000003oookJ_l0003o000000Ko0000
00?ooo]Zo`000?l000005_l000001?oonf[o0000oookJ_oonfX6o`000003oookJ_l0003o000000oo
000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000006o`0000;ooo]Z4Ol000000ooonf[o
0000o`000004o`000003oookJ_l0003ooo]Z00Co000000?ooo]Zo`000?oonfX00_l000000ooonf[o
0000o`000003o`000004oookJ_l0003o0000oookJPko000000?ooo]Zo`000?l000001ol000000ooo
nf[o0000o`000006o`0000;ooo]Z3_l000000ooonf[o0000o`000006o`0000;ooo]Z2?l000000ooo
nf[o0000o`00000?o`000003oookJ_l0003o000000Ko00000_oonfX5o`000006oookJ_l0003o0000
oookJ_l0003ooo]Z3?l000000ooonf[o0000o`000007o`000003oookJ_l0003o000000Co000000?o
oo]Zo`000?oonfX06ol000000ooonf[o0000o`000004o`000003oookJ_l0003ooo]Z01So000000?o
oo]Zo`000?l000001ol000000ooonf[o0000o`00000?o`000003oookJ_l0003o000000Co000000?o
oo]Zo`000?oonfX01_l000001?oonf[o0000o`000?oonfXQo`000003oookJ_l0003o000001Ko0000
00?ooo]Zo`000?oonfX02Ol00002oookJP7o000000000ol0003ooo]Zo`00000<o`000003oookJ_l0
003o000000Ko000000?ooo]Zo`000?l00000=Ol000000ooonf[o0000o`000007o`000003oookJ_l0
003o000000;o000000?ooo]Zo`000?l000008Ol000000ooonf[o0000o`00000Po`000003oookJ_l0
003o000000;o000000Gooo]Zo`000?l0003o0000oookJP0Jo`000003oookJ_l0003o000001co0000
00?ooo]Zo`000?l000009Ol000000ooonf[o0000o`000006o`000003oookJ_l0003o000000Wo0000
00?ooo]Zo`000?l000001ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000Ko0000
00Kooo]Zo`000?l0003ooo]Zo`000?oonfXAo`000004oookJ_l0003o0000oookJP?o000000?ooo]Z
o`000?l000000_l000000ooonf[o0000o`00000Ho`000003oookJ_l0003o000000Ko000000?ooo]Z
o`000?l000008Ol000000ooonf[o0000o`000009o`000003oookJ_l0003o000001Co000000?ooo]Z
o`000?l000001_l000000ooonf[o0000o`00000?o`000003oookJ_l0003o000000Ko000000?ooo]Z
o`000?l000008?l000000ooonf[o0000o`00000Qo`000003oookJ_l0003o000000;o000000?ooo]Z
o`000?oonfX00Ol000000003o`000?oonf[o000000?o000000Cooo]Zo`000?l0003ooo]Z1?l00002
oookJPOo00000_oonfX8o`000005oookJ_l0003o0000o`000?oonfX00_l000000ooonf[o0000oook
JP07o`0000;ooo]Z1ol00002oookJPCo000000Cooo]Zo`000?l0003ooo]Z1Ol000001?oonf[o0000
o`000?oonfX3o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000001_l000000ooonf[o
0000o`000006o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?oonfX01?l000001Ooonf[o
0000o`000?l0003ooo]Z00Co000000?ooo]Zo`000?l000000_oonfX2o`000006oookJ_l0003o0000
oookJ_l0003ooo]Z0ol000001?oonf[o0000o`000?oonfX6o`000004oookJ_l0003o0000o`0000;o
oo]Z1ol00002oookJPOo000000?ooo]Zo`000?l000000_l000001Ooonf[o0000o`000?l0003ooo]Z
00So000000Cooo]Zo`000?l0003ooo]Z0_l000001?oonf[o0000oookJ_oonfX2o`000003oookJ_l0
003o000000?o000000?ooo]Zo`000?l000000ol000001?oonf[o0000o`000?oonfX3o`000003oook
J_l0003o000000;o000000?ooo]Zo`000?l000001Ol00002oookJPOo00000_oonfX3o`000005oook
J_l0003o0000o`000?oonfX02?l000001?oonf[o0000o`000?oonfX2o`000004oookJ_l0003o0000
oookJPSo00000_oonfX2o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000001_l00000
0ooonf[o0000o`000005o`0000;ooo]Z1ol00002oookJP_o000000Cooo]Zo`000?oonf[ooo]Z0_l0
00000ooonf[o0000o`000005o`0000;ooo]Z1ol00002oookJPOo000000?ooo]Zo`000?l000000_l0
00001Ooonf[o0000o`000?l0003ooo]Z00Co000000?ooo]Zo`000?l000000_oonfX8o`000004oook
J_l0003o0000oookJP;o000000Cooo]Zo`000?l0003ooo]Z0_l000000ooonf[o0000oookJP03o`00
0005oookJ_l0003o0000o`000?oonfX00ol00002oookJPOo00000_oonfX7o`000003oookJ_l0003o
000000;o000000Gooo]Zo`000?l0003o0000oookJP08o`000004oookJ_l0003o0000oookJPGo0000
0_oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o000000Gooo]Zo`000?l0003o0000oookJP04o`00
0003oookJ_l0003o000000;ooo]Z1?l000000ooonf[o0000oookJP05o`0000;ooo]Z2?l000001Ooo
nf[o0000o`000?l0003ooo]Z00Co000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000005
o`0000;ooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00?o000000?ooo]Zo`000?l000000_l0
00000ooonf[o0000oookJP06o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000001?l0
0001oookJP7o000000000ol0003ooo]Zo`000003o`000003oookJ_l0003o000000Go00000ooonfX3
o`000003oookJ_l0003o000000?ooo]Z1_l00002oookJPOo00000_oonfX7o`0000;ooo]Z1ol00002
oookJP?o000000Gooo]Zo`000?l0003o0000oookJP08o`0000;ooo]Z0ol000000ooonf[o0000o`00
0003oookJPKo00000ooonfX6o`0000;ooo]Z2?l000000ooonf[o0000o`000005o`0000;ooo]Z1ol0
0002oookJPOo00000_oonfX7o`0000;ooo]Z1ol00002oookJPOo00000_oonfX7o`0000;ooo]Z0_l0
00000ooonf[o0000o`000002o`000004oookJ_l0003o0000oookJPGo000000?ooo]Zo`000?l00000
1Ol00003oookJP?o000000?ooo]Zo`000?l000000_oonfX4o`000003oookJ_l0003o000000;ooo]Z
1ol00002oookJPOo00000_oonfX2o`000003oookJ_l0003o000000;o00000_oonfX7o`0000;ooo]Z
1ol00002oookJPKo00000ooonfX3o`000003oookJ_l0003o000000?ooo]Z1ol000000ooonf[o0000
o`000006o`000003oookJ_l0003o000000Go00000_oonfX7o`0000?ooo]Z1_l00002oookJPOo0000
0_oonfX7o`0000;ooo]Z1ol00002oookJPCo000000Cooo]Zo`000?l0003ooo]Z2?l000000ooonf[o
0000o`000005o`0000?ooo]Z0_l000001?oonf[o0000o`000?l00003oookJPKo00000_oonfX8o`00
0003oookJ_l0003o000000Go00000_oonfX7o`0000;ooo]Z1ol00002oookJPOo00000_oonfX7o`00
00;ooo]Z1_l00003oookJPOo000000?ooo]Zo`000?l000000ol000001?oonf[o0000o`000?oonfX8
o`000003oookJ_l0003o000000Go00000ooonfX6o`0000;ooo]Z1ol00002oookJPOo00000_oonfX7
o`0000;ooo]Z1ol00002oookJPOo000000?ooo]Zo`000?l000001_l00002oookJPKo00000ooonfX5
o`00007ooo]Z0Ol000000003o`000?oonf[o000000;o00000ooonfX5o`0000Cooo]Z1_l00003oook
JPKo00000_oonfX4o`000003oookJ_l0003o000000;ooo]Z1_l00004oookJPGo00001?oonfX5o`00
00?ooo]Z1_l00003oookJPKo00000ooonfX2o`000004oookJ_l0003o0000o`0000?ooo]Z1_l00003
oookJPKo00000ooonfX5o`0000Cooo]Z1Ol00004oookJPKo00000ooonfX2o`000004oookJ_l0003o
0000o`0000;ooo]Z0_l000001?oonf[o0000o`000?l00003oookJPCo000000?ooo]Zo`000?oonfX0
0ooonfX2o`000003oookJ_l0003o000000?ooo]Z1_l00003oookJP;o000000Cooo]Zo`000?l0003o
00000ooonfX6o`0000?ooo]Z1_l00003oookJP03o`000?oonf[ooo]Z00?o00000_oonfX7o`0000?o
oo]Z1Ol00004oookJPGo00001?oonfX6o`0000;ooo]Z1ol00002oookJPKo00000ooonfX6o`0000?o
oo]Z1?l000000ooonf[o0000oookJP02oookJPKo00000ooonfX00ol0003ooo]ZoookJP02o`0000Co
oo]Z1_l00003oookJPKo00000_oonfX7o`0000;ooo]Z00?o0000oookJ_l000000ol00003oookJPKo
00001?oonfX5o`0000?ooo]Z1_l00003oookJP03o`000?oonf[o000000?o00000ooonfX6o`0000?o
oo]Z1_l00002oookJP03o`000?oonf[o000000Co00000ooonfX5o`0000Cooo]Z1Ol00004oookJPGo
00000ooonfX2o`000003oookJ_l0003o000000;o00000_oonfX6o`0000?ooo]Z1_l00003oookJPKo
00000ooonfX6o`0000?ooo]Z1_l00003oookJP;o000000Cooo]Zo`000?l0003o00000ooonfX6o`00
00;ooo]Z1?l000000ooonf[o0000o`000002oookJPOo00000_oonfX6o`0000Cooo]Z1Ol00004oook
JP;o000000?ooo]Zo`000?l000000ooonfX6o`0000?ooo]Z1_l00003oookJPGo00000OoonfX1o`00
000000?o0000oookJ_l000000_l00003oookJPGo00001?oonfX5o`0000Cooo]Z1Ol00004oookJPKo
00000ooonfX5o`0000Cooo]Z1Ol00004oookJPGo00000ooonfX6o`0000?ooo]Z1Ol00005oookJPCo
00001OoonfX5o`0000?ooo]Z0ol000000ooonf[o0000o`000003oookJPGo00001?oonfX5o`0000Co
oo]Z1Ol00004oookJPGo00001?oonfX5o`0000Cooo]Z1Ol00004oookJPGo00001?oonfX5o`0000?o
oo]Z1_l00003oookJPGo00001OoonfX4o`0000Gooo]Z1Ol00003oookJPKo00000ooonfX5o`0000Co
oo]Z1Ol00004oookJPGo00000ooonfX6o`0000Cooo]Z1?l00005oookJPGo00001?oonfX5o`0000?o
oo]Z1_l00003oookJPGo00001?oonfX5o`0000Cooo]Z1Ol00004oookJPGo00001?oonfX5o`0000Co
oo]Z1Ol00004oookJPGo00000ooonfX6o`0000?ooo]Z1Ol00004oookJPGo00001OoonfX5o`0000?o
oo]Z1_l00003oookJPGo00001?oonfX5o`0000Cooo]Z0_l000000ooonf[o0000o`000003oookJPKo
00000ooonfX5o`0000Gooo]Z1Ol00004oookJPGo00000ooonfX6o`0000?ooo]Z1Ol00004oookJPGo
00001?oonfX5o`0000Gooo]Z1?l00004oookJPGo00001?oonfX5o`0000Cooo]Z1Ol00004oookJPGo
00000ooonfX2o`000004oookJ_l0003o0000o`0000?ooo]Z1Ol00005oookJPCo00000OoonfX1o`00
000000Co0000oookJ_l0003o00001OoonfX4o`0000Gooo]Z1?l00005oookJP04o`000?oonf[o0000
o`0000Cooo]Z1Ol00004oookJPCo00001_oonfX3o`0000Kooo]Z0ol00005oookJPGo00001?oonfX4
o`0000Gooo]Z1?l00005oookJPCo00001OoonfX4o`0000Gooo]Z0ol00006oookJP?o00001_oonfX4
o`0000Gooo]Z1?l00004oookJP04o`000?oonf[o0000o`0000Gooo]Z1?l00005oookJPCo00001_oo
nfX3o`0000Gooo]Z1?l00005oookJPCo00001OoonfX4o`0000Gooo]Z00Co0000oookJ_l0003o0000
1?oonfX5o`0000Gooo]Z0ol00006oookJP?o00001_oonfX4o`0000Cooo]Z1Ol00004oookJPCo0000
1OoonfX4o`0000Gooo]Z1?l00005oookJPCo00001OoonfX3o`0000Kooo]Z1?l00005oookJPCo0000
1?oonfX5o`0000Cooo]Z1?l00005oookJPCo00001_oonfX3o`0000Gooo]Z1Ol00004oookJPCo0000
1OoonfX4o`0000Gooo]Z1?l00004oookJPGo00001?oonfX4o`0000Kooo]Z0ol00006oookJP?o0000
1OoonfX5o`0000Cooo]Z1?l00005oookJPCo00001OoonfX4o`0000Kooo]Z0ol00005oookJP?o0000
1_oonfX4o`0000Gooo]Z00Co0000oookJ_l0003o00001OoonfX4o`0000Cooo]Z1?l00005oookJPCo
00001_oonfX3o`0000Kooo]Z0ol00005oookJPCo00001OoonfX4o`0000Gooo]Z1?l00001oookJP7o
000000001?l0003ooo]Zo`000?l00005oookJP?o00001_oonfX3o`0000Oooo]Z0_l00007oookJP;o
00001_oonfX2o`0000Oooo]Z0ol00006oookJP?o00001_oonfX3o`0000Gooo]Z0ol00007oookJP;o
00001ooonfX2o`0000Oooo]Z0ol00005oookJP?o00001_oonfX3o`0000Kooo]Z0ol00007oookJP;o
00001_oonfX2o`0000Oooo]Z0_l00007oookJP?o00001_oonfX3o`0000Gooo]Z0ol00007oookJP;o
00001ooonfX2o`0000Oooo]Z0_l00006oookJP?o00001_oonfX3o`0000Kooo]Z0ol00006oookJP?o
00001_oonfX3o`0000Kooo]Z0_l00007oookJP;o00001ooonfX3o`0000Gooo]Z1?l00005oookJP?o
00001ooonfX2o`0000Oooo]Z0_l00006oookJP?o00001_oonfX2o`0000Oooo]Z0ol00006oookJP?o
00001OoonfX4o`0000Kooo]Z0_l00007oookJP;o00001ooonfX2o`0000Kooo]Z1?l00005oookJP?o
00001_oonfX3o`0000Kooo]Z0ol00007oookJP;o00001_oonfX2o`0000Oooo]Z0_l00007oookJP?o
00001_oonfX3o`0000Gooo]Z0ol00007oookJP;o00001ooonfX2o`0000Oooo]Z0_l00006oookJP;o
00001ooonfX3o`0000Kooo]Z0ol00006oookJP?o00001_oonfX2o`0000Oooo]Z0_l00007oookJP;o
00000_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000?oo0000ool0
0012o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z
02;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000oookJ_oonfX00Ol000000003o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP05oookJP;o00001ooonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00Ol000000003o`000?oonf[ooo]Z00Oooo]Z
0_l00007oookJP;o00006OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Kooo]Z
0_l00007oookJP;o00006OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX01_oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0000Sooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Gooo]Z
0_l00007oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z01?ooo]Z0Ol000000003o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX0:_oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Sooo]Z00?o
0000oookJ_oonfX08?oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Sooo]Z00?o
0000oookJ_oonfX08?oonfX2o`0003Cooo]Z00?o0000oookJ_oonfX01OoonfX2o`0002;ooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP05oookJP;o00001ooonfX00ol0003ooo]Zoook
JP0:oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oook
J_l000004?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000Ioook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00Gooo]Z0_l0000IoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP05oookJP;o00004OoonfX00ol0003ooo]ZoookJP0>oook
JP;o00001ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0000@oook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX05_oonfX2o`00017ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX00Ol000000003o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0GoookJP;o00002?oonfX00ol0003o
oo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0IoookJP;o00001_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z027o
oo]Z0_l00008oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX05ooonfX01?l0003o
oo]ZoookJ_oonfX1o`00000000?o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP05oookJP;o
00001_oonfX2o`0001_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0FoookJP;o
00001ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP0PoookJP;o00006OoonfX00ol0003ooo]ZoookJP0=oookJP03
o`000?oonf[ooo]Z013ooo]Z0_l0000IoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX03ooonfX2o`0000Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP06oookJP;o
00001ooonfX2o`0000_ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000
00000ol0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_l000001_oo
nfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP06oookJP;o00002?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z00Kooo]Z0_l00009oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00008oookJP03o`000?oo
nf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP05oookJP;o00001ooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Gooo]Z00Co0000oookJ_oonf[ooo]Z
0Ol000000003o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`00
000?oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zo`00
000coookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP0GoookJP03o`000?oonf[ooo]Z00oooo]Z0_l00009oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0>oookJP?o00002?oonfX00ol0003ooo]Zoook
JP05oookJP;o00002?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX03_oonfX2o`0000Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX07?oonfX1o`00000000?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_l000008_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000A
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zo`000006
oookJP;o00004?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00006
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0P
oookJP03o`000?oonf[o000001Wooo]Z00?o0000oookJ_oonfX03OoonfX2o`0000Wooo]Z00?o0000
oookJ_oonfX01?oonfX2o`0001[ooo]Z00?o0000oookJ_oonfX03_oonfX2o`0000;ooo]Z0Ol00000
0003o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP06oook
JP;o0000;?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l0000Hoook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_l000004?oonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0?oook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`00000@oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z02kooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000000ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0
6?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
1OoonfX2o`0000Oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[o000000Kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[o000000Kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP0boookJP;o0000
2?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z017ooo]Z0Ol00001oookJP7o0000
00000ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01oooo]Z0_l00008oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo
nf[ooo]Z00Gooo]Z0_l00009oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000002?oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0HoookJP;o00002?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_l000004?oonfX00ol0003ooo]ZoookJP0>oookJP04o`000?oo
nf[o0000o`0000Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0IoookJP7o0000
0OoonfX1o`00000000?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z0_l00006oookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01ooonfX2o`0000Kooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0UoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1
o`00000000?o0000oookJ_l000006OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o0000
03Cooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0>oookJP;o00001ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00oooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l000001_oonfX00ol0
003ooo]ZoookJP0QoookJP03o`000?oonf[o000000Kooo]Z0_l00002oookJP7o000000000ol0003o
oo]ZoookJP06oookJP03o`000?oonf[o000000oooo]Z00?o0000oookJ_l000001_oonfX00ol0003o
oo]Zo`000006oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_l000004OoonfX2o`0000So
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0GoookJP;o00004OoonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP0=oookJP;o00003ooonfX2o`0000Oooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00oooo]Z0_l0000ToookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0:oookJP7o000000000ol0003ooo]Z
o`00000@oookJP;o00002OoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o000001Wooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP;o00006_oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0<oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02?oonfX2o`0001[ooo]Z
00?o0000oookJ_oonfX01?oonfX2o`0000Kooo]Z0_l0000ToookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX01_oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP06oookJP7o00000OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol0
00000003o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`00000>
oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Sooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_l000001_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o000000Oooo]Z00?o0000
oookJ_oonfX07_oonfX2o`0000Wooo]Z0_l00007oookJP;o00002_oonfX1o`00000000?o0000oook
J_oonfX01_oonfX2o`0001;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`00000Qoook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[o000001Oooo]Z00?o0000oookJ_oonfX01_oonfX2o`000003oookJ_l0003ooo]Z
00Cooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o0000
00kooo]Z00?o0000oookJ_oonfX01_oonfX2o`00013ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[o000001Sooo]Z00Co0000oookJ_oonf[o00001_oonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_l000006?oonfX0
0ol0003ooo]ZoookJP0@oookJP;o00003_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z013ooo]Z00Co0000oookJ_l0003ooo]Z0Ol000000003o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_l0000aoookJP04o`000?oonf[ooo]Zo`0000Sooo]Z
00?o0000oookJ_oonfX0<?oonfX01?l0003ooo]ZoookJ_l0000HoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z027o
oo]Z0_l00009oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0EoookJP03o`000?oonf[ooo]Z017ooo]Z0_l0000@oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX02OoonfX1o`00000000?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00Gooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP06oookJP;o0000;OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX03OoonfX3o`00013ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0PoookJP;o00004?oonfX00ol0003ooo]ZoookJP05oookJP;o00001_oonfX01?l0003o
oo]Zo`000?l0000IoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00kooo]Z00Co0000oookJ_oonf[o00004ooonfX1
o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_l00000:_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02So
oo]Z0_l00006oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l000000ooonf[o0000oookJP07oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[o000000kooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
00Gooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01Oooo]Z00Co0000oookJ_oonf[o00001OoonfX0
0ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP01o`00000000?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03?oonfX2o`0001?ooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP;o00002OoonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00Gooo]Z0_l0000>oookJP;o00001ooonfX01?l0003ooo]ZoookJ_l00006
oookJP?o00006?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX01?oonfX2o`0002Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03
oookJP;o00002?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01Sooo]Z0_l00007
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00_ooo]Z0Ol000000003o`000?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000Coook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP02oook
JP;o000000?ooo]Zo`000?oonfX0:?oonfX00ol0003ooo]ZoookJP0?oookJP04o`000?oonf[ooo]Z
o`0000oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z00cooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX04?oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX01OoonfX0
1?l0003ooo]ZoookJ_l0000:oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1
o`00000000?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l0000@oookJP03o`000?oonf[o
oo]Z00Gooo]Z0_l0000BoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX06ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000Gooo]Z00Co0000oookJ_oonf[o00001ooo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Oooo]Z00Co0000oookJ_l0003o0000
1?oonfX00ol0003ooo]Zo`000009oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00008oookJP;o0000
6?oonfX01?l0003ooo]ZoookJ_l0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0JoookJP7o000000001?l0003ooo]Zo`000?l00005oookJP03
o`000?oonf[o000001;ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP1;oookJP03
o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00006ooonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0;oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02?oonfX2o`0001Wooo]Z0_l00005oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Wooo]Z0_l0000>oook
JP05o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]Zo`00000KoookJP7o00000OoonfX1
o`00000000?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
01Gooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00ooonfX01?l0
003ooo]ZoookJ_l0000ZoookJP03o`000?oonf[o000000kooo]Z0_l00009oookJP03o`000?oonf[o
oo]Z00?ooo]Z0_l0000JoookJP03o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP0;oookJP;o00006_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0;oookJP04o`000?oonf[o
oo]Zo`0000Gooo]Z00Co0000oookJ_oonf[o00002_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nf[ooookJSkooo]Z0Ol000000003o`000?oonf[o000001;ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]Zo`00000IoookJP;o00001_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[o
oo]Zo`0000Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o0000COoonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[o000001_ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_l00000
1OoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol000000ooonf[o0000
oookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_l000008OoonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol000000003o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0>oookJP;o00005?oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000003ooonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000001OoonfX01?l0003ooo]Zo`00
0?l00005oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z0_l0000JoookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00[o
oo]Z0Ol000000004o`000?oonf[o0000o`0000Oooo]Z00?o0000oookJ_oonfX03?oonfX2o`0000Wo
oo]Z0_l0000YoookJP03o`000?oonf[ooo]Z00kooo]Z0_l000000ooonf[o0000oookJP0OoookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z
00Kooo]Z0_l0000BoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l000003ooonfX00ol0
003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Wooo]Z0_l0000@oookJP03o`000?oonf[ooo]Z
00cooo]Z00Co0000oookJ_oonf[o00001?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o
0000oookJ_oonfX01ooonfX2o`0000kooo]Z00?o0000oookJ_l000005ooonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z00gooo]Z0_l0000BoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0
0001oookJP7o000000001?l0003ooo]ZoookJ_l0000>oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP04oookJP;o00003_oonfX00ol0003ooo]Zoook
JP0?oookJP;o00006ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX04?oonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP;o00002OoonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP0;oookJP04o`000?oonf[ooo]Zo`0002?ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP04oookJP;o00005OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z013ooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o000000Kooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX01_oonfX2o`0000[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o000000Kooo]Z00Co
0000oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP0AoookJP;o00002?oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]Z
oookJ_l00007oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04?oonfX2o`000003
oookJ_l0003ooo]Z01kooo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0>oookJP;o00002?oonfX00ol0003ooo]ZoookJP05oookJP05o`00
0?oonf[o0000oookJ_l000007ooonfX01?l0003ooo]ZoookJ_l00008oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX00ooonfX2o`000003oookJ_l0003ooo]Z00gooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000?oook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z00kooo]Z00Co0000oookJ_oonf[ooo]Z0Ol000000003o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_l000003ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000008oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]Zo`00000:oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01Cooo]Z00Go0000
oookJ_oonf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03_oo
nfX01Ol0003ooo]ZoookJ_oonf[o0000017ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX04?oonfX2o`000003oook
J_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_l00004oookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX03OoonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX03OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o0000013ooo]Z00?o0000oookJ_oo
nfX02OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oo
nf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX04?oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000001Ooo
nfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]Zo`0000Sooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_l00000
1?oonfX00ol0003ooo]ZoookJP02o`0000Sooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0000Cooo]Z
00?o0000oookJ_l000006?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000005oookJP04o`000?oonf[ooo]Zo`0000Oo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02;o
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;o
00008_oonfX00ol0003ooo]ZoookJP08oookJP7o000000000ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00Gooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00;o00001?oonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003ooo]Z
o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00000?oookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`0000kooo]Z00?o
0000oookJ_oonfX01OoonfX2o`0000?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0GoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[o000000_ooo]Z0Ol000000003o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00007oookJP03o`000?oonf[o000001Wooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o0000013ooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0OoookJP;o00000_oonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]Zoook
JP07oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP0HoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP06oookJP;o00001ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX07?oonfX1o`00000000?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z00oooo]Z00Co0000oookJ_oonf[o00001?oonfX01?l0003ooo]Z
oookJ_l0000JoookJP;o00000ooonfX2o`0000_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z00Co0000oookJ_l0003o00004?oonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX08?oonfX01?l0
003ooo]ZoookJ_l00005oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01ooonfX2
o`00017ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0@oookJP04o`000?oonf[o
oo]Zo`0001Kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0BoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000Co0000oookJ_oonf[o00001OoonfX0
1?l0003ooo]ZoookJ_l00007oookJP;o00002?oonfX00ol0003ooo]ZoookJP04oookJP?o00001?oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP0HoookJP;o00001?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_l000008_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX03OoonfX01Ol0003ooo]ZoookJ_oonf[o000003Wooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Kooo]Z
00Co0000oookJ_oonf[o00001ooonfX00ol0003ooo]ZoookJP01o`00000000Co0000oookJ_oonf[o
00003_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l00004oookJP05
o`000?oonf[ooo]ZoookJ_l000005ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX06OoonfX3o`0000Wooo]Z00?o0000oookJ_oonfX04ooonfX01?l0
003ooo]ZoookJ_l00007oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000:oookJP;o00001?oonfX0
1Ol0003ooo]ZoookJ_oonf[o000000cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP0[oookJP04o`000?oonf[o0000o`0000Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP04oookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00oooo]Z0Ol00001oookJP7o000000000ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[o000000gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_l00009oookJP03
o`000?oonf[ooo]Z00gooo]Z0_l00004oookJP04o`000?oonf[ooo]Zo`0003;ooo]Z00?o0000oook
J_l000001OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z01Kooo]Z00Co0000oook
J_oonf[o00003ooonfX00ol0003ooo]Zo`00000@oookJP03o`000?oonf[o000000Sooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX02OoonfX01Ol0003ooo]ZoookJ_oonf[o000000cooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]Zo`00000GoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o0000
1OoonfX2o`00013ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP03o`000?oonf[o000000go
oo]Z00?o0000oookJ_oonfX00ooonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z01cooo]Z00Go0000oookJ_oonf[ooo]Zo`00000:oookJP03o`00
0?oonf[o000000Gooo]Z0ol00004oookJP03o`000?oonf[ooo]Z01Wooo]Z00Go0000oookJ_oonf[o
oo]Zo`00000>oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX07_oonfX01?l0003o
oo]ZoookJ_l00007oookJP;o00002?oonfX00ol0003ooo]ZoookJP04oookJP04o`000?oonf[ooo]Z
o`0000cooo]Z0_l0000;oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP05oookJP;o00003OoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z00;ooo]Z0Ol000000003o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0XoookJP;o00000ooonfX00ol0003ooo]ZoookJP0;oookJP;o00006?oonfX00ol0
003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03_oonfX2o`00
00;ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX02ooonfX2o`0000;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP06oookJP;o00004ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
01gooo]Z0_l0000DoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00004?oonfX2
o`0000Kooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP0=oookJP04o`000?oonf[o
oo]Zo`0000Kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP;o00000_oo
nfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP07oookJP7o000000000ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000kooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00_ooo]Z
0_l00007oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX2o`00013ooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zo`00000DoookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02?ooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00Oooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP0K
oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00006OoonfX00ol0003ooo]Zoook
JP0RoookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00004oookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z00cooo]Z0_l0000IoookJP;o00001ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000<oookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000FoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000Sooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol00000
0003o`000?oonf[o000000Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00000?oookJP03o`000?oonf[o
oo]Z00Oooo]Z0_l00006oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z017ooo]Z0ol00004oookJP05o`000?oonf[o
oo]ZoookJ_l000006OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o0000013ooo]Z0_l0
0004oookJP04o`000?oonf[ooo]Zo`0000kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000<oookJP03
o`000?oonf[ooo]Z01?ooo]Z0_l00004oookJP03o`000?oonf[o000000Wooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z013ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000MoookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000oooo]Z00Co0000oookJ_oonf[o00001ooonfX1o`00007ooo]Z0Ol000000003o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[o000000oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP;o00001_oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l000000_oonfX01ol0003ooo]Z
oookJ_oonf[o0000oookJ_l000002_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00009oookJP05o`000?oonf[o
oo]ZoookJ_l000002_oonfX00ol0003ooo]ZoookJP0>oookJP05o`000?oonf[ooo]ZoookJ_l00000
6OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00[ooo]Z0Ol000000003o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]ZoookJ_l0000YoookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z01Oooo]Z00Co0000oookJ_oonf[o00002?oonfX2o`0002;ooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX00_l0000Ooook
JP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000001Gooo]Z00Co0000oook
J_oonf[o00001OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP05oookJP;o00001OoonfX00ol0003ooo]ZoookJP0N
oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_l0
00001OoonfX01?l0003ooo]ZoookJ_l0000?oookJP05o`000?oonf[ooo]ZoookJ_l000007OoonfX0
1?l0003ooo]ZoookJ_l0000IoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX05?oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]Z
oookJ_l00004oookJP05o`000?oonf[o0000oookJ_l000003?oonfX2o`000003oookJ_l0003ooo]Z
00Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00Kooo]Z0_l0000SoookJP03o`000?oonf[ooo]Z00gooo]Z0_l00008oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o0000
01Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000HoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX02ooonfX1o`00000000?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0;oook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP02oook
JP;o00001OoonfX00ol0003ooo]ZoookJP04oookJP;o00000_oonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z00Wooo]Z00Go0000oookJ_oonf[ooo]Zo`00000:oookJP;o00004_oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP0]oookJP;o00001?oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX02ooonfX0
1?l0003ooo]ZoookJ_l00005oookJP;o00001_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[o000001Sooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP05o`000?oo
nf[ooo]ZoookJ_l00000G?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00?o0000oookJ_l0
00002ooonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]ZoookJP7o000000000ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000000_oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000002?oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02ooonfX01?l0003o
oo]ZoookJ_l0000EoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_l000005_oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0
0007oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX07_oonfX01Ol0003ooo]Zoook
J_oonf[o000002Wooo]Z0_l00005oookJP;o00002ooonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX02?oonfX01Ol0003ooo]ZoookJ_oonf[o000000;o
oo]Z00?o0000oookJ_l000004?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]ZoookJ_oonfX1o`00000000?o0000oookJ_oo
nfX0oooonf[ooookJSkooo]Z0Ol000000004o`000?oonf[ooo]Zo`0000gooo]Z00Ko0000oookJ_oo
nf[o0000oookJ_l00007oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01OoonfX2
o`0000Oooo]Z0_l00005oookJP03o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_l000008OoonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP04oookJP;o00002?oonfX00ol0003ooo]ZoookJP0HoookJP;o00005OoonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX02?oonfX0
1?l0003ooo]ZoookJ_l0000:oookJP03o`000?oonf[ooo]Z00Wooo]Z00Go0000oookJ_oonf[ooo]Z
o`00000CoookJP03o`000?oonf[ooo]Z00Cooo]Z0_l0000@oookJP;o00001ooonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[o0000017ooo]Z00?o0000oookJ_oonfX04?oonfX1o`00000000Co
0000oookJ_oonf[o00002?oonfX2o`0002;ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_l000007_oonfX00ol0003ooo]Z
oookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]ZoookJP0EoookJP;o
00006ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[o00001?oonfX0
0ol0003ooo]ZoookJP0;oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_l000005_oo
nfX00ol0003ooo]ZoookJP05oookJP05o`000?oonf[o0000oookJ_l000001OoonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP0FoookJP04o`000?oonf[ooo]Zo`0001Oooo]Z00Go0000oookJ_l0003ooo]Zo`000004oook
JP05o`000?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP03oookJP7o000000000ol0
003ooo]ZoookJP06oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Z
o`0000Cooo]Z00?o0000oookJ_oonfX01_oonfX01Ol0003ooo]ZoookJ_oonf[o000000gooo]Z00?o
0000oookJ_oonfX03ooonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP06oookJP05o`000?oonf[ooo]ZoookJ_l000009_oonfX00ol0003o
oo]ZoookJP06oookJP?o00002ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o000000Oo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0>oookJP04o`000?oonf[ooo]Zo`00
013ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00Gooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00004oookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP02oookJP;o00000_oonfX01Ol0
003ooo]ZoookJ_oonf[o000000_ooo]Z00?o0000oookJ_oonfX02OoonfX1o`00000000?o0000oook
J_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oo
nfX03_oonfX01Ol0003ooo]Zo`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX02ooonfX01?l0
003ooo]ZoookJ_l0000:oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00Co0000oookJ_oonf[o0000
5_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]Zo`00000=oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3?oonfX00ol0003ooo]ZoookJP02oookJP7o000000000ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0@oookJP04o`000?oo
nf[ooo]Zo`0000?ooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00002oookJP03o`00
0?oonf[ooo]Z00;ooo]Z0_l0000EoookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000:oookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[o000002cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zo`00000;oookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP02oookJP05o`00
0?oonf[ooo]ZoookJ_l000007?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[ooo]Zoook
J_l000001OoonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00[ooo]Z0_l0000Ioook
JP03o`000?oonf[ooo]Z00;o00002_oonfX1o`00000000?o0000oookJ_oonfX01ooonfX01?l0003o
oo]ZoookJ_l00007oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX00_l00007oookJP04o`000?oonf[o
oo]ZoookJP;o0000;?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_l000004_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00;ooo]Z00Go
0000oookJ_oonf[ooo]Zo`00000:oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
4OoonfX2o`0002Kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP03o`0000?ooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02;ooo]Z
0_l0000/oookJP03o`000?oonf[ooo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03
o`000?oonf[o000001Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP05oookJP05
o`000?oonf[ooo]ZoookJ_l000000ooonfX2o`0000Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z0Ol000000003o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX08?oonfX01?l0003ooo]ZoookJ_oonfX2o`0000Cooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oook
J_oonf[ooo]Zo`00000=oookJP03o`000?oonf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00
000>oookJP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zo`00
0007oookJP03o`000?oonf[ooo]Z00[ooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01ooonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l00000
0ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
3?oonfX01?l0003ooo]ZoookJ_l0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP05oookJP7o00000OoonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000005o`000?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z02Kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000DoookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0:oookJP04
o`000?oonf[ooo]Zo`0002Sooo]Z00?o0000oookJ_oonfX02_oonfX2o`0000Oooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX01_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Kooo]Z00?o0000oookJ_l00000?Ooo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP05oookJP;o00000ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP0;oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
o`000003oookJP03o`000?oonf[ooo]Z00cooo]Z0Ol000000003o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_l000006_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o000000oooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0HoookJP04o`000?oonf[ooo]ZoookJP;o0000
2?oonfX00ol0003ooo]ZoookJP0;oookJP;o00006?oonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z00Kooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP0EoookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0_l0000<oookJP03
o`000?oonf[ooo]Z00gooo]Z00Co0000oookJ_oonf[o00003_oonfX2o`0001Sooo]Z00?o0000oook
J_oonfX0E?oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z007o000000001Ol0003ooo]ZoookJ_oonf[o000001Cooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX09_oonfX01Ol0003ooo]Zo`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0;oookJP;o00001OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z0_l0
0002oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00003OoonfX00ol0003ooo]Z
oookJP0EoookJP03o`000?oonf[ooo]Z00kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000AoookJP05
o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Z
o`0000Cooo]Z00?o0000oookJ_oonfX00_l00006oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX04?oonfX01?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00[ooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z02Oooo]Z
00Co0000oookJ_oonf[o00001_oonfX2o`0001Gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX00ooonfX1o`000000
00?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_l000008_oonfX00ol0003ooo]Zo`00000:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX01ooonfX01Ol0003ooo]ZoookJ_oonf[o0000017ooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00003oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX2o`000003oookJ_l0003ooo]Z02Oooo]Z
00Ko0000oookJ_oonf[o0000oookJ_l0000@oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l00008oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00[ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z01_ooo]Z00?o0000oookJ_oonfX00ooonfX1o`00000000Go0000oookJ_oonf[ooo]Zo`000007
oookJP;o00004?oonfX01Ol0003ooo]ZoookJ_oonf[o000000[ooo]Z00?o0000oookJ_oonfX01ooo
nfX01?l0003ooo]ZoookJ_l0000?oookJP;o00000ooonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]ZoookJP0PoookJP;o
00001OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX02_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000Sooo]Z00Co0000oookJ_oonf[o00001?oonfX0
0ol0003ooo]ZoookJP0:oookJP06o`000?oonf[ooo]Zo`000?oonf[o00005OoonfX01Ol0003ooo]Z
oookJ_oonf[o000000Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000MoookJP03o`000?oonf[ooo]Z
00;o00004_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z0_l0000MoookJP;o00005ooonfX2
o`0000Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX02OoonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z0Ol000000003o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zo`000009oookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP08oookJP;o000000?o
oo]Zo`000?oonfX01OoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0:oookJP05o`000?oonf[ooo]ZoookJ_l00000
2OoonfX00ol0003ooo]ZoookJP0HoookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Oooo]Z00Co0000oookJ_l0003o00000ooonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00007oookJP03o`000?oonf[ooo]Z
00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000:oookJP03o`000?oonf[ooo]Z00Sooo]Z00Go0000
oookJ_oonf[ooo]Zo`00000OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o000000cooo]Z00?o0000oookJ_oonfX03?oo
nfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_l000005?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00Gooo]Z00Co0000oookJ_oonf[o00007OoonfX00ol0003ooo]ZoookJP0=oookJP;o00003_oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_oonfX0
1Ol0003ooo]ZoookJ_oonf[o000001oooo]Z00?o0000oookJ_l000001ooonfX2o`0000;ooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]Zo`00000FoookJP03o`000?oonf[ooo]Z00_ooo]Z00Co
0000oookJ_oonf[o00002?oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000?ooo]Z
00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX05ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[o000000;ooo]Z0Ol000000003o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zo`000008oookJP03o`000?oonf[o000001[o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_l000006OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003o
oo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`00013ooo]Z0_l0000;oookJP;o00005_oonfX00ol0
003ooo]ZoookJP0BoookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00_oonfX2
o`0000Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0>oookJP04o`000?oonf[o
oo]ZoookJP;o00003OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0CoookJP;o00003ooonfX01?l0003ooo]Zoook
J_l0000>oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Z
oookJP0:oookJP;o00004?oonfX00ol0003ooo]Zo`00000;oookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z
0Ol000000005o`000?oonf[o0000oookJ_l000005ooonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000AoookJP03o`000?oonf[o000000;o
oo]Z00Ko0000oookJ_oonf[o0000oookJ_l0000<oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP05o`000?oonf[o0000oookJ_l000005Ooo
nfX01Ol0003ooo]ZoookJ_oonf[o000000[ooo]Z00?o0000oookJ_oonfX02_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000Kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000Oooo]Z00?o0000oookJ_oo
nfX00_l0000?oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`00
00Wooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP04oookJP;o00001ooonfX01?l0
003ooo]ZoookJ_l00006oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o0000:Ooo
nfX1o`00000000?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z00Wooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0HoookJP07o`000?oo
nf[ooo]ZoookJ_l0003ooo]Zo`00000BoookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_oo
nfX03?oonfX00ol0003ooo]ZoookJP0=oookJP04o`000?oonf[ooo]Zo`0000kooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX03?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX02OoonfX01?l0003ooo]Zo`000?l00003oookJP03o`000?oonf[ooo]Z00Oooo]Z00Co0000
oookJ_oonf[o00002ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`00000YoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX05OoonfX01Ol0003ooo]ZoookJ_oonf[o000002Sooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]Zo`00000MoookJP03o`000?oonf[ooo]Z00;ooo]Z00Go0000oookJ_l0003o
oo]Zo`00000DoookJP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX01?oonfX1o`000000
00?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000004o`000?oonf[ooo]Zo`0001;ooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00006oookJP03o`000?oonf[ooo]Z00Go
oo]Z0_l0000=oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0>oookJP;o00004?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX03OoonfX2o`0001gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02ooonfX2o`0000?o
oo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP0:oookJP;o00005OoonfX00ol0003ooo]Zo`00000?oook
JP03o`000?oonf[ooo]Z013ooo]Z00Co0000oookJ_l0003o00003OoonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP7o00000000
0ol0003ooo]Zo`000005oookJP04o`000?oonf[ooo]Zo`0000[ooo]Z00?o0000oookJ_oonfX02Ooo
nfX2o`0000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP05o`000?oonf[ooo]ZoookJ_l0
00001ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX03?oonfX00ol0003ooo]ZoookJP08oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0hoookJP05o`000?oonf[ooo]ZoookJ_l000004OoonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00_ooo]Z00Co0000oookJ_oonf[o00003OoonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03_oonfX01Ol0003ooo]Zoook
J_oonf[o0000017ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0:oookJP04o`00
0?oonf[ooo]Zo`0000[ooo]Z00?o0000oookJ_l000001?oonfX01?l0003ooo]ZoookJ_l0000=oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`00000?oook
JP04o`000?oonf[ooo]Zo`0001Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02ooonfX01Ol0003ooo]ZoookJ_oo
nf[o0000017ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[o000000cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0;oookJP7o00000000
1Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0SoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP0;oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]Zoook
J_oonf[o000000gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01ooonfX01ol0003ooo]ZoookJ_oonf[o0000oook
J_l000003?oonfX00ol0003ooo]ZoookJP0^oookJP;o00000ooonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oook
JP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l000002?oonfX01?l0003ooo]ZoookJ_l00005
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_l000001OoonfX01ol0003ooo]ZoookJ_oo
nf[o0000oookJ_l000001ooonfX01Ol0003ooo]ZoookJ_oonf[o000000_ooo]Z00Co0000oookJ_oo
nf[o00002?oonfX00ol0003ooo]ZoookJP04oookJP;o00001?oonfX01Ol0003ooo]ZoookJ_oonf[o
000000Oooo]Z00?o0000oookJ_oonfX02?oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0Ol000000003o`000?oonf[ooo]Z00[ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0coook
JP04o`000?oonf[ooo]Zo`0000?ooo]Z00Co0000oookJ_l0003o00001OoonfX00ol0003ooo]Zoook
JP0@oookJP04o`000?oonf[ooo]Zo`0001Sooo]Z00?o0000oookJ_l000001OoonfX2o`0000?ooo]Z
00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX01_oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03_oonfX01Ol0003o
oo]ZoookJ_oonf[o000000kooo]Z00?o0000oookJ_oonfX00ol0000RoookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX06ooonfX2o`00
00?ooo]Z00?o0000oookJ_oonfX02_oonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`00000:oookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_l000002ooonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_l000004?oonfX00ol0003ooo]ZoookJP02oookJP7o00000000
0ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00kooo]Z0_l0000MoookJP03o`000?oonf[o
oo]Z00Wooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX01_oonfX0
1Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_l0003o00001_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000gooo]Z00?o0000oookJ_l000002_oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0=oookJP;o
00001ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03?oonfX01?l0
003ooo]ZoookJ_l00009oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02?oonfX0
1?l0003ooo]ZoookJ_oonfX1o`00000000?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP;o00002Ooo
nfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX00ol0003ooo]Z
oookJP06oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000007oookJP04o`000?oonf[ooo]Z
o`0001Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`00000>oookJP05o`000?oonf[o
oo]ZoookJ_l000004OoonfX00ol0003ooo]ZoookJP0?oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01Kooo]Z
00So0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`00037ooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0002oookJPCo00001ooonfX2o`0000Cooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`00
0003oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Zo`00
000loookJP03o`000?oonf[ooo]Z00?ooo]Z0Ol000000005o`000?oonf[ooo]ZoookJ_l000002?oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000oookJ_oonf[ooo]Z
o`000005oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]Zo`00000=oookJP;o00005?oonfX2o`0001?ooo]Z0_l000000ooonf[o0000oookJP0LoookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0;oookJP05
o`000?oonf[ooo]ZoookJ_l000004OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o0000
01kooo]Z00Co0000oookJ_oonf[o00002_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z00;o00000_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX03?oonfX2o`0001Wooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00Kooo]Z00Go0000
oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX02ooo
nfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o0000oookJ_oonfX04_oonfX1o`00000000?o
0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000000ooo
nfX01Ol0003ooo]ZoookJ_oonf[o000002Gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP09oookJP?o00000_oonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oonf[ooo]Z01go
oo]Z00?o0000oookJ_oonfX01_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z0_l00002oook
JP03o`000?oonf[ooo]Z00;ooo]Z0_l00002oookJP;o000000?ooo]Zo`000?oonfX01?oonfX01Ol0
003ooo]ZoookJ_oonf[o000000Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z017ooo]Z00Co0000oookJ_oonf[o00001ooonfX2o`0000?ooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP04oookJP;o00001_oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z00Wooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]Z
oookJP0MoookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]Zo`000002oookJP03
o`000?oonf[ooo]Z01Kooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Cooo]Z0Ol000000003o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0:oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0/oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`00000PoookJP03o`00
0?oonf[o000000cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[o000001Kooo]Z00?o0000oookJ_l000005OoonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0:oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0:oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00;o
oo]Z00Go0000oookJ_l0003ooo]Zo`00000BoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0AoookJP7o000000000ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP;o
00000ooonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP;o00000_oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00001?oonfX2o`0000;ooo]Z0_l0000F
oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l0000>oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000
oookJ_oonf[o00002OoonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l00000
1?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z00Go0000oookJ_oonf[o
oo]Zo`00000NoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP0DoookJP;o00002?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP02o`0000Oooo]Z00?o0000oookJ_oo
nfX00ooonfX01?l0003ooo]ZoookJ_l0000JoookJP04o`000?oonf[ooo]Zo`0000Wooo]Z0Ol00001
oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0AoookJP;o00002_oonfX00ol0003ooo]ZoookJP02oookJP05
o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00Kooo]Z0_l000000ooonf[o0000oookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o000001_ooo]Z0_l00005oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX02_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX05?oonfX2
o`0000?ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
000000Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX04OoonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[o000000Wooo]Z00?o
0000oookJ_oonfX07OoonfX01?l0003ooo]ZoookJ_l0000:oookJP07o`000?oonf[ooo]ZoookJ_l0
003ooo]Zo`000009oookJP03o`000?oonf[ooo]Z01kooo]Z0Ol000000003o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0;oookJP07o`000?oonf[ooo]Zoook
J_l0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00Sooo]Z00Co0000oookJ_l0003o00001ooo
nfX2o`0000Kooo]Z00?o0000oookJ_oonfX03?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z
0_l00003oookJP03o`000?oonf[ooo]Z00Wooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l000000ooonf[o0000oookJP0=oookJP05
o`000?oonf[ooo]ZoookJ_l000004?oonfX00ol0003ooo]ZoookJP0MoookJP;o00003?oonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0DoookJP05o`000?oonf[ooo]ZoookJ_l000003OoonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01ooonfX01Ol0003ooo]Zo`000?oo
nf[o000000Sooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02OoonfX1o`00000000Go0000oookJ_oonf[ooo]Zo`00
0005oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX01OoonfX01?l0003ooo]Zoook
J_l00003oookJP;o00001OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z
0_l00002oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP06oookJP05o`000?oonf[ooo]ZoookJ_l0
00003OoonfX00ol0003ooo]ZoookJP0;oookJP;o00000_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0EoookJP07
o`000?oonf[o0000oookJ_l0003ooo]Zo`00000CoookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0000B
oookJP03o`000?oonf[o000000Cooo]Z00Co0000oookJ_l0003o00000ooonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00oooo]Z0_l0
0003oookJP03o`000?oonf[ooo]Z00Gooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z01_ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Zoooo
nfXnoookJP7o000000000ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00006
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`000005
oookJP04o`000?oonf[ooo]Zo`0001oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX2o`0000;ooo]Z00?o
0000oookJ_oonfX01ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00?o0000oookJ_oonfX0
3?oonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Sooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00kooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oo
nf[o000001?ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01ooonfX2o`0001Cooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX04?oo
nfX1o`00000000?o0000oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_oonfX2o`0000?ooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0<oookJP;o00002ooonfX01?l0003ooo]Zoook
J_l00003oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000Kooo]Z00?o0000oookJ_oonfX00_l00002oookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01So
oo]Z00Go0000oookJ_oonf[ooo]Zo`00000AoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX04OoonfX00ol0003ooo]ZoookJP0:oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000Sooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP07oookJP;o000000Cooo]Zo`000?oonf[o0000
6?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX0
0_oonfX2o`0000Sooo]Z0Ol000000003o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]Zo`000002oookJP04o`000?oonf[ooo]Zo`0000cooo]Z0_l00002oookJP05o`00
0?oonf[ooo]ZoookJ_l000003?oonfX00ol0003ooo]ZoookJP0VoookJP;o000000?ooo]Zo`000?oo
nfX00ooonfX01?l0003ooo]ZoookJ_l00009oookJP03o`000?oonf[ooo]Z00Cooo]Z00Go0000oook
J_oonf[ooo]Zo`00000CoookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]Zoook
JP02o`0000_ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z00Wooo]Z0_l00004oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[o000001_ooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_l00000:_oonfX00ol0003ooo]ZoookJP02oookJP04
o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Kooo]Z00?o0000oook
J_oonfX07_oonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oonf[ooo]Z00Kooo]Z00Go0000
oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0?oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z0Ol000000005o`000?oo
nf[ooo]ZoookJ_l000003?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z017ooo]Z
00?o0000oookJ_oonfX01?oonfX2o`0000;ooo]Z00Go0000oookJ_l0003ooo]Zo`000009oookJP03
o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_l0003o00003_oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0Goook
JP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP08
oookJP04o`000?oonf[ooo]Zo`0000gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP02oookJP;o00001?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX02?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o0000oookJ_oonfX0
1_oonfX01?l0003ooo]ZoookJ_l0000MoookJP;o00002ooonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP07oookJP04
o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o
0000013ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o
000000?ooo]Z00?o0000oookJ_oonfX00Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoook
JP7o000000000ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP02o`0000Cooo]Z00?o0000oookJ_oonfX02_oonfX01Ol0003o
oo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o
000000Oooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[o000000Kooo]Z0_l0000SoookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]Z
oookJP02oookJP04o`000?oonf[ooo]Zo`0000kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00ooonfX1o`000000
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0EoookJP05o`000?oonf[ooo]ZoookJ_l0
00000ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP04oookJP;o00000ooonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z00kooo]Z0_l00003oookJP03o`000?oonf[o000000kooo]Z00Co0000oookJ_oo
nf[o00002_oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000004ooonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00cooo]Z0_l00002oookJP03o`000?oonf[o
oo]Z00cooo]Z00?o0000oookJ_l000004ooonfX00ol0003ooo]ZoookJP0BoookJP05o`000?oonf[o
oo]ZoookJ_l000000ooonfX00ol0003ooo]Zo`00000;oookJP03o`000?oonf[ooo]Z00Gooo]Z00Go
0000oookJ_oonf[ooo]Zo`00000LoookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000oookJ_oonf[o
oo]Zo`00000?oookJP09o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000?oonf[o000000[ooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP?o00002?oonfX01?l0003ooo]Zoook
J_l0000?oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00;o0000
3_oonfX4o`0000[ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0CoookJP7o0000
00001?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00Go0000oookJ_oonf[o
oo]Zo`000009oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]Zo`00000FoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX01?l0003o
oo]ZoookJ_l0000BoookJP;o000000?ooo]Zo`000?oonfX03_oonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0;oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_oonfX2
o`0000Gooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l0
0007oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX04?oonfX01ol0003ooo]Zoook
J_oonf[o0000oookJ_l000000_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000004o`000?oonf[ooo]Zo`0000Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[o000000Cooo]Z00Co0000oookJ_oonf[o00003OoonfX00ol0003o
oo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]ZoookJP0Coook
JP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0h
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000003OoonfX00ol0003ooo]ZoookJP04
oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]Zo`000?l00004oookJP04o`00
0?oonf[o0000o`0000Sooo]Z00?o0000oookJ_oonfX03_oonfX2o`0000gooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000GoookJP?o00000_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Kooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000001Cooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02Ooo
nfX01Ol0003ooo]ZoookJ_oonf[o000000gooo]Z0Ol000000003o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z013ooo]Z00?o
0000oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[o000001Sooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0@oookJP;o00000_oonfX01?l0003ooo]ZoookJ_l00007oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02OoonfX2o`0000;ooo]Z00?o0000oookJ_oo
nfX03OoonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]ZoookJ_l000002_oonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP02oookJP04o`000?oonf[o0000o`0000Sooo]Z00?o0000oookJ_oonfX02ooonfX0
1Ol0003ooo]ZoookJ_oonf[o000000kooo]Z00Go0000oookJ_oonf[ooo]Zo`000008oookJP05o`00
0?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;o
00001OoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o000000?ooo]Z00?o0000oook
J_oonfX06?oonfX01?l0003ooo]Zo`000?l00004oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX01_oonfX1o`00000000?o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP0@oook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Foook
JP?o00001ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`0000[ooo]Z0_l00002
oookJP03o`000?oonf[o000000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00006oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00_l00002oookJP03o`000?oonf[ooo]Z00gooo]Z00Oo
0000oookJ_oonf[ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_l000001OoonfX01?l0003o
oo]ZoookJ_l00007oookJP;o00003_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Gooo]Z00Co0000oookJ_oonf[o00003?oonfX00ol0003ooo]Zo`00000FoookJP03o`000?oonf[o
oo]Z00Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000?oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Cooo]Z00Co
0000oookJ_oonf[o00002ooonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oo
nfX00ooonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Cooo]Z00Co0000oookJ_oonf[o00003_oo
nfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000[ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0;oookJP04o`000?oonf[ooo]Zo`0000Sooo]Z00?o0000oookJ_oonfX03?oonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX02?oonfX0
1?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[o000000Sooo]Z00Co0000oookJ_oonf[o0000
4OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
7OoonfX2o`0000?ooo]Z0_l00009oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01?ooo]Z0_l00003oookJP03o`00
0?oonf[ooo]Z00Gooo]Z0_l00007oookJP;o00000ooonfX01Ol0003ooo]Zo`000?oonf[o000000Ko
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z01co
oo]Z00Co0000oookJ_oonf[o00003?oonfX01?l0003ooo]ZoookJ_l00008oookJP03o`000?oonf[o
oo]Z00cooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l0000:oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00Co0000oookJ_oonf[o00006_oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00;ooo]Z0Ol000000005o`000?oonf[ooo]ZoookJ_l000004?oonfX00ol0003ooo]Z
oookJP03oookJP04o`000?oonf[ooo]Zo`0002?ooo]Z00Co0000oookJ_oonf[o00005ooonfX2o`00
01Kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP04oookJP04o`000?oonf[o0000
o`0000oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zo`000005oookJP04o`000?oonf[o
oo]Zo`0000Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP04oookJP;o00001?oo
nfX00ol0003ooo]ZoookJP0KoookJP;o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z00;o00001ooonfX00ol0003ooo]ZoookJP06oookJP04o`000?oo
nf[ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP06oookJP;o0000
2_oonfX00ol0003ooo]ZoookJP02oookJP;o00001?oonfX00ol0003ooo]ZoookJP0EoookJP03o`00
0?oonf[ooo]Z00?ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[o
oo]Zo`00000?oookJP03o`000?oonf[o000000Wooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oook
JP?o00000ooonfX2o`0000Cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0001;ooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP09oookJP04o`000?oonf[ooo]Zo`0000Wooo]Z0Ol00000
0003o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP03oook
JP04o`000?oonf[o0000o`0000gooo]Z00?o0000oookJ_oonfX05?oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000;ooo]Z00Go0000oookJ_l0003ooo]Zo`000009oookJP03o`000?oonf[ooo]Z01Gooo]Z
00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00005oookJP04o`000?oonf[ooo]Zo`00
00kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0;oookJP04o`000?oonf[ooo]Z
o`0001Sooo]Z0_l000000ooonf[o0000oookJP03oookJP03o`000?oonf[ooo]Z01?ooo]Z0_l00002
oookJP03o`000?oonf[ooo]Z01Wooo]Z00Co0000oookJ_oonf[ooo]Z0_l00008oookJP03o`000?oo
nf[ooo]Z00cooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Gooo]Z
0_l000000ooonf[o0000oookJP03oookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000oookJ_oonf[o
oo]Zo`000007oookJP03o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oook
JP04o`000?oonf[ooo]Zo`00017ooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oo
nf[o000000;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02?oonfX1o`00000000?o0000oookJ_l000001OoonfX2
o`000005oookJ_l0003ooo]ZoookJ_l000009OoonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o0000
00?ooo]Zo`000?oonfX01OoonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oonf[o000000Go
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP05o`000?oonf[ooo]Zoook
J_l000005?oonfX2o`0000Cooo]Z00Co0000oookJ_oonf[o00001OoonfX01Ol0003ooo]ZoookJ_oo
nf[o000000;ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02o`0001[ooo]Z00Co
0000oookJ_oonf[o00005?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX01OoonfX2o`0000?ooo]Z00?o0000oookJ_oonfX00_l00008oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00?ooo]Z0_l00004oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP06oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000Go0000oookJ_oonf[ooo]Zo`000008oookJP;o00001ooonfX00ol0003ooo]Zoook
JP05oookJP05o`000?oonf[ooo]ZoookJ_l000007OoonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX01Ol0003ooo]ZoookJ_oonf[o0000013o
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;o
00003ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o000000Kooo]Z00Co0000oookJ_oo
nf[o00000_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Gooo]Z00Go0000oook
J_oonf[ooo]Zo`00000?oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l0000@oookJP03o`000?oonf[o
oo]Z00gooo]Z00Co0000oookJ_oonf[ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0=oookJP05o`000?oonf[ooo]ZoookJ_l00000
4OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0DoookJP?o00001ooonfX00ol0003ooo]ZoookJP0<oookJP;o0000
3?oonfX01?l0003ooo]ZoookJ_l0000:oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP09oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000006
oookJP03o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_l0003ooo]Z0_l00008oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00ooonfX1o`00000000?o0000oookJ_oonfX01?oonfX3
o`0000Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP06o`000?oonf[o
oo]Zo`000?oonf[o00000ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01?ooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX00_l00002oookJP03o`000?oonf[ooo]Z00kooo]Z00Go0000oookJ_oonf[o
oo]Zo`000002oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00004oookJP03o`000?oonf[o000000_o
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX01_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001?oonfX0
1Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z00?o0000oookJ_l000000_oonfX2o`0000?ooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0IoookJP05o`000?oonf[o0000oookJ_l00000
FOoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l00000
1ooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP09oookJP;o00001ooonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z01_ooo]Z00Ko0000oookJ_l0003o0000oookJ_l00003oookJP03o`000?oonf[o0000
00;ooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[o
oo]ZoookJ_l000001_oonfX1o`00000000?o0000oookJ_oonfX03ooonfX01?l0003ooo]ZoookJ_oo
nfX3o`0001;ooo]Z0_l0000HoookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[o0000
0_oonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX01ooonfX01?l0003ooo]ZoookJ_l00006oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX00ooonfX2o`0000;ooo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01Sooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oookJP?o00001ooonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol00008oookJP03o`000?oonf[o
000000Kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z00Kooo]Z0_l00002oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX02?oonfX0
1?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003ooo]Z00Cooo]Z00Co0000oookJ_oonf[o0000
3_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP02o`0001Gooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP03oook
JP04o`000?oonf[ooo]ZoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00
000000?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP06oookJP;o00003?oonfX01?l0003o
oo]ZoookJ_l0000AoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_l000001ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX05_oonfX0
1ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001_oonfX00ol0003ooo]Zo`00000OoookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000008ooonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z00Sooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
0ooonfX2o`00013ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[o000000Sooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`00000=oookJP03o`00
0?oonf[ooo]Z00kooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00;o
oo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0=oookJP7o000000000ol0003o
oo]ZoookJP0AoookJP;o00000_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Ko
oo]Z0_l000000ooonf[o0000oookJP02oookJP;o00006?oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[o000000Oooo]Z0_l000000ooonf[o0000oookJP05oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP07oookJP;o00009_oonfX00ol0003o
oo]Zo`000007oookJP?o000000?ooo]Zo`000?oonfX01OoonfX3o`0001[ooo]Z00?o0000oookJ_l0
00002ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX01?oonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oook
J_oonf[ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_l00000
0ooonf[o0000oookJP04oookJP03o`000?oonf[o000000Gooo]Z0_l000001Ooonf[o0000oookJ_oo
nf[o000000_ooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]ZoookJ_l0000KoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0
1?oonfX2o`0000kooo]Z1?l00003oookJP03o`000?oonf[o0000017ooo]Z0Ol000000003o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oo
nf[ooo]Z00Oooo]Z00Go0000oookJ_oonf[ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_l00003oookJP05o`000?oonf[ooo]Zoook
J_l000005_oonfX00ol0003ooo]ZoookJP0;oookJP;o00001OoonfX00ol0003ooo]ZoookJP08oook
JP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z017ooo]Z0_l00008oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z0_l0
00000ooonf[o0000oookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]Zo`00000<oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]Zo`00000<oookJP04o`000?oonf[ooo]Zo`0001Cooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0001Oooo]Z00?o0000oookJ_oo
nfX01_oonfX01?l0003ooo]Zo`000?l00004oookJP;o00001OoonfX2o`000004oookJ_l0003ooo]Z
o`0000;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o
oo]Z00oooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00Oooo]Z0_l00004oookJP05o`000?oonf[ooo]ZoookJ_l000003ooonfX01?l0003ooo]Z
oookJ_l00005oookJP;o00001OoonfX00ol0003ooo]Zo`00000>oookJP04o`000?oonf[ooo]Zo`00
00cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP7o00000OoonfX1o`00
000000?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00co
oo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP06oookJP;o00000ooonfX01Ol0003ooo]ZoookJ_oonf[o0000013ooo]Z00?o0000oook
J_oonfX06?oonfX2o`000004oookJ_l0003ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000000ooonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00001Ooo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000001Ooo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00kooo]Z00Co0000oookJ_oonf[o0000
0ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0
3ooonfX2o`0000oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP03o`000?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00?o
oo]Z00Co0000oookJ_oonf[o00002OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o0000
00;ooo]Z00?o0000oookJ_oonfX04OoonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX01_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00_l000001?oonf[o0000oookJ_l00005oook
JP03o`000?oonf[ooo]Z01Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
000001?ooo]Z00?o0000oookJ_oonfX00_l00003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Oooo]Z00Go
0000oookJ_oonf[ooo]Zo`00000CoookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00?o0000oookJ_oo
nfX00_l00006oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_l0003o00001?oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0:oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000001?oonfX2
o`0000Sooo]Z0ol00006oookJP?o00002?oonfX2o`000003oookJ_l0003ooo]Z01Oooo]Z00Co0000
oookJ_oonf[ooo]Z0_l00009oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX08Ooo
nfX3o`0000Cooo]Z00Co0000oookJ_oonf[o00002OoonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP08oookJP05o`00
0?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]Zo`00000>oookJP03o`000?oonf[ooo]Z00;o
oo]Z0_l0000>oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Kooo]Z0Ol000000003o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0=oookJP;o00001ooonfX01Ol0003ooo]Z
oookJ_oonf[o000000Wooo]Z00?o0000oookJ_oonfX00_oonfX01ol0003ooo]ZoookJ_oonf[o0000
oookJ_l000002?oonfX01Ol0003ooo]ZoookJ_oonf[o000001gooo]Z00?o0000oookJ_l000001_oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX06Ooo
nfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
1?oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0001Sooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX2o`00
00Kooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]Z
o`0000gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z00Gooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00005oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000?ooo]Z
00?o0000oookJ_oonfX02_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oookJ_oo
nfX01ooonfX2o`0000?ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zo`000008oookJP03
o`000?oonf[o000000gooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX01?oonfX1o`00000000?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000006oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
00oooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ooonfX2o`00
00?ooo]Z0_l00008oookJP;o00003_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0AoookJP;o00001_oonfX00ol0
003ooo]ZoookJP0@oookJP;o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z0_l0000?
oookJP04o`000?oonf[ooo]Zo`0001gooo]Z00Go0000oookJ_oonf[o0000oookJP02o`0000oooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02o`0000[ooo]Z00?o0000oookJ_oonfX0
2OoonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00?o0000oookJ_l000001_oonfX00ol0003o
oo]Zo`000004oookJPGo00001OoonfX01?l0003ooo]ZoookJ_l0000aoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000008oookJP03o`000?oonf[o0000
00Oooo]Z0_l00006oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`000000
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Kooo]Z
0_l00002oookJP03o`000?oonf[o000002Gooo]Z00?o0000oookJ_l000001OoonfX2o`0001Wooo]Z
00?o0000oookJ_l000004_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX02OoonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[ooo]Z00Co
oo]Z00Go0000oookJ_oonf[ooo]Zo`00000FoookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00
0002oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01OoonfX01?l0003ooo]Zoook
J_l00006oookJP05o`000?oonf[ooo]ZoookJ_l000002_oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[o000000;o000000?ooo]Zo`000?oonfX02_oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0@oookJP;o
00003_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oo
nf[o00000ooonfX00ol0003ooo]ZoookJP0@oookJP;o00001_oonfX3o`0000Oooo]Z0_l000000ooo
nf[o0000oookJP04oookJP;o00001?oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[ooo]Z
oookJ_l000002?oonfX00ol0003ooo]ZoookJP08oookJP;o00001_oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0=
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01ooonfX01?l0003ooo]ZoookJ_l0
0005oookJP03o`000?oonf[ooo]Z00?ooo]Z0Ol000000003o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP;o00002?oonfX00ol0003ooo]Zo`00000F
oookJP;o00001_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[o000001Wooo]Z00Co0000
oookJ_l0003o00000ooonfX00ol0003ooo]ZoookJP0:oookJP05o`000?oonf[o0000oookJ_l00000
0_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Wooo]Z00Oo0000oookJ_oonf[o
0000oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?oonfX01?oonfX00ol0003ooo]Zo`00000?oook
JP;o00003?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oook
J_l0003o00001_oonfX00ol0003ooo]Zo`000009oookJP07o`000?oonf[o0000oookJ_l0003ooo]Z
o`000005oookJP04o`000?oonf[ooo]Zo`00027ooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_l000000_oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000E
oookJP;o00001ooonfX00ol0003ooo]ZoookJP08oookJP;o00001_oonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP03
oookJP04o`000?oonf[ooo]ZoookJP;o00002?oonfX01Ol0003ooo]Zo`000?oonf[o000000oooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o000000oooo]Z
0Ol000000003o`000?oonf[ooo]Z00?o00002?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[o000000cooo]Z0_l00005oookJP03o`000?oonf[o000000cooo]Z00Co0000oookJ_oonf[ooo]Z
0_l0000CoookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_oonf[o00001?oonfX2o`0000Oo
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0;oookJP04o`000?oonf[ooo]Zo`00
00Wooo]Z00?o0000oookJ_oonfX05OoonfX01?l0003ooo]ZoookJ_l00006oookJP03o`000?oonf[o
000000?ooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Wooo]Z00?o0000oookJ_oonfX04?oonfX0
0ol0003ooo]ZoookJP0MoookJP;o00000ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP0FoookJP;o00002OoonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00008oookJP03o`000?oonf[o
000000;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX04?oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX02_oonfX4
o`0000gooo]Z00?o0000oookJ_l000002OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP03oookJP;o00001_oonfX1
o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX06?oonfX3o`0000Sooo]Z00?o0000oookJ_l000001OoonfX01_l0003o
oo]ZoookJ_l0003ooo]Zo`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zo`00000>oookJP03o`000?oo
nf[ooo]Z00gooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP04o`00
0?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX04?oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Gooo]Z00?o0000oookJ_oonfX01?oonfX2o`0001;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP06oookJP05o`000?oonf[o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00005oookJP;o00004?oonfX00ol0003ooo]Zo`00000B
oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00002?oonfX2o`0000;ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP06oookJP;o00000_oonfX00ol0003ooo]Zoook
JP02oookJP;o00002?oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Kooo]Z00?o
0000oookJ_oonfX01?oonfX1o`00000000?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05
oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Oooo]Z00Co
0000oookJ_oonf[o00005OoonfX3o`0000Kooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]Z
oookJ_l00006oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l00007oookJP03o`000?oonf[o000000Co
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP06oookJP;o00002ooonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX2o`00023o
oo]Z0_l00006oookJP03o`000?oonf[o000001;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[o000000Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oook
JP03o`000?oonf[ooo]Z00?ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oook
J_oonf[o00001?oonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000
oookJ_oonf[o00000_oonfX2o`00017ooo]Z0_l00003oookJP03o`000?oonf[o000001Cooo]Z00Go
0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_l00000
1?oonfX00ol0003ooo]Zo`00000HoookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0000@oookJP03o`00
0?oonf[o000000?ooo]Z00?o0000oookJ_oonfX00_l00006oookJP04o`000?oonf[ooo]Zo`0000Oo
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP06oookJP7o000000001?l0003ooo]Z
oookJ_l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oook
JP?o00001OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_l000000_oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zo`000008oook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP0;oook
JP;o00001ooonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00002oook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP04oook
JP05o`000?oonf[o0000oookJ_l000002ooonfX01?l0003ooo]ZoookJ_l00008oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0;oookJP;o00001Ooo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z00Go0000oookJ_oonf[ooo]Z
o`000003oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0=oookJP;o000000Sooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`0000Kooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00?o
0000oookJ_l000003ooonfX3o`0001?ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zoook
JP0OoookJP05o`000?oonf[o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP01o`00000000?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l00000
1ooonfX01Ol0003ooo]Zo`000?oonf[o000000_ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000?o
oo]Z0_l000001?oonf[o0000oookJ_l0000>oookJP;o00001_oonfX00ol0003ooo]ZoookJP03oook
JP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03
oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00Co0000oookJ_l0003o00001_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000kooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z00Gooo]Z0_l00006oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00003oook
JP05o`000?oonf[ooo]ZoookJ_l000002?oonfX01Ol0003ooo]Zo`000?oonf[o000000Gooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP04o`000?oonf[ooo]Zo`0000_ooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0FoookJP;o00003ooonfX2o`0000Oooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Gooo]Z
0_l00003oookJP03o`000?oonf[ooo]Z00cooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00003oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03OoonfX2o`000003oookJ_l0003ooo]Z
00Cooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00Cooo]Z0Ol000000003o`000?oonf[ooo]Z0?oo
oo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z
0_l0000AoookJP06o`000?oonf[o0000o`000?oonf[o00000ooonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z00Gooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX00ooonfX2o`0000?ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP05oook
JP;o00001OoonfX2o`000003oookJ_l0003o000000Wooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00[ooo]Z00Go0000oookJ_oonf[ooo]Zo`000006
oookJP06o`000?oonf[ooo]Zo`000?oonf[o00004_oonfX00ol0003ooo]ZoookJP03oookJP;o0000
0ooonfX01?l0003ooo]ZoookJ_l00005oookJP05o`000?oonf[o0000oookJ_l000000_oonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX00_l00005oook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP06oook
JP;o00001ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0000;oook
JP03o`000?oonf[ooo]Z00?o00000_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00?ooo]Z00Co0000oookJ_oonf[o00002OoonfX00ol0003ooo]ZoookJP04oookJP;o00001?oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000003_oonfX0
0ol0003ooo]ZoookJP07oookJPCo00001OoonfX00ol0003ooo]ZoookJP0EoookJP04o`000?oonf[o
oo]Zo`0000Wooo]Z00?o0000oookJ_l000002OoonfX2o`0000cooo]Z00Oo0000oookJ_oonf[ooo]Z
o`000?oonf[o000000;ooo]Z0Ol000000003o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l000001?oonf[o0000
oookJ_l00003oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0EoookJP05o`000?oonf[o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]Zo`000?l00004
oookJP03o`000?oonf[o000000[ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJPCo000000?o
oo]Zo`000?oonfX00_oonfX2o`0000Oooo]Z00?o0000oookJ_l000001OoonfX2o`000003oookJ_l0
003ooo]Z00Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00Go0000oookJ_oonf[o0000oookJP02o`000003oookJ_l0003o000000Wooo]Z
0_l00004oookJP;o00001_oonfX00ol0003ooo]ZoookJP07oookJP;o00001?oonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00007oookJP03o`000?oonf[o000000Sooo]Z
00Co0000oookJ_oonf[o00001ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;o
oo]Z0Ol000000003o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00006oookJP03o`000?oonf[ooo]Z00Kooo]Z
00Go0000oookJ_oonf[ooo]Zo`000003oookJP?o00002_oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z00cooo]Z00Co0000oookJ_l0003o00000ooonfX01?l0003ooo]ZoookJ_l0000A
oookJP03o`000?oonf[o0000013ooo]Z00?o0000oookJ_oonfX01_oonfX01Ol0003ooo]ZoookJ_l0
003ooo]Z00Co000000?ooo]Zo`000?oonfX03_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0GoookJP04o`000?oonf[ooo]Zo`0000co
oo]Z00Co0000oookJ_oonf[o00002?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
00;ooo]Z00Co0000oookJ_oonf[o00001OoonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o
0000oookJ_oonfX00ooonfX2o`0000Gooo]Z0_l00007oookJP;o000000?ooo]Zo`000?oonfX00_oo
nfX01?l0003ooo]ZoookJ_l00006oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0:oookJP05o`000?oonf[o0000oookJ_l000002OoonfX00ol0003o
oo]ZoookJP08oookJP05o`000?oonf[o0000oookJ_l000002OoonfX00ol0003ooo]Zo`000006oook
JP;o00001ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l0000>oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Kooo]Z0_l00007oook
JP03o`000?oonf[o000000_ooo]Z00?o0000oookJ_oonfX02?oonfX01?l0003ooo]ZoookJ_l0000?
oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000?oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0EoookJP03
o`000?oonf[ooo]Z00oooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_l0
00001?oonfX2o`0000?ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Oooo]Z0_l00006
oookJP;o00004ooonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o
0000oookJ_l000001OoonfX01?l0003ooo]ZoookJ_l00004oookJP04o`000?oonf[ooo]Zo`0000Oo
oo]Z00?o0000oookJ_oonfX04?oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX02?oonfX01ol0003o
oo]ZoookJ_oonf[o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000007oookJP;o00005?oonfX0
1ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001?oonfX01ol0003ooo]ZoookJ_oonf[o0000oook
J_l000003?oonfX00ol0003ooo]Zo`000002o`0000Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Wooo]Z00Go0000oookJ_oonf[ooo]Zo`00000A
oookJP;o00001ooonfX00ol0003ooo]Zo`00000:oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0GoookJP?o00001OoonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0A
oookJP7o000000000ol0003ooo]ZoookJP0VoookJP;o00001_oonfX2o`0000Kooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP08oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`000003
oookJP;o00002?oonfX00ol0003ooo]ZoookJP04oookJP;o00002?oonfX00ol0003ooo]Zo`00000?
oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP09
oookJP;o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zo`00000BoookJP03o`000?oonf[o
oo]Z00;ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Zo`000007oookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oo
nf[ooo]ZoookJ_l000003?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Wooo]Z00Co0000oookJ_oo
nf[o00003_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP08oookJP;o00000_oonfX00ol0003ooo]ZoookJP0:oook
JP;o00001ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[o0000013ooo]Z0ol00006oookJP0;o`000?oonf[o
oo]ZoookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP06oook
JP05o`000?oonf[ooo]ZoookJ_l000000ooonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01OoonfX0
1?l0003ooo]ZoookJ_l0000=oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01?oo
nfX1o`00000000?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000006oookJP;o00001OoonfX0
1?l0003ooo]ZoookJ_oonfX2o`0000?ooo]Z0_l00007oookJP;o00001_oonfX01?l0003ooo]Zo`00
0?l00006oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000<oookJP05o`000?oonf[ooo]ZoookJ_l0
00001ooonfX00ol0003ooo]Zo`000006oookJP;o00001?oonfX3o`0000Sooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP04oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00Co0000oook
J_oonf[o00002ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l00008
oookJP03o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[o0000oookJP02o`0000?ooo]Z00?o
0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]Zo`000008oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oo
nfX01OoonfX01?l0003ooo]ZoookJ_l0000>oookJP04o`000?oonf[ooo]Zo`0001Sooo]Z0_l00003
oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Kooo]Z00Ko0000oookJ_oonf[o0000
oookJ_l0000=oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00004OoonfX01Ol0
003ooo]ZoookJ_oonf[o000000?ooo]Z0_l0000JoookJP03o`000?oonf[ooo]Z01Gooo]Z00Co0000
oookJ_oonf[o00000_oonfX00ol0003ooo]ZoookJP02oookJP?o00001OoonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co
0000oookJ_l0003ooo]Z0_l00007oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000?o0000oookJ_oonfX02ooonfX2o`0000gooo]Z0_l00002oookJP03o`000?oonf[o
oo]Z00Gooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]ZoookJP02o`0000Gooo]Z0ol0
0007oookJP;o000000?ooo]Zo`000?oonfX00ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]Zo`000?l0000CoookJP03o`00
0?oonf[o000001Gooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Oooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP05oookJP;o00001ooonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z00;o000000?ooo]Zo`000?oonfX02?oonfX00ol0003ooo]ZoookJP0BoookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02o`0000Kooo]Z
0_l00004oookJP03o`000?oonf[ooo]Z00Sooo]Z00Go0000oookJ_oonf[ooo]Zo`00000?oookJP;o
00001?oonfX01?l0003ooo]ZoookJ_l00003oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00
0006oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003ooo]Zoook
J_oonf[o000000Gooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
1OoonfX4o`0000Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0:oookJP7o0000
00000ol0003ooo]ZoookJP08oookJP04o`000?oonf[o0000o`0000Wooo]Z00?o0000oookJ_oonfX0
3_oonfX3o`0000;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000CoookJP04o`000?oonf[ooo]Zo`00
00?ooo]Z00?o0000oookJ_oonfX02ooonfX01?l0003ooo]ZoookJ_l00008oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[o
0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX01ooonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z0_l00005oookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z01cooo]Z00Co0000oookJ_oonf[o00002ooonfX00ol0003ooo]ZoookJP04oookJP07
o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00cooo]Z00Go0000
oookJ_oonf[ooo]Zo`00000>oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol00007oookJP03o`000?oo
nf[ooo]Z00gooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0000EoookJP04o`000?oonf[o0000o`00
00;ooo]Z00?o0000oookJ_oonfX00_l00007oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l000000_l00003oookJP?o00001ooonfX2o`00
00Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00;ooo]Z0_l00005oookJP05o`000?oonf[o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00kooo]Z0ol00009oookJP03o`000?oonf[ooo]Z00;ooo]Z00Go0000
oookJ_oonf[ooo]Zo`000006oookJP7o000000000ol0003ooo]Zo`000003oookJP04o`000?oonf[o
oo]Zo`0000oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP?o00002?oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000_ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP08oookJP;o00003_oonfX4o`0000;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00003oookJP05
o`000?oonf[ooo]ZoookJ_l000003ooonfX01?l0003ooo]ZoookJ_l00009oookJP05o`000?oonf[o
0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP05oookJP?o00001_oonfX2o`000003oookJ_l0
003ooo]Z00?ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zo`000005oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01?oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000_o
oo]Z0_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[ooo]Z00;o00001ooonfX00ol0003o
oo]Zo`000003oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z00Co0000oookJ_oonf[o00001ooonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000004
oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP03o`0000Gooo]Z00?o0000oookJ_oonfX01ooonfX01?l0003ooo]Zoook
J_l00004oookJP;o00001ooonfX2o`00013ooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP;o
00000_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o000000Oooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000HoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02?oonfX01?l0
003ooo]ZoookJ_l00003oookJP03o`000?oonf[o000000Sooo]Z0_l00003oookJP05o`000?oonf[o
oo]ZoookJ_l000001OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00gooo]Z0Ol0
00000003o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00cooo]Z00Co0000oookJ_l0003o00001ooonfX00ol0003ooo]Zo`00
0005oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Oooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l00000
6OoonfX00ol0003ooo]ZoookJP05oookJP?o000000Cooo]Zo`000?oonf[o00000_oonfX2o`0000;o
oo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00006oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP08oookJP06o`000?oonf[ooo]Z
o`000?oonf[o00000_oonfX00ol0003ooo]ZoookJP05oookJPCo00002?oonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP03o`0000Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000009oookJP;o00001Ooo
nfX2o`0000Sooo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP03oookJP;o00001_oo
nfX00ol0003ooo]Zo`000006oookJP?o00002?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX04ooonfX2o`0001Kooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01_oo
nfX2o`0000Sooo]Z0ol00004oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Gooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX03OoonfX2o`000003oookJ_l0003ooo]Z00Gooo]Z00?o0000oook
J_l000000ooonfX02?l0003ooo]Zo`000?l0003ooo]Zo`000?oonf[o00002ooonfX00ol0003ooo]Z
oookJP0@oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[o0000
00?ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0000>oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0
0008oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP02o`0000Sooo]Z0_l00007oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01OoonfX01_l0003ooo]Z
oookJ_l0003ooo]Zo`0000Gooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002oookJP;o00001ooo
nfX3o`0000Kooo]Z00?o0000oookJ_oonfX02ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z
00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]Zo`000007oookJP03o`000?oonf[o000000Ko
oo]Z0_l00007oookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX00_oonfX01_l0003o
oo]Zo`000?l0003ooo]Zo`0000gooo]Z0ol00008oookJP;o00001OoonfX3o`0000Cooo]Z00Go0000
oookJ_oonf[ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ooo
nfX01Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00Cooo]Z
00Go0000oookJ_oonf[ooo]Zo`00000;oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX03?oonfX2o`0000Oooo]Z0_l00003oookJP04o`000?oonf[ooo]ZoookJP;o00005?oonfX00ol0
003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00cooo]Z0Ol000000003o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX00_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Oooo]Z0ol00002
oookJP06o`000?oonf[ooo]Zo`000?oonf[o00002?oonfX00ol0003ooo]ZoookJP06oookJP;o0000
1ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l00000
1_oonfX3o`0000Kooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00Gooo]Z00Oo0000oookJ_oonf[o
oo]Zo`000?oonf[o0000017ooo]Z00?o0000oookJ_oonfX02?oonfX3o`0000Oooo]Z00?o0000oook
J_l000000ooonfX01?l0003ooo]ZoookJ_l00008oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Gooo]Z0ol00006
oookJP;o00001ooonfX2o`0000cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<
oookJP03o`000?oonf[o000000Sooo]Z0ol00006oookJP03o`000?oonf[ooo]Z01Gooo]Z00Go0000
oookJ_oonf[ooo]Zo`00000?oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP;o
00001_oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Sooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP0;oookJP05o`000?oonf[o
oo]ZoookJ_l000001_oonfX01?l0003ooo]Zo`000?l00007oookJP;o00001ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
o`00000?oookJP?o00000_oonfX01?l0003ooo]ZoookJ_oonfX1o`00000000Ko0000oookJ_oonf[o
oo]Zo`000?oonfX2o`0000Kooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00007oook
JP;o00002?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oook
J_oonf[o00002?oonfX00ol0003ooo]Zo`000003o`0000;ooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX2
o`0000Kooo]Z00Co0000oookJ_oonf[o00002_oonfX01?l0003ooo]ZoookJ_oonfX2o`000003oook
J_l0003ooo]Z00Gooo]Z0ol00006oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
1OoonfX01?l0003ooo]ZoookJ_oonfX3o`0001?ooo]Z00Co0000oookJ_l0003o00001OoonfX00ol0
003ooo]Zo`000006oookJP05o`000?oonf[o0000oookJ_l000000ooonfX01?l0003ooo]ZoookJ_l0
0006oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z00Gooo]Z0_l00007oookJP;o00000ooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00007oookJP;o0000
1ooonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000007OoonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00;o00000ooonfX3o`0000Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[o000000Sooo]Z00Oo0000oookJ_oonf[o0000oookJ_l0
003ooo]Z00Co00001ooonfX00ol0003ooo]ZoookJP04oookJP;o00002?oonfX00ol0003ooo]Zoook
JP09oookJP07o`000?oonf[o0000oookJ_l0003ooo]Zo`000008oookJP04o`000?oonf[ooo]Zo`00
00Gooo]Z0_l00007oookJP;o00001ooonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[o0000
00Oooo]Z00So0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJP7o000000000ol0003ooo]Zoook
JP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP07
oookJP05o`000?oonf[o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP06oookJPCo000000?o
oo]Zo`000?oonfX00_oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000Sooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000Sooo]Z00?o
0000oookJ_l000001OoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01_oonfX01ol0003ooo]Zoook
J_oonf[o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP06oookJP06o`000?oonf[ooo]Zo`00
0?oonf[o00000_oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000007
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000000ooonfX2o`0000;ooo]Z00?o0000
oookJ_oonfX01OoonfX2o`0000Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06
oookJP;o00000_oonfX00ol0003ooo]Zo`00000>oookJP03o`000?oonf[o000001Gooo]Z0_l00007
oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_l0003o00001OoonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z00oooo]Z0_l00009oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z
0_l00008oookJP?o000000Gooo]Zo`000?oonf[o0000oookJP02o`0000Oooo]Z0_l0000AoookJP;o
00001ooonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_l0
00001_oonfX00ol0003ooo]ZoookJP05oookJP;o00004_oonfX00ol0003ooo]ZoookJP05oookJP04
o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000oooo]Z00?o0000oook
J_oonfX01_oonfX2o`0000Gooo]Z00Co0000oookJ_oonf[o00001ooonfX2o`0000Oooo]Z0_l00007
oookJP;o00003?oonfX00ol0003ooo]ZoookJP09oookJP;o000000?ooo]Zo`000?oonfX01?oonfX1
o`00000000?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o0000
00kooo]Z00Co0000oookJ_l0003o00001ooonfX2o`0000cooo]Z00Go0000oookJ_l0003ooo]Zo`00
0009oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00008oookJP05o`000?oonf[o0000oookJ_l00000
1?oonfX00ol0003ooo]ZoookJP05oookJP;o00002?oonfX00ol0003ooo]Zo`00000?oookJP;o0000
1OoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01_oonfX02?l0003ooo]ZoookJ_oonf[o0000oook
J_l0003ooo]Z0_l00008oookJP;o00004?oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000;ooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Cooo]Z
0ol00007oookJP;o00001OoonfX01?l0003ooo]Zo`000?l00007oookJP;o00001ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00006oookJP;o00001ooonfX01_l0003o
oo]ZoookJ_l0003ooo]Zo`0000?ooo]Z0_l00007oookJP;o00001ooonfX2o`000003oookJ_l0003o
oo]Z00;ooo]Z00?o0000oookJ_l000002_oonfX00ol0003ooo]ZoookJP03oookJP;o00004?oonfX2
o`0000Sooo]Z00?o0000oookJ_oonfX01OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX01_oonfX2
o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP0>oookJP08o`000?oo
nf[o0000oookJ_l0003ooo]Zo`000?oonfX2o`0000Sooo]Z0_l00005oookJP03o`000?oonf[o0000
00Sooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX02OoonfX3o`0000Kooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000;ooo]Z00?o0000
oookJ_l000002ooonfX00ol0003ooo]ZoookJP09oookJP04o`000?oonf[ooo]ZoookJP;o00002Ooo
nfX00ol0003ooo]ZoookJP05oookJP7o000000001ol0003ooo]ZoookJ_oonf[o0000oookJ_l00000
2?oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP;o0000
1_oonfX3o`000006oookJ_l0003ooo]ZoookJ_l0003ooo]Z0ol000000ooonf[o0000oookJP04oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000000_l00002oookJP04o`000?oonf[o0000
oookJP?o00001_oonfX2o`0000Oooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00oooo]Z00co0000
oookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l00005oookJP;o00002?oonfX0
0ol0003ooo]ZoookJP05oookJP;o00002?oonfX2o`0000Gooo]Z00Co0000oookJ_l0003o00001Ooo
nfX00ol0003ooo]Zo`000007oookJP?o00001_oonfX2o`0000Oooo]Z0_l00007oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00So0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJP?o000000Sooo]Zo`00
0?oonf[o0000oookJ_l0003ooo]Zo`0000Sooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000001ooonfX3o`0000Kooo]Z
0_l00007oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Z
oookJP06oookJP;o000000oooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oook
J_l0003ooo]Zo`000?oonfX00_l00008oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX01OoonfX2o`0000Oooo]Z0_l00006oookJP?o00001ooonfX2o`0000Oooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l0
00000ooonfX00ol0003ooo]Zo`000002o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_l0
00001ooonfX2o`0000Oooo]Z0_l00007oookJP;o00001_oonfX2o`0000Sooo]Z00?o0000oookJ_l0
00001OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP7o
000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX00ooo
nfX02?l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z0_l00008oookJP;o00001_oonfX2o`00
00Sooo]Z0_l000001?oonf[o0000oookJ_l00002oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_l000001OoonfX2o`0000Sooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00oooo]Z00[o0000
oookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o00002?oonfX00ol0003ooo]ZoookJP05oook
JP;o00001ooonfX2o`0000?ooo]Z00Go0000oookJ_l0003ooo]Zo`00000AoookJP;o00001ooonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00007oookJP;o00000_oonfX0
0ol0003ooo]Zo`000002oookJP;o000000Kooo]Zo`000?oonf[o0000oookJ_l00002oookJP03o`00
0?oonf[ooo]Z00Gooo]Z0_l0000@oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01ooonfX2o`0000Gooo]Z0_l00008oook
JP;o00001OoonfX00ol0003ooo]Zo`000008oookJP07o`000?oonf[o0000oookJ_l0003ooo]Zo`00
0002oookJP07o`000?oonf[ooo]Zo`000?oonf[o0000oookJP02o`0000Wooo]Z00?o0000oookJ_oo
nfX01OoonfX2o`0000Oooo]Z0_l00006oookJP;o00002?oonfX00ol0003ooo]ZoookJP06oookJP;o
00001OoonfX00ol0003ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00007oookJP?o
000000Cooo]Zo`000?oonf[o00000_oonfX02_l0003ooo]ZoookJ_l0003ooo]Zo`000?oonf[o0000
oookJ_l00008oookJP;o00001_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_l000001ooonfX2o`0000Sooo]Z00?o0000oookJ_l000003ooonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l000002?oonf[o0000oookJ_l0003ooo]Z
o`000?oonf[o00000ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP7o000000000ol0003ooo]ZoookJP0<
oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00006oookJP03o`000?oonf[o000000Wooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP06oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Z
o`000003oookJP03o`000?oonf[ooo]Z00[ooo]Z00Co0000oookJ_l0003ooo]Z0_l0000HoookJP;o
00002?oonfX2o`0000Gooo]Z0ol00007oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z0_l0000@oook
JP07o`000?oonf[ooo]Zo`000?oonf[o0000oookJP03o`0000Sooo]Z00?o0000oookJ_l000000ooo
nfX01?l0003ooo]Zo`000?l00008oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP05oookJP?o00001?oonfX4o`0000Oooo]Z00?o0000oookJ_l00000
1OoonfX3o`0000Kooo]Z0_l00008oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oook
JP03o`000?oonf[ooo]Z00Kooo]Z0_l00006oookJP;o00002?oonfX00ol0003ooo]ZoookJP05oook
JP;o00001ooonfX2o`0000Oooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP07oook
JP05o`000?oonf[o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00Kooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002oookJP03o`000?oonf[ooo]Z00Kooo]Z
00Co0000oookJ_oonf[o00000ooonfX01?l0003ooo]Zo`000?l00007oookJP03o`000?oonf[ooo]Z
00Kooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP09oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z0_l00008oookJP03o`000?oonf[o
oo]Z00Kooo]Z0_l00002oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX01_oonfX2
o`0000?ooo]Z00?o0000oookJ_l000002OoonfX00ol0003ooo]ZoookJP05oookJP;o00002?oonfX2
o`0000Oooo]Z0_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[o000000Oooo]Z0Ol00000
0003o`000?oonf[ooo]Z00;ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_l000000_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zo`000006oook
JP?o00001_oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000;ooo]Z00?o0000oook
J_oonfX03?oonfX2o`0000Oooo]Z0_l00005oookJP03o`000?oonf[o000000Oooo]Z0_l000001?oo
nf[o0000o`000?oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP06
oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]ZoookJP05oookJP;o00004_oo
nfX00ol0003ooo]ZoookJP04oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000ooonfX00ol0003o
oo]ZoookJP06oookJP?o00003ooonfX00ol0003ooo]ZoookJP0=oookJP04o`000?oonf[ooo]Zo`00
00Oooo]Z00[o0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o00001ooonfX3o`0000Go
oo]Z00?o0000oookJ_l000004ooonfX2o`0000;ooo]Z00Co0000oookJ_oonf[o00001ooonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0CoookJP04o`000?oonf[ooo]ZoookJP;o00002?oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00007oookJP04o`000?oonf[o0000o`0000;ooo]Z00Co
0000oookJ_oonf[o00001ooonfX01?l0003ooo]ZoookJ_l0000GoookJP;o00001_oonfX3o`0000Oo
oo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX01_oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Cooo]Z00Co0000oook
J_oonf[ooo]Z0_l00006oookJP7o000000000ol0003ooo]ZoookJP03oookJP03o`000?oonf[o0000
00oooo]Z00?o0000oookJ_oonfX00_l00003oookJP;o00001ooonfX2o`0000Oooo]Z00?o0000oook
J_l000001_oonfX00ol0003ooo]ZoookJP07oookJP;o00001?oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP07oook
JP;o00001ooonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX0
1?l0003ooo]ZoookJ_l0000PoookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00003oookJP03o`000?oo
nf[o000000_ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_l000000ooonfX2o`0000Gooo]Z0_l00008oookJP03o`000?oo
nf[ooo]Z027ooo]Z00Co0000oookJ_oonf[o00001OoonfX2o`0000Kooo]Z00?o0000oookJ_oonfX0
1ooonfX2o`0000kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0:oookJP04o`00
0?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000001_oonfX4o`0000Kooo]Z0_l000000ooonf[o
0000oookJP02oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]Zo`00000:oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01?oonfX4o`0000Go
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Oo
oo]Z0_l00006oookJP;o00002?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00Ko0000oookJ_oonf[o0000oookJ_l00003oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000
oookJ_l0003o00001ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Kooo]Z00Ko
0000oookJ_oonf[o0000oookJ_l00002oookJP;o00001ooonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ooo
nfX01?l0003ooo]Zo`000?l00008oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l00000
2_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
0_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP03o`0000Gooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00006oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP?o
00001_oonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_l0
003ooo]Z0ol00005oookJP03o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX01OoonfX01?l0
003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP07oookJP;o00001_oonfX2o`0000?ooo]Z00?o0000oookJ_l000000_oonfX0
0ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Gooo]Z00Oo0000oookJ_oonf[ooo]Zo`00
0?oonf[o000000cooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Ko
oo]Z1?l00006oookJP;o00001?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00Co0000oookJ_oonf[o00003OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Gooo]Z00Co0000oookJ_oonf[o00000ooonfX01?l0003ooo]ZoookJ_l00007oookJP;o00002?oo
nfX00ol0003ooo]ZoookJP06oookJP;o00001_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l0
00000_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l0
00000_oonfX00ol0003ooo]Zo`000002oookJP?o00001OoonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z00gooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Zo`00000Aoook
JP;o00001_oonfX1o`00000000Go0000oookJ_oonf[o0000oookJP02o`0000?ooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX01_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000Gooo]Z0_l00008oookJP;o00001ooonfX0
0ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000000ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000gooo]Z00?o0000oookJ_l000001ooonfX3
o`0000Oooo]Z00?o0000oookJ_oonfX01?oonfX2o`000003oookJ_l0003ooo]Z00gooo]Z00?o0000
oookJ_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z0_l00006oookJPCo00001ooo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z00Oooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00003oook
JP04o`000?oonf[ooo]Zo`0000Cooo]Z0_l000000ooonf[o0000oookJP05oookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z0_l0
0008oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00_ooo]Z00Co
0000oookJ_l0003o00000ooonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Go0000oookJ_oo
nf[o0000oookJP02o`0001_ooo]Z00?o0000oookJ_oonfX01ooonfX01Ol0003ooo]ZoookJ_oonf[o
000000;ooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP05oookJP;o00006_oonfX0
1ol0003ooo]ZoookJ_l0003ooo]Zo`000?oonfX00ol00007oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_l000004?oonfX1o`00000000?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[o000000Cooo]Z0_l0000AoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;o00001ooo
nfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o000000_ooo]Z00Go0000oookJ_oonf[ooo]Z
o`000006oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]Z
o`000005oookJP03o`000?oonf[ooo]Z00_ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]Zo`00000@oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00007oookJP;o00002?oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Wo
oo]Z0_l00006oookJP;o00001ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[o0000o`00
00Kooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP05oookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_l0000=oookJP05o`000?oonf[o
oo]ZoookJ_l000001OoonfX2o`0000Oooo]Z0ol00006oookJP;o00001OoonfX3o`0000[ooo]Z00?o
0000oookJ_oonfX03?oonfX2o`0000Oooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX01_oonfX2o`0001?ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP05oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oook
J_oonfX00ooonfX2o`0000Wooo]Z00?o0000oookJ_oonfX00ooonfX3o`0000Gooo]Z0_l00002oook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000[ooo]Z00So0000oook
J_oonf[o0000oookJ_l0003ooo]Zo`0000Oooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]Z
oookJ_l00009oookJP03o`000?oonf[ooo]Z00cooo]Z00Co0000oookJ_oonf[o00002?oonfX00ol0
003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000;ooo]Z00Oo0000
oookJ_oonf[ooo]Zo`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
o`00000CoookJP03o`000?oonf[ooo]Z00;o00001_oonfX01ol0003ooo]ZoookJ_oonf[o0000oook
J_l000002_oonfX2o`0001[ooo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00ooonfX2o`00013ooo]Z00?o0000
oookJ_l000002?oonfX2o`0000Kooo]Z0_l00007oookJP;o00002?oonfX2o`0000;ooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP03o`0000oooo]Z00?o0000oookJ_oonfX02?oonfX0
1Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX01_oonfX1o`00000000?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP04oookJP;o00000ooonfX00ol0003ooo]Zo`000002
oookJP03o`000?oonf[ooo]Z00_ooo]Z00Co0000oookJ_oonf[o00002OoonfX2o`0000oooo]Z0_l0
0006oookJP?o00001ooonfX2o`0000Kooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]Zoook
JP07oookJP;o00001_oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oonfX0
1OoonfX3o`000007oookJ_l0003ooo]Zo`000?oonf[o0000oookJP02o`0000Oooo]Z00?o0000oook
J_oonfX03OoonfX01Ol0003ooo]ZoookJ_oonf[o000000cooo]Z00Co0000oookJ_oonf[o00001_oo
nfX00ol0003ooo]Zo`000007oookJP04o`000?oonf[ooo]Zo`0001Cooo]Z0_l0000;oookJP06o`00
0?oonf[ooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_l000003_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000kooo]Z00?o0000
oookJ_oonfX01OoonfX2o`0001;ooo]Z00Co0000oookJ_oonf[o00007_oonfX2o`0000Oooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX02OoonfX01?l0003ooo]ZoookJ_oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l00000
2?oonfX00ol0003ooo]ZoookJP05oookJP?o000000?ooo]Zo`000?oonfX01OoonfX00ol0003ooo]Z
oookJP05oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00000;oookJP;o00000_oonfX00ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000000_oonfX00ol0
003ooo]ZoookJP02o`0000_ooo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_oo
nfX02_oonfX4o`0000Kooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP09oookJP;o
00001OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000AoookJP03
o`000?oonf[ooo]Z00Kooo]Z0_l00007oookJP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0?oookJP?o00000ooonfX00ol0003ooo]ZoookJP08oookJP05
o`000?oonf[ooo]ZoookJ_l000002OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z
00Cooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z00;o00001ooonfX01?l0003ooo]ZoookJ_l00003
oookJP03o`000?oonf[o000000[ooo]Z00?o0000oookJ_oonfX02OoonfX01?l0003ooo]ZoookJ_l0
0008oookJP;o00002?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP07o`000?oonf[o0000oookJ_l0003o
oo]Zo`000002oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[o000000_ooo]Z00?o0000oookJ_l000001?oonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00003OoonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[o000000Oooo]Z0_l0000JoookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]Zo`000005oookJPCo00001?oonfX01?l0
003ooo]ZoookJ_l00008oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000_oonfX1o`00000000?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP;o00002_oonfX00ol0003ooo]Zoook
JP03oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00000:oookJP;o00002?oonfX2o`0000ko
oo]Z1?l00006oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[o000000;ooo]Z0_l00008oookJP05o`000?oonf[ooo]Zoook
J_l000000_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o000000Oooo]Z0_l00007oook
JP03o`000?oonf[ooo]Z00Gooo]Z0_l0000@oookJP03o`000?oonf[o000000Oooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP08oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z0_l00007
oookJP03o`000?oonf[ooo]Z00cooo]Z0_l0000:oookJP;o00000_oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00Wooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP04o`000?oo
nf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000004_oonfX2o`0000;ooo]Z00Oo0000oookJ_oonf[o
oo]Zo`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_l00007
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04
oookJP04o`000?oonf[ooo]Zo`0000Sooo]Z0_l00003oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP07oookJP04o`000?oonf[ooo]Zo`0000go
oo]Z00Co0000oookJ_oonf[o00001OoonfX2o`0000Cooo]Z00Co0000oookJ_l0003o00001ooonfX0
0ol0003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX2o`0001_ooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000Kooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP03oook
JP04o`000?oonf[ooo]Zo`0000Cooo]Z0ol00002oookJP05o`000?oonf[ooo]ZoookJ_l000004ooo
nfX2o`0000cooo]Z00?o0000oookJ_oonfX00ooonfX01Ol0003ooo]Zo`000?oonf[o000000Wooo]Z
00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP05oookJP;o00000_oonfX00ol0003ooo]Z
o`000004oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Sooo]Z
00?o0000oookJ_oonfX00ooonfX3o`000003oookJ_l0003ooo]Z00gooo]Z00Ko0000oookJ_oonf[o
0000oookJ_l00004oookJP;o00006OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
00?ooo]Z0_l00006oookJP03o`000?oonf[o000000Wooo]Z00Go0000oookJ_oonf[ooo]Zo`00000=
oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00009oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000Wooo]Z00?o0000
oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00?o0000oookJ_l000001Ooo
nfX00ol0003ooo]ZoookJP02oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00000GoookJP03
o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX03ooonfX4o`0001Kooo]Z00Co0000oookJ_oo
nf[ooo]Z0_l00006oookJP;o00002?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP05
oookJP?o00001_oonfX00ol0003ooo]Zo`000006oookJP04o`000?oonf[o0000o`0000[ooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000Cooo]Z00?o
0000oookJ_l000003_oonfX1o`00000000?o0000oookJ_oonfX00_l0000:oookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`000005oookJP;o00001_oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02_oonfX0
1?l0003ooo]ZoookJ_l00007oookJP;o00001ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP04o`000?oo
nf[ooo]Zo`0000Sooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP04oookJP;o0000
1?oonfX01?l0003ooo]ZoookJ_l0000=oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l0
00002OoonfX01Ol0003ooo]ZoookJ_oonf[o000000[ooo]Z0_l00007oookJP03o`000?oonf[ooo]Z
00Cooo]Z0_l00004oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00000FoookJP04o`000?oo
nf[ooo]Zo`0001[ooo]Z00?o0000oookJ_oonfX01?oonfX2o`0001;ooo]Z00?o0000oookJ_oonfX0
1OoonfX2o`0000;ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000?ooo]Z00Ko0000oook
J_oonf[o0000oookJ_l0000>oookJP;o00002OoonfX00ol0003ooo]ZoookJP0>oookJP;o00001?oo
nfX01?l0003ooo]ZoookJ_l0000?oookJP03o`000?oonf[o000001Kooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
0_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX01OoonfX2o`0001Sooo]Z0Ol000000003o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00000CoookJP05o`000?oonf[ooo]ZoookJ_l0
00001ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l0000<oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Oooo]Z0_l0000<oookJPCo00001ooonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX02OoonfX2o`0000Kooo]Z00?o0000oookJ_l000001ooonfX01?l0
003ooo]ZoookJ_l00003oookJP;o00001OoonfX01?l0003ooo]ZoookJ_oonfX2o`0000[ooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP07oookJP;o00001OoonfX01?l0003ooo]Zo`00
0?l00006oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP04
o`000?oonf[ooo]Zo`0000[ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z00kooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP;o000000Cooo]Z
o`000?oonf[o00003?oonfX00ol0003ooo]ZoookJP0>oookJP;o000000?ooo]Zo`000?oonfX00ooo
nfX00ol0003ooo]ZoookJP0@oookJP;o00000ooonfX00ol0003ooo]Zo`00000;oookJP04o`000?oo
nf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]Zo`000005oookJP7o000000000ol0003ooo]Z
oookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP02oookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP08oookJP04o`00
0?oonf[ooo]Zo`0000Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_l000002OoonfX00ol0003ooo]Zo`00000;oookJP03
o`000?oonf[o000001Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0?oookJP04
o`000?oonf[o0000o`0000gooo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP05
oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX2o`0000Gooo]Z00Oo0000oookJ_oonf[ooo]Z
o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX03ooonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP06oookJP;o000000?ooo]Zo`00
0?oonfX01_oonfX2o`0000?ooo]Z0ol00008oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX00_oonfX01?l0003ooo]ZoookJ_l0000?oookJP03o`000?oonf[o000001?ooo]Z00Co0000
oookJ_oonf[o00002OoonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001?oonfX00ol0003o
oo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00004_oonfX00ol0
003ooo]ZoookJP02oookJP?o00001_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_l000004OoonfX00ol0003ooo]ZoookJP04oookJP;o00004ooonfX00ol0
003ooo]ZoookJP05oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00000:oookJP7o00000000
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z00Oo0000oookJ_oonf[ooo]Zo`00
0?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Cooo]Z00Ko0000oookJ_oonf[o
0000oookJ_l00004oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l00002oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP;o000000Cooo]Zo`00
0?oonf[o00000_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00Ko
0000oookJ_oonf[o0000oookJ_l00006oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00cooo]Z0_l00006oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00001_oonfX2o`00017ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP04oookJP;o00002_oonfX00ol0003ooo]ZoookJP02oook
JP05o`000?oonf[ooo]ZoookJ_l000002?oonfX4o`0000Cooo]Z0_l00003oookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02oookJP;o00002?oonfX0
0ol0003ooo]ZoookJP0<oookJP05o`000?oonf[o0000oookJ_l000003_oonfX00ol0003ooo]Zoook
JP05oookJP;o00000ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0
0005oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03ooonfX2o`0000Oooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000Kooo]Z0Ol0
00000003o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oo
nf[o0000017ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zo`00000:oookJP05o`000?oo
nf[ooo]ZoookJ_l000000_oonfX01?l0003ooo]ZoookJ_l0000>oookJP04o`000?oonf[ooo]Zo`00
00Sooo]Z00?o0000oookJ_oonfX01_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z01Sooo]Z0_l00006
oookJP03o`000?oonf[o000000gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03
oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX01?l0003ooo]ZoookJ_l0000?oookJP04o`00
0?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03?oonfX01Ol0003ooo]Zo`000?oonf[o0000
00Oooo]Z0_l0000@oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0_l00005oookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP08oookJP06o`000?oonf[o
oo]Zo`000?oonf[o00001ooonfX01?l0003ooo]ZoookJ_l0000GoookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX01OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z00;ooo]Z0_l00002oookJP03o`000?oonf[o000000_ooo]Z00?o
0000oookJ_oonfX01OoonfX01Ol0003ooo]Zo`000?oonf[o0000013ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o0000013ooo]Z0_l00005oookJP;o0000
0_oonfX00ol0003ooo]ZoookJP0DoookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00Co0000oookJ_oo
nf[o00003ooonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o000000Cooo]Zo`000?oonf[o0000
0ooonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l0
00000ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oo
nf[o00005ooonfX00ol0003ooo]ZoookJP0:oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Sooo]Z00Co0000oookJ_oonf[o00001Ooo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000002?oo
nfX00ol0003ooo]ZoookJP0<oookJP06o`000?oonf[ooo]Zo`000?oonf[o00003ooonfX2o`0000Oo
oo]Z0_l0000?oookJP;o00001_oonfX2o`000003oookJ_l0003o000000;ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX04?oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000005
oookJP7o000000000ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_l000001_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00Ko0000oook
J_oonf[o0000oookJ_l00007oookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Oooo]Z0_l0000;oookJP05o`000?oo
nf[ooo]ZoookJ_l000004ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00;o0000
1?oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP04oookJP04o`00
0?oonf[ooo]Zo`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000009oookJP03o`000?oonf[o0000
00Kooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z00gooo]Z00Go0000oookJ_oonf[ooo]Zo`00000:
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_l000004?oonfX01?l0003ooo]ZoookJ_l0
000;oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l000000ooonf[o0000oookJP05oookJP04o`000?oo
nf[ooo]Zo`0000Kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000BoookJP03o`000?oonf[o000000Co
oo]Z00?o0000oookJ_oonfX00_l0000@oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]Zo`000002oookJP05o`000?oonf[o0000oookJ_l000004ooonfX00ol0
003ooo]ZoookJP04oookJP7o000000001_l0003ooo]Zo`000?oonf[o0000oookJP;o00001_oonfX0
0ol0003ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX2
o`0001Cooo]Z0_l00003oookJP03o`000?oonf[ooo]Z017ooo]Z0_l0000AoookJP04o`000?oonf[o
oo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_oonfX3o`0001Sooo]Z
00?o0000oookJ_l000002_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o000000Oooo]Z
00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01?ooo]Z
00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_oonfX2o`0000kooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00005oookJP03
o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX02OoonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Sooo]Z0_l00002oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05_oonfX01?l0
003ooo]ZoookJ_l00008oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00001_oo
nfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`0000Wooo]Z00Go0000oookJ_l0003o
oo]Zo`000009oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Oo
oo]Z00Go0000oookJ_l0003ooo]Zo`00000=oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o000000Sooo]Z00Ko0000oook
J_oonf[o0000oookJ_l0000;oookJP03o`000?oonf[ooo]Z00;ooo]Z00Go0000oookJ_l0003ooo]Z
o`000006oookJP;o00001OoonfX1o`00007ooo]Z0Ol000000003o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX02ooonfX01?l0003ooo]ZoookJ_l00008oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`0000So
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Co
oo]Z0ol000000ooonf[o0000oookJP0?oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP0CoookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oook
J_oonfX01OoonfX3o`0000Sooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP09oook
JP;o00003ooonfX3o`00027ooo]Z0_l00004oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l00006oook
JP05o`000?oonf[ooo]ZoookJ_l000004?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP05oookJP05o`000?oonf[o
0000oookJ_l000002OoonfX3o`0000kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP03oookJP;o00001?oonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[o000000gooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_l000003?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_l000001_oonfX00ol0003ooo]Zo`000009oookJP03o`000?oonf[ooo]Z00oooo]Z
0_l0000:oookJP03o`000?oonf[ooo]Z01?ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Zoooo
nfXnoookJP7o000000000ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00gooo]Z00Go0000
oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX00_oo
nfX01?l0003ooo]ZoookJ_l0000:oookJP;o00001ooonfX00ol0003ooo]ZoookJP05oookJP04o`00
0?oonf[ooo]Zo`0000_ooo]Z00Co0000oookJ_oonf[o00002OoonfX00ol0003ooo]ZoookJP03oook
JP;o00004OoonfX00ol0003ooo]Zo`00000HoookJP03o`000?oonf[ooo]Z00gooo]Z00Co0000oook
J_oonf[o00000ooonfX01?l0003ooo]ZoookJ_l0000MoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_l000003?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX02_oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX00ooonfX01Ol0003ooo]Zoook
J_oonf[o000000Kooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`000003oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX01ol0003ooo]Zo`000?oonf[o0000oook
J_l000001_oonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00gooo]Z0_l0000<oook
JP03o`000?oonf[ooo]Z00Sooo]Z0_l00002oookJP;o00002_oonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00009
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP08
oookJP;o00001?oonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX06?oonfX1o`00000000?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP06o`000?oonf[o
oo]Zo`000?oonf[o00001ooonfX2o`0001;ooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Gooo]Z
00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[o0000oookJP;o
00001ooonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP03
o`000?oonf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP03o`000?oonf[o0000
00gooo]Z0_l00006oookJP05o`000?oonf[ooo]ZoookJ_l000003?oonfX00ol0003ooo]ZoookJP07
oookJP05o`000?oonf[o0000oookJ_l000003ooonfX00ol0003ooo]Zo`00000:oookJP;o00000_oo
nfX3o`0001Oooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000001ooo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?oo
nfX3o`0000Sooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000gooo]Z
00?o0000oookJ_l000002OoonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o0000oookJ_oo
nfX00ooonfX2o`0000Cooo]Z00?o0000oookJ_oonfX05_oonfX01?l0003ooo]ZoookJ_l0000Aoook
JP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_oonfX2
o`0000Cooo]Z00Co0000oookJ_oonf[ooo]Z0Ol000000003o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o0000023ooo]Z0_l00000
0ooonf[o0000oookJP0<oookJP03o`000?oonf[ooo]Z00?ooo]Z00Oo0000oookJ_oonf[ooo]Zo`00
0?oonf[o000000kooo]Z00Co0000oookJ_oonf[ooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00?o
oo]Z0_l00006oookJP03o`000?oonf[o000000Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00000;oook
JP;o00002OoonfX02_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonfX2o`0000;o
oo]Z0_l00003oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000005
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP04
oookJP04o`000?oonf[ooo]Zo`0000cooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX00_l000000ooonf[o0000oookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP;o00002_oonfX01Ol0003ooo]Zoook
J_oonf[o000000kooo]Z00Go0000oookJ_oonf[ooo]Zo`000009oookJP03o`000?oonf[ooo]Z00Go
oo]Z0_l0000QoookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[ooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP09oookJP05o`00
0?oonf[ooo]ZoookJ_l000003ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0DoookJP05o`000?oonf[ooo]Zoook
J_l000004?oonfX00ol0003ooo]ZoookJP0=oookJP;o000000?ooo]Zo`000?oonfX02OoonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP04oookJP;o00001?oonfX00ol0003ooo]ZoookJP0HoookJP04o`000?oonf[ooo]Z
o`0000Gooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000Sooo]Z0ol00004oookJP03o`000?oonf[o
oo]Z00?ooo]Z00Co0000oookJ_oonf[o00002?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[o000000;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02o`0000Gooo]Z0_l0
000:oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000006ooonfX00ol0003ooo]Zo`00
0003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00008oookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]Zo`000?l0000?oook
JP04o`000?oonf[ooo]Zo`0000?ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0000AoookJP03o`00
0?oonf[ooo]Z00cooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0FoookJP;o00001ooonfX00ol0003ooo]Zo`000003oookJP05o`00
0?oonf[ooo]ZoookJ_l000002_oonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z00Ko0000oookJ_oo
nf[o0000oookJ_l0000BoookJP7o000000000ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_l000005ooonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z
00;ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00_l0
000@oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03OoonfX2o`0000Cooo]Z00Co
0000oookJ_oonf[o00000ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000Sooo]Z
00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000go
oo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Go
oo]Z0_l000000ooonf[o0000oookJP09oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX06_oonfX00ol0003ooo]ZoookJP04oookJP?o00001?oonfX01?l0003ooo]ZoookJ_l00005oook
JP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0Joook
JP04o`000?oonf[o0000oookJP;o00001_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z00[ooo]Z00Co0000oookJ_oonf[o0000;OoonfX00ol0003ooo]ZoookJP04oookJP7o00000000
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX06_oonfX0
1Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00?o0000oookJ_oonfX02?oonfX01?l0003ooo]Zoook
J_l0000PoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Z
oookJP08oookJP;o000000?ooo]Zo`000?oonfX04?oonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Cooo]Z00Go0000oookJ_oonf[o
oo]Zo`000008oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01_oonfX4o`0000Go
oo]Z00?o0000oookJ_l000003_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`00
00Oooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00007oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX03_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l0
0004oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP02oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP0@oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP05o`000?oonf[ooo]ZoookJ_l000001ooo
nfX00ol0003ooo]ZoookJP0=oookJP?o000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJP03o`00
0?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z00Gooo]Z0ol00004oookJP04o`000?oonf[ooo]Zo`0000[ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000009oookJP;o00001OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o0000
00Gooo]Z00?o0000oookJ_l000001ooonfX2o`0000Oooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[o000000_ooo]Z00Co0000oookJ_oonf[o00001?oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_l000003OoonfX0
1?l0003ooo]ZoookJ_l0000:oookJP?o00002OoonfX00ol0003ooo]ZoookJP04oookJP05o`000?oo
nf[o0000oookJ_l000005_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Cooo]Z
0ol00008oookJP;o00006OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00gooo]Z
00Co0000oookJ_oonf[ooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000;oookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX02?oonfX01?l0003ooo]ZoookJ_l0000;oook
JP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX02ooonfX1o`00000000Co0000oookJ_oonf[o00005_oonfX0
0ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03_oonfX0
1?l0003ooo]ZoookJ_l00009oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00ooo
nfX2o`0000Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00007oookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000Ko
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0;oookJP06o`000?oonf[ooo]Zo`00
0?oonf[o00001?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_l000006_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000002OoonfX00ol0003o
oo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP04oookJP05o`000?oonf[o0000oookJ_l000001OoonfX01?l0003ooo]ZoookJ_l00003
oookJP03o`000?oonf[ooo]Z01;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000<oookJP05o`000?oo
nf[o0000oookJ_l000003_oonfX00ol0003ooo]ZoookJP02oookJP;o00002OoonfX00ol0003ooo]Z
oookJP08oookJP;o00003_oonfX1o`00000000Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000002ooonfX2o`0000Cooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
1?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z0_l00003oookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP07oookJP05o`000?oonf[o0000oook
J_l000002?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP04oookJP;o000000?ooo]Zo`000?oonfX00ooonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000002OoonfX00ol0003ooo]Zo`000008
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zo`00000B
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000004
oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000001?o
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP06oookJP;o000000?ooo]Zo`000?oo
nfX00_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o000000Wooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oo
nfX00_l00006oookJP;o00002_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00Wo
oo]Z0Ol000000003o`000?oonf[ooo]Z01;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000009oookJP03
o`000?oonf[ooo]Z00Gooo]Z0_l00006oookJP;o00000ooonfX00ol0003ooo]ZoookJP02oookJP04
o`000?oonf[ooo]ZoookJP;o00004?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00cooo]Z0_l00005oookJP05o`000?oonf[ooo]ZoookJ_l000003OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[o000001gooo]Z0_l0000boookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00000
0ooonf[o0000oookJP0IoookJP03o`000?oonf[ooo]Z01kooo]Z0_l0000;oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0CoookJP05o`000?oonf[o
oo]ZoookJ_l000001OoonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000Wooo]Z
00Go0000oookJ_oonf[ooo]Zo`00000;oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_l0
00001?oonfX01Ol0003ooo]ZoookJ_oonf[o000001[ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000:
oookJP05o`000?oonf[o0000oookJ_l000001?oonfX00ol0003ooo]Zo`000006oookJP03o`000?oo
nf[ooo]Z017ooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]Zo`000?oonf[o000000Wooo]Z
0_l00004oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000000_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z00Co0000oookJ_oonf[o00006_oonfX00ol0003o
oo]Zo`00000FoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP04oookJP05o`000?oonf[o0000oookJ_l000007_oonfX00ol0003ooo]ZoookJP0@oook
JP;o00002?oonfX00ol0003ooo]ZoookJP0<oookJP;o00004ooonfX00ol0003ooo]ZoookJP0Coook
JP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oo
nf[o000000Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]Zo`00000:oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`00000;oookJP03o`00
0?oonf[o000000Wooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_oonfX2o`0000;o
oo]Z00?o0000oookJ_l000004OoonfX00ol0003ooo]ZoookJP0;oookJP05o`000?oonf[ooo]Zoook
J_l000003ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00Co0000oookJ_oonf[ooo]Z0_l0
000CoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX05?oonfX2o`0000Sooo]Z0Ol0
00000003o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP06
oookJP04o`000?oonf[o0000o`0000Gooo]Z0_l00006oookJP;o00006_oonfX00ol0003ooo]Zoook
JP05oookJP04o`000?oonf[ooo]Zo`0000[ooo]Z00?o0000oookJ_l000002OoonfX2o`0000Sooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o000000Wooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_l000006OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Wooo]Z
00Co0000oookJ_oonf[o00003_oonfX2o`000003oookJ_l0003ooo]Z01Oooo]Z00?o0000oookJ_l0
00002?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_l0
00001ooonfX00ol0003ooo]ZoookJP0BoookJP04o`000?oonf[ooo]Zo`0000Sooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP06oookJPCo00002_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[o000000Cooo]Z0ol0000<oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000001?oonfX0
1ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001ooonfX00ol0003ooo]Zo`000002oookJP03o`00
0?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX01?oonfX1o`00000000?o0000oookJ_oonfX01_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000001Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP05oookJP;o000000?ooo]Zo`000?oonfX01?oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0FoookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX01Ol0003o
oo]ZoookJ_oonf[o000000Kooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00004
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02?oonfX01ol0003ooo]ZoookJ_oo
nf[o0000oookJ_l000003OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_l000006ooonfX01?l0003ooo]ZoookJ_l0000EoookJP03o`000?oonf[ooo]Z00;o
oo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`00017ooo]Z0_l00002
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP05
oookJP04o`000?oonf[ooo]Zo`0000Wooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP0;oookJP;o00000_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_l000001?oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol00000
0003o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00Kooo]Z00Go0000oookJ_l0003ooo]Zo`00000<oookJP04o`000?oonf[o
oo]Zo`0000Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[o000000Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[o000000Gooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX02?oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP08oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX01_l0003ooo]ZoookJ_l0003ooo]Z
o`0000oooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0000XoookJP05o`000?oonf[ooo]ZoookJ_l0
00004_oonfX3o`00017ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP09oookJP;o
00001_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX02?oonfX01?l0003ooo]ZoookJ_l0000UoookJP03o`000?oonf[ooo]Z00;o00001OoonfX01?l0
003ooo]ZoookJ_l00005oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX04OoonfX0
1Ol0003ooo]ZoookJ_oonf[o000000_ooo]Z0_l00007oookJP03o`000?oonf[o000001Cooo]Z00?o
0000oookJ_oonfX04_oonfX1o`00000000?o0000oookJ_oonfX03OoonfX01?l0003ooo]ZoookJ_l0
0005oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]Zoook
J_l00003oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX02_oonfX01?l0003ooo]Z
oookJ_oonfX3o`0000Kooo]Z00?o0000oookJ_oonfX01ooonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Gooo]Z00?o0000oookJ_l000003OoonfX01?l0003ooo]ZoookJ_l00009oookJP04o`000?oonf[o
oo]ZoookJP?o00001?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX04_oonfX01?l0003ooo]ZoookJ_l00007oookJP03o`000?oonf[o000000gooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP;o00001OoonfX00ol0003ooo]Z
oookJP0>oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000000ooonfX2o`0000?o
oo]Z00?o0000oookJ_oonfX03?oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000008ooonfX0
1Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP06oookJP;o00001OoonfX00ol0003ooo]ZoookJP0JoookJP;o00003ooonfX01?l0003ooo]Zoook
J_l0000ZoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00003oookJP04o`000?oonf[ooo]Zo`0000oo
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0?oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z0Ol000000006o`000?oonf[ooo]Zo`000?oonf[o00008?oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000Oooo]Z00Co0000oookJ_oonf[o00002OoonfX01Ol0003ooo]Zo`000?oonf[o000000[o
oo]Z00?o0000oookJ_oonfX00_l0000FoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX07?oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oo
nf[ooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Gooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oo
nf[o000000Kooo]Z0_l0000HoookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX00ooo
nfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000[ooo]Z00Co0000oookJ_oonf[o00003?oonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01_oonfX01?l0
003ooo]ZoookJ_l0000;oookJP03o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0005oookJP03o`000?oonf[ooo]Z00Wooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX01?l0003ooo]Z
oookJ_l00005oookJP04o`000?oonf[ooo]Zo`0000Sooo]Z00Co0000oookJ_oonf[o00000ooonfX0
0ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]Zo`00000AoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Sooo]Z0Ol000000003o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]Zo`00000?oookJP;o00004ooonfX00ol0
003ooo]ZoookJP06oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000009oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP03oookJP;o00003_oo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP09oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP05oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003o
oo]ZoookJP08oookJP;o000000?ooo]Zo`000?oonfX01_oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zo`000002o`0000[o
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]Zoook
J_l000002OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP0>oookJP;o00003ooonfX00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX08ooonfX1o`00000000?o0000oookJ_oo
nfX0oooonf[ooookJSkooo]Z0Ol000000005o`000?oonf[ooo]ZoookJ_l000002ooonfX00ol0003o
oo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`00013ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_l000003ooonfX3o`00
01;ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX01ooonfX2o`0000Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00007oookJP;o000000?ooo]Zo`00
0?oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP;o00001ooonfX01Ol0003ooo]ZoookJ_oonf[o
000000?ooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP09oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l000000ooonf[o0000oookJP0DoookJP03o`000?oo
nf[ooo]Z00;o00006_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0_l00006oookJP03o`00
0?oonf[ooo]Z00_ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000GoookJP03o`000?oonf[ooo]Z00;o
oo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00cooo]Z00Go0000oook
J_oonf[ooo]Zo`00000:oookJP03o`000?oonf[ooo]Z00Cooo]Z0Ol000000003o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o0000
00Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Gooo]Z00Co0000oookJ_oonf[o00002?oonfX00ol0003ooo]ZoookJP0:oookJP04o`000?oonf[o
oo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00008oookJP;o0000
3?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_l00000
0_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l00000
2OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[o
oo]Zo`000004oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]Zo`00000PoookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00004oookJP03o`000?oonf[o000000Ko
oo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX06?oonfX01?l0003o
oo]ZoookJ_l00008oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003ooo]ZoookJP05oookJP04o`000?oonf[ooo]Zo`0000_ooo]Z0_l0000>oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
000000;ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP04oookJP7o000000000ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]Zo`00000@oookJP03o`000?oonf[ooo]Z01Gooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP06oookJP;o00001OoonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02
o`0000_ooo]Z00?o0000oookJ_oonfX01ooonfX2o`0000cooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[o000000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`00
000;oookJP03o`000?oonf[ooo]Z01;ooo]Z00Co0000oookJ_oonf[o00001ooonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000003OoonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04ooonfX01Ol0003ooo]Z
oookJ_oonf[o000000Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00Cooo]Z0_l00005oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oo
nfX03?oonfX00ol0003ooo]Zo`000009oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oo
nf[o00004OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX03?oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000000_l0000?oookJP;o00001ooonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX06?oonfX01?l0003ooo]Z
o`000?l00004oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[o000000_ooo]Z00?o0000oookJ_l000001_oonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[o000000_ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0<oookJP04o`000?oonf[ooo]Zo`00
00Cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
00;ooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_l000001OoonfX01Ol0
003ooo]ZoookJ_oonf[o000000Oooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000kooo]Z00Go0000
oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP07oookJP7o000000000ol0003ooo]ZoookJP02oookJP04o`000?oonf[o
oo]Zo`0000;ooo]Z00?o0000oookJ_l000003_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00?ooo]Z0_l00004oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o0000
1ooonfX2o`0000Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP06oookJP05o`00
0?oonf[ooo]ZoookJ_l000002OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`00000AoookJP03o`000?oonf[o000001Co
oo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX07OoonfX01?l0003ooo]Zo`000?l0000<oookJP05o`000?oonf[ooo]Z
oookJ_l000005OoonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0001Wooo]Z0_l00003oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_l00007oookJP03o`000?oonf[ooo]Z00;ooo]Z
00Co0000oookJ_oonf[ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0?oookJP;o00001OoonfX00ol0003ooo]Zo`00000BoookJP06
o`000?oonf[ooo]Zo`000?oonf[o00002ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
000000Cooo]Z0Ol00001oookJP7o000000000ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000009oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0>oookJP;o00004?oonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05_oonfX2o`000003oookJ_l0003o
oo]Z00gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP06oookJP;o00001OoonfX0
0ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00001Ooo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03Ooo
nfX01?l0003ooo]ZoookJ_oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX01Ol0003ooo]Z
oookJ_oonf[o000000Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z00Cooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000cooo]Z00?o0000
oookJ_oonfX02?oonfX01Ol0003ooo]ZoookJ_oonf[o0000017ooo]Z00?o0000oookJ_oonfX01?oo
nfX01?l0003ooo]Zo`000?l0000BoookJP03o`000?oonf[ooo]Z00cooo]Z00Co0000oookJ_oonf[o
00005OoonfX00ol0003ooo]ZoookJP02o`0000Oooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oook
JP03o`000?oonf[ooo]Z00[ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000000ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;o00001ooonfX01?l0003ooo]Z
oookJ_l0000;oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02?oonfX3o`0000?o
oo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01_oonfX01?l0
003ooo]ZoookJ_l0000;oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03ooonfX0
1Ol0003ooo]ZoookJ_oonf[o000000kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX02ooonfX01?l0003ooo]Zo`00
0?l00009oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP02oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z0_l00007oookJP;o00000_oonfX00ol0003o
oo]ZoookJP0;oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z0Ol000000004o`000?oonf[ooo]Zoook
JP;o00002?oonfX01Ol0003ooo]Zo`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX03?oonfX0
1Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z00?o0000oookJ_oonfX06ooonfX01Ol0003ooo]Zoook
J_oonf[o000000Gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zo`000007oookJP;o0000
2ooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
3_oonfX01?l0003ooo]ZoookJ_l0000:oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l0
00004ooonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP0HoookJP?o00000ooonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z017ooo]Z00Co0000oookJ_oonf[o00002ooonfX00ol0003ooo]Zo`000006
oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00005oookJP7o000000000ol0003ooo]Zo`00000=oook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000003oook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0?oook
JP04o`000?oonf[ooo]Zo`0001;ooo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z00;o00000_oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_l000002_oonfX00ol0003ooo]ZoookJP0BoookJP06o`000?oonf[o
oo]Zo`000?oonf[o00001ooonfX2o`0000oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000003?oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00_ooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000
oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX02_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000008oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0<oookJP03
o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP7o
000000000ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0
3_oonfX01?l0003ooo]Zo`000?l00008oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000004
oookJP03o`000?oonf[o000001Cooo]Z0_l0000IoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_l000002?oonfX00ol0003ooo]Zo`00000@oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l0000=oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l0
0004oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zo`00
0002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02_oonfX2o`0000Oooo]Z00?o
0000oookJ_oonfX00ooonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z00Co0000oookJ_oonf[o
00002?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]ZoookJ_l000006?oonfX1o`00
000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000002;ooo]Z
00?o0000oookJ_oonfX01ooonfX01?l0003ooo]ZoookJ_l0000@oookJP03o`000?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`00000;oookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00oo
oo]Z0_l00009oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00008
oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Zo`00
000;oookJP03o`000?oonf[ooo]Z01Cooo]Z00Co0000oookJ_oonf[o00002?oonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP03oookJP06
o`000?oonf[ooo]Zo`000?oonf[o00002ooonfX01?l0003ooo]ZoookJ_oonfX1o`00000000?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP05oookJP;o00000_oonfX00ol0003ooo]Zo`00000^
oookJP03o`000?oonf[ooo]Z00Oooo]Z00Co0000oookJ_oonf[o00007ooonfX01Ol0003ooo]Zoook
J_oonf[o000000Gooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01ooonfX01?l0003ooo]ZoookJ_l00008oook
JP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00002?oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]ZoookJ_l0
000:oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_l00002oookJP;o00001ooonfX00ol0003ooo]Z
oookJP03oookJP04o`000?oonf[ooo]ZoookJP;o00001ooonfX01?l0003ooo]ZoookJ_l0000Coook
JP03o`000?oonf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0:oookJP04o`000?oonf[o
oo]ZoookJP;o00002OoonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000oooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0DoookJP04o`000?oonf[ooo]ZoookJP7o
000000000ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP09oookJP04o`000?oonf[ooo]Zo`0001[ooo]Z00Co0000oookJ_oo
nf[o00001OoonfX01?l0003ooo]Zo`000?l00003oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0?oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z013ooo]Z00?o
0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00Co0000oookJ_oonf[o
00001OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oo
nf[o00000_oonfX00ol0003ooo]ZoookJP0:oookJP;o00000ooonfX01?l0003ooo]ZoookJ_l0000K
oookJP05o`000?oonf[o0000oookJ_l000001OoonfX01Ol0003ooo]ZoookJ_oonf[o000001Gooo]Z
00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o000000gooo]Z
00?o0000oookJ_oonfX08OoonfX01Ol0003ooo]ZoookJ_oonf[o000000[ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z00Oo0000oookJ_oo
nf[ooo]Zo`000?oonf[o000000gooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoook
JP7o000000001?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[o000000Gooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o000000;ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o000000Gooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00;o00002?oonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0;oookJP05o`000?oonf[o0000oookJ_l000000_oonfX2o`0000Oooo]Z0_l0
0003oookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00002OoonfX00ol0003ooo]Zo`00000MoookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0=oookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zo`00000>oookJP03
o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[o00001OoonfX1o`00000000?o0000oookJ_l0
00001_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00002oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX01ooonfX01?l0003ooo]ZoookJ_l0000=oookJP05o`000?oonf[o
oo]ZoookJ_l000004?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX01?oonfX2o`0000Oooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00;ooo]Z00Go
0000oookJ_oonf[ooo]Zo`00000=oookJP03o`000?oonf[ooo]Z00;ooo]Z00Go0000oookJ_oonf[o
oo]Zo`000009oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]Zo`00000QoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003o
oo]ZoookJ_l0000<oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]Zo`000003oookJP05o`000?oonf[ooo]ZoookJ_l000008_oonfX2o`0000Cooo]Z00?o0000
oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_l00009oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX08OoonfX01?l0003ooo]ZoookJ_l00007oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX04_oonfX01?l0003ooo]Zoook
J_oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0MoookJP;o0000
3OoonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[ooo]Z01;ooo]Z00Co0000oookJ_oo
nf[o00005ooonfX00ol0003ooo]ZoookJP03oookJP0:o`000?oonf[ooo]Zo`000?oonf[o0000oook
J_l0003ooo]Zo`0002_ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0<oookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP03oookJP05
o`000?oonf[ooo]ZoookJ_l000002ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o000001Cooo]Z00?o0000
oookJ_oonfX03ooonfX3o`00017ooo]Z00Co0000oookJ_oonf[o00002?oonfX00ol0003ooo]Zoook
JP03oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX04_oonfX01?l0003ooo]Z
oookJ_oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z01Kooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000
00001Ol0003ooo]ZoookJ_oonf[o000000Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
o`00000<oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0<oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX01_oonfX2o`0002[ooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l0
00007?oonfX00ol0003ooo]ZoookJP0>oookJP05o`000?oonf[ooo]ZoookJ_l000005_oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[o000001Sooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l000000ooonf[o0000oookJP04oook
JP03o`000?oonf[ooo]Z01?ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000KoookJP04o`000?oonf[o
oo]Zo`0001[ooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[ooo]Z01Cooo]Z
00Co0000oookJ_oonf[o00001ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o000000go
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000009oookJP7o000000000ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01ooonfX01Ol0003ooo]Z
oookJ_oonf[o000000Gooo]Z00?o0000oookJ_l000003OoonfX2o`0001gooo]Z0_l00003oookJP05
o`000?oonf[ooo]ZoookJ_l000000_oonfX01?l0003ooo]ZoookJ_l0000;oookJP05o`000?oonf[o
oo]ZoookJ_l000007_oonfX00ol0003ooo]ZoookJP02oookJP;o00000_oonfX2o`0001Gooo]Z00?o
0000oookJ_oonfX08OoonfX01Ol0003ooo]ZoookJ_oonf[o0000017ooo]Z00Go0000oookJ_oonf[o
oo]Zo`00000=oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP02o`0000Sooo]Z00?o0000oookJ_oonfX02_oonfX01?l0003ooo]ZoookJ_l0000Noook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`00000Ioook
JP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000Gooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Zo`000003oookJP;o0000
0_oonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000Sooo]Z00?o0000oookJ_oo
nfX04_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z013ooo]Z0_l0000YoookJP;o
00002_oonfX1o`00000000?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]ZoookJ_oonfX2o`0000Co
oo]Z0_l00006oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z017ooo]Z00Go0000oookJ_l0003ooo]Zo`00000P
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0S
oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_l000005?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000
oookJ_oonf[o00001?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP02oookJP7o000000000ol0003ooo]ZoookJP04
oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00_ooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00009oookJP05o`000?oonf[ooo]ZoookJ_l0
00001_oonfX00ol0003ooo]Zo`00000;oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX00_oonfX2o`0000kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0AoookJP03
o`000?oonf[ooo]Z02?ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000@oookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01OoonfX2o`0001Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01Kooo]Z0Ol000000003o`000?oonf[ooo]Z0?oo
oo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP0PoookJP05o`000?oonf[ooo]ZoookJ_l0
00001?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX01Ol0003ooo]ZoookJ_oonf[o000000gooo]Z0_l000000ooonf[o0000oookJP09oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00cooo]Z00Co0000oookJ_oonf[o00004?oonfX00ol0003ooo]ZoookJP0:
oookJP;o00003OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000
oookJ_oonf[o00002OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX06_oonfX00ol0003ooo]Zo`00000BoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX01_oonfX2o`0000oooo]Z00?o0000oookJ_oonfX00ooonfX01Ol0003ooo]Zoook
J_oonf[o000000_ooo]Z00?o0000oookJ_oonfX03?oonfX2o`0000Kooo]Z0_l00003oookJP05o`00
0?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?o
oo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP06oookJP7o000000000ol0003o
oo]ZoookJP02o`0000?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP02oookJP05
o`000?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
013ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP07oookJP;o00004OoonfX01?l0003ooo]ZoookJ_l0
000HoookJP03o`000?oonf[ooo]Z00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0?oookJP05o`00
0?oonf[ooo]ZoookJ_l000003?oonfX00ol0003ooo]Zo`00000<oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0:oookJP;o00004OoonfX00ol0003o
oo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP02o`00017ooo]Z00Co0000oookJ_oonf[o00002OoonfX00ol0003ooo]ZoookJP06
oookJP;o00001ooonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX00Ol0
00000003o`000?oonf[ooo]Z00Wooo]Z0_l00005oookJP03o`000?oonf[o000000Wooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX01OoonfX2o`0000Wooo]Z00Go0000oookJ_oonf[ooo]Zo`00000noookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02_oonfX01Ol0003ooo]ZoookJ_oonf[o000000[ooo]Z
00?o0000oookJ_oonfX00ooonfX01Ol0003ooo]ZoookJ_oonf[o000001cooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oo
nf[o00001_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000?ooo]Z00?o0000oook
J_oonfX02_oonfX00ol0003ooo]Zo`00000;oookJP03o`000?oonf[ooo]Z01?ooo]Z00Co0000oook
J_oonf[ooo]Z0_l00003oookJP05o`000?oonf[ooo]ZoookJ_l000004_oonfX01?l0003ooo]Zoook
J_l0000PoookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX01?l0003ooo]ZoookJ_l00002oook
JP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP01
o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Go
oo]Z0_l0000IoookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]ZoookJP03oook
JP;o00000_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000<oook
JP;o00001?oonfX01?l0003ooo]ZoookJ_l0000=oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l00008
oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00kooo]Z0_l00002
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000<oookJP05o`000?oo
nf[ooo]ZoookJ_l000003?oonfX00ol0003ooo]ZoookJP0EoookJP05o`000?oonf[ooo]ZoookJ_l0
00002OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0FoookJP;o00003ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Sooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP;o00003ooonfX01?l0
003ooo]ZoookJ_l00004oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l000000ooonf[o0000oookJP08
oookJP;o00004?oonfX00ol0003ooo]ZoookJP0YoookJP7o00000OoonfX1o`00000000?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX05_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04?oonfX2
o`0000?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX06ooonfX01?l0003ooo]ZoookJ_l0000AoookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?oonfX2o`0001Wooo]Z0_l00009oookJP03o`000?oo
nf[ooo]Z00;o00001?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00kooo]Z0_l0
000FoookJP03o`000?oonf[ooo]Z00Gooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]Z
oookJP0<oookJP04o`000?oonf[ooo]Zo`0000gooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX04?oonfX01?l0003o
oo]ZoookJ_l0000:oookJP7o000000000ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o000000Ko
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0GoookJP05o`000?oonf[ooo]Zoook
J_l000003OoonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]ZoookJP;o00001?oonfX0
1?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX02?oo
nfX01Ol0003ooo]ZoookJ_oonf[o000001;ooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Sooo]Z
0ol00008oookJP04o`000?oonf[ooo]Zo`0001Gooo]Z00?o0000oookJ_oonfX02?oonfX01?l0003o
oo]ZoookJ_oonfX2o`0001Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z01Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX01ooonfX2o`0001Gooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
01Oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_l00006oookJP;o00001OoonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP0CoookJP;o00002ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z00Oooo]Z0_l00005oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX03ooonfX2
o`0000?ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP03oookJP;o00002_oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04ooonfX0
1Ol0003ooo]ZoookJ_oonf[o000000Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP05oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP;o00001ooonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z013ooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00Oooo]Z00Co0000oookJ_l0003o00002_oonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00;o00004?oonfX01?l0003ooo]ZoookJ_l0000CoookJP03o`000?oonf[ooo]Z
00Oooo]Z0Ol000000003o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Sooo]Z00Co0000oookJ_oonf[o0000:?oonfX00ol0
003ooo]ZoookJP02o`0000Sooo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0003ooo]ZoookJP0F
oookJP04o`000?oonf[ooo]Zo`0000gooo]Z0_l000000ooonf[o0000oookJP0<oookJP05o`000?oo
nf[ooo]ZoookJ_l000005ooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX02_oonfX01?l0003ooo]ZoookJ_l0000GoookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o000000So
oo]Z00?o0000oookJ_oonfX01ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z0Ol000000003
o`000?oonf[ooo]Z017ooo]Z0_l00009oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0MoookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000004
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00Gooo]Z00Co0000oookJ_oonf[o00000_oonfX01Ol0003ooo]Zoook
J_oonf[o000000Sooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z00Cooo]Z0_l0000>oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]ZoookJP?o00000_oonfX01Ol0003o
oo]ZoookJ_oonf[o000000Wooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`00000;oook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04?oonfX1o`00000000?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP07oookJP04o`000?oonf[ooo]Zo`0000oooo]Z0ol0000;oook
JP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX01ooonfX01Ol0003ooo]ZoookJ_oonf[o
000000Sooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0MoookJP05o`000?oonf[ooo]ZoookJ_l00000
1ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l00008oookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`00000:oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000@oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z00?ooo]Z0_l0000BoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000BoookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX02_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nf[ooookJSkooo]Z0Ol000000005o`000?oonf[ooo]ZoookJ_l000003OoonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zo`00
0005oookJP03o`000?oonf[ooo]Z01?ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000RoookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0<oookJP04o`00
0?oonf[ooo]Zo`0000kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP04oookJP;o
00002?oonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]Zo`000003oookJP06o`000?oonf[ooo]Zo`000?oonf[o0000:ooonfX0
0ol0003ooo]ZoookJP05oookJP;o00002?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP09oookJP?o0000=?oonfX01Ol0003ooo]Zoook
J_oonf[o000000cooo]Z00?o0000oookJ_oonfX00ooonfX2o`0001Gooo]Z0Ol000000003o`000?oo
nf[o000000Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oo
nf[ooo]ZoookJ_l000001OoonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o000000Go
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Go
oo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o000003Cooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00008oook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX02OoonfX01?l0003ooo]ZoookJ_l0000A
oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00?o0000oookJ_oonfX07OoonfX1o`00000000?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_l000001_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX02OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0=
oookJP03o`000?oonf[ooo]Z017ooo]Z00Wo0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJ_l0
00004OoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0000KoookJP03
o`000?oonf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00000DoookJP;o00004_oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Gooo]Z00Co0000oookJ_oonf[o00003_oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0007oookJP;o00000ooonfX00ol0003ooo]ZoookJP07oookJP05o`000?oonf[ooo]ZoookJ_l00000
7_oonfX2o`0000oooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX00ooonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z00;o00003ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00Oooo]Z0_l00007oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX06?oo
nfX2o`0000Kooo]Z0_l00008oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z02[ooo]Z00Go0000oookJ_oonf[ooo]Z
o`000007oookJP03o`000?oonf[o000002Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
o`000002oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_l000005OoonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00004ooonfX00ol0003o
oo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000000ooonfX01Ol0003o
oo]ZoookJ_oonf[o000000Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX05?oonfX01?l0003ooo]ZoookJ_l00002
oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<
oookJP7o000000000ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000oook
J_oonf[ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]Zo`00000_oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00Co0000oookJ_oonf[o0000
5?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]Zo`00000FoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP08oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z00?o0000oookJ_oo
nfX00ooonfX01Ol0003ooo]ZoookJ_oonf[o000001Sooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_l000002ooonfX0
1?l0003ooo]ZoookJ_l00003oookJP;o00004OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z00Oooo]Z0_l00003oookJP7o000000000ol0003ooo]ZoookJP07oookJP04o`000?oonf[o
oo]Zo`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00_l00004oookJP05o`000?oonf[ooo]ZoookJ_l00000
8ooonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000002OoonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Wooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Wooo]Z0_l00008oook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0?oook
JP03o`000?oonf[ooo]Z00Sooo]Z0_l00004oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l00003oook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04_oonfX01Ol0003ooo]ZoookJ_oonf[o
000000?ooo]Z0_l0000>oookJP04o`000?oonf[ooo]Zo`0001Kooo]Z0_l000000ooonf[o0000oook
JP07oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]Zoook
J_oonfX1o`00000000?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z
00?o0000oookJ_oonfX05OoonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z0_l0000?oookJP04
o`000?oonf[ooo]Zo`0001Gooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP0?oook
JP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0_l00006oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000gooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
1_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`00023ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP0:oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_l000003ooonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z02kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000=oookJP03o`000?oo
nf[ooo]Z00Oooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zo`00000:
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP04
oookJP;o00002?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o
0000oookJ_oonfX02?oonfX01?l0003ooo]ZoookJ_l00007oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX03_oonfX01?l0003ooo]ZoookJ_l0000ZoookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Ko
oo]Z0ol0000=oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00007OoonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX01OoonfX2o`00
01kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX00ooonfX1o`00000000?o0000oookJ_l000006_oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z02Wooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP;o00001OoonfX00ol0
003ooo]ZoookJP05oookJP04o`000?oonf[ooo]ZoookJP;o00001?oonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z01Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00000JoookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX05OoonfX2o`0000;ooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[o0000
0ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l0000hoookJP05o`00
0?oonf[ooo]ZoookJ_l000008ooonfX00ol0003ooo]Zo`00000>oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o000000Oo
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00;o
oo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z01Sooo]Z0_l00006oook
JP05o`000?oonf[o0000oookJ_l000004?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX01?oonfX2o`00
00oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJP;o00000_oonfX00ol0
003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00?o0000oookJ_oonfX01?oonfX2
o`0000Sooo]Z00Go0000oookJ_l0003ooo]Zo`00000GoookJP;o00003_oonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z01Cooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXn
oookJP7o000000001Ol0003ooo]ZoookJ_oonf[o000001Oooo]Z00?o0000oookJ_oonfX02?oonfX0
1Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_l000001?oonfX01?l0003ooo]Zoook
J_l0000[oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000008oookJP;o00003OoonfX00ol0
003ooo]Zo`00000:oookJP05o`000?oonf[ooo]ZoookJ_l000004OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Sooo]Z0_l0000S
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX05OoonfX01?l0003ooo]ZoookJ_l0
0005oookJP03o`000?oonf[ooo]Z00oooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Kooo]Z00Go
0000oookJ_oonf[ooo]Zo`000004oookJP05o`000?oonf[ooo]ZoookJ_l000004?oonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX00ooonfX01_l0003o
oo]ZoookJ_oonf[o0000oookJP7o000000001?l0003ooo]ZoookJ_l0000koookJP04o`000?oonf[o
0000o`0000Kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zo`00000BoookJP03o`000?oo
nf[o000000gooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP0EoookJP05o`000?oo
nf[ooo]ZoookJ_l00000;?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o000000Sooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Wooo]Z
0ol00008oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04OoonfX2o`0000gooo]Z00Go0000oookJ_l0
003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX05_oonfX01?l0
003ooo]Zo`000?l0000ToookJP7o000000001Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0;oookJP04o`000?oonf[ooo]Zo`0000oooo]Z00Go
0000oookJ_oonf[ooo]Zo`000004oookJP04o`000?oonf[ooo]Zo`0000gooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000Sooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l0000Doook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o
000000Cooo]Z0_l0000UoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP03oookJP;o00002?oonfX00ol0003ooo]ZoookJP06oookJP05o`000?oonf[o
oo]ZoookJ_l000007_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX02?oonfX01?l0003ooo]ZoookJ_l0000?oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX04?oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol0
00000003o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_l0
000>oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0?oookJP05o`000?oonf[ooo]ZoookJ_l000002_oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[o000001;ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0CoookJP04o`00
0?oonf[ooo]ZoookJP?o000000?ooo]Zo`000?oonfX01ooonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z00;o00000ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Oo
oo]Z0_l0000AoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP06oookJP05o`000?oonf[ooo]ZoookJ_l000007_oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Go
oo]Z00Co0000oookJ_oonf[o00008OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX06ooonfX01Ol0003ooo]ZoookJ_oonf[o000001;ooo]Z00Co0000
oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0:oookJP05o`000?oonf[ooo]ZoookJ_l00000
1?oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0NoookJP05o`00
0?oonf[ooo]ZoookJ_l000001OoonfX2o`0001;ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP0DoookJP;o00004OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX02_oonfX2o`000003oookJ_l0003ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX00ooonfX2o`0000Oooo]Z00Co0000oookJ_oonf[o00000_oonfX1o`00000000?o0000oookJ_oo
nfX01_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00007oookJP03o`000?oonf[ooo]Z
00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000008oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000
oookJ_oonf[o00001ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o0000013ooo]Z00?o
0000oookJ_oonfX01OoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z01?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z027ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000@oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX00ooonfX1o`00000000?o0000oookJ_oonfX01_oonfX01?l0003ooo]Z
o`000?l00004oookJP03o`000?oonf[o000000Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00kooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000;
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP0?
oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Wooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX04?oonfX3o`0003cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000008oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]Zo`000?l0000BoookJP03
o`000?oonf[ooo]Z01kooo]Z00Co0000oookJ_oonf[o00003ooonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z02;ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000001Ol0003ooo]ZoookJ_oonf[o000004Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP05oookJP04o`000?oonf[ooo]Zo`0001Oooo]Z00?o0000oookJ_l000000_oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_l000002?oonfX00ol0
003ooo]ZoookJP1<oookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX2o`0000?ooo]Z00?o0000
oookJ_oonfX0:_oonfX01Ol0003ooo]ZoookJ_oonf[o0000037ooo]Z00?o0000oookJ_oonfX02?oo
nfX2o`0000gooo]Z00?o0000oookJ_oonfX01_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z
00?o0000oookJ_oonfX05ooonfX2o`00017ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[o000000Cooo]Z00Co0000oookJ_l0003ooo]Z0_l00007oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX1o`00000000?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP06oookJP;o000000?ooo]Zo`000?l000001?oonfX01Ol0003ooo]Z
oookJ_oonf[o000000oooo]Z00?o0000oookJ_oonfX03OoonfX01Ol0003ooo]ZoookJ_oonf[o0000
01Kooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
000001_ooo]Z00?o0000oookJ_oonfX02ooonfX2o`000003oookJ_l0003ooo]Z00gooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0>oookJP04o`000?oonf[ooo]Zo`00017ooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co
0000oookJ_oonf[o00003?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000oooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP04oookJP;o00007?oonfX1o`00000000Go
0000oookJ_oonf[ooo]Zo`000006oookJP;o00001OoonfX00ol0003ooo]ZoookJP05oookJP;o0000
4?oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0<oookJP04o`00
0?oonf[o0000o`0000?ooo]Z00?o0000oookJ_l000008OoonfX01Ol0003ooo]ZoookJ_oonf[o0000
00gooo]Z0_l0000;oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02?oonfX2o`00
02?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP;o00004_oonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Oooo]Z0_l0000AoookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP0@oookJP;o00004_oonfX00ol0
003ooo]ZoookJP04oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z0_l000000ooonf[o0000oookJP0;
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_l000007?oonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX00ooonfX2o`000003oookJ_l0003o
oo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z00Kooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00Sooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]ZoooonfXnoookJP7o000000001?l0003ooo]ZoookJ_l0000HoookJP03o`000?oonf[o0000
00Gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
03_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX02ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o0000
oookJ_oonfX01_oonfX2o`0001Sooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0K
oookJP04o`000?oonf[ooo]ZoookJP;o00006ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo
nf[ooo]Z01Oooo]Z0_l0000=oookJP7o000000000ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
0000013ooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00002Ooo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00_l0
000>oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zo`00
0006oookJP04o`000?oonf[ooo]Zo`0002;ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000IoookJP03
o`000?oonf[ooo]Z02Kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000AoookJP03o`000?oonf[ooo]Z
01Cooo]Z0_l00002oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP02oookJP;o00006OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX01_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001ooo
nfX00ol0003ooo]ZoookJP02oookJP7o000000000ol0003ooo]Zo`000009oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX00_l0000QoookJP;o0000:_oonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00009oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000
oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o000000Oooo]Z00?o
0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0?oookJP;o000000?ooo]Zo`000?l000002?oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o000000Wooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z017ooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o0000
01Sooo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_l000008OoonfX00ol0003ooo]ZoookJP0:oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Z
o`00000KoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX06?oonfX2o`0000Oooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o000001_ooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX05ooonfX1o`00007ooo]Z0Ol000000003o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000001;ooo]Z00?o0000oookJ_oonfX0
8?oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX04?oonfX01?l0003ooo]ZoookJ_l0000HoookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o0000
017ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
00kooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
000000oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00000=oookJP;o00000ooonfX1o`00000000?o0000
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Oooo]Z00Co0000
oookJ_oonf[o0000:ooonfX00ol0003ooo]ZoookJP04oookJP;o00001OoonfX2o`0001Cooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0;oookJP;o00002OoonfX00ol0003ooo]Zo`00
0005oookJP03o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03_oonfX2o`0000Sooo]Z00?o
0000oookJ_l000004?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o
0000oookJ_oonfX01ooonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oonf[o000002Wooo]Z
00Go0000oookJ_oonf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z02Sooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX04?oonfX01?l0
003ooo]ZoookJ_oonfX1o`00000000?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0Foook
JP;o00004ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJPCo00006_oonfX00ol0003ooo]ZoookJP0Moook
JP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[o
oo]Zo`0000Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX07ooonfX01?l0003ooo]ZoookJ_l00006oookJP03o`00
0?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o000000So
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0HoookJP05o`000?oonf[ooo]Zoook
J_l000004_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000004o`00
0?oonf[ooo]Zo`00017ooo]Z00?o0000oookJ_oonfX01OoonfX2o`0001oooo]Z00Co0000oookJ_l0
003o00006OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o000000Sooo]Z00?o0000oook
J_oonfX00ooonfX01Ol0003ooo]ZoookJ_oonf[o000001Oooo]Z00?o0000oookJ_oonfX05ooonfX0
1?l0003ooo]ZoookJ_l0000QoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003ooo]ZoookJP04oookJP04o`000?oonf[ooo]Zo`0000gooo]Z00?o0000oookJ_oonfX0
1_oonfX01?l0003ooo]ZoookJ_l00008oookJP03o`000?oonf[ooo]Z00gooo]Z0_l00007oookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0AoookJP03
o`000?oonf[o000000Gooo]Z0_l00009oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP0AoookJP;o00002_oonfX1o`00000000?o0000oookJ_l00000
4_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o
00005ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_l0
00006_oonfX2o`00023ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l0000?oook
JP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX04?oonfX1o`00000000?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX03?oonfX2o`0001Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX06?oonfX01?l0003ooo]ZoookJ_l0000Ooook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP03oook
JP04o`000?oonf[ooo]Zo`00017ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01ooonfX01?l0003ooo]Zo`000?l0
000>oookJP03o`000?oonf[o000000oooo]Z00?o0000oookJ_oonfX05ooonfX2o`0000Wooo]Z00?o
0000oookJ_oonfX05OoonfX2o`0001Wooo]Z0_l0000<oookJP7o000000000ol0003ooo]ZoookJP3o
oookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0Aoook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_l000006?oonfX2o`0000Oooo]Z00Co0000oook
J_oonf[o00001?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000
oookJ_oonf[o00003_oonfX2o`0001?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX03?oonfX01?l0003ooo]Zoook
J_l00006oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00002?oonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l00001oookJP7o000000000ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX00ooonfX2o`0001[ooo]Z
00?o0000oookJ_oonfX03_oonfX2o`0000Oooo]Z00?o0000oookJ_l000005ooonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z00cooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP05oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00Co0000oookJ_oonf[o00001ooonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX02?oonfX1
o`00000000?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`00000AoookJP;o00001OoonfX01?l0
003ooo]ZoookJ_l0000FoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0AoookJP;o00008_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000008oookJP03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z01;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z02[ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_l000001?oonfX2
o`0000Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX05ooonfX01?l0003ooo]Zo`000?l00007oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03?oonfX01?l0003ooo]ZoookJ_l00006oookJP03o`00
0?oonf[o000000Oooo]Z0_l0000@oookJP;o00001ooonfX2o`00007ooo]Z0Ol000000004o`000?oo
nf[ooo]Zo`0000kooo]Z0ol00006oookJP04o`000?oonf[ooo]Zo`00017ooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oo
nfX03ooonfX2o`0000kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0QoookJP04
o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[o000002_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[o000000oooo]Z00?o0000oookJ_l000001ooonfX2o`0000kooo]Z00?o0000oook
J_oonfX00_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[o000001Sooo]Z0_l00008oookJP;o00004OoonfX00ol0003ooo]ZoookJP02oookJP05o`00
0?oonf[o0000oookJ_l000005ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o000000Go
oo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_l000003_oonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000Oo
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0?oookJP04o`000?oonf[ooo]Zo`00
00Cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP;o00001ooonfX00ol0
003ooo]ZoookJP0;oookJP7o000000000ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0FoookJP;o00002?oonfX2o`0000Co
oo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Gooo]Z00Co0000oookJ_oonf[o00006?oonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_l00000;OoonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX08?oonfX01?l0
003ooo]ZoookJ_l0000IoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z017ooo]Z0Ol00001oookJP7o000000000ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Kooo]Z00Co0000oookJ_oonf[o0000C?oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02cooo]Z0_l0000boookJP;o00002OoonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0GoookJP;o00001OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zo`00000QoookJP?o00001_oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[o000001Sooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0<oookJP05o`000?oonf[ooo]Zo`000?oonfX00Ol000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
02?ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Kooo]Z00Co0000oookJ_oonf[o0000:OoonfX0
0ol0003ooo]Zo`00000coookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP06oookJP;o00001_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00Oooo]Z00?o0000oookJ_l000001OoonfX01?l0003ooo]ZoookJ_l00004oookJP04o`000?oo
nf[ooo]Zo`00027ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0@oookJP;o0000
4?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o000003Kooo]Z0Ol000000004o`000?oo
nf[ooo]Zo`0002Sooo]Z00?o0000oookJ_l00000=_oonfX00ol0003ooo]ZoookJP03oookJP;o0000
00?ooo]Zo`000?oonfX05_oonfX2o`0001Sooo]Z0_l000000ooonf[o0000oookJP04oookJP;o0000
2OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
1ooonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00003ooonfX00ol0003ooo]Zo`000005oookJP;o
00004?oonfX00ol0003ooo]ZoookJP0>oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00Co0000oook
J_oonf[o0000J_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX02_oonfX1o`00000000?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP0Ooook
JP05o`000?oonf[ooo]ZoookJ_l000001_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX05ooonfX2o`00017ooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol00005oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_l000004OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00cooo]Z00?o0000oookJ_l00000:ooonfX2o`0000Sooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01cooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00oo
oo]Z00Co0000oookJ_oonf[o0000:?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX03ooonfX01?l0003ooo]ZoookJ_l00007oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`00000PoookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX2o`0000Oooo]Z0_l0000/oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00Cooo]Z00Co0000oookJ_l0003o0000:_oonfX00ol0003ooo]ZoookJP0=oookJP04o`000?oo
nf[o0000o`0000Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP07oookJP;o0000
8?oonfX00ol0003ooo]ZoookJP07oookJP04o`000?oonf[ooo]ZoookJP7o000000000ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000;ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o0000013ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX01_oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP0>oookJP;o00001ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_l000003_oonfX00ol0003ooo]Zo`000009oookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_oonfX1o`00000000Co0000oookJ_oonf[o
00001ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX03_oonfX3o`0002Wooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00005oookJP;o
00001ooonfX00ol0003ooo]ZoookJP0GoookJP;o00002_oonfX00ol0003ooo]ZoookJP0=oookJP03
o`000?oonf[ooo]Z03_ooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z02[ooo]Z0_l0000@oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000005oookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP02oookJP7o
000000000ol0003ooo]Zo`000009oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0=oookJP?o00001_oonfX00ol0003ooo]Zo`000005oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0001Oooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]Zo`00000XoookJP;o00004OoonfX2o`00017ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP04oookJP;o00002OoonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]Zo`00000?oookJP03o`000?oonf[o0000017ooo]Z00?o0000oookJ_oonfX05_oonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP0=oookJP;o00003ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o
oo]Z00Gooo]Z0_l0000@oookJP;o00006OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_l000006?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z01_ooo]Z00?o0000oookJ_oonfX05OoonfX2o`0000Oooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_l000001ooonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z007o000000001?l0003ooo]ZoookJ_l0000H
oookJP;o00002?oonfX00ol0003ooo]ZoookJP0PoookJP;o00002?oonfX00ol0003ooo]ZoookJP03
oookJP;o00002OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0>oookJP;o00002?oonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0F
oookJP;o00006ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o000000oooo]Z0_l0000@
oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l000000_oonfX1o`00000000Co0000oook
J_oonf[o00001_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_l000008ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o000000Sooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00008
oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`00000?
oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX05ooonfX2o`0000Kooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX01?oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04OoonfX1o`00000000?o0000oook
J_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000006oookJP?o
00004OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l0
0000<_oonfX2o`0001Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zo`000006oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z00_ooo]Z0Ol000000003o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o
00001_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX01OoonfX3o`0001[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0=oookJP;o
00006_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX01_oonfX2o`00027ooo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Oooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_oo
nfX04_oonfX1o`00000000?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[o0000027ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
0ooonfX01?l0003ooo]Zo`000?l0000?oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP07oookJP;o00001_oonfX00ol0003ooo]Zo`00000?oookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000Kooo]Z00?o0000oookJ_l0
0000:ooonfX00ol0003ooo]ZoookJP0KoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z
?_oonfX1o`00000000?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0>oookJP;o00004?oo
nfX00ol0003ooo]ZoookJP0GoookJP?o00004?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z01Sooo]Z0_l0000AoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]Zo`00000QoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0??oo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_l000001_oo
nfX2o`0000_ooo]Z0Ol000000003o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP05oookJP;o00001ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z02Wooo]Z0_l0000@oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_l000001ooonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX05_oonfX0
0ol0003ooo]ZoookJP07oookJP;o00002?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z00Gooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]ZoookJP7o000000000ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06
oookJP;o00002?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000
oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_l000001_oonfX2o`0001Wooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000HoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX06?oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0<OoonfX2o`0000;ooo]Z0Ol00000
0003o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP05oook
JP;o00002?oonfX00ol0003ooo]ZoookJP05oookJP;o00001_oonfX2o`0002?ooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP06oookJP;o00004OoonfX00ol0003ooo]ZoookJP0?oook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0?oook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP06oook
JP;o00001ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP01o`00000000?o0000oookJ_oonfX0oooonf[ooookJSko
oo]Z0Ol000000003o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0000noookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP;o00008ooonfX00ol0003ooo]Z
oookJP0FoookJP;o00004OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX01_oonfX2o`0001Sooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Gooo]Z
0_l00007oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX05ooonfX2o`0000_ooo]Z
0Ol000000003o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX2o`0000oooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0
0008oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l0000RoookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0
0007oookJP;o00001ooonfX2o`0002[ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP0RoookJP03o`000?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z01Sooo]Z0_l0000AoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01_oonfX2
o`0002;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000001ooonfX0
0ol0003ooo]ZoookJP0PoookJP;o00008_oonfX00ol0003ooo]ZoookJP0HoookJP;o00001_oonfX0
0ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX04_oonfX1
o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o000000So
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00ko
oo]Z0_l0000AoookJP03o`000?oonf[ooo]Z02Wooo]Z0_l0000@oookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z023o
oo]Z0_l00008oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[ooo]Z0Ol000000003
o`000?oonf[o000003Cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0PoookJP04
o`000?oonf[ooo]ZoookJP7o000000000ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX02_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000003oo`000?oo0000@_l00000
0001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.0256409, -0.0250052, \
0.00182832, 0.00295828}},
  ImageSoundCache->{{{0, 575}, {354.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000100200000000000000000l002J]<cP
koWnoOO[f/F^TgQNAC0M40L41PhK;D9JLXbT^loOj_7bk^GHak>LQFiHA3<V7ATI
7RLdA5M[Oi>V]/C>eMOEd<Nk[If<O6]LD4Hn>SXl@TYDGfaiQI6KY:Z_/;2]ZJ:J
TXZ2NW=]J6ETI6EXJfmcN7aoPXB5QXF4Ph:0OgimOGioPXB7RhjATiBDTi6=R89l
MFiWH5]GEEEFFV1XLWb7TinY/[Vm_kji/jVMSh1`H595>S8];C0g@DiNL8>GZ[_:
e]kRhMcCa[BQRgENBCHV6Q8?4QTU=DUPN96Y`=CTl?Oim>_LbK>JP6I<=B4B1`42
1a<S>51ZQJ2id>?bnoomm^SG`JR>LeQ0:aT<1@863ad`AEigTJ[1e>C^mOC_i]O5
/9R0JE8n;B4H51HL9SA6FFj4V:^lb]CJg=WCbKb/VhUgIUM:@3Pe=3LnAe9OKG^9
UZ6Z/KFg][:]YIfCRH1gKfQRGeiMGf9VJg1fO824R8Z;S8^:R8J4PX60Ogn1PXB6
R8Z<SHj=S8V6PGafL6YUH5eKFeePIVeeOhVCWJJ^];Ri^;>]XiR;OFiPDTLm=S<b
=Se7E6AeQiZ[^lWDf]kLe/fo[i^6LE]7=BLL5A<F7R/kCfImUZg3e^G`mOG`i]O4
[IEkHDPb7a060P@:5bPmEFn;YKkDioCmoocciM>lXhQ]Dc/V5@T20@H@7c=:HgfG
/<OJjO;gmo3Ue/:/U7]SC3PX6a@A4aXV=DMLLXRN/L;@f]oPgMK:_:^IQW=QDD@i
<Rl_<cY5DEm^OXfJY[2g^kfk]k6XWiB9OG=ZHUeIEeMIGF5XKWEkPHN;Si6BTY2>
S8V6Q85oOginOh62Q8F7QhR7QH>0O7McKVYVHf9QHfI[LGR0RI:KXjV_/[>a[JJN
ThMjKF1DBD4k>3Pl@deJJ7V:W:bkam7FfMOAakVYUX9]F4He9adH5a/T<45EJh>J
/LGGiNkcl^cQd[jXSgELA2lM3`L41PhK;D9KMI2Z`mSYm_gono7Rc[NMPfM>=R4A
1P411a8R=diXPYffc=o]m_[hlNCD_jR?MUe7<R8F3`d@6BHfBUmfSJ>hb=KOi>GP
f<^kZYJ2KUa;?S</:B/`>4=AH761TJ2/][g2`l6l]:^PThMkKfEMEU9@DE=GGFE/
MGb4RY2DUiVHUiFBSXZ7Ph1mO7]kNgamOh21PX>2PGmmNGIbKfaZJ6QYK71eNh:9
TIROYJV/[:ZWXIV?Q7Q/H5E<AD0n?d9:Dem]OHfM[;[5cM;CdL_0/j>AOFYFACDX
81`L82TfAe]`QijdamSTkO3_j=c<^:::L5Q1;1`?1`D94QlbB61kUZo7fncgoOgh
k]k9/YQmHTPa7@h4004852HkDff8Xk_Aho7io?W`hm6kY8Y`F44]7A8;2`lH9SQ=
I7^CZKg>fnCYj>;IbkZWTgiYETDg;BHT9R`e@U5RLhFFYK:ma<S8a/2g[J2CQGQ[
H5M@C4Y;CU=JHV]dOXJ>UIZMWinMViNBSXR3Og]hMWEeMWMhNWamOh1oOgilNWMe
LW1_KfmaM7QmPhV?UY^PXjFVY:2KU8^1MfaQF519AD=5BE1IIG:0Sij/^<;9c/k;
aKZ]WXajIeE4=R/S820V;ca=HGJ;XKK8en?ZkN_SelNcW8A/E3hZ6Pl920`F9CM>
Ih2K]<[NkOSmo?KZfLF/TWMM@bdJ30<00PXG:CmHLhjX`MKWm?_mnNoQc[ROQF]B
>bPH3PP93QPW>e1XP9R_`mCQjNg[iMW;^JF?NFA@?c4W8AlR:CA2DVAfRI^Z^<?:
c/k:`kZ^X9:2M6IKDDY5A4E9CUMPJgEoRY:JX:BUYZBPW9J@RX=nNGAbKfm_L79d
MgUkOGn0OgmnO7YiMgIeMGIhNWj2R8bBUYZMWinNViJ?R7mfK6=KE4i;BT]?EUiY
MH>AWZ^f_lG8b<Fn]:NHR7ITE4Dg;BLT9R/e@e=VNXnT^<WGh^OYiMgA`:fGOfM@
>bTJ40/;41/Z?E=/QYnhc^3^n?cjl^KD_jN=LELn:AL:0@0331/^A5ihU:k6f^_g
oOkhk]k:/iYoID`f8Q@:1PL>6BTmE6b5W[G9f^K^l>gVf/ZgXH]dGTXi:b4L71lW
<d9CIgZ>X;2nbM3Cd/k6^jjOSgm`HUE;@cln?dA;E5iZMX:=UinVZZb[ZZJPVI::
PgafL6eZJFQZK6mbMGUlOh62Ph:2PGmmO7]jNW]mOh:6RXjAUINIVINETHb5OGI]
IUiHE55@DUIKI6eiQI:NZK>k`<?3_kR^XY>4Lf=CACT`:bT[<C]9FF]oTjNibMKO
i>GQf<^jYi5jHddi:1/A3PlE82m3FW:;Y;c@h^ogn_O_hLniXHM/DSXU50P200D?
7S9:HgjI/l_OkoWno_S/flJ_U7YOAS0N40L41PdJ;45HLH^T^loOjo;cknOIb;BN
QVmHA3<V71LH72Dc@UEZOY>U]lC?e]WGd/Vm[ij=O6]LCdDm>CPj@4QBGV]hQI6L
YJb`/k:_ZZBLU8^2NG9/IfARHV=VJFebMW]oPXF7R8N7QXB2P7mnOWmoPHB6RHb>
TI:BTHn<R8=mMVmXHeeIEeMHG65YLWb7TYfW/;Nk_Kbh/ZRLSh1aHUA6?3@_;S4h
@TmNL8>FZ;W8e=cPh=_BaKFQS7IPBSPX71@@4aXU=DUOMi2X_m?SkoKhm>_Lb[BK
PFM>=R8B2082218S=dmYQ9nhcn;anoomm^WH`ZZ?M5U1:aT<10853Q`_A5egT:[0
e>C_mOKaimW6/IV1JE<n;B0G4a@J9C=4F6f3V:^mb]GKg]_Ebkf^WHYhIUM9?SLc
<SDlAE1NK7Z8UJ6[/[Nh^;F_YinDRX1fKVMQGE]KGF1TJVmeNh25R8^=SXf<RhR6
Q8:0P7n0P8:4QXR:Rhb<RXR5PGagLFaWHUmNGEmRIfeeOXRBVjB//[Jg][:/XiR;
OFmQE4Po>3Dd=ci8EFAeQYRZ^LOBfMcKeLbo[ib7LUe8=bPM5Q@G7b/kCfElUJc2
eNC_m?G`i]O4[YIlHTTc81470P@;5bLmE6n9Y;gDi_Cloocdi]>mY8U^E3/V5@T2
0@D?7c99HGbF[lKIjO?hmo7WelB]UGaTCCPX6a<?4QPT<dIKLHNN//?@fn7Rg]O<
_ZbJQWAQDD<h<Bd^<SU3D5i^OHfJYk6h_Knm^K>ZX9F:OW=ZHE]GEEEGFf1VKGAk
PXN<T9>DU9>ASX^8QH:0OWemOWn0PX>5QHJ6Q8:0O7QdL6]XIVATIFM/LWR0R96I
XJN]/;6_[:FMThMkKV5EBd8m>SXnA4iJJ7V9VZZiaLoEemG?a[VYUX=^FTLf:AlI
61`T<D5EJh:I[lCFhngblNcQd[jXT7IMAC0N40L41PhK;D9JM8nY`]OYmOgnn_7S
ckRNQ6Q?=b8B1`411Q4Q=TeWPIbec=o]m_[il^KE`:V@Mei7<b8F3``?62@eBEie
SJ>gb=KPiNKRfLbmZiN3Kea;?C8[:2T^=T9?Gg21TJ2]]ko3aL>n]ZbQUHQkL6EL
EE1?Ce5FFf=[M7b4Ri6EVIZJVINDT8^7Q81mNgUiNGYkOGj0PH61PGmmNWMdLFi/
JVY[KG5eNh68SiNMXjNYZZVUX9R?Q7U]HUM>Ad8o@4A;E5m]OHbLZ[S3bm7Bd<[0
/j>AOVYHASLZ8QdM8BXgAeY`QYbbaMKSjno^imc<^J>;LEU2;Q`@20H94QlbAf1j
UJk6f^_goOgik]k:/iUnHdTb7Pl4004752@jDVb7X[_@ho7io?Wai=:mYH]aF44]
7A8;2PhG9CI;HWZBZKg>g>GZjNCKcKbYU7mZETDg;2DS92Xd@DmPLXBEYK>naLW:
b<:i[Z6DQWQ[H5I?BTQ9C55HH6YcOHN>UY^OXJ6OWIVDShV4Og]hMGAcM7AfN7Yl
OWmoOgimNgUgM79aLG5bMGQmPXR>U9VNXJ>TXYnJTh^2N6eSFU9;AdE7BU5IIG9o
SYbZ]/37c<g9`kZ]WXajJ5I6=b`U8B8W<3e=H7F:X;G7e^;Yk>[Re/JcWHE]ECl[
710:2@dF9CM=IWnJ//WMkOOlo?KZf/F]TgQNABdK30<00PTF:CmGLXfW`=KWm?_m
nO3RckVPQVaB>bPH3@P73ALV>DmVOiN_`mCQj^k/i]_<^ZJ@NVA@?c4V81hQ:390
DF=fRI^[^LC;clo<aK^_XI:3M6IJD4U4@T=6CEENJGAoRI>KXJFWZ:JRWYRBRXAn
N7A`KVe]KW1bMGQjOGn0P81oOWakNGQgMWMiNgj2Qh^@UIRKWIfLVIF?R7mfKVEM
EU1=C4eAEemYMH:?WJVd_L?6alBm]:NHR7MVEDHi;bPV9b`f@e=UNXjS]/OEh>KX
iMg@`:fGP6QB?2XL4@`<4A/Z?E=[QIjfc=o]mo_ilnKE`:R>LePo:QP:0P0331X]
@eahTjg5f^_goOkik]o;]9^0ITdf8a@:1@H=62PlDf^5WKC9f^K_lNkWfl^hXhae
GdXi:b4K6QhU<D1BIGV=X;6ob]7Ee=38_K2QTH1`HEE:@Sdl?D99DUeYMH:=Uj2W
[:j^[:NRVi>;Q7aeKf]XIfIXJFe`M7QkOh63Q8B4Ph60OWelO7amOh:5R8b?TiFF
UiJDT8^5OWM^If1JEU=BDeMMIFiiQ96LZ;6i_l70_KN^XY>4M6AEAc/b;B/]<Sa9
FF]nTZFgamCMhn?PelZjYi9kI4lj:A`B3PlE82m2FG6:Xk[?hNkgnOO_hM2jXXQ]
Dc/V5@T20@D?7S59HWfH//[Nk_Wno_S]g<N`UW]PAc0N40L31@`I:d1GL8ZS^/oO
jo;dlNSKb[FOQg1IA3<U6aHF6b@a@EAXOI:V]lG@em[Idl^n/:2>O6]LCd@l=cHh
?TI@GFYgQI6LYZfb];Ba[:JNUHb2NW9[IV9PH65SIf]`MGYoPhJ8RHZ9R8J4PX60
OgmoPH:5QhZ<SY2@Shj;Qh9mMg1ZI5mKFEUJGF9ZLWb6TI^U[[Fi^k^g/JRLSh5b
HeE8?SHa<38i@TmNKh:EYkS7dm[Ogm[AaKFQSGMQC3TY7ADB4aXV=DUNMXnW_];R
k_Ggln[Mb[BLPVQ?=b@C20821a8R=diXPijgcn;anoonm^[H`j^@MEY2;1X<1085
3A/]@eafSjW0e>C_m_Kbj=[8/Y^2JU<n;B0F4Q<H8c52Efb2UjbmbmKMgmgFc;n_
WX]hIeM9?CHa<C@j@dmLJgZ8UZ:/];Vk^[NaZJ2FRh5gKVIPG5UIFeiRJ6edNX25
RHb?Shn?SH^8QH>1P7moP822Q8J8RHZ:RHN4PGehLfiXIF5PGf1SJ6ieOXN@VZ>Z
/;Be];2ZXYN;OW1RETY1>SHf>Cm8EF=dQYNX^<K@em[Ie<^o[Yb8Lei:>2XN61DH
7b/kCVAlU:_0dn;]loC`i]O5[iImHd/d8A880`@:5RLlDfj8XkcBiO?loogdimBn
YHY_EC`W5PT20@D?7C58H7^E[/GIjO?hn?;Wf<F^UWeTCCTW6Q8>41LS<TAJL8NM
/L?Ag>;Sh=W>_jjKR7AQDD<g;b`/<3M1CUe/O8bKYk:j_l6o^kF/XYJ:OW=YH5YF
De=EFEiTJg=jPHR=TYBFUYFCTHf9QX>0OWelO7enP863Q8B4Q8:0OGUeLVeZJ6IV
IfU]LWV0R92HWjJ[[Zn]ZZBLThMlKf=GCDDo>c`oADmJJ7R9VJVga<gCe]C>aKVX
Uh=_FdPh:b4K6QdU<D5DJX6H[/?Dh^calN_Qd[nYTGQNAc4O4@P41`hJ;45JLhjX
`MKXmOcnno7Sd;VPQFY?>2<B1P401A0Q=4aVP9^dbmk]m__jlnOF`ZZAN5m7<b8F
3P`>5R<cAeedS:>gbMOQinOSfljo[9R4Kea;?34Z9RL/=3m>GVn0TJ2]^<35a/G0
^:jRUXUkKfAKE4m=CDmDFV5ZLg^4Ri6GVYbLW9VFTXf8Q81mNWQgMgQiNganOh21
P7mnO7UfLg1^K6a]Kg9fNh67SYFKXJFWZ:NSWiN>QGU^HeU@BDA1@TE<EF1]O8^J
ZKK1b/o@c/Ro/Z>AOfaIAcT/8ahN8RXgAeY_QI^aa=GRj^k]im_<^J>;LUY3;ahA
2@L:4QlaAemiTjg5fN[fo?ghk]o;]9YoI4Xc7`l500074b@iDF^6XK[@ho7ioO[b
iM>nYXabFD8]7A4:2@dF8cE:HGVAZ;g?g>K[j^GLc[fZUGmZETDf:b@Q8bTb?diO
LXBEYK>nal_<b/>k/:>EQgQ[GeE>BDI7BTmFGfQbOHJ?UibPXj>RWi^FTH^4Og]g
M79aLW9dMWQkO7ioOgmnO7]iMWEcLg=dMWUmPXN=TYNLWj6RXIjITX^2N6iUFe=>
BDM8C59JIG9oSI^X];k6b/_8`[V/WXekJEM7>BhV8b<X<3e=H7B9Wk?5e>3Xj^WR
e/JcWHI^ET0]7A8;2@dG9CM<IGjH/LSLk?KlnoKZf/J^U7UNARhK3@<00@TF:3iF
L8bV_mGWm?cnn_7Sd;ZQQfeC?2PH3@L731HU>4iUOYN^`mCRjnk^imc>_:NANfE@
?S0U7adO9S4oCf9eR9Z[^LG=dM7>akfaXiB4M6IJCdM2@454Be=MJ7=oRY>LXZNY
ZZRUX9ZCS8EnN7=_K6][K6i`LgIiO7j0PH61P7mmNgYiN7UjNgj1QHZ>TiJIVY^J
UiB>Qh1gKfINF59?CTmBF61ZMH:?VjNb^l75aL:l/ZNHR7QWEdPk<BXW:2df@e=U
NHjQ]<KDg^GWi=c@`:fHPFUC?R/M4Pd<4A/Z?59ZQ9febmk]m_[il^KE`:R>M5U1
:aP;0P032aX/@e]gTJc4fN[goOkjkn3=]Ib1Iddg8a<:10D<5bLkDVZ4WKC9f^O_
l_3YgLfjY8efGd/i:R0J61`T<3m@I7R=X;6obm?Ge];:_k6RTH5`HEA9@C`j>d17
D5aXMH6=V:6X[K2`[ZZTWIF<Q7aeKfYVIFAUIfY^LWMkOX63QHJ6QH>2P7mnOGen
Oh64QhZ=T9>DUIBBShZ5OWM`JF9LF5EDEEQNIFiiQ8nKYZng_;no_;J/XIB5MFIF
B3dd;R`^=3e9FFYmTJBfaM;LhN;OelZkYi9lIU0l:adD410F82m2F729X[W>h>ge
nOK^h]2kXhU^E3`W5PT30@D?7C58HGbG/LWMkOWno_S]gLV`UgaQB34N40H210`H
:CiFKhVR^/kOjo?el^WLbkNPR75IA3<U6aDE6R8_@5=WOI:U]lKAf=_JeLc0/J6?
OFaLCT8k=S@f?4A?FfQgQ96MYjnc][Jc[jRPUXf3NG5ZI65NGUmQIFY_M7YoPhJ9
RX^;RXR7Q8:1P7moP863QXR:S8j>SXb:Qh9mN75/IV5MFeYLGf=ZLW^5T9ZT[;:g
^KRe[jNLSh5cI5M:?cPc<S@j@dmNKh6DY[O5dMWMgMW@a;BRSGQRCCX[7QHC51/V
=DQNMXjV_=3PkOCfln_MbkFMPfU@>B@D2@<2218R=TeWPYbfcN7`noonmn[Ia:^A
MU]2;1X<10443AX/@U]eSjS0e>C`m_ScjM_9]9b3Je@o;AlF4A8G8Rm1EF^1Uj^m
c=ONh=kHc/6aWhaiIeI8?3@`;c8h@DeKJGV8UZ:]]KZm_;VcZj:GS85gKFEOFUQG
FEaPIVacNX25RXj@TI6AShf:QhB2P7moOWn0PXB5QhR8R8J4PGehM6m[IfARHF9U
JFifOHN?VJ6X[K:c/ZnYXIN;Og5TEda3?3Pg>T19EF=dQIJW]/?>eMWHdlZn[Yb9
Lem;>R/P6ALI82/kCV=kTZZod^7/l_?_i]O5[iMnI4`e8Q<910@;5RHkDVf7X[_A
i??koocdimFoYXa`ESdX5PT200@>7C16GgZD[/GIjO?inO?YfLJ`UgiUCSTW6Q4>
3aHQ<D=HKhJL/L?Bg>?Th]_?`;2LRGERD48f;RXZ;SDoCE][O8bKZ;>k`<;1_KJ^
XiN;Og=YH5UDDE5CEUaRJW9jPXR>TiJHV9NEThn;QhB0OWakNg]lOGn0PX>3Ph60
OGYfLfm/JVQXJ6]^LgUoQhnFWJBX[:b/Z:>LTXMlL6AHCdM1?Ce0AdmKJ7R8V:Rf
`/_Ae=?=a;RXUhA`GDXj;28L6ahV<D5DJH2G[L7ChN_`l>_Qd[nYTWUPB38P4PT5
1`hJ;41ILXfW`=GWm?cnno;SdKZQQV]@>2<C1`401A0O<d]UP9Zdbmk]mo_jm>SG
`j^CNF18<b8E3@X=5B4bAUacRj:gbMORj>WTgM30[YV4L5a;?30Y9BDZ<ci<G6io
T:2^^L;7b<O2^[2TUhUlKfAJDde;BdeAF5mXLW^3Ri:HW9jOWY^HU8n:QH1mNGMf
MGEgN7YlOWmoP7mnO7YhMG=`Kfi_L7=fNh67SIBIWj>UYZFRWIN>QGY_IEYBBdI3
A4M=EF1]NhZIYkG0b<g>cLNn/Z>BP6eJBCX^9B0O8b/gAeY^Q9Z_`m?PjNg/i]_<
^JB<M5a5<1lB2PP:4QlaAUihTZc4f>Weo?ghkmo<]I^0ID/d810500074R<hD6Z5
X;W?h_7ioO_ci]BoYhecFT8]7A4920`E8SA9H7RAZ;g?gNO/k>OMd;n[UX1[Ed@f
:R<P8BL`?DeNL8>EYKBob<c>c<Jm/ZBFQgU[GeA<AdE5B4eDGFMbO8J?UijRY:FT
XIfHTXb5Og]fLg1_Kg1aM7IiNgeoOh1oOWakNGMeMGEeMgYmPHJ;T9FJWInPWYbH
TXZ2NG1VGEI@BdY:CE=KIG5oS9ZW/kg4b<W7`KR/WXilJUU9>c0X92@Y<Ci=GgB9
WK;4dmoVjNOQe/JcWXM_Ed8^7Q<<2PhG93I<I7fG/<OKj_GknoK[f/J_UGYPAc0L
3@@00@TF9ceEL8^V_]CVlocnno;TdK^RR6iD?BPH3@H62aDS=TaTOIJ^`mCRk?3_
jMk@_JRBO6EA?S0U7Q/N92lmCV1dR9Z[^/K>d]??bKnbY9F4MFIICTI1?Sm3B55K
Ig=nRYBMXjR[[:ZWXI^DSHEnN79^JfUYJVa^LGAhNgj0PX:2PX5oOWakNWYkO7n1
QHV=TIBGV9VHUY>=Qh1hL6QPFEEAD51DFF1ZMH6>VZJ`^Ko3`l2k/ZJHRGUXF4Tm
<R`Y:RhgA5=UN8bP/lCBgN?Uhm_@`:fHPVYD?bdN4`h=4Q/Z?59YPibdb]g/mO[i
l^KF`JV?MEY2;1T<0`022aT[@U]eTJ_4fN[foOkjl>7>]Yf2J4hg8a@910@;5RHi
D6V3W;?9f^O`lo7Zg/jkYHifH4Xh:QlH5a/R;Se?HgR<Wk70c=CHf=?<`K>TTh5a
HEA8@3Xh>Ci5CeYVM86=V::Z[k:b/:bVWiN=QGaeKVUUHf9SIFQ/LGEjOX64QXN7
QhF4PX5oOWinOh63QHR;SY2BTY:ASHZ4OWQaJVANFUMFEeYOIVmhPhjJY:fe^[fm
^[B/XI>5MVIHBSlf<2h_=Ci:FFYlT::da=7Jh>7Ne/ZjZ9=mIe4m;1lE4A4G8C12
Efn8X;S=g^cdn?K^h]2kY8Y_ECdX5`X30@D>7C17H7^F/<SMkOWno_W^g/VaV7eR
BC8N40H210/G:3eDKXRQ^LkOk?Cfln[Nc;RQRG5JAC<T6Q@D624^?U5VO96U]lKB
fMgLelk2/j:@OVaLCT8i=38d>T9=FVMeQ9:MZ;2e^;Re/JZQV8j3NW5YHemLG5eO
HfQ]LgUnPhN:S8f=S8^9QXB2PGmoOh22Q8J8RX^<S8^9QX9nN7=]J6=PGEaMH6A[
Lg^5SiVRZ[2e]kNd[ZJKSh9cIEQ<@CXe<cHkA51NKh6BY;G3cmOLg=S@a;BRSWQS
Cc`/81PD5A`V=DQMMHfT^loOjo?fl^[MbkJNQ6YA>RDE2@<21a8Q=DaVP9^ec>7`
n_onmn_JaJbBMea3;AX<104431T[@EYcSZNoe>C`moSdjmg:]If4K5@o;AlE410F
82i0E6Z0UZ^mc=SOh^3Jd<:bX8ejIeI7?3<^;C0f@4]IJGR8UZ>^][bn_[Ze[J>H
SH5gKFAMF5IEEUYNI6YbNGn5RXnBTi>CTHn<RHJ3PGmnOWioP863Q8J6QXF4PGij
MG5]JFITHfAVJVmfOXJ>UinV[;2a/:fXX9J;Og9UFDi5?SXi>d5:EV=cQ9FV]<;<
e=OFd/Zn[Yf9M61=>bdR6QPJ8B`kCV=jTJRmd>3[lO;^iMO5/9QoIDdf8a@:10@;
5RHjDVb7XK[@ho;koogej=K0YheaEchX5PT200@=72i5GWVC[LCHj?Cin_CZf/Na
V7mVCSTW6A0<3QDP;d9GKXFL/L?BgNCVhmcA`[6MRGERD44e;BTX;3<nBeYZNhbK
Z;Bm`/C3_kV`YIV<Og=XGeMBCdm@E5YQJG5iPHR?U9NIVYVHU96=RHB1OWajNGUj
NgenP862PX5oOW]hMG5_K6YZJVa_LgUoQXfEW:6VZZZZYj:KTXQmLFEKDDQ3?cm2
B51KJ7N7UjJd`<[?d]7<a;NXUhEaGT/k;R<N71lV<T5DJGnE[;oAgnW_kn[Pd/2Z
TWYQBC@R4`X620hJ:d1HLHbV_mCVlo_nno;TdK^RQfaA>B@C1`001@lO<dYTOiVc
b]g]mockm>WHa:fDNV19<b8E3@X<520aA5]bRZ:gbMSSj>[Vg]72[i^5L5a:>blW
8b@X<Ca;FfaoT:2^^/?8b/W4_;:UV8YlKfAIDDa9BD]?EUiWLGZ4S9>IWJ2QX9fJ
UY2;QX5lN7IdLg=eMWQjO7ioOgmnOG]iMgEbLG1aLG=gNh26S9:HWJ2SY:>QW9J>
QG]`IUaDCDQ5ADU>EV5]NhVHY[>ma/_=blJn/J>BP6iLBc`_9R8Q92`hAeU^Q9V^
`M;Oinc[iM_<^ZB=MEe6<B0D2`P;4QlaAUegTJ_2enSdnoghkn3<]Yb1IT`e8105
00064R8gCfV4WkS?h_3jo__dimK0Z8idFT<^7A091`/C8C=8GgN@Ykg?gNS]kNSO
dL6]Uh5[Ed@e:B8O82D_?4]ML8:EY[C1bLk?cLRn/jJGR7U[GU=;AD=3AT]BFfIa
O8J@V9nTYZNVXinIThf6P7YeLFm]KFi_LWAgNWanOh20OgimNgUhMgIgN7YmPHF:
Si>HVifNWI^GTHZ2NW5WGeQACTa<CeALIW5nRiVU/K[2a/O5`;N[WXimJeY;?C8Z
9RHZ<Si=Gg>8W;32dMgUj>KPeLJdWhQ`FD<`7a@=2`hG93I;HgfF[lKJj_CjnoG[
flN`UWaQB34M3P@00@PE9SaDKhZU_]CVlocono;Td[bTRFiE?BPH30H52Q@S=D]S
O9F]`mCSk?7`j]oA_ZZCO6IA?RlT7AXL8RdkC5mcQiZ[^/O?e=GAbl6dYYJ6MFII
CDDo?3e1AdmIIG5nRIBMYJZ][ZbYY9fFSXInN75]JFMWIfU/Kg=fNWj0PX>4Ph>1
P7imO7alOGn1Q8N;Si:DUYNFU96=Qh1iLFURG5MCDU=EFV5[MH6=VJB_]kg1`[nj
/JJHRWUYFD/n=BhZ:c0hA5=TN8^O//?Afn;Th]_?`:jIPfaF@BlP5@l>4a`Z?55Y
PY^cbMcZm?Whl^KF`ZZ@MUa3;AX<0`032aP[@EYdT:[3f>[fo_ojlN;>^9j4JDlg
91@90`@:5B@hCfR2Vk?8f^S`m?;[h=2lYXmgH4/h:AhH5QTQ;Ca>HWN<Wk71cMGI
fMG>`[FUU89aHE=7?SPg>3a3CEUVLh2=VJ>[/;>d/ZjXX9R>QGedKFQSHF1QHfIZ
KgAiOX65QhV9RHR6Q8>1P7moOh22Q8J9S8j@T96?SHV4OgUbK6IQG5UHFE]PIfmh
PhfHXjbc^;^k^K>[X9>6MfQIC44h<S0a=Sm:FFYlSZ6c`/oIg^3MeLVjZ9AnJ5<o
;R0G4Q8G8C12Efn7WkO;gN_cmoG^h]6lY8]`EchY60/40@D>7Bm6GgZE[lOLk?So
ooW^glZbVGiSBS8O40H20`XF9caCKHNQ^LkOk?Cgm>_OcKVSRW9KAC<S6A<B5al/
?E1UNi2U]lOCfmkNfM33]:BAOfaLCD4h<c4b>41;F6IeQ9:NZK6g^[Zh/Z^SVHn4
NW5YHUeJFEYMHFI/LWQnPhR;SHn?Shf;R8J4PX1oOh21PXB6R8V:RXZ8QH9nNGA_
JVERGemOHVI[Lg^4SYNPZ:nc]KFb[JFKT89eIeY=@c`g=CLlAE1NKX2BXk?2cMKJ
fmO?`kBRSWUTD3h^8ATE5Q`W=TQMM8^S^/gNj_;dl^[MbkJOQF]B>bLF2P@3218Q
=DaUP9^dbmo_n_knmncKaZfCN5e4;Q/=10032aPZ@5QbSJNndnC`n?Wek=g;]Yj5
KEDo;AhD3a0E7bdnDfV0UZ^ncMSPhn;LdLBcXXijIeI7>c8]:bhd?TYHIgN7UZ>_
]kg0`;bg[jFJSX9gKFALEeACE5QLHVUaN7n6Ri2CUIFETi6>RXN4PGmmO7amOWn1
PXB4QHB3P7ijMW9_JfQVIFIXJg1fOHF=UIfTZZf_[jbWWiJ;Og=VFdm7@3`k?D=;
EVAcPiBT/l3:d]KFdLVm[Yf:MV5>?BhS71TK8BdkCF=iT:NlcmkYl?7^iMO6/9V0
IThh91D;1@D;5RHjDFZ5X;W@ho7jo_gej=O1Z8ebF3lY5`X200<<6bi4GGRB[<CH
j?Cjn_G[g<RbVH1WCcTW6A0<3A<N;D1FKHBK/<?Cg^GWi=kBa;:ORWIRD44d;2LW
:S4lBEQYNX^KZKFn`lK5`K^aYiZ=P7=XGUIACDe>DUQOIg1hPHV?UIVKW9^JUY>>
RXF1OW]iN7MhNG]lOWn0PH5oOWajMg=aKVe/K6i`M7UoQHbCVYnTYjVXYJ6JTHQm
LVMLDT]5@D54BE5LJ7N6UZFb_/O>d=3;`kNXV8EbGddm;bDO7B0W<d5DJ7jDZ[k@
g^S^k^[Pd/2[Tg]RBSDS50/720lJ:cmGLH^U_M?Ulo_nno;Td[bSR6eB>RDD2040
10lN<TUROIRbbMg]moclmN[IaJjENf59=28D30T;4ah_@eUaRJ6gbMSSj^_Wgm?3
/9b6LEa:>bhV8R8W;c]9FVanSj2_^lC:c<_5_[>WVH]mKf=HD4Y7AdU=E5aUL7V3
S9BJWj:SXZ2LV9:<QX5lN7EcLW5bM7IhNWamOgmoOWekNGMeLg9bLgEhO825Ri2F
VYjQXZ6OViF=QG]aIeiFCdY7AdY?Ef5]NXVGY;6la<W;b/Fl/J>BPFmMC3da:2<R
9BdiAeU]PYR/`=3Mi^[ZiM[<^ZF>MUi7<b4E30T;4al`AEafT:W1e^Ocnochkn3=
]Yf2Iddf8A4600064B8fCVR3W[S>h_3io_cej=O1ZHmeFd<^7A081PXB8356GGJ?
Ykc?g^W^k^[Pdl:^V89/Ed@d:B4M7R<]>TUKKX:DY[G1b/oAclW1]JNIRGU[GU9:
A451@dUAFVA`NhJ@VJ2UZ:VXYZ6KUHj7P7YeL6e/Jfa]L79eN7]mOh61PH1oOGaj
NGQhNG]mP8B9SI6EV9^LViVET8Z2NW9YHEUCD4i>D5IMIW5nRYRT[kW0a<K4_kJ[
WXimK5]<?S@/9bL[<cm>Gg:7Vjo0d=_SinGOeLJdWhUaFT@a8AD>30lG93I;HgbE
[/GHjOCjn_G[g<RaUgeRBC4N3`@00@PD9C]CKXVT_M?Ulocoo??VdkfTRVmF?RTH
30D42A8Q=4YRO9F/`]CSkO7ajn7B`:^DOFIA?RhS6aTK8B`jBeebQYZ[^lO@eMKC
cL>fYiN6MVIHC4@m>c/oADiHI71mRIBNYZ^_[jj[YYnGShMnMg5/J6EUIFMZKG5e
NWf0PhB5QHF3PX1oOWemOGn0PhJ:SI2BU9FETi2<QX5iLV]TGUUEE5AGFf9[MH2<
Uj:]]K^o`;fh/:FHRWYZFde0=S0/;C4iAE=TMhZN/<7?f^7ShM[?`:jIPfeG@S0Q
5Q0?4a`Z?55XPIZab=[YloShl^KF`Z^BMee4;Q/=10432aPZ@5UcSjW2enWfoOok
l^;?^In5JU0h91@90`<952<gCVN1V[;8f^SamO?/hM6nZ91hHD/h:AdG5APO:cY=
HGF;Wk71cMKJfmO?a;JVUH=aHE96?CLe=SY1BeMTLX2=VJB//[Ff];2ZXYV?QWed
K6IRGeiOHFAXKG=hOH65R8Z;RhZ8QhF3PH1oOh21PhF8RXb>SXj>S8R4OgYcKFQR
GUaJFeeRJ6mhPXfGXJZa][Vi]k:ZX9B6N6UKCT8j=34b=cm;FFUkSZ2a`<kGgMkK
e<VjZ9AoJEA0;b8H4a<H8S12Efj6W[G:g>WbmoG^h]6mYHabF40[6@`40PD>72m5
GWVD[/KKk?Snoo[_gl^cVWmTBS<P40H10`TE9S]BK8JP^<kOkOGhmNgPck^TRg=K
AC8S618A5Ah[>dmTNY2U]lOCg>3Of];5]ZFBOfeLC40g<Bla=Si9EfEdPi:NZK:h
^kbj]:jUVi25NW1XHEaIEeQKGfAZLGQnPhV<Si6ATHn=RXR5Ph5oOgioP8:4QHN8
R8R7QH9nNWEaK6QTHV5QHfM/Lg^3S9JOYZba/k>`[:BJSh=fJ5]?ACdi=cTnAE5N
KWn@X[;0bmCHfMK>`[BSSgYUDSl_8a/G5adW=TMLLhZR^<cMjO7dlNWMc;NOQVeD
?2PG2`@3218Q=4]TOiZcb]o_nOknn>cLajjENEm5;Q/=10032QPY?eMaS:JndnC`
n?[fkMo<]j27KEDo;AhC3PhC7B/mDFQoUJZncMWQi>?MdlFeXhmkJ5I6>S4/:Rdc
?4QGIWJ7UZB_^Ko2`[ni/JNKSh=gK6=KEE9ADUEJHFQ`Mgn6S96EUiRGUI>@S8R5
PGmmO7]kO7eoP8:3Ph>2P7ikN7A`KFYXIfQYKG5gOHB<U9bRYj^][JZUWYF<P7AX
G599@Shm?dA<EfAbPi>S/Ko9d=CDd<Rl[Yf:Mf=@?S0T7A/L8RdlCV9hSjJkcMgX
ko7]i=O6/IZ1Idli9QH<1PD;5RDiD6Z4WkS?h_3jo_cejMO1ZHidFD0Z60X200<<
6Re3G7NAZl?Hj?CjnoK/gLZcVh5WCcTW6@l;318M;3mEK8>K/<?CgnKYi]oDaKBP
RgISD40c:bHU:30jB5MXNX^KZKFoaLS7`kbcZ9^>P7=XGEE?C4]<D5IMIFmhPHV@
UYZMWYfLV9F@RhJ1OWYhMgIfMgQjO7eoOh1oOWekN7EcLFm^KVmaMGYoQH^BV9fR
YJNVY9nITHQnLfQME4e7A4=5BU9MJGJ5UJ>a_LK<clk:`[JXV8IcH4ho<BLQ7b4X
<d5CIgfCZKg>g>O/kNWOd/2[U7aSC3HT5P`82@lJ:cmFL8ZT_=;Tl_[mn_;UdkbT
RFiC>bDD204010hM<DQQO9NabMc/moclm^_KaZnFNf99=28D2`P:4Ah^@UQ`RJ2f
bMWTjncYhMC4/Yf7LUe:>RdU8B4U;CU7F6]mSj2__<G;cLc7`;FXVhamL6=HCdU5
ADM;DUYTKWV3S9FKX:BUY::NVI>>Qh5lMgAaL71`LW=fN7YmOWn0OgimNgUgMGEd
MGIhO824RXnDVIbOX:2MVIB=QGabJEmGDDa9BDaAF69]NXRFXjnj`/O9b<Bk/:>C
PG1OCSlc:RDT9bhiB5U]PIN[_/kKi>WYi=[<^ZF>Mem9=2<F3@X<4al`AEaeSjS0
eNKbn_chkn3=]ij3JDhg8Q8600064B4eCFN2WKO=hO3jo_cejMO2ZY1fG4@^7A08
1PPA7S15G7F>Y[c?g^W_l>_Re<>_VH=]Ed@d:20L7B8[>4QJKH6DY[G2bm7CdL_2
]jVJRWY[GE99@Slo@DM>F6=_NXJ@VZ6VZZ^ZZ:>MUXn7P7YdKfaZJFU[KG1dMgYm
Oh62PX61OgilNgYjNW]nP8B7S92CUYRIVINDShV2NW=ZHU]FDU1@DUMNIg5mRYJR
[KNn`/C2_KFZWHinKUe>@3D]:BT/=3m>Gg:6VZfoc][Ri^COe<JdX8UbFdHb8QH?
3A0H9CI:HW^D[L?Gio?in_G[g<RbV7iSBS8O3`D00@PD9CYBK8RR_=;Ulocoo?CV
e;jURg1F?RTH30D4214P<dQQNYB/`]GSkO;bkN;D`JbEOVMA?RhR6QPI82XhBEaa
QIV[_<SAemSEc/BgZ9R7MVIHC48l>CTl@d]FHfmlRIFOYjf`/K2]Z:6IT8QoMg1Z
IVASHfEWJg1dN7f0PhF6QhN6Q8>1OginOWn0PXF8Rhf@TY>CTHn;QX1jLfaVH5]G
EUIIGF=/MH2;UZ6[/kVm_[bg[jBHRW][G4i2>38^;S8jAUATMXZL[ko=f=oQgmW>
`:jJQ6iH@c4S618@51dZ?51WP9R`amWXl_SglNKG`j^CN5i5;a`>1@432QPY?eQb
SJS1enSeoOokl^C@^Z25Je0i91@90`<84b8fCFJ0VK;8f^SamOC]h]:oZI5iHD/h
:AdF4aHN:SU;H7F:Wk72c]OLg=WAa[RXUXAbHE95?3Hc=3Q0BEESLGn=VZB]/kNh
][:/Y9^AQgedK6EPGEaMGf9VK79gOH:6RH^=SHb;RHN5PX60Ogn0PH>6R8Z;S8b<
RXR4OgYeKfUTHEiLG5mSJG1hPHbFWjR_];Nh][6YWiB6N6YLCd@l=S<d>D1<FFUk
SIn`_lcEfmgJdlRjZIF0JUE2<B<J51@I8S11EVf5WKC9fnSbmOC]hM6mYXecFD4/
6Pd50PD>72i4GGRC[LGJjoOnoo[`h<beVh1UBc@P40H10PPD9CYAJhFO]lgOkOGh
m^kQd;bUS7ALAS8S614@51`Y>TiSNHnT^<SDgN7Qg=?7^:JCP6eLC3lf<2d_=3e8
EF=cPi6OZkBj_Kjl]jnVW965NW1WH5YGEEIIGF=YL7MnQ8V>T9:CTi:?S8Z6Q85o
OWinOh22PhF6QhN6Q89oNgIbKVYVI6=SIFU]M7^3RiBMY:Z_/K6_ZZ>JSh=fJEeA
Ad0j>CXoAe9NKWj?XK2nb];Gf=G=`[BST7]WDd0a9A`H6AhX=TMLLXVQ]l_Kj?3c
lNWMc;NPQfiE?RTH30H4218P<dYSOYRbb]k^nOknn>cLajnENUm6;a`=10022QHX
?UI`RjFmdnCan?[gk^3>^J68KUI0;AhC3@dB72XlD6MnUJZmcM[Ri^GNeLNgY91l
J5I6>BlZ:B/a>TMEIGJ6UZB`^/33a<6k/jRLT8=gK69JE51?D5=HGfI^Mgj6SI:F
VIZIUiFBSXZ6PWmlNgYiNW]lOX21PX:1P7mlNGIbKfa[JFY[KW5gOHB;TiZPYJV[
ZjRTWIF;P7EYGU=:A40n@DE=EfAbPY:Q/;c7c];Bc/Nl[Yf;MfAA@38V7a`M8bhl
CF9gSZFic=_Wk^o]i=O6/I^2JE4j9aP=1`H<5RDiD6V3WKO=hNojo_cejMS2ZY1e
FT4Z60/2008;6Ba2FgJAZl?Gj?Cko?O]g/^eW89XD3XW6@l:2a4L:ciCJh:J/<?C
gnOZin7EakFRS7MSD40c:R@T9bhhAUIWN8^KZ[O0a/W9aKjeZYf?PG=WG5A>BTU:
CUAKI6igP8VAUibOX:2NViNBS8N2OWYgMGAdMGIhNWamOgmoOgilNGMeLg5`L75b
MGYnQ8ZAUYbPXjFTXYjHTHQnM6UOETi9ATE7C5=MJGJ4Tj:_^/C:cLg9`KJXV8Id
HU10<bTS82<Y=49CIgbBYk_=fnK[k>SOdL2/UGeTCCLU5`d82@lJ:SiEKhVS^m7S
lOWmn_;UdkfTRVmD?2LE204010hL<4MPNiJ`b=c/mogmmncKak2GO6=:=B8D2`L9
41`/@5M_R:2fbMWUk>gZh]K6/ij8LUe:>RdT7alS:cM6EfUlSj2`_LK<clk9`KNZ
W8enL69GCTM3@dE9D5USKGR3SIFMXZFWYZBPViF?R89lMg=`KVi^Kg5dMWUlOWn0
P7mnOG]iMgMfMWMiO7n4RHfBUiZMWYjLV9>=QGacJV5JDdi;BdeBFF9]NXNDXJjh
`<K7a/:j/::CPW5OCd4d;2HU:2ljB5U/PIJZ_LgJhnSXhmW<^ZJ?N61:=B@G3P/<
51l`A5]dSZNoe>GbnO_hkn7>^9n4JDlg8a860@05420dC6J1W;K=h>oio_gfjMW4
Zi9gGD@_7A081@P@7Bm4FgB=Y[c?gnW`l>cSe/BaVXA]Ed@d9alJ6b0Y=dMIK82D
Y[G3c=;Ddlg4^JZKRg][GE58@Cdm?dE=EV9]NXJAVj:X[:f/ZZFOV968PGYdKf]X
IfMYJfibMWUmOh63Q8>3PH1nOGakNganP8>6RXjAU9JGUiJCSXV3NgA/I5eHE59B
E5QOIg9mRIFQ[;Fl`<;1_;BZWHioKUi?@SL_:bX]=D1>GW65VJbnc=WPi>?NdlJd
X8YcG4Ld91P@3Q4H9CE:HGZCZl;Fi_;hnOG[g<VbVGiTBc<P40H10@PD93UAJhNQ
^m7Tlo_ooOCWeKnVS75G?bXI30D31a4O<TMPNI>[`MGTk_?ck^?E`jjFOfQB?RhQ
6AHH7RPfB5]`QIV[_<WBf=WGd<JiZYV8MVIGBd4j=cPj@DYEHFmlRIFPZ:nb];:_
ZJ:JTHQoMfmYIF9QHF9UJFicMgb0PhJ8RHV8QXF3PH1oOWn0PHB6RH^>T96AT8j:
QX5kM6iWHEeJF5QJGVA/MGn:UJ2Y/KNk_;Ze[ZBHRW]/GU14>S<`<3@kAUATMXRK
[Kk;e]gPg]S>`:nKQFmIAC<T6A<A5AdZ>e1WOiN_aMSWlOOglNKG`jbDNEm6<1d?
1@432QLY?UMaS:O0e^SeoOollnCA^j67K54j9A@90`874R4eBfEnVK77f^Wbm_G_
hmC0ZY9jHT`h:1`E4QDL:3M:GWB:Wk72cmWMg]_Cb;VYUhAbHE95>c@b<SHmAeAQ
L7n=VZF_]KVj^;B^YIbBQgecJfAOG5YJGF1UJW1fO8:6RXf>Shj=RhV7Q8:1Ogmo
P8:4QHR9RX^:RHN3Og]fL6]VHf1NGf5TJG1hPH^DWZJ]/[Ff]:nXWi>7NF]NDDHn
>3De>T5<FFUjS9f^_L[DfM_Id/NjZIF0JeI3<RDK5ADI8c11EVb4W;?8fNO`mO?]
hM:mYhedFd8]6`h60PH>6bi3G7NB[<GJj_Onoo[`hLffW85VC3@Q4@H10PLD93Q@
JXBN]lgOkOGimnoSd[fVSGALAS8R5a4?4a/X>4aRN8jT^<SEg^;RgMG8^JNDPFeL
C3he;b`]<S]6Df=bPY6OZkFk_l2n^K6XWI:6Ng1VGeUEE5AGFf1WKWImQ8Z>TYBE
UIBASX^8QH9oOWemOGioPH:4QHF5Q85oNgMdKfaYIVEUIfY^M7^3Ri>KXZR][jn]
ZJ:IShAgJUiCBD8l>Sa0B59OKWj?Wjjlb=3Ee]?<`KBST7aXE48c9QhI6AhX=TMK
LHRO]/WJi^obl>SLc;RQR6mF?bXI3@H52A8P<dURO9NabMg]n?knn>gMb;2FNf17
<1`>10022AHW?5E_RZBld^Can?_gkn7?^Z:8KeM0;1dC30`A6bPjCfEmU:Zmc]_S
inKPelVhYI5lJEI6>2hY9bT_>DEDI7F6UZBa^l;5aL>m]:ZNTHAgJf5IDdi=CU5F
GFE]MWj6SI>HVYbLVYNDSh^7PWmlNGQhN7UjO7eoP861P7mmNWMdLFm]Jfa]Kg9g
OH>:TIRNXjNYZJNSW9F;PGEZGeE=AT90@TI>F6AbPI6P[[_5c=3AcLJk[Ij;N6EB
@C<X8AdO92hlCF5gSJ>hbm[Vk>o/hmO6/Y^3JU8l:1P>1`L<5RDhCfR2W;K<h>oi
o_cfjMS3Zi5eFd8/6@/2008;6B]1FWB@Z/;Gj?Cko?S^glbfWH=YD3XW6@h92Q0J
:CeBJX6I/<?Dh>S[jN;GbKNSSGQSD3lb:B<R9B`gA5AVN8ZKZ[O1b<_;al2gZij@
PG=WG5=<B4M8C59JHfafP8ZBV9fQXZ:PWIVCSXR2OWUfM79bLgAfN7YlOGmoOgim
NgUgMG=bLW9dMWYoPhV?U9ZNXJ>RXIfGT8QnMF]QF51;B4M8CEANJGJ4Tj2^^L;8
bl_7`;FXV8MeHe52=BXT8R@Z=49CIWbAY[[;fNCZjnONdL2/UGiVCSTV60h92Q0K
:SiEKXRQ^]3Rl?Wln_;Ue;jURg1F?BLF2@400`dL;dIONYF_amc/mogmmncMb;6H
OVA;=28D2`L83a/[?eI^QinebM[UkNo/i=O8]J29Lei:>B`S7QhR:SI5EVQkSZ2`
_LS>dM3;a;V/WHioL69FCDI2@D=7CUMQK7N3SIJNY:NYZJJRWIN@RH9lMW9^K6a/
KFmbMGQkOGn0PH60OgekNWUhN7UjO823QhbAUIRKW9bJUi:<QGedJf=KEE1>CDmC
FV=]NHJCX:bf_/C6aL6j[j:CPg9QDD8g;BPW:C0jB5U/P9FY^l_HhNKWh]W;^ZJ@
NF5;=bHI40`=51l_@e]cSJJnd^CanO_gkn7?^:25JU0h91<70@0541lcBfF0VkG<
h>ojo_ggjm[5[I=hGTD_7A0710L?72e3FW><YK_?gn[`l^kTelJbW8E]F4@c9ahI
6QlX=DEGJh2CY[K3c]CFe<o6^ZbLS7][GE16?c`k?D=;EF1/NHFAVj>Z[Jn^[:NQ
VY:9PGUcKFUWIFEWJFa`M7QlOh:4Q8F5Q8:1OgimO7enP8:5RHb?TYBEUIBBSHV3
O7E]IUmJEUACEUUPJ75mR9BOZ[>j_/2o^[>YWHmoL61AA3Ta;B`_=T5>GW64V:^l
bmOOhn;MdlFeX8]dGTPe9ATA3a4I9CE:H7VBZ/7EiO7gnOC[g<VcVX1UC3DQ4@H1
0PPC93Q@JXJP^]3Tl_cooOGXe/2XSG9H?bXI30D31a0N<DION9:[`MGTk_CdknGF
a:nHP6QB?RdQ61DF72LeAUY_Q9R/_<[CfM_Id/RkZiZ9MfIGBT0i=SHi?dQCH6ek
RIFPZK2d][Ba[:BLTXUoMfmXHf1NGf1SIfaaMgb0Q8N9RXZ:R8N5Ph60OgmoPH:4
QhV<SHn?SXb9QX5kMFmYHemLFUYLH6E/MGn9TijW[kFi^[Rd[J>HRga]Ge55?3Db
<CDlAeASMHRJ[;c:eMcNgMO=_jjKQW1JAS@V6Q@B5QhZ>dmVOYJ^a=OVl?KflNKG
a:fDNV17<Ah?1P832aLX?UI`RjJoeNOdo?ollnGB_::8K58j9AD90`464B0dBVAm
V;37f^SbmoK`iMG1Zi=jHd`h:1`D4A<J9cI8GG>9W[;2d=WNh=cEbK^ZV8EbHE54
>S<`<3@lAU9PKgj=VZJ`][^l^[J`YijCR7idJV=NFUQHFUiSJ6meO8:7Rhj@TI2?
SH^8QX>1OgmoOh22PhF7R8V9R8J3OgagLVeXIF9PHF9UJW5hPHZCW:B[/;>d/ZjW
WY>7NVaODTPo>SLh>d==FVUiRib]_<SBf=WHdLNjZ9J1K5Q5=2HM5aHJ8c11EF^3
Vk;6f>K_lo?/hM:nYhieG4<^70l60`H>6be3FgJAZl?Ij_Kmoo[ahLjgWH9WCCDQ
4@H10@LC8cM?JH>M]/cOkOKjmo3TdkjWSWEMAS8R5a0>4AXV=d]PMhjT]lWEgnCS
gmO:^jVFPFiLBchd;BX[<CU4DV5aPI6O[;Jl`L70^[>ZWi>7Ng1VGUMCDU9DFEiU
KGEmPhZ?TiJGUiJCT8f9QX9oOGakNgamOX22PhB3Ph5oO7UeLFi[J6MWJ6]_M7^2
RY:IX:JZ[Jf/Yj6IShAgK61DBd<n?3e1BE=OKWf=WZfka/kCeM;;`K>STGeYED@d
:1lK6alY=TMKLHRN]<SIiNkaknSLc;RQRG1G@2`K3PL52A8P<TQQNiJ`b=c/mogn
n>gMbK6GO658<Ad>10012ADV>eA^RJ>ld^CanO_hl>;A^j>9L5M0;AdB30/@6BLi
CFAlTjZmc]_Tj>OR\>"]},
  ImageCacheContents->"Sound",
  CellTags->{
  "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", "mmtag:17:Play[]", 
    "mmtag:17:sound_generation"}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->{
  "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", "mmtag:17:Play[]", 
    "mmtag:17:sound_generation"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Play[If[t > 0.5, CNote, 0], {t, 0, 1}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 8192 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080101F32475F7992AB
C2D7E8F4FCFFFDF6EADAC6B0977D644C352212070100040C1A2B4058718AA4BBD1E3F1FAFFFF
F9EFE0CDB79F866C533C28170A020002091525395069829CB4CADDEDF8FEFFFBF2E5D3BEA78E
745B432E1C0E0400000611203349617A94ADC4D8E8F5FDFFFDF6EAD9C5AE967C634A34211207
0100040D1B2C4159728CA5BDD2E4F2FBFFFEF9EEDFCCB69E846B523B27160A0200020A16263A
516A849DB5CBDEEEF8FEFFFBF2E4D2BDA58C7359422D1B0D040001071221344A627C95AEC5D9
E9F6FDFFFDF5E9D8C4AD947B6149332011060100040E1C2D435A748DA6BED3E5F2FBFFFEF8ED
DECBB49C8369503A2615090200020A17273C536B859EB7CDDFEEF9FFFFFBF1E3D1BCA48B7158
412C1A0D040001071222354B647D97AFC6DAEAF6FDFFFDF5E8D7C3AC93796048321F10060000
050E1C2F445C758FA8BFD4E5F3FCFFFEF8ECDDC9B39B81684F392515090200030B17283D546D
86A0B8CEE0EFF9FFFFFAF0E2D0BAA38970573F2B190C030001081323364C657E98B0C7DBEBF7
FEFFFCF4E7D6C2AA91785F47311E10050000050F1D30455D7690A9C0D5E6F3FCFFFEF7ECDCC8
B29980664E372414080100030B18293E556E88A1B9CFE1F0FAFFFFFAF0E1CFB9A1886E553E2A
180B030001081424374E668099B2C8DCECF7FEFFFCF3E6D5C0A990765D45301D0F0500000510
1E31465E7891AAC1D6E7F4FCFFFEF7EBDBC7B1987E654D362313080100030C192B3F577089A3
BAD0E2F0FAFFFFF9EFE0CEB8A0876D543D28180B030002091525384F68819BB3C9DDECF8FEFF
FCF3E5D4BFA88F755C442F1C0E05000006101F3248607993ACC3D7E8F5FDFFFDF6EADAC6AF97
7D644B352212070100040D1A2C4158718BA4BCD1E3F1FBFFFFF9EEDFCDB79F856C533C27170A
0200020915263A5069839CB4CBDEEDF8FEFFFBF2E5D3BEA68D745A432E1C0E04000106112033
49617B94ADC4D8E9F5FDFFFDF6E9D9C5AE957C624A342112070100040D1B2D4259728CA5BDD2
E4F2FBFFFEF8EEDECBB59D846A513B26160A0200020A16273B526A849DB6CCDFEEF9FEFFFBF2
E4D2BDA58C7259422C1B0D040001071221344A637C96AEC5D9E9F6FDFFFDF5E9D8C4AD947A61
49332011060100040E1C2E435B748EA7BED3E5F2FBFFFEF8EDDECAB49C826950392515090200
020A17283C536C859FB7CDE0EFF9FFFFFAF1E3D1BBA48A7158402B1A0C040001071222354C64
7D97B0C6DAEAF6FDFFFCF4E8D7C2AB92795F47321F10060000050E1D2F445C758FA8BFD4E6F3
FCFFFEF7ECDDC9B39A81674F382414090200030B18293D546D87A0B8CEE1EFF9FFFFFAF0E2D0
BAA2896F563F2A190C030001081323364D657F98B1C7DBEBF7FEFFFCF4E7D6C1AA91775E4631
1E0F050000050F1E30465D7790A9C1D5E6F4FCFFFEF7EBDCC8B29980664E372314080100030B
192A3E566F88A2B9CFE1F0FAFFFFFAF0E1CFB9A1886E553E29180B030001081424384E67809A
B2C9DCECF7FEFFFCF3E6D5C0A990765D452F1D0F05000006101E31475F7892ABC2D6E7F4FCFF
FEF6EBDBC7B0987E654C362213080100030C192B4057708AA3BBD0E2F1FAFFFFF9EFE0CDB8A0
866D543D28170B030002091525394F68829BB3CADDEDF8FEFFFBF3E5D4BFA78E755B442E1C0E
05000006101F3248607A93ACC3D7E8F5FDFFFDF6EADAC6AF967D634B352212070100040D1A2C
4158718BA4BCD1E3F1FBFFFFF9EEDFCCB69E856B523B27160A0200020916263A5169839CB5CB
DEEDF8FEFFFBF2E4D3BEA68D735A422D1B0D0400010611203349627B95ADC4D8E9F5FDFFFDF5
E9D9C4AE957B624A342111070100040D1B2D425A738DA6BDD2E4F2FBFFFEF8EDDECBB59D836A
513A2616090200020A16273B526B849EB6CCDFEEF9FEFFFBF1E3D1BCA58B7259412C1A0D0400
01071221344B637C96AFC5D9EAF6FDFFFDF5E8D8C3AC937A6048322011060000040E1C2E435B
748EA7BED3E5F3FBFFFEF8EDDDCAB49B826850392515090200020A17283C536C869FB7CDE0EF
F9FFFFFAF1E3D0BBA38A7057402B1A0C030001071322364C647E97B0C7DAEBF6FDFFFCF4E7D7
C2AB92785F47311F10060000050F1D2F455C768FA8C0D4E6F3FCFFFEF7ECDCC9B29A81674E38
2414080100030B18293E556E87A1B9CEE1EFFAFFFFFAF0E2CFBAA2896F563F2A190C03000108
1323374D667F99B1C8DBEBF7FEFFFCF4E7D5C1AA91775E46301E0F050000050F1E30465E7791
AAC1D6E7F4FCFFFEF7EBDBC8B1997F664D372313080100030C192A3F566F89A2BACFE2F0FAFF
FFFAEFE1CEB8A1876E553D29180B030001081424384F67819AB3C9DCECF7FEFFFCF3E6D4C0A8
8F765C452F1D0F05000006101F31475F7992ABC2D7E8F4FCFFFDF6EADAC6B0977E644C362213
070100030C1A2B4057708AA3BBD0E3F1FAFFFFF9EFE0CDB79F866C533C28170A020002091525
395068829BB4CADDEDF8FEFFFBF2E5D3BEA78E745B432E1C0E0400000611203248617A94ACC3
D8E8F5FDFFFDF6EAD9C5AF967C634B342112070100040D1A2C4159728CA5BCD2E3F1FBFFFEF9
EEDFCCB69E846B523B27160A0200020916263A516A839DB5CBDEEEF8FEFFFBF2E4D2BDA68C73
5A422D1B0D040001071121344A627B95AEC5D9E9F5FDFFFDF5E9D8C4AD947B61493320110601
00040D1B2D425A738DA6BED3E4F2FBFFFEF8EDDECBB59C8369513A2615090200020A17273B52
6B859EB6CCDFEEF9FFFFFBF1E3D1BCA48B7158412C1A0D040001071222354B637D96AFC6DAEA
F6FDFFFDF5E8D7C3AC93796048321F10060000050E1C2E445B758EA7BFD4E5F3FCFFFEF8EDDD
CAB39B82684F392515090200030B17283D546D86A0B8CDE0EFF9FFFFFAF1E2D0BBA38A705740
2B190C030001081323364C657E98B0C7DBEBF7FEFFFCF4E7D6C2AB92785F47311E1006000005
0F1D2F455D7690A9C0D5E6F3FCFFFEF7ECDCC9B29A80674E382414080100030B18293E556E88
A1B9CFE1F0FAFFFFFAF0E1CFB9A1886F563E2A190B030001081424374E668099B2C8DCEBF7FE
FFFCF4E6D5C1A990775D45301E0F050000050F1E31465E7791AAC1D6E7F4FCFFFEF7EBDBC7B1
987F654D362313080100030C192A3F566F89A2BAD0E2F0FAFFFFF9EFE0CEB8A0876D543D2918
0B030002091424384F67819AB3C9DDECF8FEFFFCF3E6D4BFA88F755C442F1D0E05000006101F
3248607993ABC2D7E8F4FCFFFDF6EADAC6AF977D644B352212070100040C1A2B4058718AA4BB
D1E3F1FAFFFFF9EEE0CDB79F856C533C28170A020002091525395069829CB4CADEEDF8FEFFFB
F2E5D3BEA78D745B432E1C0E0400010611203349617A94ADC4D8E9F5FDFFFDF6E9D9C5AE957C
624A342112070100040D1B2C4259728CA5BDD2E4F2FBFFFEF9EEDFCCB69D846A523B27160A02
00020A16273B526A849DB5CCDFEEF8FEFFFBF2E4D2BDA58C7259422D1B0D040001071221344A
627C95AEC5D9E9F6FDFFFDF5E9D8C4AD947A6149332011060100040E1C2E435A748DA6BED3E5
F2FBFFFEF8EDDECAB49C8369503A2615090200020A17283C536C859FB7CDDFEEF9FFFFFBF1E3
D1BCA48B7158402C1A0C040001071222354B647D97AFC6DAEAF6FDFFFDF5E8D7C3AC93796048
321F10060000050E1D2F445C758FA8BFD4E5F3FCFFFEF8ECDDC9B39B81684F38251409020003
0B18293D546D87A0B8CEE0EFF9FFFFFAF0E2D0BAA28970573F2A190C030001081323364D657F
98B1C7DBEBF7FEFFFCF4E7D6C1AA91785E46311E10050000050F1D30455D7690A9C0D5E6F3FC
FFFEF7ECDCC8B29980664E372414080100030B182A3E556E88A1B9CFE1F0FAFFFFFAF0E1CFB9
A1886E553E29180B030001081424374E668099B2C8DCECF7FEFFFCF3E6D5C0A990765D45301D
0F05000006101E31475F7892AAC2D6E7F4FCFFFEF7EBDBC7B0987E654C362313080100030C19
2B3F577089A3BBD0E2F0FAFFFFF9EFE0CEB8A0866D543D28170B030002091525394F68819BB3
CADDECF8FEFFFCF3E5D4BFA88E755C442E1C0E05000006101F3248607993ACC3D7E8F5FDFFFD
F6EADAC6AF967D634B352212070100040D1A2C4158718BA4BCD1E3F1FBFFFFF9EEDFCCB79E85
6B533C27170A0200020915263A5169839CB5CBDEEDF8FEFFFBF2E4D3BEA68D735A432D1B0E04
00010611203349617B94ADC4D8E9F5FDFFFDF5E9D9C5AE957C624A342111070100040D1B2D42
5A738CA5BDD2E4F2FBFFFEF8EEDECBB59D846A513A26160A0200020A16273B526B849EB6CCDF
EEF9FEFFFBF1E4D2BCA58C7259412C1B0D040001071221344A637C96AEC5D9EAF6FDFFFDF5E8
D8C3AC947A6149332011060000040E1C2E435B748EA7BED3E5F2FBFFFEF8EDDDCAB49C826950
392515090200020A17283C536C869FB7CDE0EFF9FFFFFAF1E3D1BBA38A7158402B1A0C030001
071322354C647E97B0C6DAEAF6FDFFFCF4E8D7C2AB92795F47311F10060000050F1D2F445C75
8FA8BFD4E6F3FCFFFEF7ECDCC9B39A81674F382414080100030B18293D556D87A0B8CEE1EFF9
FFFFFAF0E2CFBAA2896F563F2A190C030001081323374D657F98B1C8DBEBF7FEFFFCF4E7D6C1
AA91775E46301E0F050000050F1E30465E7790A9C1D5E7F4FCFFFEF7EBDBC8B1997F664D3723
13080100030C192A3F566F88A2BACFE2F0FAFFFFFAEFE1CEB9A1876E553E29180B0300010814
24384E67809AB2C9DCECF7FEFFFCF3E6D5C0A88F765D452F1D0F05000006101F31475F7892AB
C2D6E7F4FCFFFDF6EBDAC7B0977E644C362213070100030C192B4057708AA3BBD0E2F1FAFFFF
F9EFE0CDB79F866C543C28170B030002091525395068829BB4CADDEDF8FEFFFBF3E5D4BFA78E
745B442E1C0E0400000611203248607A93ACC3D7E8F5FDFFFDF6EAD9C6AF967D634B35211207
0100040D1A2C4159728BA4BCD1E3F1FBFFFEF9EEDFCCB69E856B523B27160A0200020916263A
516A839DB5CBDEEDF8FEFFFBF2E4D2BDA68D735A422D1B0D0400010711203349627B95ADC4D8
E9F5FDFFFDF5E9D8C4AD957B6249332011070100040D1B2D425A738DA6BDD2E4F2FBFFFEF8ED
DECBB59D836A513A2616090200020A16273B526B859EB6CCDFEEF9FEFFFBF1E3D1BCA48B7259
412C1A0D040001071221354B637D96AFC6D9EAF6FDFFFDF5E8D7C3AC937A6048322011060000
040E1C2E445B748EA7BFD4E5F3FBFFFEF8EDDDCAB49B826850392515090200030B17283C546C
869FB7CDE0EFF9FFFFFAF1E2D0BBA38A7057402B190C030001071322364C647E97B0C7DAEBF6
FDFFFCF4E7D6C2AB92785F47311F10060000050F1D2F455D768FA8C0D5E6F3FCFFFEF7ECDCC9
B29A80674E382414080100030B18293E556E87A1B9CEE1EFFAFFFFFAF0E2CFBAA2886F563F2A
190C030001081323374D667F99B1C8DBEBF7FEFFFCF4E7D5C1A990775E46301E0F050000050F
1E30465E7791AAC1D6E7F4FCFFFEF7EBDBC8B1987F654D372313080100030C192A3F566F89A2
BACFE2F0FAFFFFF9EFE1CEB8A0876D553D29180B030001081424384F67819AB3C9DCECF7FEFF
FCF3E6D4BFA88F755C442F1D0F05000006101F31475F7992ABC2D7E8F4FCFFFDF6EADAC6B097
7E644C352213070100030C1A2B4058718AA3BBD1E3F1FAFFFFF9EFE0CDB79F866C533C28170A
020002091525395069829CB4CADDEDF8FEFFFBF2E5D3BEA78E745B432E1C0E04000006112033
49617A94ACC3D8E8F5FDFFFDF6EAD9C5AE967C634A34
pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003oool0003o
o`0004;o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX0oooonfXNoookJP03o`000?oonf[ooo]Z0?oooo]Z7OoonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Z
oookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooook
JQoooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP0;o`000?oonf[o0000oookJ_l0003ooo]Z
o`000?oonf[o0000oookJ_l000000_oonfX01Ol0003ooo]Zo`000?oonf[o000000?ooo]Z00co0000
oookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l00002oookJP0;o`000?oonf[o
0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX02Ol0003ooo]Zo`000?oonf[o
0000oookJ_l0003ooo]Zo`000002oookJP0;o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o
0000oookJ_l000000_oonfX02Ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000002oook
JP09o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00_o0000oookJ_l0003o
oo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000002oookJP09o`000?oonf[o0000oookJ_l0003o
oo]Zo`000?oonf[o000000;ooo]Z00Wo0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l00000
0_oonfX02ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o000000Cooo]Z00Oo
0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00Wo0000oookJ_l0003ooo]Zo`000?oonf[o
0000oookJ_l000000_oonfX02ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o
000000Cooo]Z00Oo0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00_o0000oookJ_l0003o
oo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000002oookJP09o`000?oonf[o0000oookJ_l0003o
oo]Zo`000?oonf[o000000Cooo]Z00Oo0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00?o
0000oookJ_l000000ooonfX01Ol0003ooo]Zo`000?oonf[o000000;ooo]Z00Wo0000oookJ_l0003o
oo]Zo`000?oonf[o0000oookJ_l000001?oonfX02Ol0003ooo]Zo`000?oonf[o0000oookJ_l0003o
oo]Zo`000002oookJP09o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00So
0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJP7o000000000ol0003ooo]ZoookJP3ooookJQoo
oo]Z00Co0000oookJ_l0003ooo]Z1_l000001Ooonf[o0000oookJ_l0003ooo]Z00Ko000000Gooo]Z
o`000?oonf[o0000oookJP06o`000007oookJ_l0003ooo]Zo`000?oonf[o0000oookJP06o`000005
oookJ_l0003ooo]Zo`000?oonfX01_l000001ooonf[o0000oookJ_l0003ooo]Zo`000?oonfX01_l0
00001Ooonf[o0000oookJ_l0003ooo]Z00Ko000000Gooo]Zo`000?oonf[o0000oookJP06o`000007
oookJ_l0003ooo]Zo`000?oonf[o0000oookJP04o`000007oookJ_l0003ooo]Zo`000?oonf[o0000
oookJP06o`000005oookJ_l0003ooo]Zo`000?oonfX01_l000001ooonf[o0000oookJ_l0003ooo]Z
o`000?oonfX01_l000001Ooonf[o0000oookJ_l0003ooo]Z00Ko000000Gooo]Zo`000?oonf[o0000
oookJP06o`000007oookJ_l0003ooo]Zo`000?oonf[o0000oookJP06o`000005oookJ_l0003ooo]Z
o`000?oonfX01_l000001ooonf[o0000oookJ_l0003ooo]Zo`000?oonfX01_l000001Ooonf[o0000
oookJ_l0003ooo]Z00Ko000000Oooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z00Ko000000Gooo]Z
o`000?oonf[o0000oookJP06o`000005oookJ_l0003ooo]Zo`000?oonfX01_l000001ooonf[o0000
oookJ_l0003ooo]Zo`000?oonfX01_l000001Ooonf[o0000oookJ_l0003ooo]Z00Ko000000Gooo]Z
o`000?oonf[o0000oookJP06o`000007oookJ_l0003ooo]Zo`000?oonf[o0000oookJP01o`000000
00?o0000oookJ_oonfX0oooonfXOoookJP03o`000?oonf[o000000Oo000000?ooo]Zo`000?oonfX0
2_l000000ooonf[o0000oookJP08o`000003oookJ_l0003ooo]Z00[o000000?ooo]Zo`000?oonfX0
2?l000000ooonf[o0000oookJP08o`000003oookJ_l0003ooo]Z00[o000000?ooo]Zo`000?oonfX0
2?l000000ooonf[o0000oookJP08o`000003oookJ_l0003ooo]Z00[o000000?ooo]Zo`000?oonfX0
2?l000000ooonf[o0000oookJP08o`000003oookJ_l0003ooo]Z00[o000000?ooo]Zo`000?oonfX0
2?l000000ooonf[o0000oookJP0:o`000003oookJ_l0003ooo]Z00So000000?ooo]Zo`000?oonfX0
2?l000000ooonf[o0000oookJP0:o`000003oookJ_l0003ooo]Z00So000000?ooo]Zo`000?oonfX0
2_l000000ooonf[o0000oookJP08o`000003oookJ_l0003ooo]Z00So000000?ooo]Zo`000?oonfX0
2_l000000ooonf[o0000oookJP08o`000005oookJ_l0003ooo]Zo`000?oonfX00Ol000000003o`00
0?oonf[o00000?oo0000:ol000000ooonf[o0000o`00000Po`000003oookJ_l0003o000001Go0000
00?ooo]Zo`000?l000002?l000000ooonf[o0000o`000008o`000003oookJ_l0003ooo]Z00[o0000
00?ooo]Zo`000?l000002?l000000ooonf[o0000o`00000:o`000003oookJ_l0003o000000So0000
00?ooo]Zo`000?l000002?l000000ooonf[o0000o`00000:o`000003oookJ_l0003o000000So0000
00?ooo]Zo`000?l000005Ol000000ooonf[o0000o`000008o`000003oookJ_l0003o000001Go0000
00?ooo]Zo`000?l000002?l000000ooonf[o0000o`00000:o`000003oookJ_l0003o000000So0000
00?ooo]Zo`000?l000002?l000001Ooonf[o0000o`000?l0003ooo]Z007o000000000ol0003ooo]Z
oookJP3ooookJQkooo]Z00?o0000oookJ_l000005_l000000ooonf[o0000o`000008o`000003oook
J_l0003o000001Go000000?ooo]Zo`000?l000002?l000000ooonf[o0000o`000008o`000003oook
J_l0003ooo]Z00[o000000?ooo]Zo`000?l000002?l000000ooonf[o0000o`00000:o`000003oook
J_l0003o000000So000000?ooo]Zo`000?l000002_l000000ooonf[o0000o`000008o`000003oook
J_l0003o000000So000000?ooo]Zo`000?l000002_l000000ooonf[o0000o`000008o`000003oook
J_l0003o000000So000000?ooo]Zo`000?l000002_l000000ooonf[o0000o`000008o`000003oook
J_l0003o000000So000000?ooo]Zo`000?l000002_l000000ooonf[o0000o`000008o`000003oook
J_l0003o000000So000000?ooo]Zo`000?oonfX02_l000001?oonf[o0000o`000?oonfX1o`000000
00?o0000oookJ_oonfX0oooonfXNoookJP04o`000?oonf[o0000oookJPSo000000?ooo]Zo`000?oo
nfX02?l000000ooonf[o0000oookJP0:o`000003oookJ_l0003ooo]Z00So000000?ooo]Zo`000?oo
nfX02?l000001Ooonf[o0000oookJ_l0003ooo]Z00So000000?ooo]Zo`000?oonfX02?l000000ooo
nf[o0000oookJP08o`000005oookJ_l0003ooo]Zo`000?oonfX02?l000000ooonf[o0000oookJP08
o`000005oookJ_l0003ooo]Zo`000?oonfX01_l000001Ooonf[o0000oookJ_l0003ooo]Z00So0000
00?ooo]Zo`000?oonfX02?l000000ooonf[o0000oookJP0:o`000003oookJ_l0003ooo]Z00So0000
00?ooo]Zo`000?oonfX02?l000000ooonf[o0000oookJP0:o`000003oookJ_l0003ooo]Z00So0000
00?ooo]Zo`000?oonfX02_l000000ooonf[o0000oookJP08o`000003oookJ_l0003ooo]Z00So0000
00Gooo]Zo`000?oonf[o0000oookJP08o`000003oookJ_l0003ooo]Z00So000000?ooo]Zo`000?oo
nfX02?l000001?oonf[o0000oookJ_l00002oookJP7o000000000ol0003ooo]ZoookJP3ooookJQko
oo]Z00Co0000oookJ_l0003ooo]Z1_l000001ooonf[o0000oookJ_l0003ooo]Zo`000?oonfX01_l0
00001Ooonf[o0000oookJ_l0003ooo]Z00Ko000000Gooo]Zo`000?oonf[o0000oookJP06o`000007
oookJ_l0003ooo]Zo`000?oonf[o0000oookJP04o`000007oookJ_l0003ooo]Zo`000?oonf[o0000
oookJP06o`000007oookJ_l0003ooo]Zo`000?oonf[o0000oookJP04o`000007oookJ_l0003ooo]Z
o`000?oonf[o0000oookJP04o`000009oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z
00Co000000Oooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z00Co000000Oooo]Zo`000?oonf[o0000
oookJ_l0003ooo]Z00Ko000000Oooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z00Co000000Oooo]Z
o`000?oonf[o0000oookJ_l0003ooo]Z00Co000000Oooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z
00Ko000000Oooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z00Co000000Oooo]Zo`000?oonf[o0000
oookJ_l0003ooo]Z00Ko000000Gooo]Zo`000?oonf[o0000oookJP06o`000007oookJ_l0003ooo]Z
o`000?oonf[o0000oookJP04o`000007oookJ_l0003ooo]Zo`000?oonf[o0000oookJP06o`000005
oookJ_l0003ooo]Zo`000?oonfX01_l000001ooonf[o0000oookJ_l0003ooo]Zo`000?oonfX01?l0
00001ooonf[o0000oookJ_l0003ooo]Zo`000?oonfX01_l000001ooonf[o0000oookJ_l0003ooo]Z
o`000?oonfX01?l000001ooonf[o0000oookJ_l0003ooo]Zo`000?oonfX01?l000001_oonf[o0000
oookJ_l0003ooo]Zo`0000;ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
0000003oo`000?oo0000@_l000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o00000000
0ol0003ooo]Zo`00003ooookJQoooo]Z00co0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oo
nf[o0000oookJ_l00002oookJP0;o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oook
J_l000000_oonfX02Ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000002oookJP09o`00
0?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00_o0000oookJ_l0003ooo]Zo`00
0?oonf[o0000oookJ_l0003ooo]Zo`000002oookJP09o`000?oonf[o0000oookJ_l0003ooo]Zo`00
0?oonf[o000000;ooo]Z00Wo0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX0
2ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00Wo0000oook
J_l0003ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX02Ol0003ooo]Zo`000?oonf[o0000oook
J_l0003ooo]Zo`000002oookJP0;o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oook
J_l000000_oonfX02Ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000002oookJP0;o`00
0?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX02Ol0003ooo]Zo`00
0?oonf[o0000oookJ_l0003ooo]Zo`000002oookJP0;o`000?oonf[o0000oookJ_l0003ooo]Zo`00
0?oonf[o0000oookJ_l000000_oonfX02Ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`00
0002oookJP09o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00_o0000oook
J_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000002oookJP09o`000?oonf[o0000oook
J_l0003ooo]Zo`000?oonf[o000000;ooo]Z00Wo0000oookJ_l0003ooo]Zo`000?oonf[o0000oook
J_l000000_oonfX02ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o000000;o
oo]Z00Wo0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX02Ol0003ooo]Zo`00
0?oonf[o0000oookJ_l0003ooo]Zo`000002oookJP0;o`000?oonf[o0000oookJ_l0003ooo]Zo`00
0?oonf[o0000oookJ_l000000ooonfX1o`00000000?o0000oookJ_oonfX0oooonfXOoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP05o`000?oonf[ooo]Zoook
J_l000001_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000ooonfX00ol0003ooo]Zoook
JP04oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000004oookJP03o`000?oonf[o000000Co
oo]Z00?o0000oookJ_oonfX00ooonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Go0000oook
J_oonf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000000ooonfX0
0ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX01ol0003ooo]Zoook
J_oonf[o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]Zoook
J_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00Oo0000oookJ_oonf[ooo]Zo`00
0?oonf[o000000?ooo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[o000000;o
oo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX00ooonfX0
1Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP07o`00
0?oonf[ooo]ZoookJ_l0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oook
J_oonf[ooo]Zo`000002oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000003oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000003oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000?ooo]Z00Co0000oook
J_oonf[o00000ooonfX00ol0003ooo]ZoookJP05oookJP7o000000000ol0003ooo]ZoookJP3ooook
JR;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX00ooonfX1o`00000000?o0000oookJ_oonfX0oooonfXeoookJP03
o`000?oonf[o000000Cooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]Zo`00000IoookJP03
o`000?oonf[o000000?ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Zo`00000Eoook
JP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000004oookJP03o`000?oonf[o000000Cooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o000000Cooo]Z00?o
0000oookJ_l000006OoonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o000000?ooo]Z00?o
0000oookJ_l000005OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000?ooo]Z00?o
0000oookJ_l000001?oonfX00ol0003ooo]Zo`00000BoookJP04o`000?oonf[ooo]Zo`0000?ooo]Z
00?o0000oookJ_l000001?oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Gooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3o
oookJR3ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000?ooo]Z00Co0000oookJ_oonf[o
00000ooonfX00ol0003ooo]ZoookJP0EoookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX01ol0
003ooo]ZoookJ_oonf[o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP0FoookJP07o`000?oo
nf[ooo]ZoookJ_l0003ooo]Zo`000003oookJP04o`000?oonf[ooo]Zo`0001Wooo]Z00?o0000oook
J_l000000ooonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z01Gooo]Z00Go0000
oookJ_oonf[ooo]Zo`000002oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000003oookJP03
o`000?oonf[ooo]Z01Kooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000?ooo]Z00Co0000
oookJ_oonf[o00006OoonfX00ol0003ooo]Zo`000003oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z
00?o0000oookJ_l000006OoonfX01?l0003ooo]ZoookJ_oonfX1o`00000000?o0000oookJ_oonfX0
oooonfXcoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z9?oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP3o
oookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXOoookJP03o`000?oonf[ooo]Z
00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP05oookJP7o000000000ol0003ooo]ZoookJP3ooook
JSSooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX07?oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000KoookJP04
o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000007?oonfX01ol0003ooo]ZoookJ_oonf[o
0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP0LoookJP05o`000?oonf[ooo]ZoookJ_l00000
0_oonfX01Ol0003ooo]ZoookJ_oonf[o000001_ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0
003ooo]Zo`00000PoookJP03o`000?oonf[o000000?ooo]Z00Co0000oookJ_oonf[o00002ooonfX1
o`00000000?o0000oookJ_oonfX0oooonfXRoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX02_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX02_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP03oookJP7o000000000ol0003ooo]ZoookJP3ooookJR7o
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00?o
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zoook
JP3ooookJSGooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000005oookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01?oo
nfX2o`0000Kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02OoonfX1o`00000000?o0000oookJ_oonfX0oooonfXP
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP05
oookJP7o000000000ol0003ooo]ZoookJP3ooookJRKooo]Z00Go0000oookJ_oonf[ooo]Zo`000006
oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oo
nf[o000001kooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000?ooo]Z00?o0000oookJ_oo
nfX07?oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000N
oookJP05o`000?oonf[ooo]ZoookJ_l000007_oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oo
nf[ooo]ZoookJ_l000007_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000OoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`000000
00?o0000oookJ_oonfX0oooonfXToookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0
5ooonfX01?l0003ooo]ZoookJ_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXjoookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0PoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP03oookJP;o0000
1OoonfX00ol0003ooo]ZoookJP07oookJP7o000000000ol0003ooo]ZoookJP3ooookJQgooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Oooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooook
JRCooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX01?oonfX2o`00027ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP04oookJP;o00001_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
007o000000000ol0003ooo]ZoookJP3ooookJQoooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP09oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0MoookJP7o000000000ol0003ooo]ZoookJP3ooookJSSooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003o
oo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003o
oo]ZoookJ_oonf[o000000Gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP03oook
JP05o`000?oonf[ooo]ZoookJ_l000001_oonfX00ol0003ooo]ZoookJP05oookJP7o000000000ol0
003ooo]ZoookJP3ooookJScooo]Z00?o0000oookJ_l000008?oonfX00ol0003ooo]ZoookJP03oook
JP04o`000?oonf[ooo]Zo`0001oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP03
oookJP04o`000?oonf[ooo]Zo`0001oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02OoonfX1o`00000000?o0000
oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z8_oonfX00ol0
003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP03oookJP7o000000000ol0003ooo]ZoookJP3ooookJRSooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0OoookJP;o00001OoonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX2o`00027ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0OoookJP7o000000000ol0003ooo]ZoookJP3ooookJR7ooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z017ooo]Z
00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01?ooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00?ooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3o
oookJScooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z00Cooo]Z0_l0000QoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00[ooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]Z=ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX02ooonfX1o`00000000?o0000oookJ_oonfX0oooonfXPoookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX01OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]Z9_oonfX01Ol0003ooo]ZoookJ_oonf[o000002Gooo]Z
00Go0000oookJ_oonf[ooo]Zo`00000RoookJP03o`000?oonf[o000002Kooo]Z00Co0000oookJ_oo
nf[o00008_oonfX01Ol0003ooo]ZoookJ_oonf[o000002;ooo]Z00?o0000oookJ_l000000ooonfX0
0ol0003ooo]ZoookJP0PoookJP04o`000?oonf[ooo]Zo`0002?ooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]Z9?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0GoookJP04o`000?oonf[ooo]ZoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJS[ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z00Oooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z>OoonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01?oonfX2o`00
027ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
02Kooo]Z0_l0000?oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`000000
00?o0000oookJ_oonfX0oooonfXNoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP07oookJP7o000000000ol0003ooo]ZoookJP3ooookJRCooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o
0000oookJ_oonfX01?oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP01o`00000000?o0000oookJ_oonfX0oooonfXVoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX07OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]Z7ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP05oookJP7o000000000ol0003ooo]Z
oookJP3ooookJSSooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0LoookJP05o`00
0?oonf[ooo]ZoookJ_l000009OoonfX01Ol0003ooo]ZoookJ_oonf[o000001kooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX07?oonfX01Ol0003ooo]ZoookJ_oonf[o000002Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00
000>oookJP7o000000000ol0003ooo]ZoookJP3ooookJScooo]Z00?o0000oookJ_l000008?oonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX07OoonfX0
1?l0003ooo]ZoookJ_l0000OoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Wooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]Z8_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]Z:?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0OoookJP7o000000000ol0003ooo]Z
oookJP3ooookJRSooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0IoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0OoookJP;o0000
8OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0OoookJP7o000000000ol0003ooo]ZoookJP3ooookJR7ooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00?ooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooook
JScooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX02_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXnoookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00_ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z8?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0EoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z00Gooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Zoooo
nfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJRKooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX07?oonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX05_oonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0MoookJP7o000000000ol0003ooo]ZoookJP3ooookJR[ooo]Z00Co0000oook
J_oonf[o00008_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o000002Kooo]Z00Co0000
oookJ_oonf[o00009_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o000002Kooo]Z00Co
0000oookJ_oonf[o00008ooonfX1o`00000000?o0000oookJ_oonfX0oooonfXToookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo
nf[ooo]Z01Kooo]Z00Co0000oookJ_oonf[ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z<ooo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP07oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1
o`00000000?o0000oookJ_oonfX0oooonfXjoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP0UoookJP;o0000:?oonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX07ooonfX2o`0002Sooo]Z0_l0000?oook
JP7o000000000ol0003ooo]ZoookJP3ooookJSWooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP07oookJP7o000000000ol0003ooo]ZoookJP3ooookJQkooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
3?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0
6ooonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]Z9?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0OoookJP;o00008OoonfX00ol0003ooo]ZoookJP01
o`00000000?o0000oookJ_oonfX0oooonfXVoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP14oookJP7o00000OoonfX1o`00000000?o0000oookJ_oo
nfX0oooonfXOoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Gooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
oooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJSSooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z01Kooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]Z??oonfX00ol0003ooo]Zo`00000VoookJP03o`000?oonf[ooo]Z02?ooo]Z00Go0000
oookJ_oonf[ooo]Zo`00000ToookJP03o`000?oonf[ooo]Z02Cooo]Z00Co0000oookJ_oonf[o0000
8_oonfX01Ol0003ooo]ZoookJ_oonf[o000002Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oook
JP7o000000000ol0003ooo]ZoookJP3ooookJTGooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Wooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
8_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP02oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000?o0000oookJ_oonfX0oooonfXYoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0PoookJP7o000000000ol0003ooo]ZoookJP3ooook
JRSooo]Z00?o0000oookJ_oonfX09_oonfX2o`00027ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX07ooonfX2o`00
02Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
01oooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z8OoonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP03oookJP7o
000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nfXfoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0;oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX02_oonfX1o`00000000?o0000
oookJ_oonfX0oooonfXloookJP03o`000?oonf[o000002Oooo]Z0_l0000QoookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_l000009ooonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0BoookJP7o000000000ol0003ooo]ZoookJP3ooookJSOooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00_ooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJR3ooo]Z
00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01Gooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Gooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]Z9_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z01cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z01gooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z:_oonfX00ol0003ooo]ZoookJP0S
oookJP05o`000?oonf[ooo]ZoookJ_l000008_oonfX00ol0003ooo]Zo`00000VoookJP04o`000?oo
nf[ooo]Zo`0002;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000ToookJP03o`000?oonf[ooo]Z02Co
oo]Z00Co0000oookJ_oonf[o00008ooonfX1o`00000000?o0000oookJ_oonfX0oooonfXSoookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z043ooo]Z00Co0000oookJ_oonf[ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oo
oo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJS?ooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
=ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Oooo]Z0Ol000000003o`000?oo
nf[ooo]Z0?oooo]Z>_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z01Cooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]Z@OoonfX00ol0003ooo]ZoookJP0OoookJP;o00009ooonfX2
o`0002Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0VoookJP;o0000:?oonfX2
o`0000oooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003o
oo]ZoookJP3ooookJQkooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z00Oooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z<ooonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0HoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0<oookJP03o`000?oonf[ooo]Z01_ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z9?oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0OoookJP;o00008OoonfX00ol0003ooo]ZoookJP01o`00000000?o0000
oookJ_oonfX0oooonfXVoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z04Cooo]Z0Ol00001oookJP7o000000000ol0
003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXaoookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0EoookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX07OoonfX1o`00000000?o0000oookJ_oonfX0
oooonfXOoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP05oookJP7o000000000ol0003ooo]ZoookJP3ooookJT;ooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0WoookJP05o`000?oonf[ooo]ZoookJ_l00000:?oonfX00ol0003ooo]Z
oookJP0LoookJP03o`000?oonf[ooo]Z02Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000UoookJP04
o`000?oonf[ooo]Zo`0000kooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000000ol0003ooo]ZoookJP3ooookJS_ooo]Z00Co0000oookJ_oonf[o00009_oonfX01?l0003o
oo]ZoookJ_l0000OoookJP03o`000?oonf[ooo]Z02Oooo]Z00Co0000oookJ_oonf[o00009OoonfX0
1?l0003ooo]ZoookJ_l0000YoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oo
nfX1o`00000000?o0000oookJ_oonfX0oooonfXeoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX02OoonfX1o`00000000?o0000oookJ_oonfX0oooonfXRoookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP02oookJP7o000000000ol0003o
oo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXYoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP14oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z023ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z:?oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX07ooonfX2o`0002Wooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01oooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]Z8OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01;ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[o
oo]Z00?ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z=_oonfX00ol0003ooo]ZoookJP0;oook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0koook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0Hoook
JP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0
oooonfXloookJP03o`000?oonf[o000002Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX09ooonfX2o`00027ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX02_oonfX1o`00000000?o0000oookJ_oonfX0oooonfYQoookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z00_ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z=ooonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0G
oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX0oooonfXPoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX01?oonfX1o`000000
00?o0000oookJ_oonfX0oooonfXVoookJP05o`000?oonf[ooo]ZoookJ_l000009OoonfX01?l0003o
oo]ZoookJ_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX09ooonfX01Ol0
003ooo]ZoookJ_oonf[o000002Sooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z01gooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z;OoonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000U
oookJP04o`000?oonf[ooo]Zo`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX01Ol0003ooo]Zoook
J_oonf[o000002Gooo]Z00Co0000oookJ_oonf[o00008ooonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z8ooonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP0FoookJP04o`000?oonf[ooo]ZoookJP7o000000000ol0003ooo]ZoookJP3ooookJSCooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX02?oonfX1o`00000000?o0000oookJ_oonfX0oooonfXjoookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z04Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z01Cooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z@OoonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z02Kooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX09_oonfX2o`0002Sooo]Z0_l0000?oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oo
oo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXNoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Wooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP07oookJP7o000000000ol0003ooo]Zoook
JP3ooookJS?ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX06ooonfX1o`00000000?o0000oookJ_oonfX0oooonfXT
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX00Ol000000003o`000?oonf[ooo]Z
0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJR_ooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o000002Oooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX09OoonfX2o`0002Cooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z9_oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0KoookJP7o00000OoonfX1o`00000000?o0000oookJ_oonfX0oooonfXOoookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo
nf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP05oookJP7o00000000
0ol0003ooo]ZoookJP3ooookJSSooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX03?oonfX1o`00000000?o0000oook
J_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z>ooonfX01Ol0003o
oo]ZoookJ_oonf[o000002Gooo]Z00?o0000oookJ_oonfX08ooonfX01?l0003ooo]ZoookJ_l0000V
oookJP03o`000?oonf[ooo]Z02?ooo]Z00Co0000oookJ_oonf[o00009_oonfX00ol0003ooo]Zoook
JP0SoookJP03o`000?oonf[ooo]Z00oooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZG_oonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP09oookJP7o000000000ol0003ooo]ZoookJP3ooookJSGooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX06OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]Z8_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z00;ooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]Z:OoonfX00ol0003ooo]ZoookJP0UoookJP;o0000:?oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Gooo]Z0_l0000XoookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0PoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJRSooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP12
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX07ooonfX1o`00000000?o0000oook
J_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z8OoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00?ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
3?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
6?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0:oookJP7o000000000ol0003ooo]ZoookJP3ooookJScooo]Z00?o
0000oookJ_l00000:?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0WoookJP;o0000:OoonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZHOoonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0;oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00
000000?o0000oookJ_oonfX0oooonfXgoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Oooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]Z8?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z00Cooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]Z9ooonfX00ol0003ooo]ZoookJP0VoookJP04o`000?oo
nf[ooo]Zo`0002Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0VoookJP04o`00
0?oonf[ooo]Zo`0002Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z01gooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000
00000ol0003ooo]ZoookJP3ooookJR[ooo]Z00?o0000oookJ_oonfX0BOoonfX01Ol0003ooo]Zoook
J_oonf[o000002Gooo]Z00Co0000oookJ_oonf[o0000B?oonfX01Ol0003ooo]ZoookJ_oonf[o0000
02Gooo]Z00Co0000oookJ_oonf[o00008ooonfX1o`00000000?o0000oookJ_oonfX0oooonfXSoook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX05_oonfX01?l0003ooo]ZoookJ_oonfX1
o`00000000?o0000oookJ_oonfX0oooonfXdoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z00Sooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJS[ooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX05?oonfX1o`00000000?o0000oookJ_oonfX0oooonfYSoookJP;o00009ooo
nfX2o`0002Sooo]Z0_l0001:oookJP;o0000:?oonfX2o`0000oooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]Z>OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX05OoonfX1o`00000000?o0000oookJ_oonfX0oooonfXNoookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
03Gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX01ooonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSko
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z9?oonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP3ooookJRcooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o000002Oooo]Z0_l0001:oookJP03o`000?oo
nf[ooo]Z02Oooo]Z0_l0000ToookJP7o000000000ol0003ooo]ZoookJP3ooookJRGooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX0A?oonfX1o`00007ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoook
JP7o000000000ol0003ooo]ZoookJP3ooookJQoooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0LoookJP7o000000000ol0003ooo]ZoookJP3ooookJSSooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP05oookJP7o000000000ol0003ooo]ZoookJP3ooookJV;ooo]Z00?o
0000oookJ_oonfX09_oonfX01?l0003ooo]ZoookJ_l0000YoookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX09_oonfX01?l0003ooo]ZoookJ_l0000VoookJP04o`000?oonf[ooo]Zo`00
00kooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Z
o`00003oo`0001ko00007OoonfX01Ol0003ooo]ZoookJ_oonf[o000002Gooo]Z00Co0000oookJ_oo
nf[o0000B?oonfX01Ol0003ooo]ZoookJ_oonf[o000002Gooo]Z00Co0000oookJ_oonf[o0000:Ooo
nfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z01?ooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]Z=OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP09oookJP7o000000000ol0003ooo]ZoookJP3ooook
JR;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP02oookJP7o000000000ol0003o
oo]ZoookJP3ooookJRkooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08?oonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z:?oonfX2o`0002Oooo]Z0_l0
000YoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX09_oonfX2o`0002Sooo]Z0_l0
001:oookJP7o000000000ol0003ooo]ZoookJP3ooookJRoooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX07ooonfX1
o`00000000?o0000oookJ_oonfX0oooonfXQoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX0=OoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX00ooonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]ZA?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0:oookJP7o000000000ol0003ooo]Zoook
JP3ooookJScooo]Z0_l0000XoookJP;o0000B_oonfX00ol0003ooo]Zo`00000WoookJP;o0000:?oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z013ooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]Z=ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0;oookJP7o000000000ol0003ooo]ZoookJP3ooook
JR3ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP04oookJP7o000000000ol0003o
oo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonfX`oookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0NoookJP7o0000
00000ol0003ooo]ZoookJP3ooookJROooo]Z00Co0000oookJ_oonf[o00009OoonfX01?l0003ooo]Z
oookJ_l00019oookJP04o`000?oonf[ooo]Zo`0002Gooo]Z00Co0000oookJ_oonf[o00009_oonfX0
1?l0003ooo]ZoookJ_l00019oookJP7o000000000ol0003ooo]ZoookJP3ooookJRgooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0VoookJP05o`000?oonf[ooo]ZoookJ_l00000:?oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0WoookJP04o`000?oonf[ooo]Zo`0002?ooo]Z0Ol000000003o`000?oo
nf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJR?ooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000
oookJ_oonfX05_oonfX01?l0003ooo]ZoookJ_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXd
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX02?oonfX1o`00000000?o0000oook
J_oonfX0oooonfXjoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00kooo]Z0Ol000000003o`000?oonf[ooo]Z0?oo
oo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJSWooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Kooo]Z0_l0000YoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z00gooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z7_oonfX00ol0003ooo]Zoook
JP0koookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP0;oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0;oookJP03o`000?oonf[ooo]Z00Oooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z<ooonfX0
0ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP0KoookJP7o000000000ol0003ooo]ZoookJP3ooookJRCooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP01o`00000000?o0000oookJ_oonfX0oooonf[ooookJSko
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z:ooonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z02Gooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Gooo]Z0_l0000ToookJP7o0000
00000ol0003ooo]ZoookJP3ooookJRGooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX06_oonfX1o`00007ooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]Z7ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX01_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z>?oonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP10oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0<oookJP7o
000000000ol0003ooo]ZoookJP3ooookJS_ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000UoookJP03
o`000?oonf[ooo]Z02?ooo]Z00Co0000oookJ_oonf[o00009_oonfX00ol0003ooo]ZoookJP0Soook
JP04o`000?oonf[ooo]Zo`0002Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0?
oookJP7o000000000ol0003ooo]ZoookJP3ooookJUkooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07?oonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX02OoonfX1o`00
000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
=OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0IoookJP7o000000000ol0003ooo]ZoookJP3ooookJR;ooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP02oookJP7o000000000ol0003ooo]ZoookJP3o
oookJRWooo]Z00?o0000oookJ_oonfX09OoonfX2o`0002Sooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP0UoookJP;o0000:?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX08?oonfX1o`00000000?o0000oookJ_oonfX0oooonfXXoook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z01oooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000000ol0003ooo]ZoookJP3ooookJR7ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Z
oookJP03oookJP7o000000000ol0003ooo]ZoookJP3ooookJSKooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0>ooo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX02_oo
nfX1o`00000000?o0000oookJ_oonfX0oooonfXmoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000
oookJ_oonfX09_oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0A
oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX0oooonfYPoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00_ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
=ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Cooo]Z0Ol000000003o`000?oo
nf[ooo]Z0?oooo]Z8?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01kooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]Z9ooonfX01?l0003ooo]ZoookJ_l0000UoookJP04o`000?oo
nf[ooo]Zo`0002Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0VoookJP04o`00
0?oonf[ooo]Zo`0002Kooo]Z00Co0000oookJ_oonf[o0000BOoonfX1o`00000000?o0000oookJ_oo
nfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z;OoonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z02Kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000UoookJP04
o`000?oonf[ooo]Zo`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0Woook
JP04o`000?oonf[ooo]Zo`0002?ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z8ooonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0FoookJP04o`000?oonf[ooo]ZoookJP7o000000000ol0003ooo]ZoookJP3ooook
JSCooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
00Sooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Z
oookJP3ooookJS[ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nfXioookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0VoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00gooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]Z7_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o
oo]Z00Kooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003o
oo]ZoookJP3ooookJS;ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP3ooookJRCooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Kooo]Z0_l0000ToookJP7o0000
00000ol0003ooo]ZoookJP3ooookJRGooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0PoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0A?oonfX1o`00007ooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]Z<_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z01cooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003o
oo]ZoookJP3ooookJQoooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0=oookJP03
o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0=oookJP03
o`000?oonf[ooo]Z00Kooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z@_oonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z02Kooo]Z00Co0000oookJ_oonf[o0000:OoonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Kooo]Z00Co0000oookJ_oonf[o00009_oonfX01?l0
003ooo]ZoookJ_l0000>oookJP7o000000000ol0003ooo]ZoookJP3ooookJS_ooo]Z00Go0000oook
J_oonf[ooo]Zo`00000UoookJP04o`000?oonf[ooo]Zo`0001oooo]Z00?o0000oookJ_oonfX09_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000002Gooo]Z00Co0000oookJ_oonf[o0000:OoonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z01?ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
oooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJSGooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP09oookJP7o000000000ol0003ooo]ZoookJP3ooookJR;ooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol00000
0003o`000?oonf[ooo]Z0?oooo]Z:OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
023ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Z
oookJP3ooookJROooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nfXQoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Zoook
JP0BoookJP03o`000?oonf[ooo]Z00?ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z=_oonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00[ooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]Z?OoonfX00ol0003ooo]ZoookJP0VoookJP;o00008OoonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z02Kooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX04OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]Z=ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00_ooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]Z8?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX01?oonfX1o`00000000?o0000oookJ_oonfX0oooonfX`
oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX07_oonfX1o`00000000?o0000oook
J_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z9ooonfX01?l0003o
oo]ZoookJ_l0000UoookJP04o`000?oonf[ooo]Zo`0002Kooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP0SoookJP04o`000?oonf[ooo]Zo`0002Kooo]Z00?o0000oookJ_oonfX08ooo
nfX01?l0003ooo]ZoookJ_l0000SoookJP7o000000000ol0003ooo]ZoookJP3ooookJR?ooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z043ooo]Z00Co
0000oookJ_oonf[ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z=?oonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX02?oonfX1o`00000000?o0000
oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z>_oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP0CoookJP7o000000000ol0003ooo]ZoookJP3ooookJT7ooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]Zo`00000WoookJP;o0000:?oonfX2o`00027ooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]Zo`00000WoookJP;o00003ooonfX1o`00000000?o0000oookJ_oonfX0
oooonfXNoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0<oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP0HoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Z
oookJP0<oookJP03o`000?oonf[ooo]Z00Kooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z<_oo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX00Ol0
00000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooook
JRGooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
02Kooo]Z0_l0000ToookJP7o000000000ol0003ooo]ZoookJP3ooookJRGooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP14oookJP7o00000OoonfX1o`00000000?o0000oookJ_oonfX0
oooonfXOoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX01_oonfX1o`00000000?o
0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z>?oonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z01Kooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]Z>ooonfX01Ol0003ooo]ZoookJ_oonf[o000002Gooo]Z00?o0000oookJ_oonfX08ooonfX0
1?l0003ooo]ZoookJ_l0000VoookJP03o`000?oonf[ooo]Z02?ooo]Z00Co0000oookJ_oonf[o0000
8_oonfX01?l0003ooo]ZoookJ_l0000VoookJP04o`000?oonf[ooo]Zo`0000kooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]Z=OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP09oookJP7o000000000ol0003ooo]Z
oookJP3ooookJR;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z:OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08?oonfX1o`00000000?o0000oook
J_oonfX0oooonfXWoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[o0000023ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07_oonfX1o`00
000000?o0000oookJ_oonfX0oooonfXQoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX01?oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oo
nf[ooo]Z0?oooo]Z=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX02_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXmoookJP03o`000?oonf[o
oo]Z02Kooo]Z0_l0000RoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP0VoookJP;o00008_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z023ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0;oookJP7o000000000ol0
003ooo]ZoookJP3ooookJSOooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Oooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000000ol0003ooo]ZoookJP3ooookJR3ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP04oookJP7o000000000ol0003ooo]ZoookJP3ooookJROooo]Z00Co0000oookJ_oonf[o0000
9OoonfX01?l0003ooo]ZoookJ_l0000VoookJP03o`000?oonf[ooo]Z023ooo]Z00Co0000oookJ_oo
nf[o00009OoonfX01?l0003ooo]ZoookJ_l0000VoookJP04o`000?oonf[ooo]Zo`0002;ooo]Z00Co
0000oookJ_oonf[o00008ooonfX1o`00000000?o0000oookJ_oonfX0oooonfXSoookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z01cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z01cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP10oookJP04o`000?oo
nf[ooo]ZoookJP7o000000000ol0003ooo]ZoookJP3ooookJSCooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP08oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1
o`00000000?o0000oookJ_oonfX0oooonfXjoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX08_oonfX01Ol0003ooo]ZoookJ_oonf[o000002Cooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX06ooonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00kooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]Z>OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP7o000000000ol0003ooo]ZoookJP3ooookJQko
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Ko
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zoook
JP3ooookJRGooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z01oooo]Z0_l0000QoookJP03o`000?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP3o
oookJRGooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0JoookJP7o00000OoonfX1
o`00000000?o0000oookJ_oonfX0oooonfXOoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP06oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oo
oo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXhoookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01gooo]Z
00Co0000oookJ_oonf[o00007ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01go
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0MoookJP04o`000?oonf[ooo]Zo`00
02Kooo]Z00Co0000oookJ_oonf[o00003_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXkoook
JP05o`000?oonf[ooo]ZoookJ_l000009OoonfX01?l0003ooo]ZoookJ_l0000OoookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07?oonfX01Ol0003ooo]ZoookJ_oonf[o000002Gooo]Z
00Co0000oookJ_oonf[o00007ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP08oookJP7o000000000ol0003ooo]Z
oookJP3ooookJR;ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0=oookJP03o`00
0?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z00;ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z:OoonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z01cooo]Z00Go0000oookJ_oonf[ooo]Zo`00000ToookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z01cooo]Z00Go0000oookJ_oonf[ooo]Zo`00000ToookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX08?oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]Z9ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z01kooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z8OoonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP04
oookJP7o000000000ol0003ooo]ZoookJP3ooookJSgooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP03oookJP;o00008OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX09_oonfX2o`00027ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX1o`00
000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
=ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0;oookJP7o000000000ol0003ooo]ZoookJP3ooookJR3ooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP04oookJP7o000000000ol0003ooo]ZoookJP3o
oookJROooo]Z00Co0000oookJ_oonf[o00009OoonfX01?l0003ooo]ZoookJ_l0000RoookJP05o`00
0?oonf[ooo]ZoookJ_l000009OoonfX01?l0003ooo]ZoookJ_l0000RoookJP04o`000?oonf[ooo]Z
o`0002;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z023ooo]Z00Go
0000oookJ_oonf[ooo]Zo`00000RoookJP7o000000000ol0003ooo]ZoookJP3ooookJR?ooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0FoookJP04o`000?oonf[ooo]ZoookJP7o0000
00000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXk
oookJP05o`000?oonf[ooo]ZoookJ_l000007_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z01cooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Sooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]Z>OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_l000008?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[o000000Gooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[o000000oooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z7_oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP01
o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oo
oo]Z:ooonfX2o`00027ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oo
nfX09_oonfX2o`00027ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oo
nfX09_oonfX2o`0002Cooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z7ooonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX01?oonfX1o`00007ooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]Z>?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z01gooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00007ooonfX00ol0003ooo]ZoookJP04oookJP04
o`000?oonf[ooo]Zo`0001oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP04oook
JP04o`000?oonf[ooo]Zo`0000kooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoook
JP7o000000000ol0003ooo]ZoookJP3ooookJSCooo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003o
oo]ZoookJ_oonf[o000000Kooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP04oook
JP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z00Oooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z00Sooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z8ooonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0Eoook
JP03o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`000?oonf[o
oo]Z01Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z01Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z00;ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z9ooonfX00ol0003ooo]Zo`000006oook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`00000Poook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zo`000006oook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000005oook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`00000Poook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX07_oonfX1o`00000000?o0000oookJ_oo
nfX0oooonfXQoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
oooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJSOooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX00ooo
nfX2o`0002;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP03oookJP;o00001Ooo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00_ooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]Z8?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP04oookJP7o000000000ol0003ooo]ZoookJP3ooook
JR?ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX07?oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000NoookJP05
o`000?oonf[ooo]ZoookJ_l000007_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o0000
00?ooo]Z00?o0000oookJ_oonfX07?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o0000
oookJ_oonfX07?oonfX01Ol0003ooo]ZoookJ_oonf[o000001kooo]Z00Co0000oookJ_oonf[ooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3o
oookJSCooo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP08oookJP7o000000000ol0003ooo]ZoookJP3o
oookJQkooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[o
oo]Z01Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[o
oo]Z01Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP06oookJP7o000000000ol0
003ooo]ZoookJP3ooookJRGooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Gooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP03oookJP;o00001OoonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`000000
00?o0000oookJ_oonfX0oooonfXNoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
3?oonfX00ol0003ooo]ZoookJP04oookJP7o00000OoonfX1o`00000000?o0000oookJ_oonfX0oooo
nfXhoookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000007?oonfX01ol0003ooo]Z
oookJ_oonf[o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o0000
00?ooo]Z00Co0000oookJ_oonf[o00007ooonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o
000001_ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[o
oo]Z01cooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP05o`000?oonf[ooo]ZoookJ_l00000
2_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXSoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]ZoookJ_l00000
1_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oook
JP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP02oook
JP7o000000000ol0003ooo]ZoookJP3ooookJR7ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
oooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJR3ooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00005oookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Gooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00ooo
nfX2o`0000Gooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00Cooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z8ooonfX01ol0003ooo]ZoookJ_oo
nf[o0000oookJ_l000001?oonfX00ol0003ooo]Zo`00000IoookJP03o`000?oonf[o000000Cooo]Z
00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_l000000ooonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z01Gooo]Z
00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_l000006ooonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[o000000?ooo]Z00Co0000oookJ_oonf[o00006OoonfX0
0ol0003ooo]Zo`000003oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX05OoonfX0
1ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001?oonfX00ol0003ooo]Zo`000003oookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nfXNoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`00
0003oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zo`00
0003oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_l000006OoonfX00ol0003ooo]Zo`00
0004oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_l000005OoonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]Zo`00
000EoookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000004oookJP03o`000?oonf[o000000?o
oo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o000000?o
oo]Z00?o0000oookJ_l000006_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[o000000Co
oo]Z00?o0000oookJ_l000002?oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]Z7_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00?ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00ooo
nfX2o`0000Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Gooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00005oookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Gooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0BoookJP;o00001OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00?ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP03oookJP;o00000OoonfX1o`00000000?o0000oookJ_oonfX0oooonfXS
oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[o000000Cooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000?ooo]Z
00?o0000oookJ_oonfX01?oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001?oonfX00ol0
003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Cooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oo
nf[o000000Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[o000000?ooo]Z00?o0000oookJ_oonfX01?oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l0
00001?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l0
00000ooonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Cooo]Z00Oo0000oookJ_oo
nf[ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP04
oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Cooo]Z
00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_l000000ooonfX00ol0
003ooo]ZoookJP04oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000004oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_oonfX0oooonfXN
oookJP0>o`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0
0002oookJP09o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00[o0000oook
J_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z0_l000002_oonf[o0000oookJ_l0003ooo]Z
o`000?oonf[o0000oookJ_l00002oookJP09o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o
000000;ooo]Z00[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z0_l000002_oo
nf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l00002oookJP09o`000?oonf[o0000oook
J_l0003ooo]Zo`000?oonf[o000000;ooo]Z00[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oook
J_l0003ooo]Z0_l000002_oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l00002oook
JP09o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00_o0000oookJ_l0003o
oo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000002oookJP09o`000?oonf[o0000oookJ_l0003o
oo]Zo`000?oonf[o000000;ooo]Z00_o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0003o
oo]Zo`000002oookJP09o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00Wo
0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX02ol0003ooo]Zo`000?oonf[o
0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00Wo0000oookJ_l0003ooo]Zo`000?oonf[o
0000oookJ_l000000_oonfX02_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonfX2
o`00000:oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`0000;ooo]Z00Wo0000oook
J_l0003ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX02_l0003ooo]Zo`000?oonf[o0000oook
J_l0003ooo]Zo`000?oonfX2o`00000:oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z
o`0000;ooo]Z00Wo0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX1o`00007o
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zoook
JP3ooookJ_oooo]Z?_oonfX1o`000000ool0003oo`0004;o00000000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.0256409, -0.0250052, \
0.00182832, 0.00295828}},
  ImageSoundCache->{{{0, 575}, {354.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@00000000P0200000000000000000lADF0P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P82041lbAemiTZ_2enSdo?omm^[Ja[2GOFA<=B8B1`4010`J:d1H
LHZT^m7SlO[oooW_h<fgWhI/Dc`X5`X200895BDiD6V2W;C:gNgho_okl^GC_ZN>
M5]3;Q`>10001Q4P<dUQNYB]a=SXmOgooOKZfLF^UWaSBS@Q4PL100@=6ba1FG:<
YKgBi?;kookik]o<]Yj4Je8k9aH:0P022QHV>U5ZQ9febmk^n?kono;Td[fUS7=I
@RdK3@@00@LB8CA:HWbE[/GIjOKmoogejMS4[IAkHDTc81460@043Q`]@eYdSJJn
dnGbnoonn>gNbkBLPfU@>RHE2@800PXG9caCJhFN]lgOk_Wooo_ahm6lY8]aF44/
6Pd400474R8eBfAmUjo6f^[foOommNSG`jbCNF18<Ql@1P001@hL;dALMHnX_mCU
locoo_S/gLVcVh5XCcTU5@T200<;5bPmE6f6X;S>h>oiooojl>;@^Z>9L5Lo:aT<
0`0121<S=TaUOYR`am_[mokoo?CWe/:ZTGQOAc4N40D000D?7C15GGJ@ZL3Ei_?l
ookgk=c8/YV0IThg91@80@032aPY?UE^R:6icn7`n_oon_3QckVQR6iE?RXH2`<0
0@PD93M>IX2I//SLk?Onoocci]G0ZI1fGDD`7@l5000541haAUihTJ[1e^Odo?on
mn_Kak6HOVE==R<C20400``I:cmGL8VS^]3Rl?[oooW_h<jhX8M]E3dX60/30089
5BDhCfR1Vk?9gNcho_ollnGD_jR?MEa4;a`>1@001Q0O<TQPNI>/`mOXmOgooOKZ
f/J_UgeTBcDR4PL100@=6Ra1F76;Y;cAho7koooik]o=]in5K5<l9aL:0P022ADV
>U1YPibdbmk]n?kono;UdkjVSGAJ@bhL3P@00@HA83=9HG^D[LCHjOGmoogfjMW5
[YElHTXd8A870@043A/]@UUbS:Fmd^Cbnoonn>kNbkFMQ6YA>bHF2P800PXF9c]B
JXBM]/cOk_Wnoo_bi=:mYHabFD8/6`d400474R4dBV=lUZk5fNWfoOommNWHa:fD
NV59<b0A1P4010hL;T=KM8jW_]?Ul__oo_S]g/ZdW89YD3TU5@T2008:5bPlDfb5
WkO=h>oiooojlN?A^jB:LEQ0:aX<10011a8R=DaTOIN`a][Zm_goo?CXel:[TWUO
Ac8O40H000D>7Bm4G7F?Z;oDi_?lookgk=g9/iZ1Idlh91@90P032aPY?EA]Qj2h
c^7_nOoon_3Rd;ZRRFmF?bXI30<00@PC8cI=IGnH/LOKjoOnoocdimK1ZY5gGTHa
7Pl500053ah`AUegT:W1eNKdo?onmn_Lb;:IP6I>=b<D20400`/I:SiFKhRR^LoQ
l?[ooo[`hLniXHQ^EChY60/3004852@hCVN0V[;9g>cgo_ollnKE`:V@MUe5;ad?
1@001Q0N<DMON9:[`]KWm?coo_K[flN`V7iUC3HR4`P100<<6B]0Eg2:Xk_@h_7j
oooikn3=^:26KE@m:1L;0`022ADU>DmXPY^cb]g]n?kono?Ue;nWSWEKA2hL3PD0
00H@7c98H7ZC[<?Gj?Gmoogfj][6[iImHd/e8Q870@043AX/@EQaRjBldN?anooo
nNkOc;JNQF]B>bLF2P800PTF9SYAJH>L]L_NkOSnoo_bi=>nYXecFT8]6`d40046
4B0cBF9kUJg4f>WeoOommNWIa:jENf9:=24A1`4010dK;D9JLhfV_M;Tl__oo_S]
g/^eWH=ZDCXV5PT2008:5RLkDV^4W[K<gnkio_oklN?A_:F;LUU1;1X=10011a8Q
=4]SO9J_aMWZm_gooOGXf<>/TgYPB38P4@H000@>72i3FgB>YkkCiO?kookhkMg:
]9^2J50i9AD90P022QLX?5=/QYngcN3_nOoon_7Sd;^SRW1G@2/J30<00@LC8SI<
I7jG/<OJjoKmoocdimO2Zi9hGdLa7a0600053ad_AEafSjS0e>Kco?onmncLbK:J
PFM>>2@D20400`/H:CiEKXNQ^LkQko[ooo[`h/njXXU_ESlZ6@`300484b<gCFIo
VK78fn_go_olm>OE`JZAMei6<1h?1@001@lN<4INMi6Z`MKWm?coo_O[flRaVGmV
CCLS4`P100<<6BXoEVn9X[[?h_3jooojkn7>^:67KUDm:AP;0`0121@T>4mWPIZc
bMc/mokoo??Ve<2XSgILABlM3`D000H@7c57GgVBZl;Gj?Cloogfj][6/9MnI4`f
8Q<70@0331X[@5M`RZ>kd>?an_oonNoPcKNOQVaC?2PG2P800PTE9CU@J8:K]<[M
kOSnoo_biM>nYhidFd<^70h400064B0bB65jU:c3f>SeoOomm^[IaJnFO6=;=24B
1`4010dJ;45ILXbU_=;SlO_oo_W^glbfWXA[DS/W5PX200895RHjDFZ3WKG;g^kh
o_okl^CB_JJ<LeY2;A/=10011a4Q=4YRNiF^aMWYmOgooOGYf<B]U7]QBC<P4@H1
00@=6be2FW>=Y[kCi?;kookhkMk;]Ib3JE4j9QD90P022QLW>e9[QIjfc=o^nOoo
no7SdKbTRg5H@B`J3@@00@LB8SE;HgfF[lKJj_Kmoogej=O3[9=iH4Pb7a060005
3Q`^A5]eSZNoe>Gco?onn>gMb[>KPVQ?>BDE2@800`/G:3eDKHJP^<gPkoWooo[a
h]2kXhY`Ed0[6@`300484b<fC6EnV;37fn_go_olm>OF`Z^BN5m7<Ah@1P001@lM
;dEMMY2Y`=GVlocoo_O/g<VbVX1WCSPT50P100<;62TnEFj8XKW?hO3jooojl>7?
^J68KeHn:QT;0`0121@T=diVP9Vbb=c[mokoo?CVeL6YT7MMAC0N3`D000D?7S56
GWNAZ/7FioClookgjm_7/IQoIDdf8a<80@0331TZ?eI_RJ:jd>;`n_oonNoPc[RP
QfeD?BTH2`<00PTD93Q?Ih6J/lWMk?Snoocci]BoZ8meG4@_7@h5000641lbB61i
Tj_2enSdo?omm^[JaZnGOFA;=B8B1`4010`J:d1HLHZT^m7SlO[oooW^h<fgWhE/
Dc`X5`X200895BDiD6V2W;C:g^gho_okl^GC_ZN=M5]3;Q`>10011Q4P<dUQNYB]
a=SYmOgooOKYfLF^UGaRBS@Q4PL100@=6ba2FG:<YKgBi?;kookik]o<]Yf4JU8k
9aH:0P022QHW>e9ZQ9fec=o^n?kono;Td[fUS79I@RdK3@@00@LB8CA:HWbE[/GI
jOKmoogejMS4[IAjHDTc81460@043Q`^@eYdSJJndnGbnoonn>gNb[BLPfU@>RHE
2@800PXG:3aCK8FO]lgOk_Wooo_ahm6lY8]aF40/6P`400474R8eBfAmUjo6f^[f
oOommNSG`jbCNF18<Ql@1P001@hM;dALMHnX_mCUlocoo_S/gLVcVh5XCcPU50T2
00<;62TmE6f7X;S>h>oiooojl>;@^Z:9L5Lo:QT<0`0121<S=TeUOiRaam_[moko
o?CWe/6ZTGQNAS4N40D000D?7C15GGJ@ZL3Ei_?lookgk=c8/YV0IThg91@80@03
2aPZ?UE^R:6icn7`n_oon_3QckVQR6iE?RTH2`<00@PD93M>IX2I//SLk?Onoocc
i]G0ZI1fGDD`7@l5000641haAemhTZ[2e^Odo?onmn_Kak2HOVE<=R<C20400``I
:cmGL8VS^m3Rl?[oooW_h<jhX8I]E3dX5`/300895BDiCfR1Vk?:gNcho_ollnGD
_jR>MEa4;Q`>1@001Q0O<TQPNI>/`mOXmOgooOKZf/J_UWeSBcDR4PL100@=6Ra1
F76;Y;cAho7koooik]o<]ij5Je<l9aL:0P022ADV>U5YPibebmk]n?kono;TdkjV
SG=J@bdK3P@00@HA83=9HG^D[LCHjOGmoogejMW5[YElHTXd8A470@043A/]@UYc
S:Fmd^Cbnoonn>kNbkFMQ6YA>RHF2P800PXF9c]BJhBN]/cOk_Wnoo_ai=:lYHab
FD4/6`d400474R4dBV=lUZk5fN[foOommNSH`jbDNV59<b0A1P0010hL;T=KM8jW
_]?Ul__oo_S]gLZdW89YD3TU5@T2008:5bPlDfb6WkO=h>oiooojlN?A^j>:LEQ0
:aX<0`011a<R=DaTOYN`a][Zm_goo?CXel:[TWUOAc4O40H000D?7Bm4G7F?Z;oD
i_?lookgk=c9/iZ1Idlh91@80@032aPY?EE]Qj2hc^7_nOoon_3RckZRRFmF?bXI
30<00@PC8cM=IGnH/LSKjoOnoocdimK1ZY5gGTH`7Pl500053ah`AUigT:W1eNOd
o?onmn_Kb;6IOfI==b<C20400``I:SmFKhRR^/oRl?[ooo[_hLjiXHM^EChY60/3
004852@hCVN0V[;9g>cgo_ollnKE`:R?MUe5;ad?1@001Q0O<DMON9:[`]KWm?co
oOK[f/N`UgiTC3HR4`L100<<6B]0Eg2:Xk_@h_7joooikn3=]in6K5@l:1L;0`02
2ADU>E1XPY^db]g]n?kono?Ue;nWSWAKA2hL3P@000HA8398H7ZC[<?Gj?Gmoogf
j]W6[iImHd/e8A870@043AX/@EUbRjBldN?anoonnNkOc;JNQF]B>bLF2P800PTF
9SYAJX>M]L_NkOSnoo_bi=:mYXecFT8]6`d400474B0cBF9kUJg4f>WeoOommNWH
a:fENf99<b0A1`4010dK;D9JLhfV_M;Tl__oo_S]g/^eWH=ZDCXV5PT2008:5RLk
DV^5W[K<gnkio_oklN?A_:B;LUU1;1X=10011a8Q=D]SOIJ_a]WZm_gooOGXel>/
TgYPB38P4@H000@>72i4FgB>YkoDiO?kookhkMg:]9^2J50i9AD90P032aLX?5A/
QYngcN3_nOoon_7Rd;^SRW1G@2/I30<00@LC8SI<I7jG/<OJjoKmoocdimK2Zi9h
GdLa7a0600053ad_AEefSjS0eNKco?onmncLbK:JP6M>>2@D20400`/H:CiEKXNQ
^LkQko[ooo[`h/njXXQ_ESlZ6@`300484b<gCFIoVK78fn_go_olm>OE`JV@Mei6
<1h?1@001@lN<4INMi6Z`MKWm?coo_O[flRaV7mUCCLS4`P100<<6BXoEVn9X[[?
h_3joooikn7>^:27KEDm:AP;0`0121@T>4mWPIZcbMc/mokoo??Ve;nXSgELA2lM
3`D000H@7c57GgVBZl;Gj?Cloogfj][6/9MnI4`e8Q<70@0331X[@5QaRZ>kdN?a
n_oonNoPcKNOQVaC?2PG2P800PTE9CU@JH:L]<[MkOSnoo_biM>nYhidFd<^70h4
00064B0cBF5jU:c3f>SeoOomm^[IaJjFO6=:=0\>"]},
  ImageCacheContents->"Sound"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Let's see if we can play this:    l",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11227 
%%ImageSize: 482 55 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.002079 -0.002079 0.002079 [
[ 0 0 0 0 ]
[ 1 .11227 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11227 L
0 .11227 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00208 translate
1.00208 .11435 scale
1446 string
482 55 8 [482 0 0 55 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF2D291000091F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF2D291000091F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EEE5E5E5EEF7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF2D291000091F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFEEEAE5E5EAF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEECD980000004F4F4100002E9FCDEEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD2985C000000000000000000000066D2F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBD798000091F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF2D2980000000000000000000000009FD2F2FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EAE5E5EAEEF7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF2984F00000000000000000000005C9FF2FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2984F00000000
000000000000005C9FF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFEE984F00002E4F4F2E002E66A5EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE5CDB7C8E0F7FFFFFFFBD79F002E98F2FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5B7700070BDFFFFFFFFFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF2A5798291895C002E91F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE5B1000079E5FFFFFFFFFFFBFBFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF2C84F00002E4F4F2E0000669FCDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7EEEAE5E5EAF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB7660070B7E5FFFFFFFBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB7660070B7E5
FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFB1B1B1000000000000000000000000141414FFFFFFFFFFFFABABABD3D3D3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFEEB7A5B7EEFFFFFFFFEA70002EC2EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBE5DCD7D7DCE5F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBE5B7000000669FBDD2D2C89866416691B1D7E5F2FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBB1660082C2EEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBE0AB000089EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE582000079B7EAFFFFD24F2E91F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3DEDEDEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8E8E8
CACACA0000000000000000000000000000000000006D6D6DD6D6D6F8F8F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E8E8E8CACACA0000000000000000000000000000000000006D6D6DD6D6D6F8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBDCDCDCF5F5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF2DCD7D7DCE5EEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFD29F5C00004170664100004FC2EAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAEAEAE4E4E4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBEBEB
E4E4E4FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFE8E8E8D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6CACACA9292927878786F6F6F7979796A6A6AA0A0A0D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
C6C6C6C4C4C4C4C4C4C4C4C4C4C4C4D3D3D3D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D65E5E5E0000000000000000000000000000000F0F0FC9C9C9D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D65E5E5E0000000000000000000000000000000F0F0FC9C9C9D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6BBBBBBC6C6C6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6CBCBCBBABABAD2D2D2D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6CACACA0000000000000000000000000000000000006D6D6DD6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6C8C8C86363631A1A1A0B0B0B4646467F7F7FD6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D68A8A8AD6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D68A8A8AD6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D4D4D47D7D7D2727270909092E2E2E787878D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6292929000000000000000000000000000000383838D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6959595
000000000000000000000000000000000000A3A3A3D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6B5B5B54C4C4C1111111212126464649C9C9C
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6B6B6B6
4E4E4E1212123030307D7D7D9C9C9CD6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6
D6D6D6D6D6D6D6D6D6F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF969696C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA3A3A3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FFFFFFFFFFFFFFFFFFFFFFFF969696D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6393939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FFFFFFFFFFFFFFFFFFFFFFFF919191C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C8C8C8050505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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBEBEB000000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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDEDED000000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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF202020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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF797979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FFFFFFFFFFFFFFFFFFFFFFFF969696D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6C1C1C1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FFFFFFFFFFFFFFFFFFFFFFFF919191C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFF969696D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6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FFFFFFFFFFFFFFFFFFFFFFFF919191C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF313131FFFFFFFFFFFFFCFCFC2F2F2F050505F8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
6A6A6A000000404040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCACACAD5D5D5
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCACACA
D5D5D5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCACACAD5D5D5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBDBDBDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCACACAD5D5D5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA5A5A5D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6D6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FFFFFFFFFFFFFFFFFFFFFFFFE1E1E1C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8000000979797FFFFFFFFFFFFFFFFFF373737CFCFCF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCACACA
D5D5D5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA5A5A5FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1B1B1B343434FFFFFFFFFFFFFFFFFF343434F1F1F1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4D4D4
DDDDDDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB6B6B6FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF575757000000C1C1C1FFFFFFFCFCFC292929FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA000000262626D8D8D8878787656565FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F91D1D1D000000000000000000B5B5B5FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA6A6A6000000000000252525FDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF919191353535C6C6C6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{482, 55},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007R0000=b000`400?l00000o`00003oo`3oool<
0?ooo`030?;BT@000940l_oo0=@0oooo003o0?ooo``0oooo00<0l]:A0000T@3bool0e03oool00=40
oooo00<0ooO^0>GUi@3^mol0=`3oool00`3bdY40002A0?;oo`3D0?ooo`00B`3oool00`3^j^D0iN[b
0?ooo`220?ooo`050>k=V0000000Cdm10000;P2OcNh0503oool01P3BV5`00000000000000000001V
0=;goa`0oooo00<0nmNH0000T@3bool0;P3oool00`3bdYP00000000000020000000309oBlP3oool0
oooo0140oooo00<0ooog0>[Ui@3Zk_L0>03oool00`3ooo80V4l00000000200000003001LW`3bool0
oooo01D0oooo00<0ooob09Q?000000000P0000000`00G9l0l_oo0?ooo`0]0?ooo`00B@3oool01P3o
onh0V4l0000^C`1?;P00;VJU0>kooh40oooo00H0iLfg0<SPm`3oool0nmNO000^V03boolC0?ooo`04
0>FgL000L;d0oooo0?okna`0oooo00D0ooob0:EiPP2ARE`002jA0?;oo`0^0?ooo`050?oU/@0007T0
iOoo0?ooo`3knol04`3oool01@3ol/P0C`0002i?C`0^0000IYo=01d0oooo00<0mnkZ0>GUjP3gool0
603oool0102gIP00L;OU0?ooo`3kno/I0?ooo`040;MV001`]nD0oooo0?_knc00oooo000c0?ooo`03
0>kZi@3Uj_80oooo01<0oooo00H0oo_U0;Nab03gool0ooog09m1002Ad_:40?ooo`030>k8R@000940
l_oo01<0oooo00<0oooZ094^001LWld07P3oool0103L`Yl0C`00001?W`3bool_0?ooo`030<:9@@00
G9l0j_oo01@0oooo00H0nnG=0;O2h03oool0oo_B04l0C`3=molK0?ooo`050<fHC`0002h0Cdl^0000
L03=k_l05`3oool00`3oj/80@@0009o=jP0J0?ooo`030?oZ`P110000WlgZ0340oooo000a0?ooo`06
0?ookP2HC`0002i?04l^000^IZD0k_oo5@3oool00`3oonh0TBh008W=lP220?ooo`040=b[PP11;P00
00110<S^naD0oooo00@0ooo^0;5i@@00@H80g?OoD03oool00`3G/GT000110;OLlP0F0?ooo`030?o^
b00^0440cOOo01X0oooo00H0ooog0<fg]`3Pmol0oooo0=NOC`0^TLdH0?ooo`040?obdP22;P00@H:g
0?OooaT0oooo00@0oo;B088^0011P[L0mooo;`3oool00140oooo00@0bLW909NGU`2b/[80nOWi703o
ool01P3onnD0]k780?Ooo`3oooL0Wd40097BlQ<0oooo00@0ooOG089L@@000000;Y78JP3oool00`3o
l/P0Cd6A0>koo`0F0?ooo`040?oon`3bk]`0TDl^08:miAL0oooo00<0eimL001?Y@3gool0D03oool0
0`3beil0001L0=Oko`0C0?ooo`040?OLZ`1L@Bh000000978jQl0oooo00<0b8T^02j9c@3oool0603o
ool00`3ooo80YDl004nOe`0J0?ooo`030?oolP2UC`00CioG02l0oooo000?0?ooo`070?Gem@1CDe<0
?Cdm0;fm_@3<c<`0PX:20:b/[00N0?ooo`030?ookP2A;P00RLgb01@0oooo00@0noOb0=bmR@0^@HT0
iOoo5`3oool00`3=RDl0RLS^0?ooo`0C0?ooo`030?O^jP3UiNh0nooo01d0oooo00<0oo_g0>[Ui@3^
l_/06@3oool00`3onld0Cd6A0?Ooo`0E0?ooo`050>[=/@2ad^h0oooo0>ZaIP00NL80503oool01P3k
iLd0]lSU0?ooo`3oh:D000290>kooa/0oooo00<0lo?c0=kNgP3kno/05P3oool00`3clo<0g]kN0?_k
n`0F0?ooo`060?oki@2g/Ld0nooo0?oog01L02h0`_;o503oool0103gl^h0_I5?0462_@3koolK0?oo
o`050?oolP2aPU`0;P00000^T@3Zool05`3oool01@3UcKL0b>Gk0?ooo`3PYE`008;801P0oooo00D0
iLfg0<SUn`3oool0h:EL0022b00_0?ooo`003`3oool0201GEeL0000001<C4`1ADE40jn_[0?ooo`2h
^;P0WinO6`3oool0103ommL0PUa10000000^TLPC0?ooo`060?ookP2gYKL0k_oo0?oojP1`02h0`^ko
5`3oool00`3BTDl0RLgg0?ooo`0B0?ooo`050;Mi;P00;Tl0G440001?T@3Unol06`3oool01@3kh;40
;P0004mLC`000000TL;U01@0oooo00P0ooog0;fHR@22PX80NGUi07U`G00002h0IWVH0>3koa@0oooo
00D0l]NO0000001VL6H0000008W2jP0D0?ooo`050?_U]`0^0000G71`0440001?TLP06`3oool01P2K
Vi/02@T90000000?3`l0NGUi0?Ogma<0oooo00H0Vi^K00T92@0000003`l?07UiN@3gmoLD0?ooo`06
0?ooi@22;P00;Ua`06I10000CiP0k_oo4P3oool01P3kj/d0YK7B0?ooo`3ok[4000220>kooa`0oooo
00@0oo_g0>kL_@1L04l0_NGk5`3oool01@3U_H80000^071`G0000000TLS^01P0oooo00D0iKf20000
;P1`L5`000000978kP0_0?ooo`003P3oool00`3Cdm<00000000000020000000505IFEP3oool0oooo
07emO@3inOT06`3oool0103kmo80g;f902i1R@3UoolB0?ooo`060?oolP2OC`00045V06I?0000@I40
j_oo4`3oool01`3gh;d0PWV2089iN@1iNGT0G44002i?G02H_N004P3oool01@3G`/P0j_oo0?ooo`2a
IP00P/S^01/0oooo00H0nn[G0<SGkP3oool0onF[0000R@3^oolC0?ooo`080?oon`2gL000001V0;g=
dP38_IP0;RiV0;78e`3boolE0?ooo`030?_bi@3GemL0iNkg01H0oooo00<0ooO^0=cGe`3LiO806`3o
ool00`3fm_H01`L7000000030000000303`l?03gmoL0oooo0100oooo00<0m_Kf00L71`0000000`00
00000`0l?3`0moOg0?ooo`0C0?ooo`040?oom`3Ug=L0emcU0?_ooa<0oooo00D0ooOB05`00011IW00
C`000469`P0K0?ooo`060?oon`3=/J/0d^ko0?ooo`2gIP00NL;^603oool00`3gk^D0emOG0>G^n`0J
0?ooo`030?O^i@3GemL0iNkk0300oooo000>0?ooo`030;6a/@00000000000080000000D051@D0?oo
o`3oool0Zj^[0=?Cd`0I0?ooo`060?ookP2gYKL0k_oo0?oojP1`02h0`^ko4`3oool0103ooo/0iMcG
0=OLi@3goolD0?ooo`070?_U]`000000IYnm0=;Bb02HIT40IY6a0=OUlP0D0?ooo`030?oon`2aIP00
P/;^01h0oooo00<0nn2[0000R@3^ool0503oool01P3oonD0PP0007VgjP3oom80CbjA0?;oobh0oooo
00<0lo?c0=kNgP3kno/06`3oool00`3Xj>P0b/[:000000050000000306e]K@3Fe]H0n?Sh00h0oooo
00<0j>SX0<[:bP0000001@0000000`1]KFd0e]KF0?Shn00A0?ooo`030?_kn`3Lg=`0mOGe01H0oooo
00<0oo_b0=cGe`3LiNh07@3oool01@3BWe`00011071V@@0004l0`^[o01P0oooo00<0j^[Z0>CTi03o
ool06P3oool00`3[jn/0i>CT0?knoP0`0?ooo`003P3oool00`3_knl030`<000000020000000503hn
?P3oool0oooo09nOW`3QhN406@3oool01P3ooo80Wdl00011IP1VC`00046A0>[oob`0oooo00D0iKf2
0000N@3Zool0ei5?08W=lP0C0?ooo`050>G2Y@1iNG00Cbh00011PP3Lmol06`3oool01@3onn00Wh9i
071VC`000000P[7L01H0oooo00D0onk202h0002[cKL0G46A0>koo`0]0?ooo`0609^KV`092@T00000
00l?3`1iNGT0moOg6@3oool00`3QhN40bLW903Xj>P050000000301dM7@39bLT0mOGe00h0oooo00<0
hN7Q0<W9b@0j>SX01@0000000`0M7Ad0bLW90?Gem@0@0?ooo`060<[:bP0J6QX0000000@4101HF5P0
i>CT=@3oool00`3biM`0emOL0>kgo`0H0?ooo`0506ATI0010@400000028R8P2NWYh0603oool01@2;
Rh/0BTY:01@D500P8200Vi^K02l0oooo000?0?ooo`050;Ng]`0I6AT00000034a<@3Jf]X00P3oool0
0`21PH40o_kn0?ooo`0I0?ooo`040?oon`3Ug=L0emcU0?Ooobh0oooo00@0`XT^001`/@2mTE`0RLS^
4`3oool00`3=RD40IZ_B0>kblP0M0?ooo`040?obb0110700d^[^0?;koaP0oooo00@0l/fH00000000
@IP0l_oo;03oool00`3fm_H01`L7000000030000000303`l?03gmoL0oooo01T0oooo00<0iNGU028R
8P0000000`0000000`0g=cL0oooo0?ooo`0@0?ooo`030>GUi@0R8R80000000<0000000<0=cLg0?oo
o`3oool0403oool00`0n?Sh00000000000020000000301LG5`3MgMd0oooo04d0oooo00<0_[jn0000
000000000`0000000`1dM7@0oooo0?ooo`0D0?ooo`070;no_`2QXJ40oooo0?Win@2>SXh01@D5071`
L00^0?ooo`004@3oool00`3clo<0oooo0?ooo`020?ooo`0307moO`3oool0oooo01/0oooo00<0h>3P
0>g]k@3oool05P3oool00`3Ph>00kNg]0?ooo`0D0?ooo`040?ookP2HC`000000097=kQ<0oooo00<0
cHU?08W8lP3oool07@3oool00`3ol/P0Cd6A0?;oo`0J0?ooo`030=NUIP00@IP0l_oo01D0oooo00<0
lo?c0=kNgP3kno/0503oool00`3alO400000000000040000000308>3P`3oool0oooo01T0oooo00H0
kno_07MgM`0P82003Ph>05ADE02HV9PC0?ooo`060>o_k`1gMgL0820P00h>3P1DE5@0V9RH4P3oool0
0`0a<C400000000000030000000304=3@`3oool0oooo0140oooo00<0no_k0=cLg03emOD07@3oool0
0`3Zj^X0i>CT0?ooo`0H0?ooo`030;:b/P000000000000@0000000<0`l?30?ooo`3oool04`3oool0
0`2c/k<0>3Ph0?clo0020?ooo`030:j^[P010@40`<3002d0oooo000F0?ooo`0307moO`3oool0oooo
01T0oooo00H0kNg]03Lg=`000000000003/k>`35aLDC0?ooo`060>g]k@0g=cL000000000000k>c/0
aLG5503oool00`3omm80IP00097=kP0C0?ooo`050=:HC`00000000000000G03=l_l06`3oool01@3o
mld0C`00000000000000G9S=02l0oooo00H0Vi^K00T92@0000003`l?07UiN@3gmoLC0?ooo`0304Y:
BP000000000000<0000000<09BDU0?ooo`3oool07P3oool00`2UYJD0oooo0?ooo`0F0?ooo`030:FU
Y@3oool0oooo0100oooo00<0RXZ:000000000000100000000`3`l?00oooo0?ooo`0?0?ooo`060<[:
bP0J6QX0000000@4101HF5P0i>CT6P3oool01@1TI6@00@410000000R8R80WYjN01L0oooo00<0lo?c
01HF5P000000100000000`1MGEd0oooo0?ooo`0C0?ooo`040?Gem@0H61P0IfMW0?gmo@80oooo00<0
H61P05aLG03oool0;03oool001D0oooo00<0jNWY09FEU@3oool06P3oool00`1nOWh0000000000002
0000000300<30`2`/;00oooo0140oooo00<0OWin0000000000000P0000000`030`<0/;2`0?ooo`0X
0?ooo`040?oon`3gmoL0moOg0?Ogmad0oooo00@0noOg0?Ogm`3gmoL0mo_o;P3oool00`3fm_H01`L7
000000030000000303`l?03gmoL0oooo0140oooo00<0iNGU028R8P0000000`0000000`0g=cL0oooo
0?ooo`0N0?ooo`030:FUY@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool0403oool00`3kno/0C4a<
0000000300000003014A4@3lo?`0oooo0100oooo00<0?Shn0000000000000P0000000`0G5aL0gMgM
0?ooo`0G0?ooo`030;jn_P000000000000<0000000<0M7Ad0?ooo`3oool05@3oool00`2m_Kd02PX:
000000030000000306m_K`3oool0oooo01@0oooo00L0`<3000/;2`0o?cl0c/k>0?ooo`2d];@0K6a/
02d0oooo00040?ooo`030>SXj03Fe]H0e]KF00T0e]KF00L0b/[:09:BTP1hN7P0Kfm_07UiN@1ZJVX0
X:2P00d0e]KF00<0a/K60<C4a034a<@00P34a<@00`3Cdm<0e]KF0=KFeP060=KFeP0305iNGP000000
000000<0000000<03`l?0<W9b@3Fe]H0403Fe]H00`1NGUh00000000000030000000300l?3`39bLT0
e]KF0180e]KF00<0^k^k0<K6aP3Fe]H0CP3Fe]H00`3;bl/0^[Zj0=;BdP0D0=KFeP030<[:bP000000
000000@0000000<0KFe]0=KFeP3Fe]H04@3Fe]H01P38b<P0Hf=S01XJ6P0;2`/0ATI607moOb00e]KF
00<0RXZ:0=KFeP3Fe]H05P3Fe]H00`2:RXX0e]KF0=KFeP0A0=KFeP060=CDe01mOGd09bLW00T92@0^
;Rh0N7Qh4P3Fe]H00`0Y:BT00000000000030000000303Ph>03Fe]H0e]KF01H0e]KF00<0UIFE0000
00000000100000000`2SXj<0e]KF0=KFeP0E0=KFeP060;Fe]@1<C4`04A4A018B4P1TI6@0W9bL5`3F
e]H01P2f][H0CTi>018B4P0`<300OGem09bLW280e]KF00<0n?Sh0?ooo`3oool0203oool000@0oooo
00<0UYJF0<W9b@39bLT01`39bLT02`2i^KT0De=C01@D501PH600TY:B0:2PX02;Rh/0;Rh^00l?3`1:
BTX0/;2`00/0bLW900H0I6AT00<30`000000000003@d=02j^[X80<W9b@0309jNWP000000000000@0
000000<0Ng]k0<W9b@39bLT03`39bLT00`2NWYh00000000000040000000307]kN`39bLT0bLW900l0
bLW900H0^[Zj02/[:`000000000002h^;P2KVi//0<W9b@0308J6QP39bLT0bLW901d0bLW900H0NWYj
00L71`0000002`/;05mOG`32`/8C0<W9b@0303Xj>P000000000000<0000000<07AdM0<W9b@39bLT0
5P39bLT00`22PX80bLW90<W9b@0?0<W9b@030::RXP2ZZZX0bLW900`0bLW900<0PX:20<W9b@39bLT0
5P39bLT00`22PX80bLW90<W9b@0F0<W9b@0308b<S039bLT0bLW90100bLW900<0K6a/000000000000
100000000`2m_Kd0bLW90<W9b@0?0<W9b@0309RHV039bLT0bLW900<0bLW900<0_kno014A4@000000
100000000`19BDT0bLW90<W9b@0J0<W9b@0309BDU039bLT0bLW901X0bLW900<0U9BD0<W9b@39bLT0
7`39bLT00`2RXZ80clo?0?ooo`090?ooo`00103oool00`2UYJD0oooo0?ooo`060?ooo`0=0=7Ad@0N
7Qh0EUIF0?;blP3oool0eMGE0<30`03oool0L71`0>k^kP1hN7P03Ph>0<30`00;0?ooo`0404A4A000
000000000>o_k`X0oooo00<0QhN70000000000000P0000000`010@40/;2`0?ooo`0A0?ooo`0308N7
Q`00000000000080000000<00@410;2`/03oool0403oool00`1nOWh00000000000020000000300<3
0`2`/;00oooo02X0oooo00<0YJFU0?ooo`3oool0703oool00`3fm_H01`L7000000030000000303`l
?03gmoL0oooo0140oooo00<0iNGU028R8P0000000`0000000`0g=cL0oooo0?ooo`0F0?ooo`030:FU
Y@3oool0oooo00l0oooo00<0b/[:0=GEe@3oool0303oool00`2UYJD0oooo0?ooo`0F0?ooo`030:FU
Y@3oool0oooo01H0oooo00<0/[:b0?ooo`3oool0403oool00`3kno/0C4a<0000000300000003014A
4@3lo?`0oooo0100oooo00<0_Kfm0?ooo`3oool0103oool00`2m_Kd02PX:000000030000000306m_
K`3oool0oooo01X0oooo00<0_Kfm0?ooo`3oool06P3oool00`2m_Kd0oooo0?ooo`0O0?ooo`030<[:
bP3EeMD0oooo00T0oooo00040?ooo`030:FUY@3oool0oooo00D0oooo00L0g]kN01<C4`1VIVH0oooo
0?clo02JVYX0d];B0080oooo00H0Kfm_0?ooo`3oool0SHf=014A4@3UiND60?ooo`050<W9b@31`L40
`L710<71`@0m?Cd00P0000000`30`<00mOGe0?ooo`090?ooo`060;Vi^@13@d<03@d=02@T9024Q8@0
eMGE4`3oool01P2i^KT0@d=300d=3@0T92@0Q8B40=GEeA40oooo00<0LG5a0000000000000`000000
0`0B4Q80l?3`0?ooo`0B0?ooo`030>3Ph03]kNd0oooo01@0oooo00<0YJFU0?ooo`3oool01@3oool0
0`3clo<0g]kN0?_kn`0D0?ooo`030?7al@000000000000@0000000<0Ph>30?ooo`3oool04@3oool0
1P3_knl0MgMg020P800>3Ph0E5AD09RHV1P0oooo00<0YJFU0?ooo`3oool03`3oool00`3:b/X0eMGE
0?ooo`0<0?ooo`030:FUY@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool05P3oool00`2b/[80oooo
0?ooo`0A0?ooo`060?gmo@2FUYH0;bl_00/;2`0h>3P0Shn?4P3oool00`2m_Kd0oooo0?ooo`050?oo
o`060=SHf01KFe/05ADE01HF5P1hN7P0^k^k703oool00`2m_Kd0oooo0?ooo`0J0?ooo`030;fm_@3o
ool0oooo01l0oooo00<0b/[:0=GEe@3oool02@3oool000@0oooo00<0YJFU0?ooo`3oool0103oool0
1`3moOd0<S8b03De=@3kno/0oooo07YjNP3YjNT00P3oool01`3UiND0RHV90?ooo`3oool0o_kn02@T
901bLW801P3oool01@1UIFD0MgMg0;Bd]02d];@0>CTi0080000000<0/;2`0??cl`3oool03@3oool0
0`3:b/X0eMGE0?ooo`0F0?ooo`030<[:bP3EeMD0oooo0100oooo00<0bLW900000000000010000000
0`2MWId0oooo0?ooo`0?0?ooo`060>g]k@0g=cL000000000000k>c/0aLG54`3oool00`2UYJD0oooo
0?ooo`040?ooo`0609^KV`092@T0000000l?3`1iNGT0moOg4`3oool00`1:BTX00000000000030000
000302DU9@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?ooo`0?0?oo
o`030<[:bP3EeMD0oooo00`0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?ooo`0F0?oo
o`030;:b/P3oool0oooo01H0oooo00<0/[:b0?ooo`3oool0403oool00`2m_Kd0oooo0?ooo`0:0?oo
o`030;fm_@3oool0oooo01X0oooo00<0_Kfm0?ooo`3oool06P3oool00`2m_Kd0oooo0?ooo`0O0?oo
o`030<[:bP3EeMD0oooo00T0oooo00040?ooo`030:FUY@3oool0oooo00@0oooo00H0Xj>S0000002b
/[80oooo0:f][@2WYjL30?ooo`030;6a/@2l_;`0oooo0080oooo00<0Hf=S02TY:@3oool01@3oool0
1@3no_h0MWIf0?Cdm03oool0D51@0080000000<0n_[j0?ooo`3oool03@3oool00`3:b/X0eMGE0?oo
o`0F0?ooo`030<[:bP3EeMD0oooo0140oooo00<0QhN70000000000000P0000000`010@40/;2`0?oo
o`0@0?ooo`0307inOP00000000000080000000<00`<30;2`/03oool04@3oool00`2UYJD0oooo0?oo
o`030?ooo`030?KfmP071`L0000000<0000000<0?3`l0?Ogm`3oool04@3oool00`3UiND08R8R0000
00030000000303Lg=`3oool0oooo01H0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?oo
o`0?0?ooo`030<[:bP3EeMD0oooo00`0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?oo
o`0F0?ooo`030;:b/P3oool0oooo01H0oooo00<0/[:b0?ooo`3oool0403oool00`2m_Kd0oooo0?oo
o`0:0?ooo`030;fm_@3oool0oooo01X0oooo00<0_Kfm0?ooo`3oool06P3oool00`2m_Kd0oooo0?oo
o`0O0?ooo`030<[:bP3EeMD0oooo00T0oooo00040?ooo`0309JFUP3Fe]H0e]KF00@0e]KF00H0>CTi
00000037alL0e]KF04=3@`2^[Zh30=KFeP0306YZJP38b<P0e]KF0080e]KF00<0EUIF00X:2P3Fe]H0
1P3Fe]H01036a/H0J6QX0=KFeP13@d<2000000030=7Ad@3Fe]H0e]KF00d0e]KF00<0ZJVY0;:b/P3F
e]H05P3Fe]H00`2YZJT0/[:b0=KFeP0B0=KFeP0609^KV`0h>3P02PX:01hN7P1^KVh0/[:b4@3Fe]H0
0`1NGUh00000000000030000000300l?3`39bLT0e]KF0100e]KF00<0RXZ:0=KFeP3Fe]H00`3Fe]H0
0`3:b/X00000000000040000000306e]K@3Fe]H0e]KF0140e]KF00H0b<S806=SH`0J6QX02`/;04I6
AP1oOglH0=KFeP0308Z:RP3Fe]H0e]KF01H0e]KF00<0RXZ:0=KFeP3Fe]H03`3Fe]H00`2YZJT0/[:b
0=KFeP0<0=KFeP0308Z:RP3Fe]H0e]KF01H0e]KF00<0RXZ:0=KFeP3Fe]H05P3Fe]H00`2EUID0e]KF
0=KFeP0F0=KFeP0309FEU@3Fe]H0e]KF0100e]KF00<0WYjN0=KFeP3Fe]H02P3Fe]H00`2NWYh0e]KF
0=KFeP0J0=KFeP0309jNWP3Fe]H0e]KF01X0e]KF00<0WYjN0=KFeP3Fe]H07`3Fe]H00`2YZJT0clo?
0?ooo`090?ooo`00103oool00`2ATI40bLW90<W9b@030<W9b@070<S8b0051@D000000<C4a039bLT0
9BDU08J6QP030<W9b@0305IFEP39bLT0bLW90080bLW900<09RHV00h>3P39bLT01`39bLT00`1MGEd0
V9RH03lo?`02000000030<G5a@39bLT0bLW900d0bLW900<0WinO0:NWY`39bLT05P39bLT00`2OWil0
YjNW0<W9b@0F0<W9b@0309nOW`2WYjL0bLW90100bLW900<0WYjN000000000000100000000`1kNg/0
bLW90<W9b@0?0<W9b@0308:2PP39bLT0bLW900@0bLW900<0>SXj0000000000000`0000000`0M7Ad0
bLW90<W9b@0F0<W9b@0308:2PP39bLT0bLW901H0bLW900<0PX:20<W9b@39bLT05P39bLT00`22PX80
bLW90<W9b@0?0<W9b@0309nOW`2WYjL0bLW900`0bLW900<0PX:20<W9b@39bLT05P39bLT00`22PX80
bLW90<W9b@0F0<W9b@0308b<S039bLT0bLW901H0bLW900<0S8b<0<W9b@39bLT04039bLT00`2DU9@0
bLW90<W9b@0:0<W9b@0309BDU039bLT0bLW901X0bLW900<0U9BD0<W9b@39bLT06P39bLT00`2DU9@0
bLW90<W9b@0O0<W9b@0309nOW`3<c<`0oooo00T0oooo00040?ooo`030:FUY@3oool0oooo00<0oooo
00L0jn_[000000000000f=SH0?ooo`0j>SX0A4A400<0oooo00L0KFe]0?ooo`3oool0oooo0;bl_000
0000>c/k00P0oooo00H0c<c<024Q8@2LW9`01PH60000003jn_X?0?ooo`030<[:bP3EeMD0oooo01H0
oooo00<0b/[:0=GEe@3oool05P3oool00`3:b/X0eMGE0?ooo`0A0?ooo`0308N7Q`00000000000080
000000<00@410;2`/03oool0403oool00`2UYJD0oooo0?ooo`040?ooo`030>GUi@0R8R80000000<0
000000<0=cLg0?ooo`3oool05P3oool00`2UYJD0oooo0?ooo`0F0?ooo`030:FUY@3oool0oooo01H0
oooo00<0YJFU0?ooo`3oool03`3oool00`3:b/X0eMGE0?ooo`0<0?ooo`030:FUY@3oool0oooo01H0
oooo00<0YJFU0?ooo`3oool05P3oool00`2b/[80oooo0?ooo`0F0?ooo`030;:b/P3oool0oooo0100
oooo00<0_Kfm0?ooo`3oool02P3oool00`2m_Kd0oooo0?ooo`0J0?ooo`030;fm_@3oool0oooo01X0
oooo00<0_Kfm0?ooo`3oool07`3oool00`3:b/X0eMGE0?ooo`090?ooo`00103oool00`2UYJD0oooo
0?ooo`030?ooo`0;0>g]k@000000000008f=S@3oool0MgMg0000002<S8`0oooo0>?Sh`29RHT00P3o
ool0103;bl/05ADE0000002;Rh/80?ooo`060?knoP0D51@0LW9b0<?3``0E5AD0n_[j3`3oool00`3:
b/X0eMGE0?ooo`0F0?ooo`030<[:bP3EeMD0oooo01H0oooo00<0b/[:0=GEe@3oool04P3oool01P2i
^KT0@d=300d=3@0T92@0Q8B40=GEeA40oooo00<0YJFU0?ooo`3oool01@3oool01P3_knl0MgMg020P
800>3Ph0E5AD09RHV1P0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?ooo`0F0?ooo`03
0:FUY@3oool0oooo00l0oooo00<0b/[:0=GEe@3oool0303oool00`2UYJD0oooo0?ooo`0F0?ooo`03
0:FUY@3oool0oooo01H0oooo00<0/[:b0?ooo`3oool05P3oool00`2b/[80oooo0?ooo`0@0?ooo`03
0;fm_@3oool0oooo00X0oooo00<0_Kfm0?ooo`3oool06P3oool00`2m_Kd0oooo0?ooo`0J0?ooo`03
0;fm_@3oool0oooo01l0oooo00<0b/[:0=GEe@3oool02@3oool000@0oooo00<0YJFU0?ooo`3oool0
103oool0400P82000000028R8P3jn_X0h^;R00`<30000000@T9206EUI@1dM7@0WIfM05aLG0051@D0
000001/K6`3bl_890?ooo`050410@0030`<0d];B0=kNgP3moOd03`3oool00`3:b/X0eMGE0?ooo`0F
0?ooo`030<[:bP3EeMD0oooo01H0oooo00<0b/[:0=GEe@3oool05P3oool00`3:b/X0eMGE0?ooo`0@
0?ooo`030:FUY@3oool0oooo00X0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?ooo`0F
0?ooo`030:FUY@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool03`3oool00`3:b/X0eMGE0?ooo`0<
0?ooo`030:FUY@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool05P3oool00`2b/[80oooo0?ooo`0F
0?ooo`030;:b/P3oool0oooo0100oooo00<0_Kfm0?ooo`3oool02P3oool00`2m_Kd0oooo0?ooo`0J
0?ooo`030;fm_@3oool0oooo01X0oooo00<0_Kfm0?ooo`3oool07`3oool00`3:b/X0eMGE0?ooo`09
0?ooo`00103oool00`2UYJD0oooo0?ooo`040?ooo`0707UiN@0000000000092@T03oool0[:b/00D5
1@060000000300/;2`38b<P0oooo00T0oooo00<0JVYZ00000010@4004@3oool00`3:b/X0eMGE0?oo
o`0F0?ooo`030<[:bP3EeMD0oooo01H0oooo00<0b/[:0=GEe@3oool05P3oool00`3:b/X0eMGE0?oo
o`0@0?ooo`030:FUY@3oool0oooo00X0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?oo
o`0F0?ooo`030:FUY@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool03`3oool00`3:b/X0eMGE0?oo
o`0<0?ooo`030:FUY@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool05P3oool00`2b/[80oooo0?oo
o`0F0?ooo`030;:b/P3oool0oooo0100oooo00<0_Kfm0?ooo`3oool02P3oool00`2m_Kd0oooo0?oo
o`0J0?ooo`030;fm_@3oool0oooo01X0oooo00<0_Kfm0?ooo`3oool07`3oool00`3:b/X0eMGE0?oo
o`090?ooo`00103oool00`2FUYH0e]KF0=KFeP040=KFeP090<71`@0820P0000000L71`2e]KD0e]KF
0:NWY`0g=cL00@410080000000<00`<303hn?P2e]KD02`3Fe]H01P1bLW80000000000022PX80a<C4
0=?Cd`h0e]KF00<0ZJVY0;:b/P3Fe]H05P3Fe]H00`2YZJT0/[:b0=KFeP0F0=KFeP030:VYZ@2b/[80
e]KF01H0e]KF00<0ZJVY0;:b/P3Fe]H0403Fe]H00`2:RXX0e]KF0=KFeP0:0=KFeP0308Z:RP3Fe]H0
e]KF01H0e]KF00<0RXZ:0=KFeP3Fe]H05P3Fe]H00`2:RXX0e]KF0=KFeP0F0=KFeP0308Z:RP3Fe]H0
e]KF00l0e]KF00<0ZJVY0;:b/P3Fe]H0303Fe]H00`2:RXX0e]KF0=KFeP0F0=KFeP0308Z:RP3Fe]H0
e]KF01H0e]KF00<0UIFE0=KFeP3Fe]H05P3Fe]H00`2EUID0e]KF0=KFeP0@0=KFeP0309jNWP3Fe]H0
e]KF00X0e]KF00<0WYjN0=KFeP3Fe]H06P3Fe]H00`2NWYh0e]KF0=KFeP0J0=KFeP0309jNWP3Fe]H0
e]KF01l0e]KF00<0ZJVY0<o?c`3oool02@3oool000@0oooo00<0TI6A0<W9b@39bLT01@39bLT01@1U
IFD000000000000Q8B40_Kfm0080bLW900@0FUYJ0:JVYP2VYZH0_Kfm3@39bLT01P1QHF400P820000
00000000=3@d0;Zj^Ph0bLW900<0WinO0:NWY`39bLT05P39bLT00`2OWil0YjNW0<W9b@0F0<W9b@03
09nOW`2WYjL0bLW901H0bLW900<0WinO0:NWY`39bLT04039bLT00`22PX80bLW90<W9b@0:0<W9b@03
08:2PP39bLT0bLW901H0bLW900<0PX:20<W9b@39bLT05P39bLT00`22PX80bLW90<W9b@0F0<W9b@03
08:2PP39bLT0bLW900l0bLW900<0WinO0:NWY`39bLT03039bLT00`22PX80bLW90<W9b@0F0<W9b@03
08:2PP39bLT0bLW901H0bLW900<0S8b<0<W9b@39bLT05P39bLT00`2<S8`0bLW90<W9b@0@0<W9b@03
09BDU039bLT0bLW900X0bLW900<0U9BD0<W9b@39bLT06P39bLT00`2DU9@0bLW90<W9b@0J0<W9b@03
09BDU039bLT0bLW901l0bLW900<0WinO0<c<c03oool02@3oool000@0oooo00<0YJFU0?ooo`3oool0
1@3oool0203jn_X0<S8b000000000000@T920?Win@3kno/0OWin4@3oool01014A4@000000000003_
knl?0?ooo`030<[:bP3EeMD0oooo01H0oooo00<0b/[:0=GEe@3oool05P3oool00`3:b/X0eMGE0?oo
o`0F0?ooo`030<[:bP3EeMD0oooo0100oooo00<0YJFU0?ooo`3oool02P3oool00`2UYJD0oooo0?oo
o`0F0?ooo`030:FUY@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?oo
o`0?0?ooo`030<[:bP3EeMD0oooo00`0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?oo
o`0F0?ooo`030;:b/P3oool0oooo01H0oooo00<0/[:b0?ooo`3oool0403oool00`2m_Kd0oooo0?oo
o`0:0?ooo`030;fm_@3oool0oooo01X0oooo00<0_Kfm0?ooo`3oool06P3oool00`2m_Kd0oooo0?oo
o`0O0?ooo`030<[:bP3EeMD0oooo00T0oooo00040?ooo`030:FUY@3oool0oooo00H0oooo00L0emOG
00T92@0000000000051@D03<c<`0YjNW00d0oooo00D0bLW90<71`@31`L40`L7103dm?@0200000003
0<30`03emOD0oooo00d0oooo00<0b/[:0=GEe@3oool05P3oool00`3:b/X0eMGE0?ooo`0F0?ooo`03
0<[:bP3EeMD0oooo01H0oooo00<0b/[:0=GEe@3oool0403oool00`2UYJD0oooo0?ooo`0:0?ooo`03
0:FUY@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?ooo`0F0?ooo`03
0:FUY@3oool0oooo00l0oooo00<0b/[:0=GEe@3oool0303oool00`2f][H0oooo0?ooo`0F0?ooo`03
0;Jf]P3oool0oooo01H0oooo00<0/[:b0?ooo`3oool05P3oool00`2b/[80oooo0?ooo`0@0?ooo`03
0;fm_@3oool0oooo00X0oooo00<0_Kfm0?ooo`3oool06P3oool00`2m_Kd0oooo0?ooo`0J0?ooo`03
0;fm_@3oool0oooo01l0oooo00<0b/[:0=GEe@3oool02@3oool000@0oooo00<0YJFU0?ooo`3oool0
1`3oool01P2ZZZX00@410000000000006a/K0=CDe0d0oooo00D0IFEU07MgM`2d];@0];Bd03Ti>@02
000000030;2`/03clo<0oooo00d0oooo00<0b/[:0=GEe@3oool05P3oool00`3:b/X0eMGE0?ooo`0F
0?ooo`030<[:bP3EeMD0oooo01H0oooo00<0b/[:0=GEe@3oool0403oool00`2UYJD0oooo0?ooo`0:
0?ooo`030:FUY@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?ooo`0F
0?ooo`030:FUY@3oool0oooo00l0oooo00<0b/[:0=GEe@3oool0?P3oool00`2b/[80oooo0?ooo`0F
0?ooo`030;:b/P3oool0oooo0100oooo00<0_Kfm0?ooo`3oool02P3oool00`2m_Kd0oooo0?ooo`0J
0?ooo`030;fm_@3oool0oooo01X0oooo00<0_Kfm0?ooo`3oool07`3oool00`3:b/X0eMGE0?ooo`09
0?ooo`00103oool00`2UYJD0oooo0?ooo`080?ooo`0608>3P`00000000000000000o?cl0l_;b303o
ool01@3no_h0MWIf0?Cdm03oool0D51@0080000000<0n_[j0?ooo`3oool03@3oool00`3:b/X0eMGE
0?ooo`0F0?ooo`030<[:bP3EeMD0oooo01H0oooo00<0b/[:0=GEe@3oool05P3oool00`3:b/X0eMGE
0?ooo`0@0?ooo`030:FUY@3oool0oooo00X0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo
0?ooo`0F0?ooo`030:FUY@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool03`3oool00`3:b/X0eMGE
0?ooo`0n0?ooo`030;:b/P3oool0oooo01H0oooo00<0/[:b0?ooo`3oool0403oool00`2m_Kd0oooo
0?ooo`0:0?ooo`030;fm_@3oool0oooo01X0oooo00<0_Kfm0?ooo`3oool06P3oool00`2m_Kd0oooo
0?ooo`0O0?ooo`030<[:bP3EeMD0oooo00T0oooo00040?ooo`0309JFUP3Fe]H0e]KF00T0e]KF00H0
E5AD000000000000000003hn?P3De=@<0=KFeP040<K6aP1XJ6P0e]KF04=3@`80000000<0dM7A0=KF
eP3Fe]H03@3Fe]H00`2YZJT0/[:b0=KFeP0F0=KFeP030:VYZ@2b/[80e]KF01H0e]KF00<0ZJVY0;:b
/P3Fe]H05P3Fe]H00`2YZJT0/[:b0=KFeP0@0=KFeP0308Z:RP3Fe]H0e]KF00X0e]KF00<0RXZ:0=KF
eP3Fe]H05P3Fe]H00`2:RXX0e]KF0=KFeP0F0=KFeP0308Z:RP3Fe]H0e]KF01H0e]KF00<0V9RH0=KF
eP3Fe]H03`3Fe]H00`2YZJT0/[:b0=KFeP0n0=KFeP030:6QX@3Fe]H0e]KF01H0e]KF00<0UIFE0=KF
eP3Fe]H0403Fe]H00`2NWYh0e]KF0=KFeP0:0=KFeP0309jNWP3Fe]H0e]KF01X0e]KF00<0ZJVY0=KF
eP3Fe]H06P3Fe]H00`2YZJT0e]KF0=KFeP0O0=KFeP030:VYZ@3?cll0oooo00T0oooo00040?ooo`03
096AT@39bLT0bLW900T0bLW900<0alO704Y:BP0000000P0000000`1bLW80bLW90<W9b@0;0<W9b@03
05eMG@2HV9P0?clo0080000000<0aLG50<W9b@39bLT03@39bLT00`2OWil0YjNW0<W9b@0F0<W9b@03
09nOW`2WYjL0bLW901H0bLW900<0WinO0:NWY`39bLT05P39bLT00`2OWil0YjNW0<W9b@0@0<W9b@03
08:2PP39bLT0bLW900X0bLW900<0PX:20<W9b@39bLT05P39bLT00`22PX80bLW90<W9b@0F0<W9b@03
08:2PP39bLT0bLW902P0bLW900<0WinO0:NWY`39bLT0E`39bLT00`2<S8`0bLW90<W9b@0@0<W9b@03
09BDU039bLT0bLW900X0bLW900<0U9BD0<W9b@39bLT0F@39bLT00`2OWil0c<c<0?ooo`090?ooo`00
103oool00`2UYJD0oooo0?ooo`0:0?ooo`060;fm_@18B4P00@410000000@4100l_;b303oool01P3<
c<`08B4Q09bLW0061PH000000?[jnPl0oooo00<0b/[:0=GEe@3oool05P3oool00`3:b/X0eMGE0?oo
o`0F0?ooo`030<[:bP3EeMD0oooo01H0oooo00<0b/[:0=GEe@3oool0403oool00`2UYJD0oooo0?oo
o`0:0?ooo`030:FUY@3oool0oooo01H0oooo00<0YJFU0?ooo`3oool05P3oool00`2UYJD0oooo0?oo
o`0X0?ooo`030<[:bP3EeMD0oooo05L0oooo00<0/[:b0?ooo`3oool0403oool00`2m_Kd0oooo0?oo
o`0:0?ooo`030;fm_@3oool0oooo05T0oooo00<0b/[:0=GEe@3oool02@3oool000@0oooo00<0YJFU
0?ooo`3oool02P3oool01P1mOGd0emOG0:^[Z`030`<00000096AT@`0oooo00H0o_kn01@D501bLW80
`l?301DE5@3jn_X?0?ooo`030=CDe03MgMd0oooo01H0oooo00<0e=CD0=gMg@3oool05P3oool00`3:
b/X0eMGE0?ooo`0F0?ooo`030<[:bP3EeMD0oooo0100oooo00<0YJFU0?ooo`3oool02P3oool00`2U
YJD0oooo0?ooo`0F0?ooo`030:FUY@3oool0oooo01H0oooo00<0][Jf0?ooo`3oool0:03oool00`3:
b/X0eMGE0?ooo`1G0?ooo`030<30`03oool0oooo0100oooo00<0_Kfm0?ooo`3oool02P3oool00`3:
b/X0oooo0?ooo`1I0?ooo`030<[:bP3EeMD0oooo00T0oooo00040?ooo`030:FUY@3oool0oooo00X0
oooo00H0C4a<0?KfmP3oool0Q8B40000000k>c/=0?ooo`050410@0030`<0d];B0=kNgP3moOd0@@3o
ool00`3:b/X0eMGE0?ooo`0F0?ooo`030<[:bP3EeMD0oooo0100oooo00<0YJFU0?ooo`3oool02P3o
ool00`2UYJD0oooo0?ooo`0F0?ooo`030:FUY@3oool0oooo0440oooo00<0b/[:0=GEe@3oool0JP3o
ool00`2m_Kd0oooo0?ooo`1V0?ooo`030<[:bP3EeMD0oooo00T0oooo00040?ooo`030:FUY@3oool0
oooo00X0oooo00L0<C4a0?ooo`3oool0o?cl02l_;`051@D0n?Sh00`0oooo00<0JVYZ00000010@400
@`3oool00`3:b/X0eMGE0?ooo`0F0?ooo`030<[:bP3EeMD0oooo0100oooo00<0YJFU0?ooo`3oool0
2P3oool00`2UYJD0oooo0?ooo`0F0?ooo`030:FUY@3oool0oooo0440oooo00<0b/[:0=GEe@3oool0
JP3oool00`2m_Kd0oooo0?ooo`1V0?ooo`030<[:bP3EeMD0oooo00T0oooo00040?ooo`030:FUY@3F
e]H0e]KF00T0e]KF00<0d];B00l?3`3Fe]H00P3Fe]H00`2CTi<000000;Bd]00<0=KFeP0407alO000
0000000008f=SD80e]KF00<0/K6a0;Vi^@3Fe]H05P3Fe]H00`2YZJT0/[:b0=KFeP0@0=KFeP0309RH
V03Fe]H0e]KF00X0e]KF00<0RXZ:0=KFeP3Fe]H05P3Fe]H00`2HV9P0e]KF0=KFeP110=KFeP030;6a
/@2i^KT0e]KF06X0e]KF00<0ZJVY0=KFeP3Fe]H0IP3Fe]H00`2a/K40e]KF0?ooo`090?ooo`00103o
ool00`3QhN40bLW90<W9b@090<W9b@030;Zj^P000000[:b/0080bLW900<0aLG500/;2`2LW9`03039
bLT01033`l<0^;Rh0;Rh^02m_KeK0<W9b@0309nOW`2WYjL0bLW901d0bLW900<0PX:20<W9b@39bLT0
o`39bLTb0<W9b@030?Gem@3oool0oooo00P0oooo000@0?ooo`030?Shn0000000UiNG00<0oooo00<0
=cLg0<o?c`3oool0JP3oool00`3:b/X0eMGE0?ooo`0M0?ooo`030:FUY@3oool0oooo0?l0oooo?@3o
ool00140oooo00<06a/K03@d=03oool00P3oool00`0d=3@0lO7a0?ooo`1Z0?ooo`030=CDe03MgMd0
oooo01d0oooo00<0][Jf0?ooo`3oool0o`3ooolm0?ooo`004@3oool01P1GEeL000000<71`@3oool0
o?cl02TY:Ol0ooooc03oool00140oooo00H0ZZZZ0000000V9RH0f=SH08N7Q`1UIFGo0?oool`0oooo
000A0?ooo`030?Win@0M7Ad000000080000000<0]KFe0?ooo`3oool0o`3oooo:0?ooo`004P3oool0
1@2VYZH000000000000U9BD0oOgm0?l0ooooc03oool001<0oooo00<0TI6A03De=@36a/H0o`3oooo=
0?ooo`00o`3ooooS0?ooo`00o`3ooooS0?ooo`00o`3ooooS0?ooo`00o`3ooooS0?ooo`00o`3ooooS
0?ooo`00\
\>"]]
}], "Text",
  CellTags->"mmtag:17:ode_to_joy"],

Cell[BoxData[
    \(Beats[list_, \ duration_, \ cadence_]\  := \ 
      Table[If[t \[GreaterEqual] \ \((i - 1)\)*cadence\  && \ 
            t\ \  \[LessEqual] \ \((i - 1)\)*cadence\  + \ duration, 
          Evaluate[list[\([i]\)]], 0], {i, 1, Length[list]}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(twoframes\  = \ {ENote, ENote, \ FNote, \ GNote, GNote, FNote, ENote, 
        DNote, CNote, \ CNote, \ DNote, \ ENote}\)], "Input"],

Cell[BoxData[
    \({Sin[2070.937877246392`\ t], Sin[2070.937877246392`\ t], 
      Sin[2194.0883092671115`\ t], Sin[2463.0086404143976`\ t], 
      Sin[2463.0086404143976`\ t], Sin[2194.0883092671115`\ t], 
      Sin[2070.937877246392`\ t], Sin[1845.3715247186444`\ t], 
      Sin[1643.68127635818`\ t], Sin[1643.68127635818`\ t], 
      Sin[1845.3715247186444`\ t], Sin[2070.937877246392`\ t]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Play[Evaluate[Beats[twoframes, \ 0.5, \ 0.75]], {t, 0, 12}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 98304 8
{ currentfile 1 index readhexstring pop }
 false 12 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003oool0003o
o`0004;o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oo
nfX0eOoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oo
nf[ooo]Z0?oooo]Z7OoonfX00ol0003ooo]ZoookJP3ooookJQkooo]Z0Ol000000003o`000?oonf[o
oo]Z05kooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[o
oo]Z0?oooo]Z1_oonfX1o`00000000?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP3ooook
JT7ooo]Z0Ol000000003o`000?oonf[o000001Oo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo
00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXHo`0000cooo]Z6?l0000;oookJQWo
00002ooonfXHo`0000_ooo]Z6Ol0002LoookJP7o000000000ol0003ooo]Zo`00000Go`0000_ooo]Z
6Ol0000;oookJQWo00002ooonfXHo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXIo`0000_ooo]Z
6?l0000;oookJQWo00002ooonfXIo`0000_ooo]Z6Ol0000:oookJQWo0000W?oonfX1o`00000000?o
0000oookJ_l00000ool0003oo`0003go00000OoonfX1o`00000000?o0000oookJ_l000005ol0000;
oookJQWo00002ooonfXIo`0000_ooo]Z6?l0000;oookJQWo00002ooonfXIo`0000_ooo]Z6Ol0000;
oookJQSo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo00003?oonfXHo`0009cooo]Z0Ol00000
0003o`000?oonf[o000001Oo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo00002ooonfXIo`00
00_ooo]Z6Ol0000;oookJQWo00002ooonfXHo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXHo`00
00_ooo]Z6Ol0002LoookJP7o000000000ol0003ooo]Zo`00000Go`0000_ooo]Z6Ol0000;oookJQWo
00002ooonfXHo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXIo`0000_ooo]Z6?l0000;oookJQWo
00002ooonfXHo`0000cooo]Z6?l0000<oookJQSo0000W?oonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJUWooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP2m
oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oo
nfX0>?oonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z0;;ooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000003oo`000?oo0000@_l000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00
000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
oooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000
oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoook
JP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Z
oookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooook
J_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`000000
00?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Zoooo
nfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oook
J_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0
003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSko
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zoook
JP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol00000
0003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oo
oo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oo
nf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1
o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oo
oo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o
0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXn
oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000
00000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[o
oookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003o
oo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3o
oookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z
?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00
000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
oooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000
oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoook
JP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Z
oookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooook
J_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`000000
00?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o00000?oooo]Zoooo
nfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oook
J_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0
003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSko
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zoook
JP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol00000
0003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oo
oo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oo
nf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1
o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oo
oo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o
0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXn
oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000
00000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[o
oookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003o
oo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3o
oookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z
?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00
000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
oooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000
oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoook
JP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Z
oookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooook
J_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`000000
00?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Zoooo
nfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oook
J_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0
003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_l000005ol0000;oookJQWo
00002ooonfXIo`0000_ooo]Z6?l0000;oookJQWo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo
00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo00002ooonfXIo`0009cooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zo`00000Go`0000_ooo]Z6Ol0
000;oookJQWo00002ooonfXHo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXIo`0000_ooo]Z6?l0
000;oookJQWo00002ooonfXIo`0000_ooo]Z6?l0000;oookJQWo0000W?oonfX1o`00000000?o0000
oookJ_l000005ol0000;oookJQWo00002ooonfXIo`0000_ooo]Z6?l0000;oookJQWo00002ooonfXI
o`0000_ooo]Z6Ol0000;oookJQSo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo00002ooonfXI
o`0009cooo]Z0Ol000000003o`000?oonf[o000001Oo00002ooonfXIo`0000_ooo]Z6Ol0000;oook
JQSo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXHo`0000_ooo]Z6Ol0000;oook
JQWo00002ooonfXHo`0000_ooo]Z6Ol0002LoookJP7o000000000ol0003ooo]Zo`00000Go`0000_o
oo]Z6Ol0000;oookJQWo00002ooonfXHo`0000cooo]Z6?l0000;oookJQWo00002ooonfXIo`0000_o
oo]Z6?l0000;oookJQWo00002ooonfXIo`0000_ooo]Z6?l0000;oookJQWo0000W?oonfX1o`000000
00?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o000001Oo00003?oo
nfXHo`0000_ooo]Z6Ol0000;oookJQSo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQWo00002ooo
nfXHo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXHo`0000cooo]Z6?l0002LoookJP7o00000000
0ol0003ooo]Zo`00000Go`0000_ooo]Z6?l0000<oookJQWo00002ooonfXHo`0000_ooo]Z6Ol0000;
oookJQWo00002ooonfXHo`0000cooo]Z6?l0000<oookJQSo00002ooonfXIo`0000_ooo]Z6?l0000;
oookJQWo0000W?oonfX1o`00000000?o0000oookJ_l000005ol0000<oookJQSo00002ooonfXIo`00
00_ooo]Z6?l0000<oookJQSo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo00002ooonfXIo`00
00_ooo]Z6Ol0000;oookJQSo00003?oonfXHo`0009cooo]Z0Ol000000003o`000?oonf[ooo]Z0?oo
oo]ZoooonfXnoookJP7o000000000ol0003ooo]Zo`00000Go`0000_ooo]Z6Ol0000<oookJQOo0000
3?oonfXHo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXIo`0000_ooo]Z6?l0000<oookJQSo0000
2ooonfXIo`0000_ooo]Z6?l0000<oookJQSo0000W?oonfX1o`00000000?o0000oookJ_l000005ol0
000;oookJQWo00002ooonfXIo`0000_ooo]Z6?l0000;oookJQWo00002ooonfXIo`0000_ooo]Z6Ol0
000;oookJQSo00002ooonfXIo`0000_ooo]Z6?l0000<oookJQSo00002ooonfXIo`0009cooo]Z0Ol0
00000003o`000?oonf[o000001Oo00003?oonfXHo`0000_ooo]Z6Ol0000;oookJQSo00002ooonfXI
o`0000_ooo]Z6Ol0000;oookJQSo00003?oonfXHo`0000cooo]Z6?l0000;oookJQWo00002ooonfXH
o`0000cooo]Z6?l0002LoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00
000000?o0000oookJ_l00000ool0003oo`0003go00000OoonfX1o`00000000?o0000oookJ_l00000
5ol0000;oookJQWo00002ooonfXIo`0000_ooo]Z6?l0000;oookJQWo00002ooonfXIo`0000_ooo]Z
6Ol0000;oookJQSo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo00002ooonfXIo`0009cooo]Z
0Ol000000003o`000?oonf[o000001Oo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo00003?oo
nfXHo`0000_ooo]Z6Ol0000;oookJQSo00003?oonfXHo`0000_ooo]Z6Ol0000;oookJQSo00003?oo
nfXHo`0000cooo]Z6?l0002LoookJP7o000000000ol0003ooo]Zo`00000Go`0000_ooo]Z6?l0000<
oookJQWo00002ooonfXHo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXHo`0000cooo]Z6?l0000;
oookJQWo00002ooonfXIo`0000_ooo]Z6?l0000;oookJQWo0000W?oonfX1o`00000000?o0000oook
J_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o000001Oo00003?oonfXHo`0000_o
oo]Z6?l0000<oookJQSo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXHo`0000_o
oo]Z6Ol0000;oookJQSo00003?oonfXHo`0000cooo]Z6?l0002LoookJP7o000000000ol0003ooo]Z
o`00000Go`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXHo`0000cooo]Z6?l0000;oookJQWo0000
2ooonfXHo`0000cooo]Z6?l0000;oookJQWo00002ooonfXIo`0000_ooo]Z6?l0000<oookJQSo0000
W?oonfX1o`00000000?o0000oookJ_l000005ol0000;oookJQWo00002ooonfXIo`0000_ooo]Z6?l0
000;oookJQWo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo00002ooonfXIo`0000_ooo]Z6Ol0
000;oookJQSo00002ooonfXIo`0009cooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXn
oookJP7o000000000ol0003ooo]Zo`00000Go`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXHo`00
00_ooo]Z6Ol0000;oookJQWo00002ooonfXHo`0000cooo]Z6?l0000;oookJQWo00002ooonfXIo`00
00_ooo]Z6?l0000<oookJQSo0000W?oonfX1o`00000000?o0000oookJ_l000005ol0000;oookJQWo
00002ooonfXIo`0000_ooo]Z6?l0000;oookJQWo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo
00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo00002ooonfXIo`0009cooo]Z0Ol000000003o`00
0?oonf[o000001Oo00002ooonfXIo`0000_ooo]Z6Ol0000;oookJQSo00002ooonfXIo`0000_ooo]Z
6Ol0000;oookJQWo00002ooonfXHo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXHo`0000_ooo]Z
6Ol0002LoookJP7o000000000ol0003ooo]Zo`00000Go`0000_ooo]Z6Ol0000;oookJQWo00002ooo
nfXHo`0000_ooo]Z6Ol0000;oookJQWo00002ooonfXIo`0000_ooo]Z6?l0000;oookJQWo00002ooo
nfXIo`0000_ooo]Z6?l0000;oookJQWo0000W?oonfX1o`00000000?o0000oookJ_oonfX0oooonf[o
oookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003o
oo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3o
oookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z
?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00
000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
oooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000
oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoook
JP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Z
oookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooook
J_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`000000
00?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Zoooo
nfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oook
J_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0
003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSko
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zoook
JP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol00000
0003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oo
oo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oo
nf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1
o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oo
oo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o
0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXn
oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000
00000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[o
oookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003o
oo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3o
oookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z
?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00
000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
oooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000
oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoook
JP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Z
oookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooook
J_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`000000
00?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Zoooo
nfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oook
J_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooo
nf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0
003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSko
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zoook
JP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol00000
0003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oo
oo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oo
nf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1
o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oo
oo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o
0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXn
oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000
00000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[o
oookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003o
oo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3o
oookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z
?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00
000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Z
oooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000
oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoook
JP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Z
oookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol0
00000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooook
J_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z
0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`000000
00?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000?oo0000ool00012o`000000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.0256409, -0.0250052, \
0.00182832, 0.00295828}},
  ImageSoundCache->{{{0, 575}, {354.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000600200000000000000000l0022QHN9
RXZ:RHR6Ph5nNgUgMWEeMGMhNgf0PhF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]nP8>5
QhV:RXZ9QhF3P7ekN7MeMGEfMgUkOX63QXR9RXZ:RHN5PWmmNWQfMGEeMWMiO7j1
Q8J8RHZ:RXR7Q89oO7YhMWEeMGIhNWaoPHB6R8V:RXV8QXB1OgajN7IeMGEfN7Ym
Oh:4QhR:RXZ9R8J4PGilNGMfMGEeMWQjOH22QHN9RXZ:RHR6Ph5nNgUgMWEeMGMh
Ngf0PhF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]nP8>5QhV:RXZ9QhF2P7ekN7MeMGEf
MgUkOX63QXR9RXZ:R8N5PWmmNWQfMGEeMWMiO7j1Q8J8RHZ:RXR6Q89oO7YhMWEe
MGIhNWaoPXB6R8V:RXV8QXB1OgajN7IeMGEfN7YmOh:4QhR:RXZ9R8J4PGilNGMf
MGEeMgQjOH22QHN9RXZ:RHR6Ph5nNgUgMWEeMGMiNgf0PhF7RHZ:RXV7QH>0OG]i
MgIeMGIgNG]nP8>5QhV:RXZ9QhF2P7ekN7MeMGEfMgUkOX63QXR9RXZ:R8N5PWmm
NWQfMGEeMWMiO7j1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8V:RXV8QXB1
OgajN7IeMGEfN7YmOh:4QhR:RXZ9R8J3PGilNGMfMGEeMgQjOH22QHN9RXZ:RHR6
Ph1nNgUgMWEeMWMiNgf0PhF7RHZ:RXV7QH>0OG]iMgIeMGIgNG]nP8>5QhV:RXZ9
QhF2P7ekN7MeMGEfMgUlOX63QXR9RXZ:R8N5PWmmNWQfMGEeMWMjO7n1Q8J8RHZ:
RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8V:RXV8QXB1OgajMgIeMGEfN7YmOh:5QhR:
RXZ9R8J3PGilNGMfMGEeMgQkOH22QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgf0PhF7
RHZ:RXV7QH>0OG]iMgIeMGIgNG]nP8>6R8V:RXZ9QhF2P7ejN7MeMGEfMgUlOX63
QXR9RXZ:R8N4PWmmNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWao
PXB6R8V:RXV8QXB1OWaiMgIeMGEfN7YmOh:5QhR:RXZ9R8J3PGikNGMfMGEeMgQk
OH22QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgf0PhF7RHZ:RXV7QH>0OG]iMgEeMGIg
NG]nPH>6R8V:RXZ9QhF2P7ejN7MeMGEfMgUlOX64QXR9RXZ:R8N4PWmmNWQfMGEe
MWQjO7n1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8Z:RXV8QXB1OWaiMgIe
MGEfN7YmOh:5QhR:RXZ9R8J3PGikNGMfMGEeMgQkOH22QHN9RXZ:RHN5Ph1nNgUg
MWEeMWMiNgj0PhF7RHZ:RXV7QH>0OG]hMgEeMGIgNG]nPH>6R8V:RXZ9QhF2P7ej
N7IeMGEfMgUlOX64QXR9RXZ:R8N4PWmmNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q85o
O7YhMWEeMGIhNWaoPXB7R8Z:RXV8QXB1OWaiMgIeMGEfN7YmOh:5QhV:RXZ9R8J3
PGikNGMfMGEeMgQkOH23QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgj0PhF7RHZ:RXV7
QH>0OG]hMgEeMGIgNG]nPH>6R8V:RXZ9QhF2OgejN7IeMGEfMgUlOX64QXR9RXZ:
R8N4PWmlNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWaoPXB7R8Z:
RXV8QXB1OWaiMgIeMGEfN7YmP8:5QhV:RXZ9R8J3PGikNGMfMGEeMgQkOH23QHN9
RXZ:RHN5Ph1nNgUgMWEeMWMiNgj0PhF7RHZ:RXV7QH:0OG]hMgEeMGIgNG]nPH>6
R8V:RXZ9QhF2OgejN7IeMGEfMgUlOX64QXR9RXZ:R8N4PWmlNWQfMGEeMWQjO7n1
Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWeoPXB7R8Z:RXV8QXB1OWaiMgIeMGEgN7Ym
P8:5QhV:RXZ9R8J3PGikNGMfMGEeMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMi
Ngj0PhF7RHZ:RXV7QH:0OG]hMgEeMGIgNG]nPH>6R8V:RXZ8QhF2OgejN7IeMGEf
MgUlOX64QXR9RXZ:R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RHZ:RHR6Q85oO7YhMWEe
MGIhNWeoPXB7R8Z:RXV8QXB1OWaiMgIeMGEgN7YmP8:5QhV:RXZ9R8J3PGikNGMf
MGEfMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMiNgj0PhF7RHZ:RXV7QH:0OG]h
MgEeMGIgNGanPH>6R8V:RXZ8QhF2OgejN7IeMGEfMgUlOh64QXR9RXZ9R8J4PWml
NWQfMGEeMWQjO7n2Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWeoPXB7R8Z:RXV8QX>1
OWaiMgIeMGEgN7YmP8:5QhV:RXZ9R8F3P7ikNGMfMGEfMgUkOH23QHN9RXZ:RHN5
Ph1mNgUgMWEeMWMiNgj0PhF8RHZ:RXV7QH:0OGYhMgEeMGIgNGanPH>6R8V:RXZ8
QhB2OgejN7IeMGEfN7YlOh64QXR9RXZ9R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RHZ:
RHR6Q85oO7UgMWEeMGIhNWeoPXF7R8Z:RXV8QX>1OWaiMgIeMGEgN7]mP8:5QhV:
RXZ9QhF3P7ikNGMfMGEfMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMiNgj1PhJ8
RHZ:RXV7QH:0OGYhMgEeMGIgNGanPHB6R8V:RXZ8QhB2OgejN7IeMGEfN7YlOh64
QXR9RXZ9R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RXZ:RHR6Q85nO7UgMWEeMGIhNWeo
PXF7R8Z:RXV8QX>1OW]iMgIeMGEgN7]mP8:5QhV:RXZ9QhF3P7ikNGMfMGEfMgUk
OH23QHN9RXZ:RHN5Ph1mNgUgMGEeMWMiNgj1PhJ8RHZ:RXV7QH:0OGYhMgEeMGIg
NGanPHB6R8V:RXZ8QhB2OgejN7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQfMGEe
MWQjO7n2Q8N8RXZ:RHR6Q85nO7UgMWEeMGIhNWeoPXF7RHZ:RXV8QX>1OW]iMgIe
MGEgN7]mP8:5QhV:RXZ9QhF3P7ikNGMfMGEfMgUkOX23QHN9RXZ:RHN5Ph1mNgQg
MGEeMWMiNgj1PhJ8RHZ:RXV7QH:0OGYhMWEeMGIgNGanPHB6R8V:RXZ8QhB2Ogaj
N7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQfMGEeMWQjO7n2Q8N8RXZ:RHR6Q85n
O7UgMWEeMGIhNWf0PXF7RHZ:RXV8QX>1OW]iMgIeMGEgN7]mP8>5QhV:RXZ9QhF3
P7ikNGMfMGEfMgUkOX23QHN9RXZ:RHN5Ph1mNgQgMGEeMWMiNgj1PhJ8RHZ:RXV7
QH9oOGYhMWEeMGIgNGanPHB6R8V:RXZ8QhB2OgajN7IeMGEfN7YlOh64QXR9RXZ9
R8J4PGmlNWQfMGEeMWQjOGn2Q8N8RXZ:RHR6Q85nO7UgMWEeMGIhNWf0PXF7RHZ:
RXV8QX>1OW]iMgIeMGEgN7]mP8>5QhV:RXZ9QhF3P7ikNGMfMGEfMgUkOX23QHN9
RXZ:RHN5PX1mNgQgMGEeMWMiNgj1PhJ8RHZ:RXR7QH9oOGYhMWEeMGIgNGanPHB6
R8V:RXZ8QXB2OgajN7IeMGEfN7YlOh:4QXR9RXZ9R8J4PGmlNWQfMGEeMWQjOGn2
Q8N8RXZ:RHR6Q85nO7UgMWEeMGMhNWf0PXF7RHZ:RXV8QX>1OW]iMgIeMGEgNG]m
P8>5QhV:RXZ9QhF3P7ekNGMfMGEfMgUkOX23QHN9RXZ:RHN5PX1mNgQgMGEeMWMi
Ngj1PhJ8RHZ:RXR7QH9oOGYhMWEeMGIgNGanPHB6R8V:RXV8QXB2OgajN7IeMGEf
N7YlOh:4QXR9RXZ9R8J4PGmlNWQfMGEeMWQjOGn2Q8N8RXZ:RHR6Ph5nO7UgMWEe
MGMhNWf0PXF7RHZ:RXV8QX>0OW]iMgIeMGIgNG]mP8>5QhV:RXZ9QhF3P7ekNGMf
MGEfMgUkOX23QHN9RXZ:RHN5PX1mNgQgMGEeMWMiO7j1PhJ8RHZ:RXR7QH9oOGYh
MWEeMGIgNWaoPHB6R8V:RXV8QXB2OgajN7IeMGEfN7YlOh:4QXR9RXZ9R8J4PGml
NWMfMGEeMWQjOGn2QHN8RXZ:RHR6Ph5nO7UgMWEeMGMhNgf0PXF7RHZ:RXV7QH>0
OW]iMgIeMGIgNG]mP8>5QhV:RXZ9QhF3P7ekNGMfMGEfMgUkOX23QXR9RXZ:RHN5
PX1mNWQgMGEeMWMiO7j1PhJ8RHZ:RXR7Q89oOGYhMWEeMGIhNWaoPHB6R8V:RXV8
QXB2OgajN7IeMGEfN7YlOh:4QXR9RXZ9R8J4PGilNGMfMGEeMWQjOGn2QHN8RXZ:
RHR6Ph5nNgUgMWEeMGMhNgf0PXF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]mP8>5QhV:
RXZ9QhF3P7ekNGMeMGEfMgUkOX63QXR9RXZ:RHN5PX1mNWQgMGEeMWMiO7j1Q8J8
RHZ:RXR7Q89oOGYhMWEeMGIhNWaoPHB6R8V:RXV8QXB2OgajN7IeMGEfN7YlOh:4
QXR:RXZ9R8J4PGilNGMfMGEeMWQjOGn2QHN8RXZ:RHR6Ph5nNgUgMWEeMGMhNgf0
PXF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]nP8>5QhV:RXZ9QhF3P7ekN7MeMGEfMgUk
OX63QXR9RXZ:RHN5PX1mNWQfMGEeMWMiO7j1Q8J8RHZ:RXR7Q89oOGYhMWEeMGIh
NWaoPHB6R8V:RXV8QXB1OgajN7IeMGEfN7YlOh:4QhR:RXZ9R8J4PGilNGMfMGEe
MWQjOGn2QHN9RXZ:RHR6Ph5nNgUgMWEeMGMhNgf0PhF7RHZ:RXV7QH>0OW]iMgIe
MGIgNG]nP8>5QhV:RXZ9QhF3P7ekN7MeMGEfMgUkOX63QXR9RXZ:RHN5PWmmNWQf
MGEeMWMiO7j1Q8J8RHZ:RXR7Q89oO7YhMWEeMGIhNWaoPHB6R8V:RXV8QXB1Ogaj
N7IeMGEfN7YlOh:4QhR:RXZ9R8J4PGilNGMfMGEeMWQjOH22QHN9RXZ:RHR6Ph5n
NgUgMWEeMGMhNgf0PhF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]nP8>5QhV:RXZ9QhF2
P7ekN7MeMGEfMgUkOX63QXR9RXZ:RHN5PWmmNWQfMGEeMWMiO7j1Q8J8RHZ:RXR7
Q89oO7YhMWEeMGIhNWaoPHB6R8V:RXV8QXB1OgajN7IeMGEfN7YmOh:4QhR:RXZ9
R8J4PGilNGMfMGEeP820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P8Z:RXV8
QX>1OW]iMgIeMGEgN7]mP8:5QhV:RXZ9QhF3P7ikNGMfMGEfMgUkOX23QHN9RXZ:
RHN5Ph1mNgQgMGEeMWMiNgj1PhJ8RHZ:RXV7QH:0OGYhMWEeMGIgNGanPHB6R8V:
RXZ8QhB2OgejN7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQfMGEeMWQjO7n2Q8N8
RXZ:RHR6Q85nO7UgMWEeMGIhNWeoPXF7RHZ:RXV8QX>1OW]iMgIeMGEgN7]mP8>5
QhV:RXZ9QhF3P7ikNGMfMGEfMgUkOX23QHN9RXZ:RHN5Ph1mNgQgMGEeMWMiNgj1
PhJ8RHZ:RXV7QH9oOGYhMWEeMGIgNGanPHB6R8V:RXZ8QhB2OgajN7IeMGEfN7Yl
Oh64QXR9RXZ9R8J4PGmlNWQfMGEeMWQjO7n2Q8N8RXZ:RHR6Q85nO7UgMWEeMGIh
NWf0PXF7RHZ:RXV8QX>1OW]iMgIeMGEgN7]mP8>5QhV:RXZ9QhF3P7ikNGMfMGEf
MgUkOX23QHN9RXZ:RHN5PX1mNgQgMGEeMWMiNgj1PhJ8RHZ:RXV7QH9oOGYhMWEe
MGIgNGanPHB6R8V:RXZ8QhB2OgajN7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQf
MGEeMWQjOGn2Q8N8RXZ:RHR6Q85nO7UgMWEeMGMhNWf0PXF7RHZ:RXV8QX>1OW]i
MgIeMGEgNG]mP8>5QhV:RXZ9QhF3P7ekNGMfMGEfMgUkOX23QHN9RXZ:RHN5PX1m
NgQgMGEeMWMiNgj1PhJ8RHZ:RXR7QH9oOGYhMWEeMGIgNGanPHB6R8V:RXZ8QXB2
OgajN7IeMGEfN7YlOh:4QXR9RXZ9R8J4PGmlNWQfMGEeMWQjOGn2Q8N8RXZ:RHR6
Q85nO7UgMWEeMGMhNWf0PXF7RHZ:RXV8QX>1OW]iMgIeMGIgNG]mP8>5QhV:RXZ9
QhF3P7ekNGMfMGEfMgUkOX23QHN9RXZ:RHN5PX1mNgQgMGEeMWMiO7j1PhJ8RHZ:
RXR7QH9oOGYhMWEeMGIgNGaoPHB6R8V:RXV8QXB2OgajN7IeMGEfN7YlOh:4QXR9
RXZ9R8J4PGmlNWQfMGEeMWQjOGn2Q8N8RXZ:RHR6Ph5nO7UgMWEeMGMhNWf0PXF7
RHZ:RXV8QH>0OW]iMgIeMGIgNG]mP8>5QhV:RXZ9QhF3P7ekNGMfMGEfMgUkOX23
QHR9RXZ:RHN5PX1mNWQgMGEeMWMiO7j1PhJ8RHZ:RXR7Q89oOGYhMWEeMGIhNWao
PHB6R8V:RXV8QXB2OgajN7IeMGEfN7YlOh:4QXR9RXZ9R8J4PGmlNGMfMGEeMWQj
OGn2QHN8RXZ:RHR6Ph5nO7UgMWEeMGMhNgf0PXF7RHZ:RXV7QH>0OW]iMgIeMGIg
NG]mP8>5QhV:RXZ9QhF3P7ekNGMfMGEfMgUkOX63QXR9RXZ:RHN5PX1mNWQgMGEe
MWMiO7j1Q8J8RHZ:RXR7Q89oOGYhMWEeMGIhNWaoPHB6R8V:RXV8QXB2OgajN7Ie
MGEfN7YlOh:4QXR:RXZ9R8J4PGilNGMfMGEeMWQjOGn2QHN8RXZ:RHR6Ph5nNgUg
MWEeMGMhNgf0PXF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]mP8>5QhV:RXZ9QhF3P7ek
NGMeMGEfMgUkOX63QXR9RXZ:RHN5PX1mNWQgMGEeMWMiO7j1Q8J8RHZ:RXR7Q89o
OGYhMWEeMGIhNWaoPHB6R8V:RXV8QXB1OgajN7IeMGEfN7YlOh:4QhR:RXZ9R8J4
PGilNGMfMGEeMWQjOGn2QHN9RXZ:RHR6Ph5nNgUgMWEeMGMhNgf0PXF7RHZ:RXV7
QH>0OW]iMgIeMGIgNG]nP8>5QhV:RXZ9QhF3P7ekN7MeMGEfMgUkOX63QXR9RXZ:
RHN5PX1mNWQfMGEeMWMiO7j1Q8J8RHZ:RXR7Q89oO7YhMWEeMGIhNWaoPHB6R8V:
RXV8QXB1OgajN7IeMGEfN7YlOh:4QhR:RXZ9R8J4PGilNGMfMGEeMWQjOH22QHN9
RXZ:RHR6Ph5nNgUgMWEeMGMhNgf0PhF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]nP8>5
QhV:RXZ9QhF3P7ekN7MeMGEfMgUkOX63QXR9RXZ:RHN5PWmmNWQfMGEeMWMiO7j1
Q8J8RHZ:RXR7Q89oO7YhMWEeMGIhNWaoPHB6R8V:RXV8QXB1OgajN7IeMGEfN7Ym
Oh:4QhR:RXZ9R8J4PGilNGMfMGEeMWQjOH22QHN9RXZ:RHR6Ph5nNgUgMWEeMGMh
Ngf0PhF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]nP8>5QhV:RXZ9QhF2P7ekN7MeMGEf
MgUkOX63QXR9RXZ:R8N5PWmmNWQfMGEeMWMiO7j1Q8J8RHZ:RXR6Q89oO7YhMWEe
MGIhNWaoPXB6R8V:RXV8QXB1OgajN7IeMGEfN7YmOh:4QhR:RXZ9R8J4PGilNGMf
MGEeMgQjOH22QHN9RXZ:RHR6Ph5nNgUgMWEeMGMiNgf0PhF7RHZ:RXV7QH>0OG]i
MgIeMGIgNG]nP8>5QhV:RXZ9QhF2P7ekN7MeMGEfMgUkOX63QXR9RXZ:R8N5PWmm
NWQfMGEeMWMiO7j1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8V:RXV8QXB1
OgajN7IeMGEfN7YmOh:4QhR:RXZ9R8J3PGilNGMfMGEeMgQjOH22QHN9RXZ:RHR6
Ph1nNgUgMWEeMWMiNgf0PhF7RHZ:RXV7QH>0OG]iMgIeMGIgNG]nP8>5QhV:RXZ9
QhF2P7ekN7MeMGEfMgUlOX63QXR9RXZ:R8N5PWmmNWQfMGEeMWMjO7n1Q8J8RHZ:
RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8V:RXV8QXB1OgajMgIeMGEfN7YmOh:5QhR:
RXZ9R8J3PGilNGMfMGEeMgQkOH22QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgf0PhF7
RHZ:RXV7QH>0OG]iMgIeMGIgNG]nP8>6R8V:RXZ9QhF2P7ejN7MeMGEfMgUlOX63
QXR9RXZ:R8N4PWmmNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWao
PXB6R8V:RXV8QXB1OWaiMgIeMGEfN7YmOh:5QhR:RXZ9R8J3PGikNGMfMGEeMgQk
OH22QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgf0PhF7RHZ:RXV7QH>0OG]iMgEeMGIg
NG]nPH>6R8V:RXZ9QhF2P7ejN7MeMGEfMgUlOX64QXR9RXZ:R8N4PWmmNWQfMGEe
MWQjO7n1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8Z:RXV8QXB1OWaiMgIe
MGEfN7YmOh:5QhR:RXZ9R8J3PGikNGMfMGEeMgQkOH22QHN9RXZ:RHN5Ph1nNgUg
MWEeMWMiNgj0PhF7RHZ:RXV7QH>0OG]hMgEeMGIgNG]nPH>6R8V:RXZ9QhF2P7ej
N7IeMGEfMgUlOX64QXR9RXZ:R8N4PWmmNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q85o
O7YhMWEeMGIhNWaoPXB7R8Z:RXV8QXB1OWaiMgIeMGEfN7YmOh:5QhV:RXZ9R8J3
PGikNGMfMGEeMgQkOH23QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgj0PhF7RHZ:RXV7
QH>0OG]hMgEeMGIgNG]nPH>6R8V:RXZ9QhF2OgejN7IeMGEfMgUlOX64QXR9RXZ:
R8N4PWmlNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWaoPXB7R8Z:
RXV8QXB1OWaiMgIeMGEfN7YmP8:5QhV:RXZ9R8J3PGikNGMfMGEeMgQkOH23QHN9
RXZ:RHN5Ph1nNgUgMWEeMWMiNgj0PhF7RHZ:RXV7QH:0OG]hMgEeMGIgNG]nPH>6
R8V:RXZ9QhF2OgejN7IeMGEfMgUlOX64QXR9RXZ:R8N4PWmlNWQfMGEeMWQjO7n1
Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWeoPXB7R8Z:RXV8QXB1OWaiMgIeMGEgN7Ym
P8:5QhV:RXZ9R8J3PGikNGMfMGEeMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMi
Ngj0PhF7RHZ:RXV7QH:0OG]hMgEeMGIgNG]nPH>6R8V:RXZ8QhF2OgejN7IeMGEf
MgUlOX64QXR9RXZ:R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RHZ:RHR6Q85oO7YhMWEe
MGIhNWeoPXB7R8Z:RXV8QXB1OWaiMgIeMGEgN7YmP8:5QhV:RXZ9R8J3PGikNGMf
MGEfMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMiNgj0PhF7RHZ:RXV7QH:0OG]h
MgEeMGIgNGanPH>6R8V:RXZ8QhF2OgejN7IeMGEfMgUlOh64QXR9RXZ9R8J4PWml
NWQfMGEeMWQjO7n2Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWeoPXB7R8Z:RXV8QX>1
OWaiMgIeMGEgN7YmP8:5QhV:RXZ9R8F3P7ikNGMfMGEfMgUkOH23QHN9RXZ:RHN5
Ph1mNgUgMWEeMWMiNgj0PhF8RHZ:RXV7QH:0OGYhMgEeMGIgNGanPH>6R8V:RXZ8
QhB2OgejN7IeMGEfN7YlOh64QXR9RXZ9R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RHZ:
RHR6Q85oO7UgMWEeMGIhNWeoPXF7R8Z:RXV8QX>1OWaiMgIeMGEgN7]mP8:5QhV:
RXZ9QhF3P7ikNGMfMGEfMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMiNgj1PhJ8
RHZ:RXV7QH:0OGYhMgEeMGIgNGanPHB6R8V:RXZ8QhB2OgejN7IeMGEfN7YlOh64
QXR9RXZ9R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RXZ:RHR6Q85nO7UgMWEeMGIhNWeo
PXF7R8Z:RXV8QX>1OW]iMgIeMGEgN7]mP8:5QhV:RXZ9QhF3P7ikNGMfMGEfMgUk
OH23QHN9RXZ:RHN5Ph1mNgUgMGEeMWMiNgj1PhJ8RHZ:RXV7QH:0OGYhMgEeMGIg
NGanPHB6R8V:RXZ8QhB2OgejN7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQfMGEe
MWQjO7n2Q8N8RXZ:RHR6Q85nO7UgMWEeMGIhNWeoPXF7RHZ:RXV8QX>1OW]iMgIe
MGEgN7]mP8:5QhV:RXZ9QhF3P7ikNGMfMGEfMgUkOX23QHN9RXZ:RHN5Ph1mNgQg
MGEeMWMiNgj1PhJ8RHZ:RXV7QH:0OGYhMWEeMGIgNGanPHB6R8V:RXZ8QhB2Ogaj
N7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQfMGEeMWQjO7n2Q8N8RXZ:RHR6Q85n
O7UgMWEeMGIhNWf0P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P7EgN7]n
P8>6R8V:RXV8QX>1OW]iMgEeMGIhNWaoPXF7RHZ:RXV7QH9oO7YhMWEeMGMiNgj1
PhJ8RHZ:RHR6Ph1nNgUgMGEeMWQjO7n2QHN9RXZ:RHN4PWmlNWMfMGEfMgUkOX64
QXR9RXZ9R8J3P7ekN7MeMGEfN7YmP8:5QhV:RXZ8QhB2OgaiMgIeMGIgNG]nPHB6
R8Z:RXV8QH>0OGYhMWEeMGIhNWf0PhF7RHZ:RXR6Q85nO7UgMWEeMWMiO7j1Q8J8
RXZ:RHN5Ph1mNWQfMGEeMWQjOH23QHR9RXZ:R8J4PGikNGMfMGEfMgUlOh:4QhR:
RXZ9QhF2P7ejN7IeMGEgN7]mP8>6R8V:RXV8QXB1OW]iMgIeMGIgNWaoPXB7RHZ:
RXV7QH9oO7YhMWEeMGMiNgj0PhJ8RHZ:RHR6Ph5nNgUgMGEeMWQjO7n2QHN9RXZ:
RHN5PWmlNWQfMGEeMgUkOX63QXR9RXZ9R8J3P7ikN7MeMGEfN7YmOh:5QhV:RXZ9
QhB2OgajMgIeMGIgNG]nPHB6R8V:RXV8QH>0OG]hMWEeMGIhNWf0PXF7RHZ:RXR7
Q85oO7UgMWEeMWMiO7j1Q8J8RXZ:RHN5Ph1mNWQfMGEeMWQjOH23QHN9RXZ:R8J4
PGilNGMfMGEfMgUlOh64QXR:RXZ9QhF3P7ejN7IeMGEfN7]mP8>5R8V:RXV8QXB1
OW]iMgIeMGIgNGaoPXB7R8Z:RXV7QH9oOGYhMWEeMGMhNgf0PhJ8RHZ:RHR6Q85n
NgUgMGEeMWMjO7n2QHN9RXZ:RHN5PWmlNWQfMGEeMgUkOX63QXR9RXZ9R8J3PGik
NGMeMGEfN7YlOh:5QhV:RXZ9QhF2OgajMgIeMGEgNG]nPHB6R8V:RXV8QX>0OG]h
MgEeMGIhNWeoPXF7RHZ:RXR7Q89oO7UgMWEeMWMiNgj1Q8J8RHZ:RHR5Ph1mNgQf
MGEeMWQjOH23QHN9RXZ:R8J4PGmlNGMfMGEfMgUlOX64QXR:RXZ9QhF3P7ejN7Ie
MGEfN7YmP8>5QhV:RXZ8QXB1OWaiMgIeMGIgNGaoPHB7R8Z:RXV7QH:0OGYhMWEe
MGIhNgf0PhJ8RHZ:RHR6Q85nNgUgMWEeMWMjO7n2Q8N9RXZ:RHN5PWmmNWQfMGEe
MgQkOX23QXR9RXZ9R8J3PGikNGMeMGEfN7YlOh:5QhV:RXZ9QhF2OgajN7IeMGEg
NG]nPH>6R8V:RXV8QX>0OW]iMgEeMGIhNWaoPXF7RHZ:RXV7Q89oO7YgMWEeMWMi
Ngj1Q8J8RHZ:RHR6Ph1mNgQgMGEeMWQjOH22QHN9RXZ:R8N4PWmlNGMfMGEfMgUk
OX64QXR:RXZ9R8F3P7ejN7IeMGEfN7YmP8>5QhV:RXZ8QXB1OWaiMgIeMGIgNGan
PHB6R8Z:RXV7QH>0OGYhMWEeMGIhNgf0PhF8RHZ:RXR6Q85nNgUgMWEeMWMiO7n2
Q8N8RXZ:RHN5PX1mNWQfMGEeMgQkOH23QXR9RXZ9R8J4PGikNGMfMGEfMgYlOh:4
QhV:RXZ9QhF2OgajN7IeMGEgNG]nP8>6R8V:RXV8QX>1OW]iMgEeMGIhNWaoPXF7
RHZ:RXV7QH9oO7YhMWEeMGMiNgj1PhJ8RHZ:RHR6Ph1nNgQgMGEeMWQjOGn2QHN9
RXZ:RHN4PWmlNGMfMGEfMgUkOX64QXR9RXZ9R8F3P7ekN7IeMGEfN7YmP8:5QhV:
RXZ8QhB1OgaiMgIeMGIgNGanPHB6R8Z:RXV7QH>0OGYhMWEeMGIhNWf0PhF7RHZ:
RXR6Q85nO7UgMWEeMWMiO7n1Q8J8RXZ:RHN5PX1mNWQfMGEeMWQkOH23QHR9RXZ9
R8J4PGikNGMfMGEfMgUlOh:4QhR:RXZ9QhF2OgejN7IeMGEgN7]mP8>6R8V:RXV8
QXB1OW]iMgEeMGIgNWaoPXF7RHZ:RXV7QH9oO7YhMWEeMGMiNgj1PhJ8RHZ:RHR6
Ph5nNgUgMGEeMWQjO7n2QHN9RXZ:RHN4PWmlNWMfMGEeMgUkOX64QXR9RXZ9R8J3
P7ekN7MeMGEfN7YmOh:5QhV:RXZ8QhB2OgaiMgIeMGIgNG]nPHB6R8V:RXV8QH>0
OG]hMWEeMGIhNWf0PhF7RHZ:RXR6Q85oO7UgMWEeMWMiO7j1Q8J8RXZ:RHN5Ph1m
NWQfMGEeMWQjOH23QHN9RXZ:R8J4PGilNGMfMGEfMgUlOh64QhR:RXZ9QhF2P7ej
N7IeMGEfN7]mP8>6R8V:RXV8QXB1OW]iMgIeMGIgNWaoPXB7RHZ:RXV7QH9oOGYh
MWEeMGMhNgj0PhJ8RHZ:RHR6Ph5nNgUgMGEeMWQjO7n2QHN9RXZ:RHN5PWmlNWQf
MGEeMgUkOX63QXR9RXZ9R8J3P7ikNGMeMGEfN7YmOh:5QhV:RXZ9QhB2OgajMgIe
MGIgNG]nPHB6R8V:RXV8QX>0OG]hMWEeMGIhNWf0PXF7RHZ:RXR7Q89oO7UgMWEe
MWMiNgj1Q8J8RXZ:RHR5Ph1mNWQfMGEeMWQjOH23QHN9RXZ:R8J4PGilNGMfMGEf
MgUlOX64QXR:RXZ9QhF3P7ejN7IeMGEfN7]mP8>5R8V:RXZ8QXB1OW]iMgIeMGIg
NGaoPXB7R8Z:RXV7QH:0OGYhMWEeMGMhNgf0PhJ8RHZ:RHR6Q85nNgUgMWEeMWMj
O7n2Q8N9RXZ:RHN5PWmlNWQfMGEeMgUkOX23QXR9RXZ9R8J3PGikNGMeMGEfN7Yl
Oh:5QhV:RXZ9QhF2OgajN7IeMGEgNG]nPH>6R8V:RXV8QX>0OW]hMgEeMGIhNWeo
PXF7RHZ:RXV7Q89oO7UgMWEeMWMiNgj1Q8J8RHZ:RHR5Ph1mNgQfMGEeMWQjOH22
QHN9RXZ:R8N4PGmlNGMfMGEfMgUlOX64QXR:RXZ9QhF3P7ejN7IeMGEfN7YmP8>5
QhV:RXZ8QXB1OWaiMgIeMGIgNGaoPHB6R8Z:RXV7QH:0OGYhMWEeMGIhNgf0PhF8
RHZ:RHR6Q85nNgUgMWEeMWMiO7n2Q8N9RXZ:RHN5PWmmNWQfMGEeMgQkOH23QXR9
RXZ9R8J4PGikNGMeMGEfN7YlOh:5QhV:RXZ9QhF2OgajN7IeMGEgNG]nPH>6R8V:
RXV8QX>1OW]iMgEeMGIhNWaoPXF7RHZ:RXV7Q89oO7YgMWEeMGMiNgj1Q8J8RHZ:
RHR6Ph1mNgQgMGEeMWQjOGn2QHN9RXZ:R8N4PWmlNGMfMGEfMgUkOX64QXR9RXZ9
R8F3P7ekN7IeMGEfN7YmP8>5QhV:RXZ8QXB1OgaiMgIeMGIgNGanPHB6R8Z:RXV7
QH>0OGYhMWEeMGIhNWf0PhF7RHZ:RXR6Q85nO7UgMWEeMWMiO7n1Q8N8RXZ:RHN5
PX1mNWQfMGEeMWQkOH23QXR9RXZ9R8J4PGikNGMfMGEfMgYlOh:4QhV:RXZ9QhF2
OgejN7IeMGEgN7]nP8>6R8V:RXV8QX>1OW]iMgEeMGIhNWaoPXF7RHZ:RXV7QH9o
O7YhMWEeMGMiNgj1PhJ8RHZ:RHR6Ph1nNgQgMGEeMWQjOGn2QHN9RXZ:RHN4PWml
NWMfMGEfMgUkOX64QXR9RXZ9R8J3P7ekN7IeMGEfN7YmP8:5QhV:RXZ8QhB2Ogai
MgIeMGIgNGanPHB6R8Z:RXV7QH>0OGYhMWEeMGIhNWf0PhF7RHZ:RXR6Q85nO7Ug
MWEeMWMiO7j1Q8J8RXZ:RHN5Ph1mNWQfMGEeMWQkOH23QHR9RXZ:R8J4PGikNGMf
MGEfMgUlOh:4QhR:RXZ9QhF2P7ejN7IeMGEgN7]mP8>6R8V:RXV8QXB1OW]iMgEe
MGIgNWaoPXB7RHZ:RXV7QH9oO7YhMWEeMGMiNgj0PhJ8RHZ:RHR6Ph5nNgUgMGEe
MWQjO7n2QHN9RXZ:RHN5PWmlNWQfMGEeMgUkOX63QXR9RXZ9R8J3P7ikN7MeMGEf
N7YmOh:5QhV:RXZ9QhB2OgaiMgIeMGIgNG]nPHB6R8V:RXV8QH>0OG]hMWEeMGIh
NWf0PXF7RHZ:RXR7Q85oO7UgMWEeMWMiO7j1Q8J8RXZ:RHN5Ph1mNWQfMGEeMWQj
OH23QHN9RXZ:R8J4PGilNGMfMGEfMgUlOh64QhR:RXZ9QhF2P7ejN7IeMGEfN7]m
P8>5R8V:RXV8QXB1OW]iMgIeMGIgNGaoPXB7RHZ:RXV7QH9oOGYhMWEeMGMhNgj0
PhJ8RHZ:RHR6Ph5nNgUgMGEeMWQjO7n2QHN9RXZ:RHN5PWmlNWQfMGEeMgUkOX63
QXR9RXZ9R8J3P7ikNGMeMGEfN7YlOh:5QhV:RXZ9QhB2OgajMgIeMGEgNG]nPHB6
R8V:RXV8QX>0OG]hMgEeMGIhNWf0PXF7RHZ:RXR7Q89oO7UgMWEeMWMiNgj1Q8J8
RXZ:RHR5Ph1mNgQfMGEeMWQjOH23QHN9RXZ:R8J4PGilNGMfMGEfMgUlOX64QXR:
RXZ9QhF3P7ejN7IeMGEfN7YmP8>5QhV:RXZ8QXB1OWaiMgIeMGIgNGaoPXB7R8Z:
RXV7QH:0OGYhMWEeMGIhNgf0PhJ8RHZ:RHR6Q85nNgUgMWEeMWMjO7n2Q8N9RXZ:
RHN5PWmmNWQfMGEeMgQkOX23QXR9RXZ9R8J3PGikNGMeMGEfN7YlOh:5QhV:RXZ9
QhF2OgajN7IeMGEgNG]nPH>6R8V:RXV8QX>0OW]hMgEeMGIhNWeoPXF7RHZ:RXV7
Q89oO7YgMWEeMWMiNgj1Q8J8RHZ:RHR6Ph1mNgQfMGEeMWQjOH22QHN9RXZ:R8N4
PGmlNGMfMGEfMgUlOX64QXR:RXZ9QhF3P7ejN7IeMGEfN7YmP8>5QhV:RXZ8QXB1
OWaiMgIeMGIgNGaoPHB6R8Z:RXV7QH>0OGYhMWEeMGIhNgf0PhF8RHZ:RHR6Q85n
NgUgMWEeMWMiO7n2Q8N8RXZ:RHN5PWmmNWQfMGEeMgQkOH23QXR9RXZ9R8J4PGik
NGMeMGEfMgYlOh:4QhV:RXZ9QhF2OgajN7IeMGEgNG]nPH>6R8V:RXV8QX>1OW]i
MgEeMGIhNWaoPXF7RHZ:RXV7QH9oO7YhMWEeMGMiNgj1Q8J8RHZ:RHR6Ph1mNgQg
MGEeMWQjOGn2QHN9RXZ:RHN4PWmlNGMfMGEfMgUkOX64QXR9RXZ9R8F3P7ekN7Ie
MGEfN7YmP8:5QhV:RXZ8QXB1OgaiMgIeMGIgNGanPHB6R8Z:RXV7QH>0OGYhMWEe
MGIhNWf0PhF7RHZ:RXR6Q85nO7UgMWEeMWMiO7n1Q8N8RXZ:RHN5PX1mNWQfMGEe
MWQkOH23QHR9RXZ9R8J4PGikNGMfMGEfMgUlOh:4QhV:RXZ9QhF2OgejN7IeMGEg
N7]nP8>6R8V:RXV8QX>1OW]iMgEeMGIhNWaoPXF7RHZ:RXV7QH9oO7YhMWEeMGMi
Ngj1PhJ8RHZ:RHR6P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P7n3QXR9
RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ9QXB1OGYhMWEeMWQjOH23QXR:RXZ8QX>0
OGYhMWEeMWQjOH24QXR:RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QX>0O7YgMWEe
MWQkOX64QhV:RXV8QH9oO7UgMGEeMWQkOX64QhV:RXV8QH9oO7UgMGEeMgUkOh:5
QhV:RXV7QH9oO7UgMGEeMgUlOh:5QhV:RXV7QH9nNgUfMGEeMgUlOh:5R8V:RXV7
Q85nNgQfMGEfMgYlP8>6R8V:RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXR6Q85mNWQf
MGEfN7YmP8>6R8Z:RXR6Ph1mNWQfMGEfN7YmPHB6R8Z:RXR6Ph1mNWMfMGEfN7]n
PHB7RHZ:RHR6Ph1lNWMfMGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEfNG]nPXF7RHZ:
RHN5PWmlNGMeMGEgNGaoPXF7RHZ:RHN5PWmkNGMeMGEgNGaoPXF8RHZ:RHN4PGik
N7IeMGEgNGaoPXF8RHZ:RHN4PGikN7IeMGIgNWb0PhJ8RHZ:RHN4PGikN7IeMGIg
NWf0PhJ8RXZ:R8J4P7ejN7IeMGIhNWf0PhJ8RXZ:R8J3P7ejN7IeMGIhNWf1Q8J9
RXZ:R8J3P7ejMgIeMGIhNgj1Q8N9RXZ9R8J3P7aiMgIeMGIhNgj1Q8N9RXZ9R8F2
OgaiMgEeMGIiNgj2QHN9RXZ9QhF2OgaiMgEeMGMiO7n2QHN9RXZ9QhF2Og]iMgEe
MGMiO7n2QHR9RXZ9QhB1OW]hMWEeMWMiO7n3QHR9RXZ9QhB1OW]hMWEeMWMjOH23
QXR:RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ8QXB0OGYhMWEeMWQjOH23QXR:RXZ8
QX>0OGYhMWEeMWQjOH64QXV:RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QH=oO7Ug
MWEeMWQkOX64QhV:RXV8QH9oO7UgMGEeMgUkOX:5QhV:RXV7QH9oO7UgMGEeMgUl
Oh:5QhV:RXV7QH9nNgUgMGEeMgUlOh:5R8V:RXV7Q85nNgQfMGEfMgUlOh>5R8V:
RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXV6Q85mNWQfMGEfN7YmP8>6R8Z:RXR6Ph1m
NWQfMGEfN7YmP8B6R8Z:RXR6Ph1mNWMfMGEfN7]nPHB7RHZ:RXR6Ph1mNWMfMGEf
N7]nPHB7RHZ:RHR5PgmlNGMfMGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEgNG]oPXF7
RHZ:RHN5PWmlNGMeMGEgNGaoPXF7RHZ:RHN5PWikNGIeMGEgNGaoPXF8RHZ:RHN4
PGikN7IeMGIgNGaoPhJ8RHZ:RHN4PGikN7IeMGIgNWf0PhJ8RXZ:RHJ4PGejN7Ie
MGIhNWf0PhJ8RXZ:R8J3P7ejN7IeMGIhNWf0Q8J8RXZ:R8J3P7ejMgIeMGIhNgj1
Q8N9RXZ9R8J3P7ajMgIeMGIhNgj1Q8N9RXZ9R8F2OgaiMgEeMGIhNgj1Q8N9RXZ9
R8F2OgaiMgEeMGMiNgn2QHN9RXZ9QhF2OgaiMgEeMGMiO7n2QHN9RXZ9QhF2OW]i
MWEeMGMiO7n2QHR9RXZ9QhB1OW]hMWEeMWMjO823QXR9RXZ9QhB1OW]hMWEeMWMj
OH23QXR:RXZ8QXB1OGYhMWEeMWQjOH23QXR:RXZ8QX>0OGYhMWEeMWQjOH64QXR:
RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QX>0O7YgMWEeMWQkOX64QhV:RXV8QH9o
O7UgMGEeMWUkOX:5QhV:RXV7QH9oO7UgMGEeMgUlOh:5QhV:RXV7QH9oNgUgMGEe
MgUlOh:5R8V:RXV7Q85nNgQfMGEeMgUlOh:5R8V:RXV7Q85nNgQfMGEfMgYlP8>6
R8V:RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXR6Q81mNWQfMGEfN7YmP8>6R8Z:RXR6
Ph1mNWQfMGEfN7YmPHB6RHZ:RXR6Ph1mNWMfMGEfN7]nPHB7RHZ:RHR6Ph1lNGMf
MGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEfNG]nPXF7RHZ:RHN5PWmlNGMeMGEgNGao
PXF7RHZ:RHN5PWmkNGMeMGEgNGaoPXF8RHZ:RHN4PGikN7IeMGIgNGaoPhF8RHZ:
RHN4PGikN7IeMGIgNWf0PhJ8RXZ:RHN4PGikN7IeMGIgNWf0PhJ8RXZ:R8J4P7ej
N7IeMGIhNWf0PhJ8RXZ:R8J3P7ejN7IeMGIhNWf1Q8J9RXZ:R8J3P7ejMgIeMGIh
Ngj1Q8N9RXZ9R8F3OgaiMgIeMGIhNgj1Q8N9RXZ9R8F2OgaiMgEeMGMiNgj2QHN9
RXZ9QhF2OgaiMgEeMGMiO7n2QHN9RXZ9QhF2OW]iMgEeMGMiO7n2QHR9RXZ9QhB1
OW]hMWEeMWMiO7n3QHR9RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ9QXB1OGYhMWEe
MWQjOH23QXR:RXZ8QX>0OGYhMWEeMWQjOH24QXR:RXZ8QX>0OGYgMWEeMWQkOX64
QhV:RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QH=oO7UgMWEeMWQkOX64QhV:RXV8
QH9oO7UgMGEeMgUkOh:5QhV:RXV7QH9oO7UgMGEeMgUlOh:5QhV:RXV7QH9nNgUf
MGEeMgUlOh:5R8V:RXV7Q85nNgQfMGEfMgUlOh>6R8V:RXV7Q85nNgQfMGEfMgYm
P8>6R8Z:RXV6Q85mNWQfMGEfN7YmP8>6R8Z:RXR6Ph1mNWQfMGEfN7YmP8B6R8Z:
RXR6Ph1mNWMfMGEfN7]nPHB7RHZ:RHR6Ph1lNWMfMGEfN7]nPHB7RHZ:RHR5PWml
NGMeMGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEgNG]oPXF7RHZ:RHN5PWmlNGMeMGEg
NGaoPXF7RHZ:RHN5PWikNGIeMGEgNGaoPXF8RHZ:RHN4PGikN7IeMGIgNWb0PhJ8
RHZ:RHN4PGikN7IeMGIgNWf0PhJ8RXZ:R8J4PGejN7IeMGIhNWf0PhJ8RXZ:R8J3
P7ejN7IeMGIhNWf1Q8J8RXZ:R8J3P7ejMgIeMGIhNgj1Q8N9RXZ9R8J3P7ajMgIe
MGIhNgj1Q8N9RXZ9R8F2OgaiMgEeMGIiNgj2QHN9RXZ9QhF2OgaiMgEeMGMiO7n2
QHN9RXZ9QhF2Og]iMgEeMGMiO7n2QHR9RXZ9QhB1OW]hMWEeMGMiO7n2QHR9RXZ9
QhB1OW]hMWEeMWMjO823QXR9RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ8QXB0OGYh
MWEeMWQjOH23QXR:RXZ8QX>0OGYhMWEeMWQjOH64QXV:RXZ8QX>0OGYgMWEeMWQk
OX64QhV:RXV8QX>0O7UgMWEeMWQkOX64QhV:RXV8QH9oO7UgMGEeMWUkOX:5QhV:
RXV7QH9oO7UgMGEeMgUlOh:5QhV:RXV7QH9oNgUgMGEeMgUlOh:5R8V:RXV7Q85n
NgQfMGEfMgUlOh>5R8V:RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXV7Q85nNgQfMGEf
MgYmP8>6R8Z:RXR6Q81mNWQfMGEfN7YmP8>6R8Z:RXR6Ph1mNWQfMGEfN7YmPHB6
RHZ:RXR6Ph1mNWMfMGEfN7]nPHB7RHZ:RHR5PgmlNGMfMGEfN7]nPHB7RHZ:RHR5
PWmlNGMeMGEgNG]nPXF7RHZ:RHN5PWmlNGMeMGEgNGaoPXF7RHZ:RHN5PWikNGMe
MGEgNGaoPXF8RHZ:RHN4PGikN7IeMGIgNGaoPhF8RHZ:RHN4PGikN7IeMGIgNWf0
PhJ8RXZ:RHJ4PGejN7IeMGIhNWf0PhJ8RXZ:R8J3P7ejN7IeMGIhNWf0Q8J8RXZ:
R8J3P7ejMgIeMGIhNgj1Q8N9RXZ:R8J3P7ejMgIeMGIhNgj1Q8N9RXZ9R8F3Ogai
MgIeMGIhNgj1Q8N9RXZ9R8F2OgaiMgEeMGMiNgn2QHN9RXZ9QhF2OgaiMgEeMGMi
O7n2QHN9RXZ9QhF2OW]iMWEeMGMiO7n2QHR9RXZ9QhB1OW]hMWEeMWMiO7n3QXR9
RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ9QXB1OGYhMWEeMWQjOH23QXR:RXZ8QX>0
OGYhMWEeMWQjOH24QXR:RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QX>0O7YgMWEe
MWQkOX64QhV:RXV8QH9oO7UgMGEeMWQkOX64QhV:RXV8QH9oO7UgMGEeMgUkOh:5
QhV:RXV7QH9oO7UgMGEeMgUlOh:5QhV:RXV7QH9nNgUfMGEeMgUlOh:5R8V:RXV7
Q85nNgQfMGEfMgYlP8>6R8V:RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXR6Q85mNWQf
MGEfN7YmP8>6R8Z:RXR6Ph1mNWQfMGEfN7YmPHB6R8Z:RXR6Ph1mNWMfMGEfN7]n
PHB7RHZ:RHR6Ph1lNWMfMGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEfNG]nPXF7RHZ:
RHN5PWmlNGMeMGEgNGaoPXF7RHZ:RHN5PWmkNGMeMGEgNGaoPXF8RHZ:RHN4PGik
N7IeMGEgNGaoPXF8RHZ:RHN4PGikN7IeMGIgNWb0PhJ8RHZ:RHN4PGikN7IeMGIg
NWf0PhJ8RXZ:R8J4P7ejN7IeMGIhNWf0PhJ8RXZ:R8J3P7ejN7IeMGIhNWf1Q8J9
RXZ:R8J3P7ejMgIeMGIhNgj1Q8N9RXZ9R8J3P7aiMgIeMGIhNgj1Q8N9RXZ9R8F2
OgaiMgEeMGIiNgj2QHN9RXZ9QhF2OgaiMgEeMGMiO7n2QHN9RXZ9QhF2Og]iMgEe
MGMiO7n2QHR9RXZ9QhB1OW]hMWEeMWMiO7n3QHR9RXZ9QhB1OW]hMWEeMWMjOH23
QXR:RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ8QXB0OGYhMWEeMWQjOH23QXR:RXZ8
QX>0OGYhMWEeMWQjOH64QXV:RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QH=oO7Ug
MWEeMWQkOX64QhV:RXV8QH9oO7UgMGEeMgUkOX:5QhV:RXV7QH9oO7UgMGEeMgUl
Oh:5QhV:RXV7QH9nNgUgMGEeMgUlOh:5R8V:RXV7Q85nNgQfMGEfMgUlOh>5R8V:
RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXV6Q85mNWQfMGEfN7YmP8>6R8Z:RXR6Ph1m
NWQfMGEfN7YmP8B6R8Z:RXR6Ph1mNWMfMGEfN7]nPHB7RHZ:RXR6Ph1mNWMfMGEf
N7]nPHB7RHZ:RHR5PgmlNGMfMGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEgNG]oPXF7
RHZ:RHN5PWmlNGMeMGEgNGaoPXF7RHZ:RHN5PWikNGIeMGEgNGaoPXF8RHZ:RHN4
PGikN7IeMGIgNGaoP820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P7n3QXR9
RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ9QXB1OGYhMWEeMWQjOH23QXR:RXZ8QX>0
OGYhMWEeMWQjOH24QXR:RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QX>0O7YgMWEe
MWQkOX64QhV:RXV8QH9oO7UgMGEeMWQkOX64QhV:RXV8QH9oO7UgMGEeMgUkOh:5
QhV:RXV7QH9oO7UgMGEeMgUlOh:5QhV:RXV7QH9nNgUfMGEeMgUlOh:5R8V:RXV7
Q85nNgQfMGEfMgYlP8>6R8V:RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXR6Q85mNWQf
MGEfN7YmP8>6R8Z:RXR6Ph1mNWQfMGEfN7YmPHB6R8Z:RXR6Ph1mNWMfMGEfN7]n
PHB7RHZ:RHR6Ph1lNWMfMGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEfNG]nPXF7RHZ:
RHN5PWmlNGMeMGEgNGaoPXF7RHZ:RHN5PWmkNGMeMGEgNGaoPXF8RHZ:RHN4PGik
N7IeMGEgNGaoPXF8RHZ:RHN4PGikN7IeMGIgNWb0PhJ8RHZ:RHN4PGikN7IeMGIg
NWf0PhJ8RXZ:R8J4P7ejN7IeMGIhNWf0PhJ8RXZ:R8J3P7ejN7IeMGIhNWf1Q8J9
RXZ:R8J3P7ejMgIeMGIhNgj1Q8N9RXZ9R8J3P7aiMgIeMGIhNgj1Q8N9RXZ9R8F2
OgaiMgEeMGIiNgj2QHN9RXZ9QhF2OgaiMgEeMGMiO7n2QHN9RXZ9QhF2Og]iMgEe
MGMiO7n2QHR9RXZ9QhB1OW]hMWEeMWMiO7n3QHR9RXZ9QhB1OW]hMWEeMWMjOH23
QXR:RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ8QXB0OGYhMWEeMWQjOH23QXR:RXZ8
QX>0OGYhMWEeMWQjOH64QXV:RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QH=oO7Ug
MWEeMWQkOX64QhV:RXV8QH9oO7UgMGEeMgUkOX:5QhV:RXV7QH9oO7UgMGEeMgUl
Oh:5QhV:RXV7QH9nNgUgMGEeMgUlOh:5R8V:RXV7Q85nNgQfMGEfMgUlOh>5R8V:
RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXV6Q85mNWQfMGEfN7YmP8>6R8Z:RXR6Ph1m
NWQfMGEfN7YmP8B6R8Z:RXR6Ph1mNWMfMGEfN7]nPHB7RHZ:RXR6Ph1mNWMfMGEf
N7]nPHB7RHZ:RHR5PgmlNGMfMGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEgNG]oPXF7
RHZ:RHN5PWmlNGMeMGEgNGaoPXF7RHZ:RHN5PWikNGIeMGEgNGaoPXF8RHZ:RHN4
PGikN7IeMGIgNGaoPhJ8RHZ:RHN4PGikN7IeMGIgNWf0PhJ8RXZ:RHJ4PGejN7Ie
MGIhNWf0PhJ8RXZ:R8J3P7ejN7IeMGIhNWf0Q8J8RXZ:R8J3P7ejMgIeMGIhNgj1
Q8N9RXZ9R8J3P7ajMgIeMGIhNgj1Q8N9RXZ9R8F2OgaiMgEeMGIhNgj1Q8N9RXZ9
R8F2OgaiMgEeMGMiNgn2QHN9RXZ9QhF2OgaiMgEeMGMiO7n2QHN9RXZ9QhF2OW]i
MWEeMGMiO7n2QHR9RXZ9QhB1OW]hMWEeMWMjO823QXR9RXZ9QhB1OW]hMWEeMWMj
OH23QXR:RXZ8QXB1OGYhMWEeMWQjOH23QXR:RXZ8QX>0OGYhMWEeMWQjOH64QXR:
RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QX>0O7YgMWEeMWQkOX64QhV:RXV8QH9o
O7UgMGEeMWUkOX:5QhV:RXV7QH9oO7UgMGEeMgUlOh:5QhV:RXV7QH9oNgUgMGEe
MgUlOh:5R8V:RXV7Q85nNgQfMGEeMgUlOh:5R8V:RXV7Q85nNgQfMGEfMgYlP8>6
R8V:RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXR6Q81mNWQfMGEfN7YmP8>6R8Z:RXR6
Ph1mNWQfMGEfN7YmPHB6RHZ:RXR6Ph1mNWMfMGEfN7]nPHB7RHZ:RHR6Ph1lNGMf
MGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEfNG]nPXF7RHZ:RHN5PWmlNGMeMGEgNGao
PXF7RHZ:RHN5PWmkNGMeMGEgNGaoPXF8RHZ:RHN4PGikN7IeMGIgNGaoPhF8RHZ:
RHN4PGikN7IeMGIgNWf0PhJ8RXZ:RHN4PGikN7IeMGIgNWf0PhJ8RXZ:R8J4P7ej
N7IeMGIhNWf0PhJ8RXZ:R8J3P7ejN7IeMGIhNWf1Q8J9RXZ:R8J3P7ejMgIeMGIh
Ngj1Q8N9RXZ9R8F3OgaiMgIeMGIhNgj1Q8N9RXZ9R8F2OgaiMgEeMGMiNgj2QHN9
RXZ9QhF2OgaiMgEeMGMiO7n2QHN9RXZ9QhF2OW]iMgEeMGMiO7n2QHR9RXZ9QhB1
OW]hMWEeMWMiO7n3QHR9RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ9QXB1OGYhMWEe
MWQjOH23QXR:RXZ8QX>0OGYhMWEeMWQjOH24QXR:RXZ8QX>0OGYgMWEeMWQkOX64
QhV:RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QH=oO7UgMWEeMWQkOX64QhV:RXV8
QH9oO7UgMGEeMgUkOh:5QhV:RXV7QH9oO7UgMGEeMgUlOh:5QhV:RXV7QH9nNgUf
MGEeMgUlOh:5R8V:RXV7Q85nNgQfMGEfMgUlOh>6R8V:RXV7Q85nNgQfMGEfMgYm
P8>6R8Z:RXV6Q85mNWQfMGEfN7YmP8>6R8Z:RXR6Ph1mNWQfMGEfN7YmP8B6R8Z:
RXR6Ph1mNWMfMGEfN7]nPHB7RHZ:RHR6Ph1lNWMfMGEfN7]nPHB7RHZ:RHR5PWml
NGMeMGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEgNG]oPXF7RHZ:RHN5PWmlNGMeMGEg
NGaoPXF7RHZ:RHN5PWikNGIeMGEgNGaoPXF8RHZ:RHN4PGikN7IeMGIgNWb0PhJ8
RHZ:RHN4PGikN7IeMGIgNWf0PhJ8RXZ:R8J4PGejN7IeMGIhNWf0PhJ8RXZ:R8J3
P7ejN7IeMGIhNWf1Q8J8RXZ:R8J3P7ejMgIeMGIhNgj1Q8N9RXZ9R8J3P7ajMgIe
MGIhNgj1Q8N9RXZ9R8F2OgaiMgEeMGIiNgj2QHN9RXZ9QhF2OgaiMgEeMGMiO7n2
QHN9RXZ9QhF2Og]iMgEeMGMiO7n2QHR9RXZ9QhB1OW]hMWEeMGMiO7n2QHR9RXZ9
QhB1OW]hMWEeMWMjO823QXR9RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ8QXB0OGYh
MWEeMWQjOH23QXR:RXZ8QX>0OGYhMWEeMWQjOH64QXV:RXZ8QX>0OGYgMWEeMWQk
OX64QhV:RXV8QX>0O7UgMWEeMWQkOX64QhV:RXV8QH9oO7UgMGEeMWUkOX:5QhV:
RXV7QH9oO7UgMGEeMgUlOh:5QhV:RXV7QH9oNgUgMGEeMgUlOh:5R8V:RXV7Q85n
NgQfMGEfMgUlOh>5R8V:RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXV7Q85nNgQfMGEf
MgYmP8>6R8Z:RXR6Q81mNWQfMGEfN7YmP8>6R8Z:RXR6Ph1mNWQfMGEfN7YmPHB6
RHZ:RXR6Ph1mNWMfMGEfN7]nPHB7RHZ:RHR5PgmlNGMfMGEfN7]nPHB7RHZ:RHR5
PWmlNGMeMGEgNG]nPXF7RHZ:RHN5PWmlNGMeMGEgNGaoPXF7RHZ:RHN5PWikNGMe
MGEgNGaoPXF8RHZ:RHN4PGikN7IeMGIgNGaoPhF8RHZ:RHN4PGikN7IeMGIgNWf0
PhJ8RXZ:RHJ4PGejN7IeMGIhNWf0PhJ8RXZ:R8J3P7ejN7IeMGIhNWf0Q8J8RXZ:
R8J3P7ejMgIeMGIhNgj1Q8N9RXZ:R8J3P7ejMgIeMGIhNgj1Q8N9RXZ9R8F3Ogai
MgIeMGIhNgj1Q8N9RXZ9R8F2OgaiMgEeMGMiNgn2QHN9RXZ9QhF2OgaiMgEeMGMi
O7n2QHN9RXZ9QhF2OW]iMWEeMGMiO7n2QHR9RXZ9QhB1OW]hMWEeMWMiO7n3QXR9
RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ9QXB1OGYhMWEeMWQjOH23QXR:RXZ8QX>0
OGYhMWEeMWQjOH24QXR:RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QX>0O7YgMWEe
MWQkOX64QhV:RXV8QH9oO7UgMGEeMWQkOX64QhV:RXV8QH9oO7UgMGEeMgUkOh:5
QhV:RXV7QH9oO7UgMGEeMgUlOh:5QhV:RXV7QH9nNgUfMGEeMgUlOh:5R8V:RXV7
Q85nNgQfMGEfMgYlP8>6R8V:RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXR6Q85mNWQf
MGEfN7YmP8>6R8Z:RXR6Ph1mNWQfMGEfN7YmPHB6R8Z:RXR6Ph1mNWMfMGEfN7]n
PHB7RHZ:RHR6Ph1lNWMfMGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEfNG]nPXF7RHZ:
RHN5PWmlNGMeMGEgNGaoPXF7RHZ:RHN5PWmkNGMeMGEgNGaoPXF8RHZ:RHN4PGik
N7IeMGEgNGaoPXF8RHZ:RHN4PGikN7IeMGIgNWb0PhJ8RHZ:RHN4PGikN7IeMGIg
NWf0PhJ8RXZ:R8J4P7ejN7IeMGIhNWf0PhJ8RXZ:R8J3P7ejN7IeMGIhNWf1Q8J9
RXZ:R8J3P7ejMgIeMGIhNgj1Q8N9RXZ9R8J3P7aiMgIeMGIhNgj1Q8N9RXZ9R8F2
OgaiMgEeMGIiNgj2QHN9RXZ9QhF2OgaiMgEeMGMiO7n2QHN9RXZ9QhF2Og]iMgEe
MGMiO7n2QHR9RXZ9QhB1OW]hMWEeMWMiO7n3QHR9RXZ9QhB1OW]hMWEeMWMjOH23
QXR:RXZ9QhB1OW]hMWEeMWMjOH23QXR:RXZ8QXB0OGYhMWEeMWQjOH23QXR:RXZ8
QX>0OGYhMWEeMWQjOH64QXV:RXZ8QX>0OGYgMWEeMWQkOX64QhV:RXV8QH=oO7Ug
MWEeMWQkOX64QhV:RXV8QH9oO7UgMGEeMgUkOX:5QhV:RXV7QH9oO7UgMGEeMgUl
Oh:5QhV:RXV7QH9nNgUgMGEeMgUlOh:5R8V:RXV7Q85nNgQfMGEfMgUlOh>5R8V:
RXV7Q85nNgQfMGEfMgYmP8>6R8Z:RXV6Q85mNWQfMGEfN7YmP8>6R8Z:RXR6Ph1m
NWQfMGEfN7YmP8B6R8Z:RXR6Ph1mNWMfMGEfN7]nPHB7RHZ:RXR6Ph1mNWMfMGEf
N7]nPHB7RHZ:RHR5PgmlNGMfMGEfN7]nPHB7RHZ:RHR5PWmlNGMeMGEgNG]oPXF7
RHZ:RHN5PWmlNGMeMGEgNGaoPXF7RHZ:RHN5PWikNGIeMGEgNGaoPXF8RHZ:RHN4
PGikN7IeMGIgNGaoP820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P81mNWQf
MGEeMgQkOH23QXR9RXZ9R8J4PGikNGMeMGEfMgYlOh:4QhV:RXZ9QhF2OgajN7Ie
MGEgNG]nPH>6R8V:RXV8QX>1OW]iMgEeMGIhNWaoPXF7RHZ:RXV7QH9oO7YhMWEe
MGMiNgj1PhJ8RHZ:RHR6Ph1nNgQgMGEeMWQjOGn2QHN9RXZ:RHN4PWmlNGMfMGEf
MgUkOX64QXR9RXZ9R8F3P7ekN7IeMGEfN7YmP8:5QhV:RXZ8QhB1OgaiMgIeMGIg
NGanPHB6R8Z:RXV7QH>0OGYhMWEeMGIhNWf0PhF7RHZ:RXR6Q85nO7UgMWEeMWMi
O7n1Q8N8RXZ:RHN5PX1mNWQfMGEeMWQkOH23QHR9RXZ9R8J4PGikNGMfMGEfMgUl
Oh:4QhV:RXZ9QhF2OgejN7IeMGEgN7]nP8>6R8V:RXV8QX>1OW]iMgEeMGIhNWao
PXF7RHZ:RXV7QH9oO7YhMWEeMGMiNgj1PhJ8RHZ:RHR6Ph1nNgUgMGEeMWQjO7n2
QHN9RXZ:RHN4PWmlNWMfMGEeMgUkOX64QXR9RXZ9R8J3P7ekN7MeMGEfN7YmP8:5
QhV:RXZ8QhB2OgaiMgIeMGIgNG]nPHB6R8Z:RXV8QH>0OG]hMWEeMGIhNWf0PhF7
RHZ:RXR6Q85nO7UgMWEeMWMiO7j1Q8J8RXZ:RHN5Ph1mNWQfMGEeMWQjOH23QHN9
RXZ:R8J4PGikNGMfMGEfMgUlOh:4QhR:RXZ9QhF2P7ejN7IeMGEfN7]mP8>6R8V:
RXV8QXB1OW]iMgIeMGIgNWaoPXB7RHZ:RXV7QH9oOGYhMWEeMGMiNgj0PhJ8RHZ:
RHR6Ph5nNgUgMGEeMWQjO7n2QHN9RXZ:RHN5PWmlNWQfMGEeMgUkOX63QXR9RXZ9
R8J3P7ikN7MeMGEfN7YmOh:5QhV:RXZ9QhB2OgajMgIeMGIgNG]nPHB6R8V:RXV8
QX>0OG]hMWEeMGIhNWf0PXF7RHZ:RXR7Q85oO7UgMWEeMWMiO7j1Q8J8RXZ:RHN5
Ph1mNWQfMGEeMWQjOH23QHN9RXZ:R8J4PGilNGMfMGEfMgUlOh64QXR:RXZ9QhF3
P7ejN7IeMGEfN7]mP8>5R8V:RXV8QXB1OW]iMgIeMGIgNGaoPXB7R8Z:RXV7QH9o
OGYhMWEeMGMhNgf0PhJ8RHZ:RHR6Q85nNgUgMGEeMWMjO7n2Q8N9RXZ:RHN5PWml
NWQfMGEeMgUkOX63QXR9RXZ9R8J3PGikNGMeMGEfN7YlOh:5QhV:RXZ9QhF2Ogaj
MgIeMGEgNG]nPHB6R8V:RXV8QX>0OG]hMgEeMGIhNWeoPXF7RHZ:RXV7Q89oO7Ug
MWEeMWMiNgj1Q8J8RHZ:RHR5Ph1mNgQfMGEeMWQjOH22QHN9RXZ:R8J4PGmlNGMf
MGEfMgUlOX64QXR:RXZ9QhF3P7ejN7IeMGEfN7YmP8>5QhV:RXZ8QXB1OWaiMgIe
MGIgNGaoPHB7R8Z:RXV7QH:0OGYhMWEeMGIhNgf0PhF8RHZ:RHR6Q85nNgUgMWEe
MWMiO7n2Q8N9RXZ:RHN5PWmmNWQfMGEeMgQkOX23QXR9RXZ9R8J3PGikNGMeMGEf
N7YlOh:5QhV:RXZ9QhF2OgajN7IeMGEgNG]nPH>6R8V:RXV8QX>0OW]iMgEeMGIh
NWaoPXF7RHZ:RXV7Q89oO7YgMWEeMWMiNgj1Q8J8RHZ:RHR6Ph1mNgQgMGEeMWQj
OH22QHN9RXZ:R8N4PWmlNGMfMGEfMgUkOX64QXR:RXZ9R8F3P7ekN7IeMGEfN7Ym
P8>5QhV:RXZ8QXB1OWaiMgIeMGIgNGanPHB6R8Z:RXV7QH>0OGYhMWEeMGIhNWf0
PhF8RHZ:RXR6Q85nNgUgMWEeMWMiO7n2Q8N8RXZ:RHN5PX1mNWQfMGEeMgQkOH23
QXR9RXZ9R8J4PGikNGMfMGEfMgYlOh:4QhV:RXZ9QhF2OgejN7IeMGEgNG]nP8>6
R8V:RXV8QX>1OW]iMgEeMGIhNWaoPXF7RHZ:RXV7QH9oO7YhMWEeMGMiNgj1PhJ8
RHZ:RHR6Ph1nNgQgMGEeMWQjOGn2QHN9RXZ:RHN4PWmlNWMfMGEfMgUkOX64QXR9
RXZ9R8J3P7ekN7IeMGEfN7YmP8:5QhV:RXZ8QhB1OgaiMgIeMGIgNGanPHB6R8Z:
RXV7QH>0OGYhMWEeMGIhNWf0PhF7RHZ:RXR6Q85nO7UgMWEeMWMiO7n1Q8J8RXZ:
RHN5Ph1mNWQfMGEeMWQkOH23QHR9RXZ9R8J4PGikNGMfMGEfMgUlOh:4QhR:RXZ9
QhF2OgejN7IeMGEgN7]mP8>6R8V:RXV8QXB1OW]iMgEeMGIgNWaoPXB7RHZ:RXV7
QH9oO7YhMWEeMGMiNgj1PhJ8RHZ:RHR6Ph5nNgUgMGEeMWQjO7n2QHN9RXZ:RHN5
PWmlNWMfMGEeMgUkOX64QXR9RXZ9R8J3P7ekN7MeMGEfN7YmOh:5QhV:RXZ8QhB2
OgaiMgIeMGIgNG]nPHB6R8V:RXV8QH>0OG]hMWEeMGIhNWf0PXF7RHZ:RXR6Q85o
O7UgMWEeMWMiO7j1Q8J8RXZ:RHN5Ph1mNWQfMGEeMWQjOH23QHN9RXZ:R8J4PGil
NGMfMGEfMgUlOh64QhR:RXZ9QhF2P7ejN7IeMGEfN7]mP8>5R8V:RXV8QXB1OW]i
MgIeMGIgNGaoPXB7RHZ:RXV7QH9oOGYhMWEeMGMhNgj0PhJ8RHZ:RHR6Ph5nNgUg
MGEeMWQjO7n2QHN9RXZ:RHN5PWmlNWQfMGEeMgUkOX63QXR9RXZ9R8J3P7ikNGMe
MGEfN7YlOh:5QhV:RXZ9QhB2OgajMgIeMGIgNG]nPHB6R8V:RXV8QX>0OG]hMgEe
MGIhNWf0PXF7RHZ:RXR7Q89oO7UgMWEeMWMiNgj1Q8J8RXZ:RHR5Ph1mNWQfMGEe
MWQjOH23QHN9RXZ:R8J4PGilNGMfMGEfMgUlOX64QXR:RXZ9QhF3P7ejN7IeMGEf
N7YmP8>5R8V:RXZ8QXB1OW]iMgIeMGIgNGaoPXB7R8Z:RXV7QH:0OGYhMWEeMGMh
Ngf0PhJ8RHZ:RHR6Q85nNgUgMWEeMWMjO7n2Q8N9RXZ:RHN5PWmlNWQfMGEeMgUk
OX23QXR9RXZ9R8J3PGikNGMeMGEfN7YlOh:5QhV:RXZ9QhF2OgajN7IeMGEgNG]n
PH>6R8V:RXV8QX>0OW]hMgEeMGIhNWeoPXF7RHZ:RXV7Q89oO7YgMWEeMWMiNgj1
Q8J8RHZ:RHR5Ph1mNgQfMGEeMWQjOH22QHN9RXZ:R8N4PGmlNGMfMGEfMgUlOX64
QXR:RXZ9QhF3P7ejN7IeMGEfN7YmP8>5QhV:RXZ8QXB1OWaiMgIeMGIgNGaoPHB6
R8Z:RXV7QH>0OGYhMWEeMGIhNgf0PhF8RHZ:RHR6Q85nNgUgMWEeMWMiO7n2Q8N8
RXZ:RHN5PWmmNWQfMGEeMgQkOH23QXR9RXZ9R8J4PGikNGMeMGEfMgYlOh:5QhV:
RXZ9QhF2OgajN7IeMGEgNG]nPH>6R8V:RXV8QX>1OW]iMgEeMGIhNWaoPXF7RHZ:
RXV7QH9oO7YgMWEeMGMiNgj1Q8J8RHZ:RHR6Ph1mNgQgMGEeMWQjOGn2QHN9RXZ:
R8N4PWmlNGMfMGEfMgUkOX64QXR9RXZ9R8F3P7ekN7IeMGEfN7YmP8>5QhV:RXZ8
QXB1OgaiMgIeMGIgNGanPHB6R8Z:RXV7QH>0OGYhMWEeMGIhNWf0PhF7RHZ:RXR6
Q85nO7UgMWEeMWMiO7n1Q8N8RXZ:RHN5PX1mNWQfMGEeMWQkOH23QXR9RXZ9R8J4
PGikNGMfMGEfMgYlOh:4QhV:RXZ9QhF2OgejN7IeMGEgN7]nP8>6R8V:RXV8QX>1
OW]iMgEeMGIhNWaoPXF7RHZ:RXV7QH9oO7YhMWEeMGMiNgj1PhJ8RHZ:RHR6Ph1n
NgUgMGEeMWQjO7n2QHN9RXZ:RHN4PWmlNWMfMGEfMgUkOX64QXR9RXZ9R8J3P7ek
N7MeMGEfN7YmP8:5QhV:RXZ8QhB2OgaiMgIeMGIgNG]nPHB6R8Z:RXV8QH>0OGYh
MWEeMGIhNWf0PhF7RHZ:RXR6Q85nO7UgMWEeMWMiO7j1Q8J8RXZ:RHN5Ph1mNWQf
MGEeMWQkOH23QHR9RXZ:R8J4PGikNGMfMGEfMgUlOh:4QhR:RXZ9QhF2P7ejN7Ie
MGEgN7]mP8>6R8V:RXV8QXB1OW]iMgIeMGIgNWaoPXB7RHZ:RXV7QH9oO7YhMWEe
MGMiNgj0PhJ8RHZ:RHR6Ph5nNgUgMGEeMWQjO7n2QHN9RXZ:RHN5PWmlNWQfMGEe
MgUkOX63QXR9RXZ9R8J3P7ikN7MeMGEfN7YmOh:5QhV:RXZ9QhB2OgaiMgIeMGIg
NG]nPHB6R8V:RXV8QH>0OG]hMWEeMGIhNWf0PXF7RHZ:RXR7Q85oO7UgMWEeMWMi
O7j1Q8J8RXZ:RHN5Ph1mNWQfMGEeMWQjOH23QHN9RXZ:R8J4PGilNGMfMGEfMgUl
Oh64QXR:RXZ9QhF2P7ejN7IeMGEfN7]mP8>5R8V:RXV8QXB1OW]iMgIeMGIgNGao
PXB7R8Z:RXV7QH9oOGYhMWEeMGMhNgf0PhJ8RHZ:RHR6Q85nNgUgMGEeMWMjO7n2
QHN9RXZ:RHN5PWmlNWQfMGEeMgUkOX63QXR9RXZ9R8J3PGikNGMeMGEfN7YlOh:5
QhV:RXZ9QhB2OgajMgIeMGEgNG]nPHB6R8V:RXV8QX>0OG]hMgEeMGIhNWeoPXF7
RHZ:RXR7Q89oO7UgMWEeMWMiNgj1Q8J8RHZ:RHR5Ph1mNgQfMGEeMWQjOH23QHN9
RXZ:R8J4PGmlNGMfMGEfMgUlOX64QXR:RXZ9QhF3P7ejN7IeMGEfN7YmP8>5QhV:
RXZ8QXB1OWaiMgIeMGIgNGaoPHB7R8Z:RXV7QH:0OGYhMWEeMGIhNgf0PhJ8RHZ:
RHR6Q85nNgUgMWEeMWMjO7n2Q8N9RXZ:RHN5PWmmNWQfMGEeMgQkOX23QXR9RXZ9
R8J3PGikNGMeMGEfN7YlOh:5QhV:RXZ9QhF2OgajN7IeMGEgNG]nPH>6R8V:RXV8
QX>0OW]iMgEeMGIhNWeoPXF7RHZ:RXV7Q89oO7YgMWEeMWMiNgj1Q8J8RHZ:RHR6
Ph1mNgQfMGEeMWQjOH22QHN9RXZ:R8N4PWmlNGMfMGEfMgUkOX64QXR:RXZ9R8F3
P7ejN7IeMGEfN7YmP8>5QhV:RXZ8QXB1OWaiMgIeMGIgNGanPHB6R8Z:RXV7QH>0
OGYhMWEeMGIhNgf0PhF8RHZ:RXR6Q85nNgUgMWEeMWMiO7n2Q8N8RXZ:RHN5PX1m
NWQfMGEeMgQkOH23QXR9RXZ9R8J4PGikNGMfMGEfMgYlOh:4QhV:RXZ9QhF2Ogaj
N7IeMGEgNG]nP8>6P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P8Z:RXV8
QX>1OW]iMgIeMGEgN7]mP8:5QhV:RXZ9QhF3P7ikNGMfMGEfMgUkOX23QHN9RXZ:
RHN5Ph1mNgQgMGEeMWMiNgj1PhJ8RHZ:RXV7QH:0OGYhMWEeMGIgNGanPHB6R8V:
RXZ8QhB2OgejN7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQfMGEeMWQjO7n2Q8N8
RXZ:RHR6Q85nO7UgMWEeMGIhNWeoPXF7RHZ:RXV8QX>1OW]iMgIeMGEgN7]mP8>5
QhV:RXZ9QhF3P7ikNGMfMGEfMgUkOX23QHN9RXZ:RHN5Ph1mNgQgMGEeMWMiNgj1
PhJ8RHZ:RXV7QH9oOGYhMWEeMGIgNGanPHB6R8V:RXZ8QhB2OgajN7IeMGEfN7Yl
Oh64QXR9RXZ9R8J4PGmlNWQfMGEeMWQjO7n2Q8N8RXZ:RHR6Q85nO7UgMWEeMGIh
NWf0PXF7RHZ:RXV8QX>1OW]iMgIeMGEgN7]mP8>5QhV:RXZ9QhF3P7ikNGMfMGEf
MgUkOX23QHN9RXZ:RHN5PX1mNgQgMGEeMWMiNgj1PhJ8RHZ:RXV7QH9oOGYhMWEe
MGIgNGanPHB6R8V:RXZ8QhB2OgajN7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQf
MGEeMWQjOGn2Q8N8RXZ:RHR6Q85nO7UgMWEeMGMhNWf0PXF7RHZ:RXV8QX>1OW]i
MgIeMGEgNG]mP8>5QhV:RXZ9QhF3P7ekNGMfMGEfMgUkOX23QHN9RXZ:RHN5PX1m
NgQgMGEeMWMiNgj1PhJ8RHZ:RXR7QH9oOGYhMWEeMGIgNGanPHB6R8V:RXZ8QXB2
OgajN7IeMGEfN7YlOh:4QXR9RXZ9R8J4PGmlNWQfMGEeMWQjOGn2Q8N8RXZ:RHR6
Q85nO7UgMWEeMGMhNWf0PXF7RHZ:RXV8QX>1OW]iMgIeMGIgNG]mP8>5QhV:RXZ9
QhF3P7ekNGMfMGEfMgUkOX23QHN9RXZ:RHN5PX1mNgQgMGEeMWMiO7j1PhJ8RHZ:
RXR7QH9oOGYhMWEeMGIgNGaoPHB6R8V:RXV8QXB2OgajN7IeMGEfN7YlOh:4QXR9
RXZ9R8J4PGmlNWQfMGEeMWQjOGn2Q8N8RXZ:RHR6Ph5nO7UgMWEeMGMhNWf0PXF7
RHZ:RXV8QH>0OW]iMgIeMGIgNG]mP8>5QhV:RXZ9QhF3P7ekNGMfMGEfMgUkOX23
QHR9RXZ:RHN5PX1mNWQgMGEeMWMiO7j1PhJ8RHZ:RXR7Q89oOGYhMWEeMGIhNWao
PHB6R8V:RXV8QXB2OgajN7IeMGEfN7YlOh:4QXR9RXZ9R8J4PGmlNGMfMGEeMWQj
OGn2QHN8RXZ:RHR6Ph5nO7UgMWEeMGMhNgf0PXF7RHZ:RXV7QH>0OW]iMgIeMGIg
NG]mP8>5QhV:RXZ9QhF3P7ekNGMfMGEfMgUkOX63QXR9RXZ:RHN5PX1mNWQgMGEe
MWMiO7j1Q8J8RHZ:RXR7Q89oOGYhMWEeMGIhNWaoPHB6R8V:RXV8QXB2OgajN7Ie
MGEfN7YlOh:4QXR:RXZ9R8J4PGilNGMfMGEeMWQjOGn2QHN8RXZ:RHR6Ph5nNgUg
MWEeMGMhNgf0PXF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]mP8>5QhV:RXZ9QhF3P7ek
NGMeMGEfMgUkOX63QXR9RXZ:RHN5PX1mNWQgMGEeMWMiO7j1Q8J8RHZ:RXR7Q89o
OGYhMWEeMGIhNWaoPHB6R8V:RXV8QXB1OgajN7IeMGEfN7YlOh:4QhR:RXZ9R8J4
PGilNGMfMGEeMWQjOGn2QHN9RXZ:RHR6Ph5nNgUgMWEeMGMhNgf0PXF7RHZ:RXV7
QH>0OW]iMgIeMGIgNG]nP8>5QhV:RXZ9QhF3P7ekN7MeMGEfMgUkOX63QXR9RXZ:
RHN5PX1mNWQfMGEeMWMiO7j1Q8J8RHZ:RXR7Q89oO7YhMWEeMGIhNWaoPHB6R8V:
RXV8QXB1OgajN7IeMGEfN7YlOh:4QhR:RXZ9R8J4PGilNGMfMGEeMWQjOH22QHN9
RXZ:RHR6Ph5nNgUgMWEeMGMhNgf0PhF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]nP8>5
QhV:RXZ9QhF3P7ekN7MeMGEfMgUkOX63QXR9RXZ:RHN5PWmmNWQfMGEeMWMiO7j1
Q8J8RHZ:RXR7Q89oO7YhMWEeMGIhNWaoPHB6R8V:RXV8QXB1OgajN7IeMGEfN7Ym
Oh:4QhR:RXZ9R8J4PGilNGMfMGEeMWQjOH22QHN9RXZ:RHR6Ph5nNgUgMWEeMGMh
Ngf0PhF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]nP8>5QhV:RXZ9QhF2P7ekN7MeMGEf
MgUkOX63QXR9RXZ:R8N5PWmmNWQfMGEeMWMiO7j1Q8J8RHZ:RXR6Q89oO7YhMWEe
MGIhNWaoPXB6R8V:RXV8QXB1OgajN7IeMGEfN7YmOh:4QhR:RXZ9R8J4PGilNGMf
MGEeMgQjOH22QHN9RXZ:RHR6Ph5nNgUgMWEeMGMiNgf0PhF7RHZ:RXV7QH>0OG]i
MgIeMGIgNG]nP8>5QhV:RXZ9QhF2P7ekN7MeMGEfMgUkOX63QXR9RXZ:R8N5PWmm
NWQfMGEeMWMiO7j1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8V:RXV8QXB1
OgajN7IeMGEfN7YmOh:4QhR:RXZ9R8J3PGilNGMfMGEeMgQjOH22QHN9RXZ:RHR6
Ph1nNgUgMWEeMWMiNgf0PhF7RHZ:RXV7QH>0OG]iMgIeMGIgNG]nP8>5QhV:RXZ9
QhF2P7ekN7MeMGEfMgUlOX63QXR9RXZ:R8N5PWmmNWQfMGEeMWMjO7n1Q8J8RHZ:
RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8V:RXV8QXB1OgajMgIeMGEfN7YmOh:5QhR:
RXZ9R8J3PGilNGMfMGEeMgQkOH22QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgf0PhF7
RHZ:RXV7QH>0OG]iMgIeMGIgNG]nP8>6R8V:RXZ9QhF2P7ejN7MeMGEfMgUlOX63
QXR9RXZ:R8N4PWmmNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWao
PXB6R8V:RXV8QXB1OWaiMgIeMGEfN7YmOh:5QhR:RXZ9R8J3PGikNGMfMGEeMgQk
OH22QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgf0PhF7RHZ:RXV7QH>0OG]iMgEeMGIg
NG]nPH>6R8V:RXZ9QhF2P7ejN7MeMGEfMgUlOX64QXR9RXZ:R8N4PWmmNWQfMGEe
MWQjO7n1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8Z:RXV8QXB1OWaiMgIe
MGEfN7YmOh:5QhR:RXZ9R8J3PGikNGMfMGEeMgQkOH22QHN9RXZ:RHN5Ph1nNgUg
MWEeMWMiNgj0PhF7RHZ:RXV7QH>0OG]hMgEeMGIgNG]nPH>6R8V:RXZ9QhF2P7ej
N7IeMGEfMgUlOX64QXR9RXZ:R8N4PWmmNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q85o
O7YhMWEeMGIhNWaoPXB7R8Z:RXV8QXB1OWaiMgIeMGEfN7YmOh:5QhV:RXZ9R8J3
PGikNGMfMGEeMgQkOH23QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgj0PhF7RHZ:RXV7
QH>0OG]hMgEeMGIgNG]nPH>6R8V:RXZ9QhF2OgejN7IeMGEfMgUlOX64QXR9RXZ:
R8N4PWmlNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWaoPXB7R8Z:
RXV8QXB1OWaiMgIeMGEfN7YmP8:5QhV:RXZ9R8J3PGikNGMfMGEeMgQkOH23QHN9
RXZ:RHN5Ph1nNgUgMWEeMWMiNgj0PhF7RHZ:RXV7QH:0OG]hMgEeMGIgNG]nPH>6
R8V:RXZ9QhF2OgejN7IeMGEfMgUlOX64QXR9RXZ:R8N4PWmlNWQfMGEeMWQjO7n1
Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWeoPXB7R8Z:RXV8QXB1OWaiMgIeMGEgN7Ym
P8:5QhV:RXZ9R8J3PGikNGMfMGEeMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMi
Ngj0PhF7RHZ:RXV7QH:0OG]hMgEeMGIgNG]nPH>6R8V:RXZ8QhF2OgejN7IeMGEf
MgUlOX64QXR9RXZ:R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RHZ:RHR6Q85oO7YhMWEe
MGIhNWeoPXB7R8Z:RXV8QXB1OWaiMgIeMGEgN7YmP8:5QhV:RXZ9R8J3PGikNGMf
MGEfMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMiNgj0PhF7RHZ:RXV7QH:0OG]h
MgEeMGIgNGanPH>6R8V:RXZ8QhF2OgejN7IeMGEfMgUlOh64QXR9RXZ9R8J4PWml
NWQfMGEeMWQjO7n2Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWeoPXB7R8Z:RXV8QX>1
OWaiMgIeMGEgN7YmP8:5QhV:RXZ9R8F3P7ikNGMfMGEfMgUkOH23QHN9RXZ:RHN5
Ph1mNgUgMWEeMWMiNgj0PhF8RHZ:RXV7QH:0OGYhMgEeMGIgNGanPH>6R8V:RXZ8
QhB2OgejN7IeMGEfN7YlOh64QXR9RXZ9R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RHZ:
RHR6Q85oO7UgMWEeMGIhNWeoPXF7R8Z:RXV8QX>1OWaiMgIeMGEgN7]mP8:5QhV:
RXZ9QhF3P7ikNGMfMGEfMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMiNgj1PhJ8
RHZ:RXV7QH:0OGYhMgEeMGIgNGanPHB6R8V:RXZ8QhB2OgejN7IeMGEfN7YlOh64
QXR9RXZ9R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RXZ:RHR6Q85nO7UgMWEeMGIhNWeo
PXF7R8Z:RXV8QX>1OW]iMgIeMGEgN7]mP8:5QhV:RXZ9QhF3P7ikNGMfMGEfMgUk
OH23QHN9RXZ:RHN5Ph1mNgUgMGEeMWMiNgj1PhJ8RHZ:RXV7QH:0OGYhMgEeMGIg
NGanPHB6R8V:RXZ8QhB2OgejN7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQfMGEe
MWQjO7n2Q8N8RXZ:RHR6Q85nO7UgMWEeMGIhNWeoPXF7RHZ:RXV8QX>1OW]iMgIe
MGEgN7]mP8:5QhV:RXZ9QhF3P7ikNGMfMGEfMgUkOX23QHN9RXZ:RHN5Ph1mNgQg
MGEeMWMiNgj1PhJ8RHZ:RXV7QH:0OGYhMWEeMGIgNGanPHB6R8V:RXZ8QhB2Ogaj
N7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQfMGEeMWQjO7n2Q8N8RXZ:RHR6Q85n
O7UgMWEeMGIhNWf0P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P7]mOh:4
QXR9RXZ:RHR6Q8:0OG]iMgIeMGEfMgUkOH22Q8J8RHZ:RXV8QXB2OgekNGMfMGEe
MWMiNgf0PXB6R8V:RXZ9R8J4PGmmNWUgMWEeMGIgNG]nP8:5QhR9RXZ:RHN6Q85o
O7YhMgIeMGEfN7UlOX23QHN8RHZ:RXV7QH>1OgajN7MfMGEeMWQjO7j1PhF7R8Z:
RXZ9QhF3PGilNWQfMGEeMGMhNWanPH>5QhV:RXZ9R8N5Ph1nO7YhMWEeMGIgN7Yl
Oh63QXN9RXZ:RHR7QH>0OW]iN7IeMGEfMgQjOGn1Q8J8RHZ:RXV8QXF2P7ikNGMf
MGEeMWMiNgeoPXB6R8V:RXZ9R8J4PX1mNgUgMWEeMGIgNG]mOh:4QXR9RXZ:RHR6
Q89oOG]iMgIeMGEfMgUkOH22Q8J8RHZ:RXV8QXB2OgekNGMfMGEeMWMiNgj0PXF7
R8V:RXZ9QhJ4PGmmNWQgMWEeMGIhNGanP8>5QhR9RXZ:RHN5Ph5oO7YhMgIeMGEf
N7YlOX23QHN8RXZ:RXV7QH>1OWajN7IeMGEeMWQjO7j1PhF7RHZ:RXZ8QhF3PGil
NWQfMGEeMWMhNWaoPH>5QhV:RXZ9R8N5Ph1nO7UhMWEeMGIgN7YmOh64QXN9RXZ:
RHR7QH:0OW]iMgIeMGEfMgUkOGn2Q8J8RHZ:RXV8QXB2P7ekNGMfMGEeMWMiNgeo
PXB6R8V:RXZ9R8J4PWmmNgUgMWEeMGIgNG]mP8:4QXR9RXZ:RHR6Q89oOG]iMgIe
MGEfMgUkOX22QHJ8RHZ:RXV8QXB1OgejN7MfMGEeMWQiNgj0PhF7R8V:RXZ9QhJ3
PGmlNWQgMWEeMGIhNWanP8>5QhR9RXZ:RHN5Ph5nO7YhMgEeMGEfN7YlOX63QHN9
RXZ:RXR7QH>1OWajN7IeMGEeMgQjO7n1PhF7RHZ:RXV8QhF3P7ilNWQfMGEeMWMh
NWaoPH>6QhV:RXZ9R8N5PX1nNgUhMWEeMGIgN7YmOh64QXR9RXZ:RHR6Q8:0OG]i
MgIeMGEfMgUkOGn2Q8J8RHZ:RXV8QXB2P7ekNGMfMGEeMWMiNgf0PXB6R8V:RXZ9
R8J4PWmmNgUgMWEeMGIgNG]mP8:4QXR9RXZ:RHR6Q85oOGYhMgIeMGEfN7UkOX22
QHN8RHZ:RXV7QX>1OgajN7MfMGEeMWQjO7j0PhF7R8V:RXZ9QhF3PGmlNWQgMGEe
MGIhNWanPH>5QhV:RXZ:RHN5Ph5nO7YhMWEeMGEgN7YlOX63QHN9RXZ:RHR7QH>0
OWajN7IeMGEfMgQjO7n1PhJ7RHZ:RXV8QhF3P7ikNGQfMGEeMWMhNWeoPHB6R8V:
RXZ9R8J4PX1nNgUgMWEeMGIgNG]mOh:4QXR9RXZ:RHR6Q8:0OG]iMgIeMGEfMgUk
OGn2Q8J8RHZ:RXV8QXB2OgekNGMfMGEeMWMiNgf0PXB6R8V:RXZ9R8J4PWmmNgUg
MWEeMGIgNG]nP8:5QhR9RXZ:RHN6Q85oOGYhMgIeMGEfN7UlOX23QHN8RHZ:RXV7
QH>1OgajN7MfMGEeMWQjO7j1PhF7R8Z:RXZ9QhF3PGilNWQfMGEeMGIhNWanPH>5
QhV:RXZ:R8N5Ph1nO7YhMWEeMGIgN7YlOh63QHN9RXZ:RHR7QH>0OWaiN7IeMGEf
MgQjOGn1Q8J7RHZ:RXV8QhF2P7ikNGMfMGEeMWMiNgeoPXB6R8V:RXZ9R8J4PX1m
NgUgMWEeMGIgNG]mOh:4QXR9RXZ:RHR6Q89oOG]iMgIeMGEfMgUkOH22Q8J8RHZ:
RXV8QXB2OgekNGMfMGEeMWMiNgj0PXF7R8V:RXZ9R8J4PGmmNWQgMWEeMGIhNG]n
P8>5QhR9RXZ:RHN6Ph5oO7YhMgIeMGEfN7YlOX23QHN8RHZ:RXV7QH>1OWajN7Me
MGEeMWQjO7j1PhF7RHZ:RXZ8QhF3PGilNWQfMGEeMWMhNWaoPH>5QhV:RXZ9R8N5
Ph1nO7UhMWEeMGIgN7YlOh64QXN9RXZ:RHR7QH:0OW]iMgIeMGEfMgUjOGn1Q8J8
RHZ:RXV8QXB2P7ekNGMfMGEeMWMiNgeoPXB6R8V:RXZ9R8J4PX1mNgUgMWEeMGIg
NG]mP8:4QXR9RXZ:RHR6Q89oOG]iMgIeMGEfMgUkOH22Q8J8RHZ:RXV8QXB1Ogej
N7MfMGEeMWQiNgj0PXF7R8V:RXZ9QhJ3PGmlNWQgMWEeMGIhNWanP8>5QhR9RXZ:
RHN5Ph5nO7YhMgEeMGEfN7YlOX63QHN9RXZ:RXV7QH>1OWajN7IeMGEeMgQjO7j1
PhF7RHZ:RXV8QhF3P7ilNWQfMGEeMWMhNWaoPH>6QhV:RXZ9R8N5PX1nNgUhMWEe
MGIgN7YmOh64QXR9RXZ:RHR6Q8:0OG]iMgIeMGEfMgUkOGn2Q8J8RHZ:RXV8QXB2
P7ekNGMfMGEeMWMiNgf0PXB6R8V:RXZ9R8J4PWmmNgUgMWEeMGIgNG]mP8:4QXR9
RXZ:RHR6Q85oOGYiMgIeMGEfMgUkOX22QHN8RHZ:RXV7QXB1OgajN7MfMGEeMWQi
O7j0PhF7R8V:RXZ9QhF3PGmlNWQgMWEeMGIhNWanPH>5QhR:RXZ:RHN5Ph5nO7Yh
MWEeMGEgN7YlOX63QHN9RXZ:RXR7QH>0OWajN7IeMGEfMgQjO7n1PhJ7RHZ:RXV8
QhF3P7ikNGQfMGEeMWMhNWeoPHB6QhV:RXZ9R8N5PX1nNgUgMWEeMGIgNG]mOh:4
QXR9RXZ:RHR6Q8:0OG]iMgIeMGEfMgUkOGn2Q8J8RHZ:RXV8QXB2OgekNGMfMGEe
MWMiNgf0PXB6R8V:RXZ9R8J4PWmmNgUgMWEeMGIgNG]nP8:5QhR9RXZ:RHN6Q85o
OGYhMgIeMGEfN7UlOX23QHN8RHZ:RXV7QH>1OgajN7MfMGEeMWQjO7j0PhF7R8Z:
RXZ9QhF3PGilNWQfMGEeMGIhNWanPH>5QhV:RXZ:R8N5Ph5nO7YhMWEeMGIgN7Yl
Oh63QHN9RXZ:RHR7QH>0OWaiN7IeMGEfMgQjO7n1Q8J7RHZ:RXV8QhF2P7ikNGMf
MGEeMWMiNgeoPXB6R8V:RXZ9R8J4PX1mNgUgMWEeMGIgNG]mOh:4QXR9RXZ:RHR6
Q8:0OG]iMgIeMGEfMgUkOH22Q8J8RHZ:RXV8QXB2OgekNGMfMGEeMWMiNgf0PXB6
R8V:RXZ9R8J4PGmmNWQgMWEeMGIhNG]nP8>5QhR9RXZ:RHN6Ph5oO7YhMgIeMGEf
N7YlOX23QHN8RHZ:RXV7QH>1OWajN7MeMGEeMWQjO7j1PhF7RHZ:RXZ9QhF3PGil
NWQfMGEeMGMhNWaoPH>5QhV:RXZ9R8N5Ph1nO7YhMWEeMGIgN7YlOh63QXN9RXZ:
RHR7QH:0OW]iN7IeMGEfMgQjOGn1Q8J8RHZ:RXV8QXB2P7ekNGMfMGEeMWMiNgeo
PXB6R8V:RXZ9R8J4PX1mNgUgMWEeMGIgNG]mP8:4QXR9RXZ:RHR6Q89oOG]iMgIe
MGEfMgUkOH22Q8J8RHZ:RXV8QXB1OgejN7MfMGEeMWQiNgj0PXF7R8V:RXZ9QhJ4
PGmlNWQgMWEeMGIhNGanP8>5QhR9RXZ:RHN5Ph5oO7YhMgEeMGEfN7YlOX63QHN8
RXZ:RXV7QH>1OWajN7IeMGEeMgQjO7j1PhF7RHZ:RXV8QhF3P7ilNWQfMGEeMWMh
NWaoPH>6QhV:RXZ9R8N5Ph1nNgUhMWEeMGIgN7YmOh64QXR9RXZ:RHR6QH:0OW]i
MgIeMGEfMgUkOGn2Q8J8RHZ:RXV8QXB2P7ekNGMfMGEeMWMiNgeoPXB6R8V:RXZ9
R8J4PWmmNgUgMWEeMGIgNG]mP8:4QXR9RXZ:RHR6Q89oOG]iMgIeMGEfMgUkOX22
QHN8RHZ:RXV7QXB1OgejN7MfMGEeMWQiO7j0PhF7R8V:RXZ9QhF3PGmlNWQgMWEe
MGIhNWanPH>5QhR:RXZ:RHN5Ph5nO7YhMWEeMGEfN7YlOX63QHN9RXZ:RXR7QH>1
OWajN7IeMGEfMgQjO7n1PhF7RHZ:RXV8QhF3P7ilNGQfMGEeMWMhNWeoPHB6QhV:
RXZ9R8N5PX1nNgUgMWEeMGIgNG]mOh:4QXR9RXZ:RHR6Q8:0OG]iMgIeMGEfMgUk
OGn2Q8J8RHZ:RXV8QXB2OgekNGMfMGEeMWMiNgf0PXB6R8V:RXZ9R8J4PWmmNgUg
MWEeMGIgNG]nP8:5QXR9RXZ:RHR6Q85oOGYhMgIeMGEfN7UkOX23QHN8RHZ:RXV7
QX>1OgajN7MfMGEeMWQjO7j0PhF7R8V:RXZ9QhF3PGilNWQgMGEeMGIhNWanPH>5
QhV:RXZ:R8N5Ph5nO7YhMWEeMGEgN7YlOh63QHN9RXZ:RHR7QH>0OWaiN7IeMGEf
MgQjO7n1Q8J7RHZ:RXV8QhF2P7ikNGMfMGEeMWMhNWeoPHB6R8V:RXZ9R8J4PX1m
NgUgMWEeMGIgNG]mOh:4QXR9RXZ:RHR6Q8:0OG]iMgIeMGEfMgUkOH22Q8J8RHZ:
RXV8QXB2OgekNGMfMGEeMWMiNgf0PXB6R8V:RXZ9R8J4PGmmNWQgMWEeMGIhNG]n
P8:5QhR9RXZ:RHN6Ph5oO7YhMgIeMGEfN7YlOX23QHN8RHZ:RXV7QH>1OgajN7Me
MGEeMWQjO7j1PhF7RHZ:RXZ9QhF3PGilNWQfMGEeMGMhNWanPH>5QhV:RXZ9R8N5
Ph1nO7YhMWEeMGIgN7YlOh63QXN9RXZ:RHR7QH>0OW]iN7IeMGEfMgQjOGn1Q8J8
RHZ:RXV8QXB2P7ekNGMfMGEeMWMiNgeoPXB6R8V:RXZ9R8J4PX1mNgUgMWEeMGIg
NG]mP8:4QXR9RXZ:RHR6Q89oOG]iMgIeMGEfMgUkOH22Q8J8RHZ:RXV8QXB1Ogek
NGMfMGEeMWMiNgj0PXF7R8V:RXZ9QhJ4PGmlNWQgMWEeMGIhNGanP8>5QhR9RXZ:
RHN5Ph5oO7YhMgIeMGEfN7YlOX63QHN8RXZ:RXV7QH>1OWajN7IeMGEeMWQjO7j1
PhF7RHZ:RXZ8QhF3P7ilNWQfMGEeMWMhNWaoPH>5QhV:RXZ9R8N5Ph1nO7UhMWEe
MGIgN7YmOh64QXN9RXZ:RHR7QH:0OW]iMgIeMGEfMgUkOGn2Q8J8RHZ:RXV8QXB2
P7ekNGMfMGEeMWMiNgeoPXB6R8V:RXZ9R8J4PWmmNgUgMWEeMGIgNG]mP8:4QXR9
RXZ:RHR6Q89oOG]iMgIeMGEfMgUkOX22QHN8RHZ:RXV7QXB1OgejN7MfMGEeMWQi
O7j0PhF7R8V:RXZ9QhJ3PGmlNWQgMWEeMGIhNWanP8>5QhR:RXZ:RHN5Ph5nO7Yh
MgEeMGEfN7YlOX63QHN9RXZ:RXR7QH>1OWajN7IeMGEfMgQjO7n1PhF7RHZ:RXV8
QhF3P7ilNGQfMGEeP820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P7UhMWEe
MGEfMgUjO7j1PhF6R8V:RXZ:RHN6Q8:0OWajN7MfMGEeMWMhNWanP8:4QXN9RXZ:
RXV8QXF3PGilNWUgMWEeMGEfN7UkOGn1PhF7R8V:RXZ9R8N5Ph5oOG]iN7IeMGEe
MWMiNWanPH>5QXR9RXZ:RXV7QXB2P7ilNWQgMWEeMGIgN7YlOX22Q8J7RHZ:RXZ9
R8J5Ph1nO7YiMgIeMGEeMWQiNgeoPH>5QhR9RXZ:RHR7QH>1OgekNGMfMGEeMGIg
NG]mOh63QHN8RHZ:RXZ9QhJ4PX1nNgYhMgIeMGEfMgQjO7j0PXB6R8V:RXZ:RHR6
Q8:0OWajN7MfMGEeMWIhNG]mOh:4QHN8RHZ:RXV8QhF3PGmmNgUgMWEeMGEfMgUk
OGn1PhF7R8V:RXZ9RHN6Q8:0OG]iN7MfMGEeMWMhNWanP8:4QXR9RXZ:RXV8QXB2
P7ilNWQgMWEeMGIgN7UkOH22Q8J7RHV:RXZ9R8N5Ph5oOG]iMgIeMGEeMWMiNgeo
PH>5QhR9RXZ:RHR7QHB2OgekNGQfMWEeMGIgN7YlOX22Q8J8RHZ:RXZ9R8J4PX1n
O7YhMgIeMGEfMgQjNgj0PXB6QhV:RXZ:RHR7QH>1OgekNGMfMGEeMGIgNG]mOh63
QHN8RHZ:RXV8QhF3PGmmNgUhMWEeMGEfMgUjO7j0PhF6R8V:RXZ:RHN6Q8:0OWaj
N7MfMGEeMWMhNWanP8:4QXN9RXZ:RXV8QXF3PGmlNWUgMWEeMGEfN7UkOGn1PhF7
R8V:RXZ9R8N5Ph5oOG]iN7IeMGEeMWMiNWanPH>5QXR9RXZ:RXV7QXB2P7ilNWQg
MWEeMGIgN7YlOX22Q8J7RHZ:RXZ9R8J5Ph5nO7YiMgIeMGEeMWQiNgeoPH>5QhR9
RXZ:RHR7QH>1OgekNGQfMGEeMGIgNGYlOh63QHJ8RHZ:RXZ9QhJ4PX1nO7YhMgIe
MGEfMgQjO7j0PXB6R8V:RXZ:RHR6Q8>0OWajN7MfMGEeMGIhNG]mOh63QHN8RHZ:
RXV8QhF3PGmmNgUgMWEeMGEfMgUkOGn1PhF7R8V:RXZ:RHN6Q8:0OG]jN7MfMGEe
MWMhNWanP8:4QXR9RXZ:RXV8QXB2P7ilNWQgMWEeMGIfN7UkOGn2Q8F7R8V:RXZ9
R8N5Ph5oOG]iMgIeMGEeMWMiNgeoPH>5QhR9RXZ:RHR7QXB2P7ekNGQgMWEeMGIg
N7YlOX22Q8J8RHZ:RXZ9R8J4PX1nO7YhMgIeMGEfMgQjNgf0PXB6QhV9RXZ:RHR7
QH>1OgekNGMfMGEeMGIgNG]mOh63QHN8RHZ:RXV8QhF4PWmmNgUhMWIeMGEfMgQj
O7j0PXB6R8V:RXZ:RHR6Q8:0OWajN7MfMGEeMWMhNW]nP8:4QXN9RXZ:RXV8QhF3
PGmlNgUgMWEeMGEfMgUkOGn1PhF7R8V:RXZ9R8N5Ph5oOG]iN7IeMGEeMWMiNWan
P8>5QXR9RXZ:RXV7QXB2P7ilNWQgMWEeMGIgN7YlOX22Q8J7RHZ:RXZ9R8J5Ph5n
O7YiMgIeMGEeMWQiNgeoPH>5QhR9RXZ:RHR7QH>1OgekNGQfMGEeMGIgNGYlOX63
QHJ8RHZ:RXZ9QhJ4PX1nO7YhMgIeMGEfMgQjO7j0PXB6QhV:RXZ:RHR6QH>0OWaj
NGMfMGEeMGIhNG]mOh63QHN8RHZ:RXV8QhF3PGmmNgUhMWEeMGEfMgUjO7n1PhF6
R8V:RXZ:RHN6Q8:0OWajN7MfMGEeMWMhNWanP8:4QXR9RXZ:RXV8QXB2P7ilNWQg
MWEeMGEfN7UkOGn1Q8F7R8V:RXZ9R8N5Ph5oOG]iMgIeMGEeMWMiNgeoPH>5QhR9
RXZ:RHV7QXB2P7ekNWQgMWEeMGIgN7YlOX22Q8J8RHZ:RXZ9R8J4PX1nO7YhMgIe
MGEfMWQiNgeoPXB6QhR9RXZ:RHR7QH>1OgekNGMfMGEeMGIgNG]mOh63QHN8RHZ:
RXV8QhJ4PWmmNgUhMWIeMGEfMgQjO7j0PXB6R8V:RXZ:RHR6Q8:0OWajN7MfMGEe
MWMhNW]mP8:4QXN9RHZ:RXV8QhF3PGmmNgUgMWEeMGEfMgUkOGn1PhF7R8V:RXZ9
R8N5Q85oOG]iN7IeMGEeMWMhNWanP8:4QXR9RXZ:RXV8QXB2P7ilNWQgMWEeMGIg
N7YlOX22Q8J7RHZ:RXZ9R8J5Ph5oO7YiMgIeMGEeMWQiNgeoPH>5QhR9RXZ:RHR7
QH>1OgekNGQfMGEeMGIgNGYlOX23QHJ8RHZ:RXZ9QhJ4PX1nO7YhMgIeMGEfMgQj
O7j0PXB6QhV:RXZ:RHR6QH>1OWajNGMfMGEeMGIhNG]mOh63QHN8RHZ:RXV8QhF3
PGmmNgUhMWEeMGEfMgUjO7j1PhF6R8V:RXZ:RHN6Q8:0OWajN7MfMGEeMWMhNWan
P8:4QXN9RXZ:RXV8QXF3P7ilNWUgMWEeMGEfN7UkOGn1PhF7R8V:RXZ9R8N5Ph5o
OG]iMgIeMGEeMWMiNgaoPH>5QhR9RXZ:RXV7QXB2P7ikNWQgMWEeMGIgN7YlOX22
Q8J8RHZ:RXZ9R8J4PX1nO7YhMgIeMGEfMWQiNgeoPXB5QhR9RXZ:RHR7QH>1Ogek
NGMfMGEeMGIgNG]mOh63QHN8RHZ:RXV9QhJ4PX1mNgYhMgIeMGEfMgQjO7j0PXB6
R8V:RXZ:RHR6Q8:0OWajN7MfMGEeMWMhNG]mP8:4QXN8RHZ:RXV8QhF3PGmmNgUg
MWEeMGEfMgUkOGn1PhF7R8V:RXZ9R8N5Q89oOG]iN7IfMGEeMWMhNWanP8:4QXR9
RXZ:RXV8QXB2P7ilNWQgMWEeMGIgN7YkOH22Q8J7RHV:RXZ9R8N5Ph5oOG]iMgIe
MGEeMWMiNgeoPH>5QhR9RXZ:RHR7QHB1OgekNGQfMGEeMGIgN7YlOX23Q8J8RHZ:
RXZ9R8J4PX1nO7YhMgIeMGEfMgQjO7j0PXB6QhV:RXZ:RHR6QH>1OgajNGMfMGEe
MGIhNG]mOh63QHN8RHZ:RXV8QhF3PGmmNgUhMWEeMGEfMgUjO7j1PhF6R8V:RXZ:
RHN6Q8:0OWajN7MfMGEeMWMhNWanP8:4QXN9RXZ:RXV8QXF3PGilNWUgMWEeMGEf
N7UkOGn1PhF7R8V:RXZ9R8N5Ph5oOG]iN7IeMGEeMWMiNWaoPH>5QXR9RXZ:RXV7
QXB2P7ilNWQgMWEeMGIgN7YlOX22Q8J7RHZ:RXZ9R8J5Ph1nO7YiMgIeMGEeMWQi
NgeoPH>5QhR9RXZ:RHR7QH>1OgekNGMfMGEeMGIgNG]mOh63QHN8RHZ:RXZ9QhJ4
PX1nNgYhMgIeMGEfMgQjO7j0PXB6R8V:RXZ:RHR6Q8:0OWajN7MfMGEeMWIhNG]m
Oh:4QHN8RHZ:RXV8QhF3PGmmNgUgMWEeMGEfMgUkOGn1PhF7R8V:RXZ9RHN6Q8:0
OG]iN7MfMGEeMWMhNWanP8:4QXR9RXZ:RXV8QXB2P7ilNWQgMWEeMGIgN7UkOH22
Q8J7RHV:RXZ9R8N5Ph5oOG]iMgIeMGEeMWMiNgeoPH>5QhR9RXZ:RHR7QHB2Ogek
NGQfMWEeMGIgN7YlOX22Q8J8RHZ:RXZ9R8J4PX1nO7YhMgIeMGEfMgQjNgj0PXB6
QhV:RXZ:RHR7QH>1OgekNGMfMGEeMGIgNG]mOh63QHN8RHZ:RXV8QhF3PGmmNgUh
MWEeMGEfMgUjO7j0PhF6R8V:RXZ:RHN6Q8:0OWajN7MfMGEeMWMhNWanP8:4QXN9
RXZ:RXV8QXF3PGmlNWUgMWEeMGEfN7UkOGn1PhF7R8V:RXZ9R8N5Ph5oOG]iN7Ie
MGEeMWMiNWanPH>5QXR9RXZ:RXV7QXB2P7ilNWQgMWEeMGIgN7YlOX22Q8J7RHZ:
RXZ9R8J5Ph5nO7YiMgIeMGEeMWQiNgeoPH>5QhR9RXZ:RHR7QH>1OgekNGQfMGEe
MGIgNGYlOh63QHJ8RHZ:RXZ9QhJ4PX1nO7YhMgIeMGEfMgQjO7j0PXB6R8V:RXZ:
RHR6Q8>0OWajN7MfMGEeMGIhNG]mOh64QHN8RHZ:RXV8QhF3PGmmNgUgMWEeMGEf
MgUkOGn1PhF7R8V:RXZ9RHN6Q8:0OG]jN7MfMGEeMWMhNWanP8:4QXR9RXZ:RXV8
QXB2P7ilNWQgMWEeMGIfN7UkOGn2Q8F7R8V:RXZ9R8N5Ph5oOG]iMgIeMGEeMWMi
NgeoPH>5QhR9RXZ:RHR7QXB2OgekNGQgMWEeMGIgN7YlOX22Q8J8RHZ:RXZ9R8J4
PX1nO7YhMgIeMGEfMgQjNgf0PXB6QhV9RXZ:RHR7QH>1OgekNGMfMGEeMGIgNG]m
Oh63QHN8RHZ:RXV8QhF4PWmmNgUhMWEeMGEfMgQjO7j0PXB6R8V:RXZ:RHR6Q8:0
OWajN7MfMGEeMWMhNWanP8:4QXN9RXZ:RXV8QhF3PGmlNgUgMWEeMGEfMgUkOGn1
PhF7R8V:RXZ9R8N5Ph5oOG]iN7IeMGEeMWMiNWanP8>5QXR9RXZ:RXV7QXB2P7il
NWQgMWEeMGIgN7YlOX22Q8J7RHZ:RXZ9R8J5Ph5nO7YiMgIeMGEeMWQiNgeoPH>5
QhR9RXZ:RHR7QH>1OgekNGQfMGEeMGIgNGYlOX63QHJ8RHZ:RXZ9QhJ4PX1nO7Yh
MgIeMGEfMgQjO7j0PXB6QhV:RXZ:RHR6QH>0OWajNGMfMGEeMGIhNG]mOh63QHN8
RHZ:RXV8QhF3PGmmNgUhMWEeMGEfMgUjO7n1PhF6R8V:RXZ:RHN6Q8:0OWajN7Mf
MGEeMWMhNWanP8:4QXR9RXZ:RXV8QXB2P7ilNWQgMWEeMGEfN7UkOGn1Q8F7R8V:
RXZ9R8N5Ph5oOG]iMgIeMGEeMWMiNgeoPH>5QhR9RXZ:RHV7QXB2P7ekNWQgMWEe
MGIgN7YlOX22Q8J8RHZ:RXZ9R8J4PX1nO7YhMgIeMGEfMWQiNgeoPXB6QhR9RXZ:
RHR7QH>1OgekNGMfMGEeMGIgNG]mOh63QHN8RHZ:RXV8QhJ4PWmmNgUhMWIeMGEf
MgQjO7j0PXB6R8V:RXZ:RHR6Q8:0OWajN7MfMGEeMWMhNW]mP8:4QXN9RHZ:RXV8
QhF3PGmmNgUgMWEeMGEfMgUkOGn1PhF7R8V:RXZ9R8N5Q85oOG]iN7IeMGEeMWMh
NWanP8:4QXR9RXZ:RXV8QXB2P7ilNWQgMWEeMGIgN7YlOX22Q8J7RHZ:RXZ9R8J5
Ph5oO7YiMgIeMGEeMWQiNgeoPH>5QhR9RXZ:RHR7QH>1OgekNGQfMGEeMGIgNGYl
OX63QHJ8RHZ:RXZ9QhJ4PX1nO7YhMgIeMGEfMgQjO7j0PXB6QhV:RXZ:RHR6QH>1
OWajNGMfMGEeMGIhNG]mOh63QHN8RHZ:RXV8QhF3PGmmNgUhMWEeMGEfMgUjO7j1
PhF6R8V:RXZ:RHN6P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P7EfMgUk
OGn1PhF7R8V:RXZ9R8N5Q85oOG]iN7IeMGEeMWMhNWanP8>4QXR9RXZ:RXV8QXB2
P7ilNWQgMWEeMGIgN7YlOX22Q8J7RHZ:RXZ9R8J5Ph5oO7YiMgIeMGEeMWQiNgeo
PH>5QhR9RXZ:RHR7QH>1OgekNGQfMGEeMGIgNGYlOX63QHJ8RHZ:RXZ9QhJ4PX1n
O7YhMgIeMGEfMgQjO7j0PXB6QhV:RXZ:RHR6QH>1OWajNGMfMGEeMGIhNG]mOh63
QHN8RHZ:RXV8QhF3PGmmNgUhMWEeMGEfMgUjO7n1PhF6R8V:RXZ:RHN6Q8:0OWaj
N7MfMGEeMWMhNWanP8:4QXN9RXZ:RXV8QXF3P7ilNWUgMWEeMGEfN7UkOGn1PhF7
R8V:RXZ9R8N5Ph5oOG]iMgIeMGEeMWMiNgeoPH>5QhR9RXZ:RXV7QXB2P7ikNWQg
MWEeMGIgN7YlOX22Q8J8RHZ:RXZ9R8J4PX1nO7YhMgIeMGEfMWQiNgeoPXB5QhR9
RXZ:RHR7QH>1OgekNGMfMGEeMGIgNG]mOh63QHN8RHZ:RXV9QhJ4PX1mNgUhMgIe
MGEfMgQjO7j0PXB6R8V:RXZ:RHR6Q8:0OWajN7MfMGEeMWMhNG]mP8:4QXN9RHZ:
RXV8QhF3PGmmNgUgMWEeMGEfMgUkOGn1PhF7R8V:RXZ9R8N5Q89oOG]iN7IfMGEe
MWMhNWanP8:4QXR9RXZ:RXV8QXB2P7ilNWQgMWEeMGIgN7YkOX22Q8J7RHZ:RXZ9
R8N5Ph5oOG]iMgIeMGEeMWMiNgeoPH>5QhR9RXZ:RHR7QH>1OgekNGQfMGEeMGIg
NGYlOX23QHJ8RHZ:RXZ9QhJ4PX1nO7YhMgIeMGEfMgQjO7j0PXB6QhV:RXZ:RHR6
QH>1OgajNGMfMGEeMGIhNG]mOh63QHN8RHZ:RXV8QhF3PGmmNgUhMWEeMGEfMgUj
O7j1PhF6R8V:RXZ:RHN6Q8:0OWajN7MfMGEeMWMhNWanP8:4QXN9RXZ:RXV8QXF3
PGilNWUgMWEeMGEfN7UkOGn1PhF7R8V:RXZ9R8N5Ph5oOG]iN7IeMGEeMWMiNWao
PH>5QXR9RXZ:RXV7QXB2P7ilNWQgMWEeMGIgN7YlOX22Q8J8RHZ:RXZ9R8J4Ph1n
O7YhMgIeMGEeMWQiNgeoPHB5QhR9RXZ:RHR7QH>1OgekNGMfMGEeMGIgNG]mOh63
QHN8RHZ:RXV9QhJ4PX1mNgYhMgIeMGEfMgQjO7j0PXB6R8V:RXZ:RHR6Q8:0OWaj
N7MfMGEeMWIhNG]mOh:4QHN8RHZ:RXV8QhF3PGmmNgUgMWEeMGEfMgUkOGn1PhF7
R8V:RXZ9R8N6Q89oOG]iN7MfMGEeMWMhNWanP8:4QXR9RXZ:RXV8QXB2P7ilNWQg
MWEeMGIgN7YkOH22Q8J7RHV:RXZ9R8N5Ph5oOG]iMgIeMGEeMWMiNgeoPH>5QhR9
RXZ:RHR7QHB2OgekNGQfMWEeMGIgN7YlOX22Q8J8RHZ:RXZ9R8J4PX1nO7YhMgIe
MGEfMgQjNgj0PXB6QhV:RXZ:RHR7QH>1OgakNGMfMGEeMGIgNG]mOh63QHN8RHZ:
RXV8QhF3PGmmNgUhMWEeMGEfMgUjO7j0PhF6R8V:RXZ:RHN6Q8:0OWajN7MfMGEe
MWMhNWanP8:4QXN9RXZ:RXV8QXF3PGilNWUgMWEeMGEfN7UkOGn1PhF7R8V:RXZ9
R8N5Ph5oOG]iN7IeMGEeMWMiNWanPH>5QXR9RXZ:RXV7QXB2P7ilNWQgMWEeMGIg
N7YlOX22Q8J7RHZ:RXZ9R8J5Ph1nO7YiMgIeMGEeMWQiNgeoPH>5QhR9RXZ:RHR7
QH>1OgekNGQfMGEeMGIgNGYlOh63QHJ8RHZ:RXZ9QhJ4PX1nO7YhMgIeMGEfMgQj
O7j0PXB6R8V:RXZ:RHR6Q8:0OWajN7MfMGEeMGIhNG]mOh64QHN8RHZ:RXV8QhF3
PGmmNgUgMWEeMGEfMgUkOGn1PhF7R8V:RXZ9RHN6Q8:0OG]jN7MfMGEeMWMhNWan
P8:4QXR9RXZ:RXV8QXB2P7ilNWQgMWEeMGIfN7UkOGn2Q8J7R8V:RXZ9R8N5Ph5o
OG]iMgIeMGEeMWMiNgeoPH>5QhR9RXZ:RHR7QXB2OgekNGQfMWEeMGIgN7YlOX22
Q8J8RHZ:RXZ9R8J4PX1nO7YhMgIeMGEfMgQjNgf0PXB6QhV9RXZ:RHR7QH>1Ogek
NGMfMGEeMGIgNG]mOh63QHN8RHZ:RXV8QhF4PGmmNgUhMWEeMGEfMgQjO7j0PXB6
R8V:RXZ:RHR6Q8:0OWajN7MfMGEeMWMhNWanP8:4QXN9RXZ:RXV8QXF3PGmlNWUg
MWEeMGEfN7UkOGn1PhF7R8V:RXZ9R8N5Ph5oOG]iN7IeMGEeMWMiNWanP8>5QXR9
RXZ:RXV7QXB2P7ilNWQgMWEeMGIgN7YlOX22Q8J7RHZ:RXZ9R8J5Ph5nO7YiMgIe
MGEeMWQiNgeoPH>5QhR9RXZ:RHR7QH>1OgekNGQfMGEeMGIgNGYlOX63QHJ8RHZ:
RXZ9QhJ4PX1nO7YhMgIeMGEfMgQjO7j0PXB6QhV:RXZ:RHR6QH>0OWajNGMfMGEe
MGIhNG]mOh63QHN8RHZ:RXV8QhF3PGmmNgUgMWEeMGEfMgUkO7n1PhF7R8V:RXZ:
RHN6Q8:0OW]jN7MfMGEeMWMhNWanP8:4QXR9RXZ:RXV8QXB2P7ilNWQgMWEeMGIf
N7UkOGn2Q8F7R8V:RXZ9R8N5Ph5oOG]iMgIeMGEeMWMiNgeoPH>5QhR9RXZ:RHV7
QXB2P7ekNWQgMWEeMGIgN7YlOX22Q8J8RHZ:RXZ9R8J4PX1nO7YhMgIeMGEfMgQi
Ngf0PXB6QhR9RXZ:RHR7QH>1OgekNGMfMGEeMGIgNG]mOh63QHN8RHZ:RXV8QhF4
PWmmNgUhMWIeMGEfMgQjO7j0PXB6R8V:RXZ:RHR6Q8:0OWajN7MfMGEeMWMhNW]m
P8:4QXN9RXZ:RXV8QhF3PGmmNgUgMWEeMGEfMgUkOGn1PhF7R8V:RXZ9R8N5Ph5o
OG]iN7IeMGEeMWMhNWanP8>4QXR9RXZ:RXV8QXB2P7ilNWQgMWEeMGIgN7YlOX22
Q8J7RHZ:RXZ9R8J5Ph5oO7YiMgIeMGEeMWQiNgeoPH>5QhR9RXZ:RHR7QH>1Ogek
NGQfMGEeMGIgNGYlOX63QHJ8RHZ:RXZ9QhJ4PX1nO7YhMgIeMGEfMgQjO7j0PXB6
QhV:RXZ:RHR6QH>1OWajNGMfMGEeMGIhNG]mOh63QHN8RHZ:RXV8QhF3PGmmNgUh
MWEeMGEfMgUjO7n1PhF6R8V:RXZ:RHN6Q8:0OWajN7MfMGEeMWMhNWanP8:4QXN9
RXZ:RXV8QXF3P7ilNWUgMWEeMGEfN7UkOGn1PhF7R8V:RXZ9R8N5Ph5oOG]iMgIe
MGEeMWMiNgeoPH>5QhR9RXZ:RXV7QXB2P7ikNWQgMWEeMGIgN7YlOX22Q8J8RHZ:
RXZ9R8J4PX1nO7YhMgIeMGEfMWQiNgeoPXB5QhR9RXZ:RHR7QH>1OgekNGMfMGEe
MGIgNG]mOh63QHN8RHZ:RXV9QhJ4PX1mNgUhMgIeMGEfMgQjO7j0PXB6R8V:RXZ:
RHR6Q8:0OWajN7MfMGEeMWMhNG]mP8:4QXN9RHZ:RXV8QhF3PGmmNgUgMWEeMGEf
MgUkOGn1PhF7R8V:RXZ9R8N5Q89oOG]iN7IfMGEeMWMhNWanP8:4QXR9RXZ:RXV8
QXB2P7ilNWQgMWEeMGIgN7YkOX22Q8J7RHZ:RXZ9R8N5Ph5oOG]iMgIeMGEeMWMi
NgeoPH>5QhR9RXZ:RHR7QH>1OgekNGQfMGEeMGIgNGYlOX23QHJ8RHZ:RXZ9QhJ4
PX1nO7YhMgIeMGEfMgQjO7j0PXB6QhV:RXZ:RHR6QH>1OWajNGMfMGEeMGIhNG]m
Oh63QHN8RHZ:RXV8QhF3PGmmNgUhMWEeMGEfMgUjO7j1PhF6R8V:RXZ:RHN6Q8:0
OWajN7MfMGEeMWMhNWanP8:4QXN9RXZ:RXV8QXF3PGilNWUgMWEeMGEfN7UkOGn1
PhF7R8V:RXZ9R8N5Ph5oOG]iN7IeMGEeMWMiNWaoPH>5QXR9RXZ:RXV7QXB2P7il
NWQgMWEeMGIgN7YlOX22Q8J8RHZ:RXZ9R8J4PX1nO7YhMgIeMGEeMWQiNgeoPHB5
QhR9RXZ:RHR7QH>1OgekNGMfMGEeMGIgNG]mOh63QHN8RHZ:RXV9QhJ4PX1mNgYh
MgIeMGEfMgQjO7j0PXB6R8V:RXZ:RHR6Q8:0OWajN7MfMGEeMWIhNG]mOh:4QXN8
RHZ:RXV8QhF3PGmmNgUgMWEeMGEfMgUkOGn1PhF7R8V:RXZ9R8N6Q89oOG]iN7If
MGEeMWMhNWanP8:4QXR9RXZ:RXV8QXB2P7ilNWQgMWEeMGIgN7YkOH22Q8J7RHV:
RXZ9R8N5Ph5oOG]iMgIeMGEeMWMiNgeoPH>5QhR9RXZ:RHR7QHB1OgekNGQfMGEe
MGIgN7YlOX22Q8J8RHZ:RXZ9R8J4PX1nO7YhMgIeMGEfMgQjO7j0PXB6QhV:RXZ:
RHR7QH>1OgakNGMfMGEeMGIhNG]mOh63QHN8RHZ:RXV8QhF3PGmmNgUhMWEeMGEf
MgUjO7j0PhF6R8V:RXZ:RHN6Q8:0OWajN7MfMGEeMWMhNWanP8:4QXN9RXZ:RXV8
QXF3PGilNWUgMWEeMGEfN7UkOGn1PhF7R8V:RXZ9R8N5Ph5oOG]iN7IeMGEeMWMi
NWanPH>5QXR9RXZ:RXV7QXB2P7ilNWQgMWEeMGIgN7YlOX22Q8J7RHZ:RXZ9R8J5
Ph1nO7YiMgIeMGEeMWQiNgeoPH>5QhR9RXZ:RHR7QH>1OgekNGQfMGEeMGIgNG]l
Oh63QHN8RHZ:RXZ9QhJ4PX1nO7YhMgIeMGEfMgQjO7j0PXB6R8V:RXZ:RHR6Q8:0
OWajN7MfMGEeMGIhNG]mOh64QHN8RHZ:RXV8QhF3PGmmNgUgMWEeMGEfMgUkOGn1
PhF7R8V:RXZ9RHN6Q8:0OG]jN7MfMGEeMWMhNWanP8:4QXR9RXZ:RXV8QXB2P7il
NWQgMWEeMGIfN7UkOGn2Q8J7R8V:RXZ9R8N5Ph5oOG]iMgIeMGEeMWMiNgeoPH>5
QhR9RXZ:RHR7QXB2OgekNGQfMWEeMGIgN7YlOX22Q8J8RHZ:RXZ9R8J4PX1nO7Yh
MgIeMGEfMgQjNgf0PXB6QhV9RXZ:RHR7QH>1OgekNGMfMGEeMGIgNG]mOh63QHN8
RHZ:RXV8QhF4PGmmNgUhMWEeMGEfMgQjO7j0PXB6R8V:RXZ:RHR6Q8:0OWajN7Mf
MGEeMWMhNWanP8:4QXN9RXZ:RXV8QXF3PGmlNWUgMWEeMGEfN7UkOGn1PhF7R8V:
RXZ9R8N5Ph5oOG]iP820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P7EeMWMi
Ngf0PXB6R8V:RXZ9R8J4PWmmNgUgMWEeMGIgNG]mP8:4QXR9RXZ:RHR6Q85oOGYh
MgIeMGEfN7UkOX22QHN8RHZ:RXV7QX>1OgajN7MfMGEeMWQjO7j0PhF7R8V:RXZ9
QhF3PGmlNWQgMGEeMGIhNWanPH>5QhR:RXZ:RHN5Ph5nO7YhMWEeMGEgN7YlOX63
QHN9RXZ:RHR7QH>0OWajN7IeMGEfMgQjO7n1PhJ7RHZ:RXV8QhF3P7ikNGQfMGEe
MWMhNWeoPHB6R8V:RXZ9R8J5PX1nNgUgMWEeMGIgNG]mOh:4QXR9RXZ:RHR6Q8:0
OG]iMgIeMGEfMgUkOGn2Q8J8RHZ:RXV8QXB2OgekNGMfMGEeMWMiNgf0PXB6R8V:
RXZ9R8J4PWmmNgUgMWEeMGIgNG]nP8:5QhR9RXZ:RHN6Q85oOGYhMgIeMGEfN7Ul
OX23QHN8RHZ:RXV7QH>1OgajN7MfMGEeMWQjO7j1PhF7R8Z:RXZ9QhF3PGilNWQf
MGEeMGIhNWanPH>5QhV:RXZ:R8N5Ph1nO7YhMWEeMGIgN7YlOh63QHN9RXZ:RHR7
QH>0OWaiN7IeMGEfMgQjOGn1Q8J7RHZ:RXV8QhF2P7ikNGMfMGEeMWMiNgeoPXB6
R8V:RXZ9R8J4PX1mNgUgMWEeMGIgNG]mOh:4QXR9RXZ:RHR6Q89oOG]iMgIeMGEf
MgUkOH22Q8J8RHZ:RXV8QXB2OgekNGMfMGEeMWMiNgj0PXF7R8V:RXZ9R8J4PGmm
NWQgMWEeMGIhNG]nP8>5QhR9RXZ:RHN6Ph5oO7YhMgIeMGEfN7YlOX23QHN8RHZ:
RXV7QH>1OWajN7MeMGEeMWQjO7j1PhF7RHZ:RXZ8QhF3PGilNWQfMGEeMWMhNWao
PH>5QhV:RXZ9R8N5Ph1nO7UhMWEeMGIgN7YlOh64QXN9RXZ:RHR7QH:0OW]iMgIe
MGEfMgUjOGn1Q8J8RHZ:RXV8QXB2P7ekNGMfMGEeMWMiNgeoPXB6R8V:RXZ9R8J4
PX1mNgUgMWEeMGIgNG]mP8:4QXR9RXZ:RHR6Q89oOG]iMgIeMGEfMgUkOH22Q8J8
RHZ:RXV8QXB1OgejN7MfMGEeMWQiNgj0PXF7R8V:RXZ9QhJ3PGmlNWQgMWEeMGIh
NWanP8>5QhR9RXZ:RHN5Ph5oO7YhMgEeMGEfN7YlOX63QHN9RXZ:RXV7QH>1OWaj
N7IeMGEeMgQjO7j1PhF7RHZ:RXV8QhF3P7ilNWQfMGEeMWMhNWaoPH>6QhV:RXZ9
R8N5PX1nNgUhMWEeMGIgN7YmOh64QXR9RXZ:RHR6Q8:0OG]iMgIeMGEfMgUkOGn2
Q8J8RHZ:RXV8QXB2P7ekNGMfMGEeMWMiNgf0PXB6R8V:RXZ9R8J4PWmmNgUgMWEe
MGIgNG]mP8:4QXR9RXZ:RHR6Q85oOGYiMgIeMGEfMgUkOX22QHN8RHZ:RXV7QXB1
OgajN7MfMGEeMWQiO7j0PhF7R8V:RXZ9QhF3PGmlNWQgMWEeMGIhNWanPH>5QhR:
RXZ:RHN5Ph5nO7YhMWEeMGEgN7YlOX63QHN9RXZ:RXR7QH>0OWajN7IeMGEfMgQj
O7n1PhJ7RHZ:RXV8QhF3P7ikNGQfMGEeMWMhNWeoPHB6QhV:RXZ9R8N5PX1nNgUg
MWEeMGIgNG]mOh:4QXR9RXZ:RHR6Q8:0OG]iMgIeMGEfMgUkOGn2Q8J8RHZ:RXV8
QXB2OgekNGMfMGEeMWMiNgf0PXB6R8V:RXZ9R8J4PWmmNgUgMWEeMGIgNG]nP8:5
QhR9RXZ:RHN6Q85oOGYhMgIeMGEfN7UlOX23QHN8RHZ:RXV7QH>1OgajN7MfMGEe
MWQjO7j0PhF7R8Z:RXZ9QhF3PGilNWQfMGEeMGIhNWanPH>5QhV:RXZ:R8N5Ph5n
O7YhMWEeMGIgN7YlOh63QHN9RXZ:RHR7QH>0OWaiN7IeMGEfMgQjO7n1Q8J7RHZ:
RXV8QhF2P7ikNGMfMGEeMWMiNgeoPHB6R8V:RXZ9R8J4PX1mNgUgMWEeMGIgNG]m
Oh:4QXR9RXZ:RHR6Q8:0OG]iMgIeMGEfMgUkOH22Q8J8RHZ:RXV8QXB2OgekNGMf
MGEeMWMiNgf0PXB6R8V:RXZ9R8J4PGmmNWQgMWEeMGIhNG]nP8>5QhR9RXZ:RHN6
Ph5oO7YhMgIeMGEfN7YlOX23QHN8RHZ:RXV7QH>1OWajN7MeMGEeMWQjO7j1PhF7
RHZ:RXZ9QhF3PGilNWQfMGEeMGMhNWaoPH>5QhV:RXZ9R8N5Ph1nO7YhMWEeMGIg
N7YlOh63QXN9RXZ:RHR7QH:0OW]iN7IeMGEfMgQjOGn1Q8J8RHZ:RXV8QXB2P7ek
NGMfMGEeMWMiNgeoPXB6R8V:RXZ9R8J4PX1mNgUgMWEeMGIgNG]mP8:4QXR9RXZ:
RHR6Q89oOG]iMgIeMGEfMgUkOH22Q8J8RHZ:RXV8QXB1OgejN7MfMGEeMWQiNgj0
PXF7R8V:RXZ9QhJ4PGmlNWQgMWEeMGIhNGanP8>5QhR9RXZ:RHN5Ph5oO7YhMgEe
MGEfN7YlOX63QHN8RXZ:RXV7QH>1OWajN7IeMGEeMgQjO7j1PhF7RHZ:RXV8QhF3
P7ilNWQfMGEeMWMhNWaoPH>6QhV:RXZ9R8N5Ph1nNgUhMWEeMGIgN7YmOh64QXR9
RXZ:RHR6QH:0OW]iMgIeMGEfMgUkOGn2Q8J8RHZ:RXV8QXB2P7ekNGMfMGEeMWMi
NgeoPXB6R8V:RXZ9R8J4PWmmNgUgMWEeMGIgNG]mP8:4QXR9RXZ:RHR6Q89oOG]i
MgIeMGEfMgUkOX22QHN8RHZ:RXV7QXB1OgejN7MfMGEeMWQiO7j0PhF7R8V:RXZ9
QhF3PGmlNWQgMWEeMGIhNWanPH>5QhR:RXZ:RHN5Ph5nO7YhMWEeMGEfN7YlOX63
QHN9RXZ:RXR7QH>1OWajN7IeMGEfMgQjO7n1PhF7RHZ:RXV8QhF3P7ilNGQfMGEe
MWMhNWeoPHB6QhV:RXZ9R8N5PX1nNgUgMWEeMGIgNG]mOh:4QXR9RXZ:RHR6Q8:0
OG]iMgIeMGEfMgUkOGn2Q8J8RHZ:RXV8QXB2OgekNGMfMGEeMWMiNgf0PXB6R8V:
RXZ9R8J4PWmmNgUgMWEeMGIgNG]nP8:5QXR9RXZ:RHR6Q85oOGYhMgIeMGEfN7Uk
OX23QHN8RHZ:RXV7QX>1OgajN7MfMGEeMWQjO7j0PhF7R8V:RXZ9QhF3PGilNWQg
MGEeMGIhNWanPH>5QhV:RXZ:R8N5Ph5nO7YhMWEeMGEgN7YlOh63QHN9RXZ:RHR7
QH>0OWaiN7IeMGEfMgQjO7n1Q8J7RHZ:RXV8QhF2P7ikNGQfMGEeMWMhNWeoPHB6
R8V:RXZ9R8J4PX1mNgUgMWEeMGIgNG]mOh:4QXR9RXZ:RHR6Q8:0OG]iMgIeMGEf
MgUkOH22Q8J8RHZ:RXV8QXB2OgekNGMfMGEeMWMiNgf0PXB6R8V:RXZ9R8J4PGmm
NWQgMWEeMGIhNG]nP8:5QhR9RXZ:RHN6Ph5oO7YhMgIeMGEfN7YlOX23QHN8RHZ:
RXV7QH>1OgajN7MeMGEeMWQjO7j1PhF7RHZ:RXZ9QhF3PGilNWQfMGEeMGMhNWan
PH>5QhV:RXZ9R8N5Ph1nO7YhMWEeMGIgN7YlOh63QXN9RXZ:RHR7QH>0OW]iN7Ie
MGEfMgQjOGn1Q8J8RHZ:RXV8QXB2P7ekNGMfMGEeMWMiNgeoPXB6R8V:RXZ9R8J4
PX1mNgUgMWEeMGIgNG]mP8:4QXR9RXZ:RHR6Q89oOG]iMgIeMGEfMgUkOH22Q8J8
RHZ:RXV8QXB1OgekNGMfMGEeMWMiNgj0PXF7R8V:RXZ9QhJ4PGmlNWQgMWEeMGIh
NGanP8>5QhR9RXZ:RHN5Ph5oO7YhMgIeMGEfN7YlOX63QHN8RXZ:RXV7QH>1OWaj
N7IeMGEeMWQjO7j1PhF7RHZ:RXZ8QhF3P7ilNWQfMGEeMWMhNWaoPH>5QhV:RXZ9
R8N5Ph1nO7UhMWEeMGIgN7YmOh64QXN9RXZ:RHR7QH:0OW]iMgIeMGEfMgUkOGn2
Q8J8RHZ:RXV8QXB2P7ekNGMfMGEeMWMiNgeoPXB6R8V:RXZ9R8J4PWmmNgUgMWEe
MGIgNG]mP8:4QXR9RXZ:RHR6Q89oOG]iMgIeMGEfMgUkOX22QHN8RHZ:RXV7QXB1
OgejN7MfMGEeMWQiNgj0PhF7R8V:RXZ9QhJ3PGmlNWQgMWEeMGIhNWanP8>5QhR:
RXZ:RHN5Ph5nO7YhMgEeMGEfN7YlOX63QHN9RXZ:RXR7QH>1OWajN7IeMGEfMgQj
O7n1PhF7RHZ:RXV8QhF3P7ilNGQfMGEeMWMhNWaoPHB6QhV:RXZ9R8N5PX1nNgUg
MWEeMGIgNGYmOh64QXR9RXZ:RHR6Q8:0OG]iMgIeMGEfMgUkOGn2Q8J8RHZ:RXV8
QXB2P7ekNGMfMGEeMWMiNgf0PXB6R8V:RXZ9R8J4PWmmNgUgMWEeMGIgNG]mP8:4
QXR9RXZ:RHR6Q85oOGYhMgIeMGEfN7UkOX22QHN8RHZ:RXV7QX>1OgajN7MfMGEe
MWQjO7j0PhF7R8V:RXZ9QhF3PGilNWQgMGEeMGIhNWanPH>5QhV:RXZ:RHN5Ph5n
O7YhMWEeMGEgN7YlOh63QHN9RXZ:RHR7QH>0OWajN7IeMGEfMgQjO7n1PhJ7RHZ:
RXV8QhF2P7ikNGQfMGEeMWMhNWeoPHB6R8V:RXZ9R8J4PX1mNgUgMWEeMGIgNG]m
Oh:4QXR9RXZ:RHR6Q8:0OG]iMgIeMGEfMgUkOH22Q8J8RHZ:RXV8QXB2OgekNGMf
MGEeMWMiNgf0PXB6R8V:RXZ9R8J4PGmmNWUgMWEeMGIgNG]nP8:5QhR9RXZ:RHN6
Q85oO7YhMgIeMGEfN7UlOX23QHN8RHZ:RXV7QH>1OgajN7MfMGEeMWQjO7j1PhF7
R8Z:RXZ9QhF3PGilNWQfMGEeMGMhNWanPH>5QhV:RXZ9R8N5Ph1nO7YhMWEeMGIg
N7YlOh63QXN9RXZ:RHR7QH>0OW]iN7IeMGEfMgQjOGn1Q8J8RHZ:RXV8QhF2P7ik
NGMfMGEeMWMiNgeoPXB6R8V:RXZ9R8J4PX1mNgUgMWEeMGIgNG]mOh:4QXR9RXZ:
RHR6Q89oOG]iMgIeMGEfMgUkOH22Q8J8RHZ:RXV8QXB2OgekNGMfMGEeMWMiNgj0
PXF7R8V:RXZ9QhJ4PGmmNWQgMWEeMGIhNGanP8>5QhR9RXZ:RHN5Ph5oO7YhMgIe
MGEfN7YlOX23QHN8RXZ:RXV7QH>1OWajN7IeMGEeMWQjO7j1PhF7RHZ:RXZ8QhF3
PGilNWQfMGEeMWMhNWaoPH>5QhV:RXZ9R8N5Ph1nO7UhMWEeMGIgN7YmOh64QXN9
RXZ:RHR7QH:0OW]iP820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P8Z:RXV8
QX>1OW]iMgIeMGEgN7]mP8:5QhV:RXZ9QhF3P7ikNGMfMGEfMgUkOX23QHN9RXZ:
RHN5Ph1mNgQgMGEeMWMiNgj1PhJ8RHZ:RXV7QH:0OGYhMWEeMGIgNGanPHB6R8V:
RXZ8QhB2OgejN7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQfMGEeMWQjO7n2Q8N8
RXZ:RHR6Q85nO7UgMWEeMGIhNWeoPXF7RHZ:RXV8QX>1OW]iMgIeMGEgN7]mP8>5
QhV:RXZ9QhF3P7ikNGMfMGEfMgUkOX23QHN9RXZ:RHN5Ph1mNgQgMGEeMWMiNgj1
PhJ8RHZ:RXV7QH9oOGYhMWEeMGIgNGanPHB6R8V:RXZ8QhB2OgajN7IeMGEfN7Yl
Oh64QXR9RXZ9R8J4PGmlNWQfMGEeMWQjO7n2Q8N8RXZ:RHR6Q85nO7UgMWEeMGIh
NWf0PXF7RHZ:RXV8QX>1OW]iMgIeMGEgN7]mP8>5QhV:RXZ9QhF3P7ikNGMfMGEf
MgUkOX23QHN9RXZ:RHN5PX1mNgQgMGEeMWMiNgj1PhJ8RHZ:RXV7QH9oOGYhMWEe
MGIgNGanPHB6R8V:RXZ8QhB2OgajN7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQf
MGEeMWQjOGn2Q8N8RXZ:RHR6Q85nO7UgMWEeMGMhNWf0PXF7RHZ:RXV8QX>1OW]i
MgIeMGEgNG]mP8>5QhV:RXZ9QhF3P7ekNGMfMGEfMgUkOX23QHN9RXZ:RHN5PX1m
NgQgMGEeMWMiNgj1PhJ8RHZ:RXR7QH9oOGYhMWEeMGIgNGanPHB6R8V:RXZ8QXB2
OgajN7IeMGEfN7YlOh:4QXR9RXZ9R8J4PGmlNWQfMGEeMWQjOGn2Q8N8RXZ:RHR6
Q85nO7UgMWEeMGMhNWf0PXF7RHZ:RXV8QX>1OW]iMgIeMGIgNG]mP8>5QhV:RXZ9
QhF3P7ekNGMfMGEfMgUkOX23QHN9RXZ:RHN5PX1mNgQgMGEeMWMiO7j1PhJ8RHZ:
RXR7QH9oOGYhMWEeMGIgNGaoPHB6R8V:RXV8QXB2OgajN7IeMGEfN7YlOh:4QXR9
RXZ9R8J4PGmlNWQfMGEeMWQjOGn2Q8N8RXZ:RHR6Ph5nO7UgMWEeMGMhNWf0PXF7
RHZ:RXV8QH>0OW]iMgIeMGIgNG]mP8>5QhV:RXZ9QhF3P7ekNGMfMGEfMgUkOX23
QHR9RXZ:RHN5PX1mNWQgMGEeMWMiO7j1PhJ8RHZ:RXR7Q89oOGYhMWEeMGIhNWao
PHB6R8V:RXV8QXB2OgajN7IeMGEfN7YlOh:4QXR9RXZ9R8J4PGmlNGMfMGEeMWQj
OGn2QHN8RXZ:RHR6Ph5nO7UgMWEeMGMhNgf0PXF7RHZ:RXV7QH>0OW]iMgIeMGIg
NG]mP8>5QhV:RXZ9QhF3P7ekNGMfMGEfMgUkOX63QXR9RXZ:RHN5PX1mNWQgMGEe
MWMiO7j1Q8J8RHZ:RXR7Q89oOGYhMWEeMGIhNWaoPHB6R8V:RXV8QXB2OgajN7Ie
MGEfN7YlOh:4QXR:RXZ9R8J4PGilNGMfMGEeMWQjOGn2QHN8RXZ:RHR6Ph5nNgUg
MWEeMGMhNgf0PXF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]mP8>5QhV:RXZ9QhF3P7ek
NGMeMGEfMgUkOX63QXR9RXZ:RHN5PX1mNWQgMGEeMWMiO7j1Q8J8RHZ:RXR7Q89o
OGYhMWEeMGIhNWaoPHB6R8V:RXV8QXB1OgajN7IeMGEfN7YlOh:4QhR:RXZ9R8J4
PGilNGMfMGEeMWQjOGn2QHN9RXZ:RHR6Ph5nNgUgMWEeMGMhNgf0PXF7RHZ:RXV7
QH>0OW]iMgIeMGIgNG]nP8>5QhV:RXZ9QhF3P7ekN7MeMGEfMgUkOX63QXR9RXZ:
RHN5PX1mNWQfMGEeMWMiO7j1Q8J8RHZ:RXR7Q89oO7YhMWEeMGIhNWaoPHB6R8V:
RXV8QXB1OgajN7IeMGEfN7YlOh:4QhR:RXZ9R8J4PGilNGMfMGEeMWQjOH22QHN9
RXZ:RHR6Ph5nNgUgMWEeMGMhNgf0PhF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]nP8>5
QhV:RXZ9QhF3P7ekN7MeMGEfMgUkOX63QXR9RXZ:RHN5PWmmNWQfMGEeMWMiO7j1
Q8J8RHZ:RXR7Q89oO7YhMWEeMGIhNWaoPHB6R8V:RXV8QXB1OgajN7IeMGEfN7Ym
Oh:4QhR:RXZ9R8J4PGilNGMfMGEeMWQjOH22QHN9RXZ:RHR6Ph5nNgUgMWEeMGMh
Ngf0PhF7RHZ:RXV7QH>0OW]iMgIeMGIgNG]nP8>5QhV:RXZ9QhF2P7ekN7MeMGEf
MgUkOX63QXR9RXZ:R8N5PWmmNWQfMGEeMWMiO7j1Q8J8RHZ:RXR6Q89oO7YhMWEe
MGIhNWaoPXB6R8V:RXV8QXB1OgajN7IeMGEfN7YmOh:4QhR:RXZ9R8J4PGilNGMf
MGEeMgQjOH22QHN9RXZ:RHR6Ph5nNgUgMWEeMGMiNgf0PhF7RHZ:RXV7QH>0OG]i
MgIeMGIgNG]nP8>5QhV:RXZ9QhF2P7ekN7MeMGEfMgUkOX63QXR9RXZ:R8N5PWmm
NWQfMGEeMWMiO7j1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8V:RXV8QXB1
OgajN7IeMGEfN7YmOh:4QhR:RXZ9R8J3PGilNGMfMGEeMgQjOH22QHN9RXZ:RHR6
Ph1nNgUgMWEeMWMiNgf0PhF7RHZ:RXV7QH>0OG]iMgIeMGIgNG]nP8>5QhV:RXZ9
QhF2P7ekN7MeMGEfMgUlOX63QXR9RXZ:R8N5PWmmNWQfMGEeMWMjO7n1Q8J8RHZ:
RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8V:RXV8QXB1OgajMgIeMGEfN7YmOh:5QhR:
RXZ9R8J3PGilNGMfMGEeMgQkOH22QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgf0PhF7
RHZ:RXV7QH>0OG]iMgIeMGIgNG]nP8>6R8V:RXZ9QhF2P7ejN7MeMGEfMgUlOX63
QXR9RXZ:R8N4PWmmNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWao
PXB6R8V:RXV8QXB1OWaiMgIeMGEfN7YmOh:5QhR:RXZ9R8J3PGikNGMfMGEeMgQk
OH22QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgf0PhF7RHZ:RXV7QH>0OG]iMgEeMGIg
NG]nPH>6R8V:RXZ9QhF2P7ejN7MeMGEfMgUlOX64QXR9RXZ:R8N4PWmmNWQfMGEe
MWQjO7n1Q8J8RHZ:RHR6Q89oO7YhMWEeMGIhNWaoPXB6R8Z:RXV8QXB1OWaiMgIe
MGEfN7YmOh:5QhR:RXZ9R8J3PGikNGMfMGEeMgQkOH22QHN9RXZ:RHN5Ph1nNgUg
MWEeMWMiNgj0PhF7RHZ:RXV7QH>0OG]hMgEeMGIgNG]nPH>6R8V:RXZ9QhF2P7ej
N7IeMGEfMgUlOX64QXR9RXZ:R8N4PWmmNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q85o
O7YhMWEeMGIhNWaoPXB7R8Z:RXV8QXB1OWaiMgIeMGEfN7YmOh:5QhV:RXZ9R8J3
PGikNGMfMGEeMgQkOH23QHN9RXZ:RHN5Ph1nNgUgMWEeMWMiNgj0PhF7RHZ:RXV7
QH>0OG]hMgEeMGIgNG]nPH>6R8V:RXZ9QhF2OgejN7IeMGEfMgUlOX64QXR9RXZ:
R8N4PWmlNWQfMGEeMWQjO7n1Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWaoPXB7R8Z:
RXV8QXB1OWaiMgIeMGEfN7YmP8:5QhV:RXZ9R8J3PGikNGMfMGEeMgQkOH23QHN9
RXZ:RHN5Ph1nNgUgMWEeMWMiNgj0PhF7RHZ:RXV7QH:0OG]hMgEeMGIgNG]nPH>6
R8V:RXZ9QhF2OgejN7IeMGEfMgUlOX64QXR9RXZ:R8N4PWmlNWQfMGEeMWQjO7n1
Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWeoPXB7R8Z:RXV8QXB1OWaiMgIeMGEgN7Ym
P8:5QhV:RXZ9R8J3PGikNGMfMGEeMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMi
Ngj0PhF7RHZ:RXV7QH:0OG]hMgEeMGIgNG]nPH>6R8V:RXZ8QhF2OgejN7IeMGEf
MgUlOX64QXR9RXZ:R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RHZ:RHR6Q85oO7YhMWEe
MGIhNWeoPXB7R8Z:RXV8QXB1OWaiMgIeMGEgN7YmP8:5QhV:RXZ9R8J3PGikNGMf
MGEfMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMiNgj0PhF7RHZ:RXV7QH:0OG]h
MgEeMGIgNGanPH>6R8V:RXZ8QhF2OgejN7IeMGEfMgUlOh64QXR9RXZ9R8J4PWml
NWQfMGEeMWQjO7n2Q8J8RHZ:RHR6Q85oO7YhMWEeMGIhNWeoPXB7R8Z:RXV8QX>1
OWaiMgIeMGEgN7YmP8:5QhV:RXZ9R8F3P7ikNGMfMGEfMgUkOH23QHN9RXZ:RHN5
Ph1mNgUgMWEeMWMiNgj0PhF8RHZ:RXV7QH:0OGYhMgEeMGIgNGanPH>6R8V:RXZ8
QhB2OgejN7IeMGEfN7YlOh64QXR9RXZ9R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RHZ:
RHR6Q85oO7UgMWEeMGIhNWeoPXF7R8Z:RXV8QX>1OWaiMgIeMGEgN7]mP8:5QhV:
RXZ9QhF3P7ikNGMfMGEfMgUkOH23QHN9RXZ:RHN5Ph1mNgUgMWEeMWMiNgj1PhJ8
RHZ:RXV7QH:0OGYhMgEeMGIgNGanPHB6R8V:RXZ8QhB2OgejN7IeMGEfN7YlOh64
QXR9RXZ9R8J4PWmlNWQfMGEeMWQjO7n2Q8J8RXZ:RHR6Q85nO7UgMWEeMGIhNWeo
PXF7R8Z:RXV8QX>1OW]iMgIeMGEgN7]mP8:5QhV:RXZ9QhF3P7ikNGMfMGEfMgUk
OH23QHN9RXZ:RHN5Ph1mNgUgMGEeMWMiNgj1PhJ8RHZ:RXV7QH:0OGYhMgEeMGIg
NGanPHB6R8V:RXZ8QhB2OgejN7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQfMGEe
MWQjO7n2Q8N8RXZ:RHR6Q85nO7UgMWEeMGIhNWeoPXF7RHZ:RXV8QX>1OW]iMgIe
MGEgN7]mP8:5QhV:RXZ9QhF3P7ikNGMfMGEfMgUkOX23QHN9RXZ:RHN5Ph1mNgQg
MGEeMWMiNgj1PhJ8RHZ:RXV7QH:0OGYhMWEeMGIgNGanPHB6R8V:RXZ8QhB2Ogaj
N7IeMGEfN7YlOh64QXR9RXZ9R8J4PGmlNWQfMGEeMWQjO7n2Q8N8RXZ:RHR6Q85n
O7UgMWEeMGIhNWf0P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P80\>"]},
  ImageCacheContents->"Sound"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Play[
      Sin[x\ Sin[3000 \((Exp[x]\ \  + \ Sin[x]/x)\)]], {x, \(-5\), 
        5}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 81920 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003oool0003o
o`0004;o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX0oooonfYeoookJS7o00001_oonfX>o`0000gooo]Z1_l00008oookJPGo00001ooonfX5o`0000Co
oo]Z1?l00005oookJP?o00001OoonfX3o`0000?ooo]Z0_l00004oookJP;o00000_oonfX4o`000004
oookJ_l0003o0000o`0000;ooo]Z0_l00002oookJP;o00000_oonfX9o`000003oookJ_l0003o0000
00Ko000000?ooo]Zo`000?l000002_l00001oookJP7o000000000ol0003ooo]ZoookJP3ooookJVco
oo]ZD?l0000:oookJPWo00001OoonfX7o`0000Kooo]Z1Ol00004oookJPCo00001OoonfX3o`0000Co
oo]Z1?l00002oookJPCo00000_oonfX3o`0000;ooo]Z1?l000000ooonf[o0000o`00000Do`000003
oookJ_l0003o000001?o00000OoonfX1o`00000000?o0000oookJ_oonfX0oooonfYUoookJR3o0000
00?ooo]Zo`000?l00000=Ol00008oookJP_o00000ooonfX9o`0000Cooo]Z1?l000000ooonf[o0000
o`000002oookJPKo00000ooonfX5o`0000;ooo]Z1Ol00002oookJP[o000000?ooo]Zo`000?l00000
0_l000000ooonf[o0000o`00000Yo`0000;ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZG?oo
nfXYo`000003oookJ_l0003o000002Wo000000?ooo]Zo`000?l000002_l00006oookJPCo000000?o
oo]Zo`000?l000004_l00002oookJPSo00000_oonfX7o`0000;ooo]Z1Ol00002oookJT?o00000Ooo
nfX1o`00000000?o0000oookJ_oonfX0oooonfYCoookJS;o000000?ooo]Zo`000?l00000=ol00004
oookJRCo00000_oonfX7o`000003oookJ_l0003o000004So00000_oonfX1o`00000000?o0000oook
J_oonfX0oooonfY8oookJSgo000000?ooo]Zo`000?l00000>?l00002oookJW[o00000OoonfX1o`00
000000?o0000oookJ_oonfX0@OoonfZSo`0005?ooo]ZCOl000000ooonf[o0000o`00000?o`000003
oookJ_l0003o000000Co000000Gooo]Zo`000?l0003o0000oookJP0No`000003oookJ_l0003o0000
07So00000OoonfX1o`00000000?o0000oookJ_l00000ool0001Go`000003oookJ_l0003o000004_o
000000?ooo]Zo`000?l00000U?l00001oookJP7o000000000ol0003ooo]Zo`00000Do`000003oook
J_l0003o000000;ooo]Z0ol000000ooonf[o0000o`00003oo`0008So000000?ooo]Zo`000?l00000
T_l00001oookJP7o000000000ol0003ooo]Zo`000013oookJYoo0000E_oonfXNo`000003oookJ_l0
003o000006Oo000000?ooo]Zo`000?l00000N?l00001oookJP7o000000000ol0003ooo]ZoookJP3o
oookJTWooo]ZB?l000000ooonf[o0000o`00000/o`0000;ooo]ZN_l00001oookJP7o000000000ol0
003ooo]ZoookJP3ooookJUCooo]ZB?l000000ooonf[o0000o`00000Po`0000Cooo]Z9?l00002oook
JPOo000000?ooo]Zo`000?l00000BOl00001oookJP7o000000000ol0003ooo]ZoookJP3ooookJUgo
oo]ZHOl00006oookJPgo000000?ooo]Zo`000?l000002Ol00002oookJPSo00000_oonfX7o`0000;o
oo]Z1Ol00002oookJPGo000000?ooo]Zo`000?l00000>_l00002oookJP7o000000000ol0003ooo]Z
oookJP3ooookJVCooo]ZFOl00008oookJP_o00000ooonfX9o`0000Cooo]Z1ol00002oookJPKo0000
0ooonfX5o`0000;ooo]Z1Ol00002oookJPoo000000?ooo]Zo`000?l00000:_l00001oookJP7o0000
00000ol0003ooo]ZoookJP3ooookJVcooo]ZD?l0000:oookJPWo00001OoonfX7o`0000Kooo]Z1Ol0
0004oookJPCo00001OoonfX4o`0000?ooo]Z1?l00002oookJPCo00000_oonfX3o`0000;ooo]Z1?l0
00000ooonf[o0000o`000009o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000004ol0
0001oookJP7o000000000ol0003ooo]ZoookJP3ooookJWGooo]Z<?l00008oookJPgo00003OoonfX6
o`0000Sooo]Z1Ol00007oookJPCo00001OoonfX3o`0000Kooo]Z0ol00005oookJP?o00000_oonfX2
o`0000Gooo]Z0_l00002oookJP?o00000_oonfX3o`0000;ooo]Z0_l00002oookJP;o000000Gooo]Z
o`000?l0003o0000oookJP06o`000003oookJ_l0003o000001?o00000OoonfX1o`00000000?o0000
oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000?oo0000ool00012o`00000000?o0000oookJ_oo
nfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o000000ko000000Gooo]Zo`000?l0003o
0000oookJP03o`0000Sooo]Z00Co0000oookJ_l0003ooo]Z0_l000000ooonf[o0000o`00001To`00
0003oookJ_l0003o000003co0000YOoonfYko`000003oookJ_l0003o000001Co000000?ooo]Zo`00
0?l000004_l000000ooonf[o0000o`00000Ro`00007ooo]Z0Ol000000003o`000?oonf[o000000;o
000000?ooo]Zo`000?l000002Ol000001Ooonf[o0000o`000?l0003ooo]Z00?o00002?oonfX3o`00
0004oookJ_l0003o0000oookJPGo000000?ooo]Zo`000?l000001Ol000000ooonf[o0000oookJP06
o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?oonfX01Ol000000ooonf[o0000o`000003
o`000004oookJ_l0003o0000oookJPKo000000Cooo]Zo`000?l0003ooo]Z1?l000000ooonf[o0000
o`00000>o`000003oookJ_l0003o000000Go000000Cooo]Zo`000?l0003ooo]Z1_l000000ooonf[o
0000o`00000>o`0000;ooo]Z1Ol000000ooonf[o0000o`000004o`000003oookJ_l0003o000002So
0000WooonfX]o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000003?l000000ooonf[o
0000o`000004o`000003oookJ_l0003o000000Go000000Gooo]Zo`000?l0003o0000oookJP08o`00
0003oookJ_l0003ooo]Z00?o000000?ooo]Zo`000?l000002?l000000ooonf[o0000oookJP08o`00
0005oookJ_l0003o0000o`000?oonfX00ol000001Ooonf[o0000oookJ_l0003ooo]Z00Co000000?o
oo]Zo`000?l000000_oonfX5o`0000;ooo]Z00?o0000oookJ_l000000ol000000ooonf[o0000o`00
0005o`0000;ooo]Z0_l000000ooonf[o0000o`00000Oo`00007ooo]Z0Ol000000003o`000?oonf[o
oo]Z00Oo000000?ooo]Zo`000?l000001?l000001Ooonf[o0000o`000?l0003ooo]Z00?o00002?oo
nfX3o`000003oookJ_l0003o000000;ooo]Z0ol000001_oonf[o0000o`000?l0003ooo]Zo`0000;o
oo]Z0_l000000ooonf[o0000o`000004o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?oo
nfX00_l000000ooonf[o0000o`000007o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l0
00000_l000000ooonf[o0000o`000002o`000004oookJ_l0003o0000oookJPSo000000Cooo]Zo`00
0?l0003o00000ooonfX6o`0000;ooo]Z00Ko0000oookJ_l0003ooo]Zo`000?oonfX2o`000004oook
J_l0003ooo]ZoookJPSo000000Gooo]Zo`000?l0003ooo]Zo`000002oookJPGo000000?ooo]Zo`00
0?l000000_l000000ooonf[o0000o`00000Oo`000003oookJ_l0003o000000_o0000V_oonfX=o`00
0004oookJ_l0003o0000oookJQ7o000000?ooo]Zo`000?l000002?l000000ooonf[o0000o`00000=
o`0000;ooo]Z2_l000000ooonf[o0000o`000004o`0000;ooo]Z00?o0000oookJ_l000000_oonfX0
1?l0003ooo]Zo`000?oonfX2o`000003oookJ_l0003o000000?o00000_oonfX00ol0003ooo]Zo`00
0008o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000_l00002oookJP;o000000?o
oo]Zo`000?l000000_l00002oookJP06o`000?oonf[o0000oookJ_l0003ooo]Z0_l00002oookJPCo
00000ooonfX01?l0003ooo]Zo`000?l00004oookJP06o`000?oonf[o0000oookJ_l0003ooo]Z0_l0
00001?oonf[o0000oookJ_oonfX2o`0000?ooo]Z00Co0000oookJ_l0003ooo]Z1Ol000000ooonf[o
0000o`000006o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000001ol00001oookJP7o
000000000ol0003ooo]Zo`000003o`000003oookJ_l0003ooo]Z00Go000000Cooo]Zo`000?l0003o
oo]Z0ol000001?oonf[o0000o`000?l00007oookJPCo000000Kooo]Zo`000?l0003ooo]Zo`000?oo
nfX3o`000005oookJ_l0003ooo]Zo`000?oonfX02?l00002oookJP;o000000?ooo]Zo`000?oonfX0
1_l00002oookJP05o`000?oonf[o0000oookJ_l000000ooonfX00ol0003ooo]Zo`000002o`0000;o
oo]Z1?l000000ooonf[o0000o`000004o`000005oookJ_l0003o0000o`000?oonfX01Ol00002oook
JPOo000000?ooo]Zo`000?oonfX01_l00002oookJPCo00000ooonfX9o`000003oookJ_l0003o0000
00;o000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`00000:o`0000;ooo]Z3_l000001?oo
nf[o0000o`000?oonfX4o`000003oookJ_l0003o000000co0000UooonfXAo`000003oookJ_l0003o
oo]Z00;ooo]Z9Ol000002?oonf[o0000o`000?oonf[o0000oookJ_l0003ooo]Z0_l000000ooonf[o
0000o`000003o`000003oookJ_l0003o000000;o00000ooonfX:o`000003oookJ_l0003o000000;o
oo]Z00Co0000oookJ_oonf[ooo]Z1ol000000ooonf[o0000oookJP02oookJPGo000000?ooo]Zo`00
0?l000000_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o000000?ooo]Zo`000?l000001?l00002
oookJP?o00000_oonfX00ol0003ooo]ZoookJP03o`000005oookJ_l0003ooo]Zo`000?oonfX00_l0
00000ooonf[o0000o`000003o`000004oookJ_l0003o0000oookJP?o00001?oonfX2o`0000;ooo]Z
2Ol000000ooonf[o0000o`000002o`000003oookJ_l0003ooo]Z00Go000000Cooo]Zo`000?l0003o
oo]Z1_l00001oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000Co
0000oookJ_l0003o00000_oonfX2o`000003oookJ_l0003o000000?o000000Cooo]Zo`000?l0003o
oo]Z0ol000001?oonf[o0000o`000?l00006oookJP;o000000Cooo]Zo`000?l0003ooo]Z0_l00002
oookJP05o`000?oonf[ooo]Zo`000?oonfX00ol000001_oonf[o0000oookJ_oonf[o0000oookJP;o
00000_oonfX01ol0003ooo]ZoookJ_l0003ooo]Zo`000?oonfX00_l000000ooonf[o0000oookJP03
o`000003oookJ_l0003ooo]Z00;ooo]Z00Go0000oookJ_l0003o0000oookJP02o`000003oookJ_l0
003ooo]Z00;o00000_oonfX2o`000003oookJ_l0003o000000?ooo]Z0ol000001?oonf[o0000o`00
0?oonfX4o`000003oookJ_l0003ooo]Z00So000000Gooo]Zo`000?l0003o0000oookJP06o`000003
oookJ_l0003o000000Co00000_oonfX5o`000003oookJ_l0003o000000oo000000Oooo]Zo`000?l0
003ooo]Zo`000?oonf[o000000;ooo]Z3ol000001Ooonf[o0000o`000?l0003ooo]Z00;o00000_oo
nfX?o`0009?ooo]Z2Ol000001Ooonf[o0000oookJ_l0003ooo]Z00?o00000_oonfX01?l0003ooo]Z
o`000?l00002oookJPSo000000?ooo]Zo`000?l000005Ol000001ooonf[o0000o`000?l0003ooo]Z
o`000?oonfX01Ol000000ooonf[o0000o`000002oookJP;o000000?ooo]Zo`000?l000001Ol00000
1_oonf[o0000o`000?l0003ooo]Zo`0000;ooo]Z1Ol000001?oonf[o0000oookJ_oonfX3o`000007
oookJ_l0003o0000o`000?oonf[o0000oookJP03o`000003oookJ_l0003o000000;o000000?ooo]Z
o`000?l000000_oonfX2o`000003oookJ_l0003ooo]Z00Cooo]Z0ol000001?oonf[o0000oookJ_oo
nfX3o`0000Cooo]Z1?l000001Ooonf[o0000o`000?oonf[o000000?ooo]Z0ol00002oookJP;o0000
00?ooo]Zo`000?oonfX00ooonfX3o`000005oookJ_l0003o0000o`000?oonfX00_l000001?oonf[o
0000oookJ_oonfX6o`0000;ooo]Z0_l000001_oonf[o0000oookJ_oonf[o0000oookJP;o000000Go
oo]Zo`000?l0003o0000oookJP04o`00007ooo]Z0Ol000000003o`000?oonf[ooo]Z00;o000000?o
oo]Zo`000?l000002Ol000001Ooonf[o0000o`000?l0003ooo]Z00?o00001_oonfX5o`0000Cooo]Z
1?l000000ooonf[o0000oookJP02oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oo
nfX01OoonfX01?l0003ooo]ZoookJ_l00003oookJP09o`000?oonf[ooo]Zo`000?oonf[o0000oook
J_l0003ooo]Z00;o00001?oonfX02Ol0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000002
oookJP;o000000?ooo]Zo`000?oonfX00_oonfX4o`0000?ooo]Z00?o0000oookJ_l000004ol00000
1Ooonf[o0000o`000?l0003ooo]Z00?o000000Cooo]Zo`000?l0003ooo]Z3?l000000ooonf[o0000
o`000003o`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?l000003?l000000ooonf[o0000
o`000003o`000003oookJ_l0003ooo]Z01Oo0000T?oonfX7o`000003oookJ_l0003ooo]Z00Oo0000
00Cooo]Zo`000?l0003ooo]Z1Ol000000ooonf[o0000oookJP02oookJP03o`000?oonf[o000001;o
000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000008o`000004oookJ_l0003o0000oook
JP;o000000Cooo]Zo`000?l0003o00000ooonfX4o`000004oookJ_l0003ooo]ZoookJP[o000000?o
oo]Zo`000?l000001?l00002oookJP;o00000_oonfX01ol0003ooo]Zo`000?l0003ooo]Zo`000?oo
nfX00_l00003oookJP;o00000_oonfX3o`000003oookJ_l0003ooo]Z00?o000000?ooo]Zo`000?l0
00000_oonfX00ol0003ooo]Zo`000003oookJP;o000000?ooo]Zo`000?oonfX00ooonfX01?l0003o
oo]Zo`000?l00002oookJP03o`000?oonf[o000000;o000000Gooo]Zo`000?oonf[ooo]Zo`000002
oookJP04o`000?oonf[ooo]ZoookJPOo000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`00
0003o`000004oookJ_l0003o0000oookJPCo00000_oonfX00ol0003ooo]ZoookJP01o`00000000Go
0000oookJ_l0003o0000oookJP02o`0000;ooo]Z00?o0000oookJ_l000000_l000001?oonf[o0000
o`000?oonfX3o`000004oookJ_l0003o0000o`0000Kooo]Z2?l00003oookJP03o`000?oonf[ooo]Z
00?o000000Cooo]Zo`000?l0003o00000_oonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oo
nf[o000000?ooo]Z00Co0000oookJ_l0003ooo]Z0ol000000ooonf[o0000o`000005oookJP;o0000
00Gooo]Zo`000?oonf[ooo]Zo`000004oookJP03o`000?oonf[o000000Co000000?ooo]Zo`000?oo
nfX00_oonfX3o`0000;ooo]Z0ol00003oookJPGo000000?ooo]Zo`000?oonfX00_l00002oookJPGo
00000_oonfX7o`0000;ooo]Z00?o0000oookJ_l000000ol000001_oonf[o0000o`000?l0003ooo]Z
o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z4ol000001Ooonf[o0000oookJ_l0003ooo]Z00?o0000
00Cooo]Zo`000?oonf[o00001OoonfX5o`000004oookJ_l0003o0000oookJP_o0000S_oonfX7o`00
0003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000_l00003oookJPGo000000Gooo]Zo`00
0?oonf[ooo]Zo`000002oookJP?o000000?ooo]Zo`000?l000004Ol000000ooonf[o0000oookJP02
o`0000Cooo]Z00?o0000oookJ_l000000ol000000ooonf[o0000o`000002o`0000;ooo]Z0ol00000
1?oonf[o0000o`000?l00002oookJP05o`000?oonf[ooo]Zo`000?oonfX01Ol000000ooonf[o0000
o`000002oookJP04o`000?oonf[o0000oookJPGo00000_oonfX3o`000004oookJ_l0003ooo]Zo`00
00;ooo]Z00?o0000oookJ_l000000_l00002oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z1?l0
0002oookJPCo00001?oonfX2o`000008oookJ_l0003o0000o`000?oonf[o0000oookJ_l00002oook
JP04o`000?oonf[o0000o`0000;ooo]Z1Ol00002oookJP03o`000?oonf[o000000?o000000?ooo]Z
o`000?l000002?l000000ooonf[o0000oookJP04o`000007oookJ_l0003o0000o`000?oonf[o0000
oookJP06o`0000?ooo]Z00?o0000oookJ_oonfX00Ol000000003o`000?oonf[ooo]Z0?oooo]Zoooo
nfXnoookJP7o000000001_l0003ooo]ZoookJ_oonf[o0000oookJP;o00000_oonfX2o`000003oook
J_l0003ooo]Z00;o000000Gooo]Zo`000?l0003o0000oookJP03o`0000Kooo]Z0ol00002oookJP?o
00001?oonfX2o`000004oookJ_l0003ooo]Zo`0000?ooo]Z0_l00004oookJP;o000000Cooo]Zo`00
0?oonf[ooo]Z0ol00003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z1?l00003oookJP05o`000?oo
nf[o0000oookJ_l000000ooonfX2o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?oonfX0
0_l000002_oonf[o0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonfX6o`000004oookJ_l0
003ooo]ZoookJP;o000000?ooo]Zo`000?l000000ooonfX4o`0000;ooo]Z0ol000000ooonf[o0000
oookJP03o`000004oookJ_l0003o0000oookJPco00000_oonfX01?l0003ooo]Zo`000?oonfX<o`00
0004oookJ_l0003o0000o`0000Cooo]Z2?l000002?oonf[o0000oookJ_oonf[o0000oookJ_l0003o
oo]Z3ol0002:oookJPGo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000002o`000005
oookJ_l0003o0000oookJ_l000000_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z01Co000000?ooo]Z
o`000?l000001ol000000ooonf[o0000oookJP07o`0000;ooo]Z1?l000001Ooonf[o0000oookJ_l0
003ooo]Z00?o00000_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`00
0007o`000003oookJ_l0003ooo]Z00;ooo]Z1?l000000ooonf[o0000o`000002o`0000?ooo]Z00Co
0000oookJ_oonf[o00000_oonfX2o`000004oookJ_l0003o0000oookJPCo00000_oonfX2o`000003
oookJ_l0003ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00000ooonfX01ol0003ooo]Zo`000?oonf[o
0000oookJ_l000000_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[o000000Cooo]Z00?o
0000oookJ_oonfX03?l00002oookJP;o000000?ooo]Zo`000?l000000ol00002oookJP05o`000?oo
nf[o0000o`000?oonfX01?l000000ooonf[o0000o`000002oookJP7o000000000ol0003ooo]Zo`00
0003o`0000?ooo]Z2?l000001Ooonf[o0000o`000?l0003ooo]Z00?o00001_oonfX2o`000003oook
J_l0003o000000Ko00001?oonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o000000?ooo]Zo`00
0?l000000_l000001Ooonf[o0000oookJ_oonf[o000000Cooo]Z00Co0000oookJ_l0003o00001?oo
nfX2o`0000;ooo]Z0_l000001?oonf[o0000o`000?l00003oookJP;o00000_oonfX01?l0003ooo]Z
oookJ_oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00000ooonfX01?l0
003ooo]Zo`000?l00005oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000001?oonfX3
o`000003oookJ_l0003o000000?ooo]Z00?o0000oookJ_l000001Ol00002oookJP;o000000Cooo]Z
o`000?l0003ooo]Z1?l000001Ooonf[o0000o`000?l0003ooo]Z00?o000000?ooo]Zo`000?l00000
2?l00002oookJP03o`000?oonf[ooo]Z00?o000000Oooo]Zo`000?l0003o0000oookJ_l0003ooo]Z
00co000000Gooo]Zo`000?l0003o0000oookJP08o`0008Oooo]Z2_l00004oookJPco000000?ooo]Z
o`000?oonfX00ol000001?oonf[o0000o`000?oonfX4o`0000;ooo]Z0ol000000ooonf[o0000o`00
0004o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?oonfX01Ol000000ooonf[o0000o`00
000@o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`00
0002oookJPCo00000_oonfX4o`000003oookJ_l0003ooo]Z00;ooo]Z1?l00003oookJP?o00000ooo
nfX2o`000006oookJ_l0003o0000o`000?oonf[o00000_oonfX2o`000004oookJ_l0003ooo]Zo`00
00;ooo]Z00?o0000oookJ_l000000_l00004oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX00_oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o000000?ooo]Zo`000?l000000_l00000
0ooonf[o0000o`000003o`0000?ooo]Z00Co0000oookJ_oonf[ooo]Z1?l000001Ooonf[o0000o`00
0?oonf[o000000;ooo]Z1ol000000ooonf[o0000oookJP02oookJP7o000000001?l0003ooo]Zo`00
0?l00002oookJP;o000000?ooo]Zo`000?l000000_oonfX2o`0000?ooo]Z0ol000001?oonf[o0000
o`000?l00006oookJPCo000000Gooo]Zo`000?l0003ooo]Zo`000002oookJP;o00000_oonfX3o`00
0004oookJ_l0003o0000oookJP?o000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000002
oookJP05o`000?oonf[o0000oookJ_l000000ooonfX01?l0003ooo]ZoookJ_oonfX2o`000005oook
J_l0003o0000oookJ_l000000ooonfX3o`0000;ooo]Z0_l00003oookJP;o00001?oonfX3o`0000;o
oo]Z00Co0000oookJ_oonf[ooo]Z1?l000001?oonf[o0000oookJ_l00002oookJP03o`000?oonf[o
000000;o00000ooonfX:o`0000;ooo]Z0_l000001?oonf[o0000o`000?oonfX;o`0000;ooo]Z0ol0
00000ooonf[o0000o`00000:o`000003oookJ_l0003o000000;o00001?oonfX2o`0000Gooo]Z00Co
0000oookJ_l0003ooo]Z0_l00002oookJP;o000000?ooo]Zo`000?l000001?l00002oookJPSo0000
QOoonfX6o`000003oookJ_l0003o000000Go000000Kooo]Zo`000?l0003ooo]Zo`000?oonfX6o`00
0006oookJ_l0003o0000oookJ_l0003ooo]Z0ol00002oookJP?o00000ooonfX00ol0003ooo]Zo`00
000;o`000003oookJ_l0003o000000?o00000_oonfX00ol0003ooo]Zo`000004o`000003oookJ_l0
003o000000Co000000?ooo]Zo`000?oonfX01_l00003oookJP03o`000?oonf[o000000?o000000Co
oo]Zo`000?oonf[ooo]Z0ol00002oookJP03o`000?oonf[o000000?ooo]Z1?l00003oookJP;o0000
1OoonfX01?l0003ooo]Zo`000?oonfX3o`0000;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l000000ooo
nf[o0000o`000003o`000003oookJ_l0003ooo]Z00;o00001?oonfX2o`0000?ooo]Z0_l00005oook
JPGo000000Cooo]Zo`000?oonf[ooo]Z0_l000000ooonf[o0000o`000004o`000006oookJ_l0003o
oo]ZoookJ_l0003ooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00;o000000Cooo]Zo`000?l0
003o00000_oonfX00ol0003ooo]Zo`000002o`0000?ooo]Z0ol00002oookJP7o000000000ol0003o
oo]ZoookJP03oookJPCo000000Gooo]Zo`000?l0003o0000oookJP02o`000003oookJ_l0003o0000
00;ooo]Z0ol00006oookJP;o00000_oonfX2o`000005oookJ_l0003o0000oookJ_l000000ooonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`000?oonfX01?oonfX4
o`0000Oooo]Z00?o0000oookJ_oonfX00_oonfX01_l0003ooo]Zo`000?oonf[o0000oookJPGo0000
00?ooo]Zo`000?l000000ooonfX3o`0000?ooo]Z0_l00002oookJP03o`000?oonf[o000000Co0000
0ooonfX01?l0003ooo]Zo`000?l00002oookJP04o`000?oonf[o0000o`0000?ooo]Z0ol00002oook
JP?o000000?ooo]Zo`000?l000001?oonfX7o`000003oookJ_l0003o000000Co000000?ooo]Zo`00
0?l000001Ol000001?oonf[o0000o`000?oonfX2o`000005oookJ_l0003o0000o`000?oonfX00ol0
00001?oonf[o0000o`000?l00003oookJP05o`000?oonf[ooo]Zo`000?oonfX01_l000000ooonf[o
0000o`000003o`0000?ooo]Z1Ol00003oookJPSo0000Q?oonfX<o`000003oookJ_l0003o000000;o
000000Kooo]Zo`000?l0003ooo]Zo`000?oonfX4o`000005oookJ_l0003o0000o`000?oonfX00ol0
00000ooonf[o0000o`000007o`000003oookJ_l0003o000000Go00000_oonfX00ol0003ooo]Zo`00
0004o`0000;ooo]Z1Ol000001?oonf[o0000o`000?oonfX4o`000003oookJ_l0003o000000Co0000
00?ooo]Zo`000?oonfX01Ol000000ooonf[o0000oookJP04o`0000;ooo]Z0_l00002oookJP03o`00
0?oonf[ooo]Z00;ooo]Z0_l000000ooonf[o0000oookJP02o`000004oookJ_l0003o0000oookJPWo
00002OoonfX00ol0003ooo]Zo`000003o`0000Cooo]Z0_l000001Ooonf[o0000oookJ_oonf[o0000
00Cooo]Z00?o0000oookJ_l000000_l00004oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX8
o`000004oookJ_l0003o0000oookJP;o00000_oonfX2o`000004oookJ_l0003o0000o`0000;ooo]Z
0ol000000ooonf[o0000oookJP02oookJP03o`000?oonf[ooo]Z00?o00000_oonfX2o`0000?ooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000001?l0003ooo]Zo`000?l0
0002oookJP04o`000?oonf[o0000o`0000;ooo]Z0_l000000ooonf[o0000oookJP02oookJP;o0000
00Cooo]Zo`000?l0003o00001_oonfX4o`000006oookJ_l0003o0000oookJ_l0003ooo]Z0ol00000
1_oonf[o0000oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00_l00003oookJP;o0000
00?ooo]Zo`000?l000000ol00003oookJP;o00000ooonfX01_l0003ooo]Zo`000?oonf[o0000oook
JP;o000000Gooo]Zo`000?l0003ooo]Zo`000002oookJP03o`000?oonf[o000000Cooo]Z00?o0000
oookJ_oonfX00ol00002oookJP03o`000?oonf[ooo]Z00Co000000Cooo]Zo`000?oonf[o00000ooo
nfX00ol0003ooo]Zo`000003oookJPSo000000?ooo]Zo`000?l000000_l00002oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00Go0000oookJ_oonf[o0000oookJP06o`0000;ooo]Z0ol000001Ooonf[o0000
o`000?oonf[o000000?ooo]Z1Ol00003oookJP;o00000ooonfX01?l0003ooo]ZoookJ_oonfX3o`00
00;ooo]Z0ol000000ooonf[o0000oookJP03oookJPKo000000?ooo]Zo`000?l000000ol000000ooo
nf[o0000o`000007o`00087ooo]Z2_l000000ooonf[o0000o`000004o`0000;ooo]Z0ol000000ooo
nf[o0000o`000003o`0000;ooo]Z0_l000001_oonf[o0000oookJ_l0003ooo]Zo`0000?ooo]Z00Go
0000oookJ_oonf[o0000oookJP02o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l00000
0ol000001?oonf[o0000oookJ_oonfX2o`0000;ooo]Z00?o0000oookJ_l000001?oonfX00ol0003o
oo]ZoookJP05o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?l0003o00001?oonfX5o`00
0005oookJ_l0003ooo]Zo`000?oonfX01?l000001Ooonf[o0000oookJ_l0003ooo]Z00;o000000Co
oo]Zo`000?l0003o00000ooonfX2o`000003oookJ_l0003ooo]Z00?o000000?ooo]Zo`000?l00000
1?oonfX02_l0003ooo]Zo`000?l0003ooo]Zo`000?oonf[o0000oookJ_l00002oookJP;o00000_oo
nfX3o`0000;ooo]Z00Co0000oookJ_oonf[o00001?oonfX2o`0000;ooo]Z00?o0000oookJ_l00000
0_l000000ooonf[o0000o`000002o`000003oookJ_l0003o000000;ooo]Z1ol000001?oonf[o0000
o`000?l00002oookJP?o00000_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003o
oo]ZoookJ_l00002oookJP7o000000000ol0003ooo]ZoookJP03o`0000Cooo]Z0_l000000ooonf[o
0000o`000002o`000003oookJ_l0003ooo]Z00;ooo]Z0ol00006oookJP;o00000ooonfX9o`000004
oookJ_l0003ooo]ZoookJPCo00001_oonfX00ol0003ooo]Zo`000004oookJP0:o`000?oonf[o0000
oookJ_l0003ooo]Zo`000?oonf[o0000oookJPCo000000?ooo]Zo`000?l000000ooonfX3o`0000?o
oo]Z1?l000000ooonf[o0000oookJP02oookJPKo000000Cooo]Zo`000?l0003o00000_oonfX00ol0
003ooo]Zo`000004o`000003oookJ_l0003o000000;o00001OoonfX3o`0000Kooo]Z0ol000001Ooo
nf[o0000oookJ_l0003ooo]Z00Co000000?ooo]Zo`000?l000000ol00002oookJPCo000000?ooo]Z
o`000?l000002Ol0000:oookJP;o000000Cooo]Zo`000?oonf[ooo]Z0ol000001?oonf[o0000o`00
0?oonfX3o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000000_l000001?oonf[o0000
o`000?oonfX5o`0007oooo]Z1?l000000ooonf[o0000o`000007o`0000;ooo]Z00Ko0000oookJ_l0
003ooo]Zo`000?oonfX4o`0000?ooo]Z0_l000000ooonf[o0000o`000003oookJP07o`000?oonf[o
0000o`000?oonf[o0000oookJP03o`0000;ooo]Z00?o0000oookJ_l000002Ol000001?oonf[o0000
o`000?oonfX5o`000003oookJ_l0003o000000;ooo]Z0ol000001?oonf[o0000oookJ_l00002oook
JP?o00000_oonfX2o`000003oookJ_l0003o000000;o000000[ooo]Zo`000?l0003o0000oookJ_l0
003ooo]Zo`000?oonf[o00000_oonfX2o`0000?ooo]Z1_l000001Ooonf[o0000oookJ_l0003ooo]Z
00;o000000Kooo]Zo`000?oonf[o0000oookJ_l00002oookJPKo00001?oonfX01Ol0003ooo]Zo`00
0?oonf[o000000;ooo]Z00?o0000oookJ_l000001?oonfX2o`000005oookJ_l0003ooo]Zo`000?oo
nfX00_l00002oookJP03o`000?oonf[ooo]Z00Go000000?ooo]Zo`000?oonfX02Ol00003oookJPCo
000000Cooo]Zo`000?l0003o00000_oonfX01?l0003ooo]Zo`000?oonfX2o`000005oookJ_l0003o
0000o`000?oonfX00ol000000ooonf[o0000o`000002oookJP03o`000?oonf[ooo]Z007o00000000
0ol0003ooo]Zo`000005o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z0ol000001Ooonf[o0000o`00
0?l0003ooo]Z00?o00001_oonfX6o`0000;ooo]Z00?o0000oookJ_l000000_l00004oookJP;o0000
1?oonfX00ol0003ooo]ZoookJP02oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000_oonfX3o`00
0003oookJ_l0003o000000?o000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJPGo000000?ooo]Z
o`000?l000000_oonfX02Ol0003ooo]Zo`000?l0003ooo]Zo`000?oonf[o0000oookJP02o`0000;o
oo]Z00Co0000oookJ_oonf[ooo]Z0ol000000ooonf[o0000o`000004oookJP;o00000_oonfX2o`00
00?ooo]Z0_l00004oookJP?o000000Cooo]Zo`000?oonf[ooo]Z0ol00003oookJP03o`000?oonf[o
000000;ooo]Z1?l00002oookJQ3o000000?ooo]Zo`000?oonfX01_l00003oookJP05o`000?oonf[o
0000o`000?oonfX00ol000001?oonf[o0000oookJ_oonfX2o`000003oookJ_l0003o000000Ko0000
00?ooo]Zo`000?oonfX01?l000000ooonf[o0000o`000005o`0007gooo]Z1?l000001?oonf[o0000
o`000?l00003oookJP?o00000_oonfX3o`000006oookJ_l0003o0000oookJ_l0003ooo]Z0_l00000
1?oonf[o0000o`000?l00004oookJP03o`000?oonf[ooo]Z00gooo]Z3?l00002oookJP;o000000Co
oo]Zo`000?l0003ooo]Z0_l000000ooonf[o0000o`000002oookJP04o`000?oonf[o0000o`0000?o
oo]Z00Co0000oookJ_l0003ooo]Z0ol00003oookJP?o00000_oonfX01Ol0003ooo]Zo`000?l0003o
oo]Z00;o00000_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z0ol0
0004oookJP03o`000?oonf[ooo]Z00Wooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002oookJPKo
000000?ooo]Zo`000?oonfX01?oonfX3o`0000;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oook
JP03o`000?oonf[ooo]Z00Ko000000Cooo]Zo`000?oonf[o00000_oonfX4o`000003oookJ_l0003o
oo]Z00Cooo]Z0_l000001?oonf[o0000o`000?oonfX3o`000003oookJ_l0003o000000Kooo]Z00?o
0000oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol00000
0003o`000?oonf[ooo]Z00Kooo]Z0_l00002oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000
oookJ_oonfX00ol00006oookJP;o00000ooonfX01Ol0003ooo]Zo`000?l0003ooo]Z00?o000000?o
oo]Zo`000?l000002OoonfX2o`0000Kooo]Z00?o0000oookJ_oonfX00_oonfX01ol0003ooo]Zoook
J_oonf[o0000oookJ_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0_l000001_oo
nf[o0000oookJ_l0003ooo]Zo`0000Oooo]Z00Co0000oookJ_oonf[ooo]Z0_l000001Ooonf[o0000
o`000?l0003ooo]Z00?o000000?ooo]Zo`000?oonfX00_oonfX01Ol0003ooo]Zo`000?l0003ooo]Z
00?o000000Wooo]Zo`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX8o`0000;ooo]Z
00Co0000oookJ_l0003o00000_oonfX2o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l0
00001?l00004oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00002oookJP;o00000_oonfX3o`0000;o
oo]Z0_l00005oookJP?o000000Cooo]Zo`000?oonf[o00000_oonfX2o`000003oookJ_l0003o0000
00Ko000000?ooo]Zo`000?l000000_l0001koookJP?o000000Gooo]Zo`000?l0003o0000oookJP08
o`000005oookJ_l0003ooo]Zo`000?oonfX00_l000000ooonf[o0000oookJP04o`0000Gooo]Z00?o
0000oookJ_oonfX01?oonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o00000_oonfX00ol0003o
oo]ZoookJP0;o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000ol000001_oonf[o
0000o`000?oonf[o0000oookJP;o000000?ooo]Zo`000?oonfX00ol00004oookJP?o000000?ooo]Z
o`000?l000000ol000000ooonf[o0000oookJP03oookJP06o`000?oonf[ooo]Zo`000?oonf[o0000
0ooonfX6o`000003oookJ_l0003o000000_ooo]Z0_l00003oookJP;o000000?ooo]Zo`000?l00000
0_l000001?oonf[o0000oookJ_l00003oookJP03o`000?oonf[o000000;o00000_oonfX2o`0000;o
oo]Z00?o0000oookJ_l000001OoonfX2o`000003oookJ_l0003o000000Co00000_oonfX00ol0003o
oo]Zo`000003o`000004oookJ_l0003o0000o`0000;ooo]Z0_l000001?oonf[o0000oookJ_oonfX3
o`0000?ooo]Z0ol000001?oonf[o0000oookJ_l00003oookJP;o00000_oonfX1o`00000000?o0000
oookJ_oonfX01_oonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oonf[ooo]Z00;o00000_oo
nfX3o`0000Kooo]Z2Ol000001Ooonf[o0000o`000?l0003ooo]Z00Co000000Cooo]Zo`000?oonf[o
00001?oonfX01?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000000ooo
nf[o0000oookJP02oookJP04o`000?oonf[o0000o`0000;ooo]Z0_l000001?oonf[o0000oookJ_l0
000<oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[o000000;o
oo]Z00Oo0000oookJ_oonf[o0000oookJ_l0003ooo]Z00;o00000_oonfX01?l0003ooo]Zo`000?l0
0002oookJP;o000000Cooo]Zo`000?l0003o00000_oonfX6o`0000;ooo]Z00?o0000oookJ_oonfX0
1ol000000ooonf[o0000o`000009o`0000Kooo]Z0_l00002oookJP04o`000?oonf[ooo]Zo`0000?o
oo]Z0_l000000ooonf[o0000o`000004oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`000?oo
nfX00_oonfX00ol0003ooo]Zo`000005o`000004oookJ_l0003ooo]ZoookJPWo0000NOoonfX8o`00
0003oookJ_l0003ooo]Z00?o00001?oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z1_l000002?oo
nf[o0000o`000?l0003ooo]Zo`000?oonf[o00000_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0
1OoonfX2o`000003oookJ_l0003o000000Ko000000Kooo]Zo`000?oonf[o0000oookJ_l00004oook
JP;o00000_oonfX4o`0000;ooo]Z00Go0000oookJ_l0003o0000oookJP07o`000003oookJ_l0003o
000000;ooo]Z0_l000000ooonf[o0000oookJP05o`0000;ooo]Z00Ko0000oookJ_l0003o0000oook
J_l00003oookJP?o00000ooonfX2o`0000?ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Z
oookJP04o`000003oookJ_l0003o000000;ooo]Z00Co0000oookJ_l0003o00000_oonfX2o`0000;o
oo]Z00?o0000oookJ_oonfX01_oonfX4o`0000Kooo]Z00?o0000oookJ_l000000ol000000ooonf[o
0000o`000002oookJP;o00000_oonfX3o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?oo
nfX00ooonfX00ol0003ooo]ZoookJP02oookJPCo000000Gooo]Zo`000?l0003ooo]Zo`000003oook
JP7o000000000ol0003ooo]Zo`000003o`000007oookJ_l0003o0000oookJ_l0003ooo]Zo`000002
oookJP;o000000Gooo]Zo`000?oonf[o0000oookJP03o`0000Kooo]Z0_l00002oookJP;o00000_oo
nfX5o`000004oookJ_l0003ooo]Zo`0000;ooo]Z00Co0000oookJ_oonf[o00001?oonfX01?l0003o
oo]ZoookJ_l00004oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l000001?oonf[o0000oookJ_l00003
oookJP08o`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l00004oookJP03o`000?oonf[ooo]Z00Oo
oo]Z1?l00002oookJPCo00000ooonfX01?l0003ooo]ZoookJ_oonfX3o`000003oookJ_l0003o0000
00;ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002oookJP04o`000?oonf[o0000oookJP?o0000
1OoonfX00ol0003ooo]Zo`000003o`000003oookJ_l0003o000000;ooo]Z0_l000001Ooonf[o0000
o`000?l0003ooo]Z00Go000000?ooo]Zo`000?oonfX00ooonfX4o`000004oookJ_l0003ooo]Zoook
JP;o00000ooonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o000000Oooo]Zo`000?oonf[ooo]Zo`00
0?oonf[o000000?ooo]Z0_l000000ooonf[o0000oookJP02o`000003oookJ_l0003o000000;o0000
00Cooo]Zo`000?l0003ooo]Z1Ol0001goookJPoo000000?ooo]Zo`000?oonfX00_oonfX02?l0003o
oo]Zo`000?oonf[o0000oookJ_l0003ooo]Z0_l000001?oonf[o0000oookJ_l00004oookJP03o`00
0?oonf[o000000?ooo]Z1?l000000ooonf[o0000oookJP02o`0000Kooo]Z1_l000000ooonf[o0000
oookJP07o`000004oookJ_l0003o0000oookJPko00000_oonfX2o`0000?ooo]Z00?o0000oookJ_l0
00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;o00001OoonfX3o`000008
oookJ_l0003o0000o`000?oonf[o0000oookJ_l00003oookJP04o`000?oonf[o0000oookJP;o0000
00?ooo]Zo`000?l000001OoonfX2o`000004oookJ_l0003o0000oookJPGo000000Cooo]Zo`000?l0
003ooo]Z0_l000002Ooonf[o0000o`000?l0003ooo]Zo`000?oonf[o0000oookJP04o`0000;ooo]Z
0ol000001Ooonf[o0000o`000?l0003ooo]Z00;o000000?ooo]Zo`000?oonfX00_l000000ooonf[o
0000oookJP02o`0000?ooo]Z00Co0000oookJ_l0003o00000_oonfX01?l0003ooo]Zo`000?l00002
oookJPOo000000?ooo]Zo`000?l000000ooonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0Ol000000003o`000?oonf[ooo]Z00?ooo]Z0_l000000ooonf[o0000oookJP02oookJP;o
000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJP?o00001_oonfX2o`000004oookJ_l0003ooo]Z
o`0000;ooo]Z1ol000000ooonf[o0000o`000002oookJP03o`000?oonf[ooo]Z00Co00001?oonfX0
1ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000_oonfX01Ol0003ooo]Zo`000?oonf[o000000Oo
oo]Z00Co0000oookJ_l0003ooo]Z0_l00002oookJP;o000000Cooo]Zo`000?l0003o00001?oonfX0
0ol0003ooo]Zo`000003oookJP;o00001?oonfX2o`0000;ooo]Z00?o0000oookJ_l000001?l00000
0ooonf[o0000oookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z2Ol00004oookJP03o`000?oonf[o
000000?o00000_oonfX2o`000003oookJ_l0003o000000?o000000Cooo]Zo`000?l0003o00000_oo
nfX2o`0000;ooo]Z00?o0000oookJ_l000000_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000;o
oo]Z0_l000001?oonf[o0000o`000?l00002oookJP07o`000?oonf[o0000o`000?oonf[o0000oook
JP02o`000004oookJ_l0003o0000oookJP;o00000_oonfX2o`0000;ooo]Z0ol000000ooonf[o0000
o`000002o`0000;ooo]Z0_l0001eoookJPWo000000Cooo]Zo`000?oonf[ooo]Z1_l00002oookJPCo
000000Cooo]Zo`000?oonf[ooo]Z0_l00002oookJP04o`000?oonf[o0000oookJP;o000000Kooo]Z
o`000?l0003ooo]Zo`000?oonfX2o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX00ol0003o
oo]Zo`000002o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?oonfX00_l000001Ooonf[o
0000oookJ_l0003ooo]Z00Co000000Gooo]Zo`000?l0003o0000oookJP02o`000008oookJ_l0003o
0000o`000?oonf[o0000oookJ_l00002oookJP?o000000?ooo]Zo`000?l000001?oonfX01Ol0003o
oo]ZoookJ_l0003ooo]Z00;o00001?oonfX2o`000003oookJ_l0003o000000;ooo]Z00Ko0000oook
J_oonf[ooo]Zo`000?oonfX4o`0000Kooo]Z0_l00002oookJP;o00000_oonfX2o`0000gooo]Z0_l0
0002oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000004oookJPKo00000_oonfX02Ol0003o
oo]ZoookJ_l0003ooo]Zo`000?oonf[o0000oookJP08o`0000;ooo]Z00?o0000oookJ_l000000ol0
0002oookJP03o`000?oonf[o000000;o00000_oonfX3o`000003oookJ_l0003ooo]Z00;ooo]Z0Ol0
00000004o`000?oonf[o0000o`0000;ooo]Z00Ko0000oookJ_l0003o0000oookJ_l00003oookJP;o
000000?ooo]Zo`000?oonfX00_oonfX3o`0000Kooo]Z0ol000000ooonf[o0000o`000003o`000003
oookJ_l0003ooo]Z00Ko00001?oonfX00ol0003ooo]Zo`000002oookJP;o00001_oonfX00ol0003o
oo]Zo`000003oookJP03o`000?oonf[o000000;ooo]Z00Ko0000oookJ_l0003ooo]Zo`000?oonfX3
o`0000;ooo]Z00?o0000oookJ_l000000_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000
oookJ_oonf[ooo]Z1Ol00008oookJP?o00000ooonfX01?l0003ooo]ZoookJ_l00002oookJP04o`00
0?oonf[o0000o`0000?ooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00;o00000_oonfX5o`00
00?ooo]Z1Ol000000ooonf[o0000oookJP03o`0000?ooo]Z0_l00003oookJP;o000000Cooo]Zo`00
0?l0003ooo]Z2Ol00003oookJP;o00000_oonfX2o`000004oookJ_l0003o0000oookJPCo00000_oo
nfX00ol0003ooo]ZoookJP02oookJP?o000000Cooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]Z
o`000004o`0007Cooo]Z5_l00004oookJP;o000000Cooo]Zo`000?oonf[o00000_oonfX01?l0003o
oo]Zo`000?l00002oookJP;o000000Cooo]Zo`000?oonf[o00000ooonfX01_l0003ooo]ZoookJ_l0
003ooo]Zo`0000;ooo]Z00?o0000oookJ_l000003_l000000ooonf[o0000o`000002o`0000;ooo]Z
0ol00003oookJP;o000000Kooo]Zo`000?l0003o0000oookJ_l00003oookJPOo00000_oonfX3o`00
0003oookJ_l0003ooo]Z00Cooo]Z0_l00002oookJP08o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00
0?oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z0_l000000ooonf[o0000oookJP03oookJP09o`00
0?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ooonfX0
1?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[ooo]Z00Oooo]Z1?l00004oookJP;o00000_oo
nfX00ol0003ooo]ZoookJP05o`0000?ooo]Z0_l000000ooonf[o0000oookJP02o`000003oookJ_l0
003ooo]Z00;o00000ooonfX3o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX00Ol0
00000004o`000?oonf[ooo]Zo`0000Kooo]Z0ol000000ooonf[o0000oookJP03oookJP;o00000_oo
nfX2o`0000Kooo]Z0_l000000ooonf[o0000o`000003o`0000;ooo]Z0ol000000ooonf[o0000o`00
0004o`000003oookJ_l0003ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[ooo]Z1?l00006oookJP?o
00001_oonfX00ol0003ooo]Zo`000009oookJP;o000000?ooo]Zo`000?l000000_oonfX3o`000005
oookJ_l0003o0000o`000?oonfX00_l00008oookJPGo00000_oonfX00ol0003ooo]Zo`000002oook
JP;o00000_oonfX2o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000001?l00003oook
JP03o`000?oonf[ooo]Z00_ooo]Z0_l00005oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0ol0
0002oookJP04o`000?oonf[o0000o`0000;ooo]Z00?o0000oookJ_l000000ooonfX01?l0003ooo]Z
o`000?oonfX5o`000003oookJ_l0003o000000Go0000L_oonfX<o`0000;ooo]Z0_l000000ooonf[o
0000o`000002o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?oonfX00_l00002oookJP03
o`000?oonf[o000000Gooo]Z00Ko0000oookJ_l0003o0000oookJ_l00002oookJP;o00001OoonfX0
0ol0003ooo]ZoookJP05oookJPCo000000?ooo]Zo`000?oonfX00_oonfX2o`000003oookJ_l0003o
oo]Z00;o000000?ooo]Zo`000?l000000_l000000ooonf[o0000oookJP02oookJP05o`000?oonf[o
0000o`000?oonfX00ol000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z0_l000000ooonf[o0000
oookJP03o`0000Cooo]Z0ol000001Ooonf[o0000o`000?oonf[o000000?ooo]Z0_l00005oookJP03
o`000?oonf[ooo]Z00?ooo]Z0_l00004oookJP;o00000_oonfX00ol0003ooo]Zo`000004oookJP;o
00000_oonfX01?l0003ooo]ZoookJ_oonfX4o`0000?ooo]Z00?o0000oookJ_oonfX00ooonfX4o`00
00;ooo]Z00?o0000oookJ_l000001?l000000ooonf[o0000o`000002oookJP04o`000?oonf[ooo]Z
oookJPCo000000Gooo]Zo`000?l0003o0000oookJP02o`0000?ooo]Z00Go0000oookJ_oonf[ooo]Z
o`00000:oookJP7o000000000ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z00Ko
0000oookJ_l0003o0000oookJ_l00002oookJP04o`000?oonf[o0000oookJP?o00001_oonfX3o`00
00;ooo]Z00Co0000oookJ_oonf[o00000_oonfX2o`000003oookJ_l0003o000000Go00000_oonfX0
0ol0003ooo]Zo`000003oookJP04o`000?oonf[o0000oookJP;o00002ooonfX00ol0003ooo]Zoook
JP09oookJP;o00000_oonfX2o`000003oookJ_l0003o000000Cooo]Z00So0000oookJ_l0003o0000
oookJ_l0003ooo]Zo`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP;o00000_oonfX0
0ol0003ooo]Zo`000002oookJP;o000000Oooo]Zo`000?l0003ooo]Zo`000?oonf[o000000;ooo]Z
0_l00002oookJP;o00001?oonfX00ol0003ooo]ZoookJP04o`0000;ooo]Z2Ol00004oookJP03o`00
0?oonf[ooo]Z00Kooo]Z1?l000000ooonf[o0000o`000003oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_l000000ol000000ooonf[o0000o`000008o`00077ooo]Z1_l000000ooonf[o0000
o`000002o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?oonf[ooo]Z0ol00002oookJP04
o`000?oonf[ooo]ZoookJPGo000000?ooo]Zo`000?oonfX00ooonfX01Ol0003ooo]Zo`000?oonf[o
000000;ooo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z0ol00002
oookJPKo00000_oonfX00ol0003ooo]ZoookJP03o`000003oookJ_l0003ooo]Z00;ooo]Z0_l00002
oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`000?l000000ol00004oookJP0;o`000?oonf[o
oo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonfX00_l000001Ooonf[o0000oookJ_l0003o
oo]Z00?o00001OoonfX2o`000004oookJ_l0003ooo]ZoookJP;o000000Cooo]Zo`000?oonf[ooo]Z
0_l000000ooonf[o0000oookJP03oookJP;o00000ooonfX2o`0000Cooo]Z00?o0000oookJ_oonfX0
1?oonfX2o`000003oookJ_l0003o000000Wo00000_oonfX2o`000009oookJ_l0003ooo]Zo`000?oo
nf[o0000oookJ_l0003ooo]Z00;o00000ooonfX01?l0003ooo]ZoookJ_l00002oookJP05o`000?oo
nf[ooo]ZoookJ_l000000_oonfX2o`000004oookJ_l0003ooo]Zo`0000;ooo]Z0_l000000ooonf[o
0000oookJP01o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000005o`000?oo
nf[ooo]Zo`000?oonfX00ol000000ooonf[o0000oookJP04oookJP;o00000_oonfX00ol0003ooo]Z
oookJP03o`0000Kooo]Z0_l00002oookJP;o00000_oonfX3o`000005oookJ_l0003ooo]Zo`000?oo
nfX01Ol00003oookJP03o`000?oonf[ooo]Z00Gooo]Z00So0000oookJ_oonf[o0000oookJ_l0003o
oo]Zo`0000;ooo]Z0_l000000ooonf[o0000o`000004oookJP03o`000?oonf[ooo]Z00Cooo]Z00Wo
0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJ_l000000ooonfX3o`0000?ooo]Z00?o0000oook
J_oonfX00_l00003oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l00004oookJP03o`000?oonf[o
000000?ooo]Z0_l000000ooonf[o0000oookJP04oookJP?o00000ooonfX00ol0003ooo]ZoookJP02
o`000007oookJ_l0003o0000o`000?oonf[o0000oookJP02o`0000;ooo]Z0ol000000ooonf[o0000
oookJP03oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?l0003o00000_oonfX00ol0003o
oo]Zo`000002oookJP;o00002_oonfX00ol0003ooo]Zo`000008o`0000?ooo]Z1?l00002oookJP?o
000000?ooo]Zo`000?oonfX01_l0001_oookJPCo000000?ooo]Zo`000?l000001_l000001Ooonf[o
0000o`000?oonf[o000000;ooo]Z0ol00003oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000_oo
nfX01?l0003ooo]Zo`000?l00004oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oook
JP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP_o00000_oonfX2
o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z0ol000000ooonf[o0000oookJP02o`0000;ooo]Z0_l0
00000ooonf[o0000oookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Z
o`000002oookJP;o00001ooonfX00ol0003ooo]ZoookJP05oookJP;o00000_oonfX00ol0003ooo]Z
o`000002oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Sooo]Z
00Go0000oookJ_oonf[ooo]Zo`000004oookJPGo00000_oonfX01?l0003ooo]Zo`000?oonfX3o`00
0004oookJ_l0003ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX01?oonfX4o`0000Kooo]Z1_l00000
0ooonf[o0000oookJP04oookJP;o00000OoonfX1o`00000000?o0000oookJ_oonfX01Ol00003oook
JP;o000000Cooo]Zo`000?oonf[ooo]Z1?l00002oookJP;o00001_oonfX2o`000004oookJ_l0003o
0000o`0000;ooo]Z1?l000001?oonf[o0000o`000?oonfX3o`000004oookJ_l0003o0000oookJP;o
00000ooonfX00ol0003ooo]ZoookJP02o`0000Kooo]Z0_l00007oookJP04o`000?oonf[ooo]Zo`00
00Cooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o000000?ooo]Z
o`000?oonfX00_oonfX2o`000006oookJ_l0003o0000o`000?oonf[o00001OoonfX5o`000004oook
J_l0003o0000o`0000;ooo]Z00Co0000oookJ_l0003o00000_oonfX01?l0003ooo]Zo`000?l00003
oookJPCo000000Gooo]Zo`000?l0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00So00001?oo
nfX00ol0003ooo]ZoookJP06oookJP;o000000Cooo]Zo`000?oonf[o00000_oonfX2o`0000;ooo]Z
00Co0000oookJ_l0003ooo]Z0ol00003oookJP?o000000Cooo]Zo`000?oonf[ooo]Z0_l00006oook
JP04o`000?oonf[o0000oookJP;o00000_oonfX3o`0000;ooo]Z1_l0001]oookJPSo00000ooonfX2
o`0000Cooo]Z00Co0000oookJ_l0003o00001?oonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z0ol0
00000ooonf[o0000o`000002o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP;o0000
0_oonfX00ol0003ooo]Zo`000009oookJP;o000000Oooo]Zo`000?l0003o0000oookJ_l0003ooo]Z
00;o00000_oonfX3o`0000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l000000ooonf[o0000oookJP02
o`000004oookJ_l0003ooo]ZoookJP?o00000ooonfX2o`0000?ooo]Z00?o0000oookJ_l000000_oo
nfX00ol0003ooo]Zo`000003o`0000?ooo]Z00Ko0000oookJ_l0003ooo]Zo`000?oonfX2o`0000?o
oo]Z1Ol000001Ooonf[o0000oookJ_oonf[o000000Cooo]Z0ol000000ooonf[o0000oookJP02o`00
00?ooo]Z0_l00004oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000ooonfX00ol0003ooo]Zoook
JP02oookJP?o00000_oonfX2o`000003oookJ_l0003o000000?o00000_oonfX00ol0003ooo]Zoook
JP04oookJP08o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000?oonfX2o`000003oookJ_l0003o0000
00;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l0
0001oookJP7o000000000ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;o00000_oonfX0
1?l0003ooo]Zo`000?l00003oookJP03o`000?oonf[o000000;o00001_oonfX3o`0000;ooo]Z1?l0
00001Ooonf[o0000oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?oonfX01?l00008oookJP?o0000
0ooonfX01?l0003ooo]ZoookJ_l00004oookJP;o00000ooonfX00ol0003ooo]Zo`000003oookJP03
o`000?oonf[ooo]Z00;ooo]Z1_l00004oookJP03o`000?oonf[o000000;o00001?oonfX3o`0000;o
oo]Z0ol00004oookJP;o000000Cooo]Zo`000?oonf[o00001?oonfX2o`0000;ooo]Z0ol00002oook
JP03o`000?oonf[o000000Go000000?ooo]Zo`000?oonfX01?l000000ooonf[o0000o`000003o`00
00Gooo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003ooo]Zo`000?oonf[o000000?ooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_l000000_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[o000000;o000000Cooo]Z
o`000?oonf[ooo]Z1ol0001[oookJPko00001?oonfX3o`000003oookJ_l0003o000000?ooo]Z00Go
0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_l00000
0ooonfX00ol0003ooo]Zo`000002o`0000?ooo]Z00?o0000oookJ_oonfX00_l000001?oonf[o0000
oookJ_oonfX2o`0000Gooo]Z0ol000000ooonf[o0000o`000002o`000003oookJ_l0003ooo]Z00;o
000000Cooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]ZoookJP09o`0000;ooo]Z1?l000000ooo
nf[o0000oookJP02oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]Zo`000003o`000003oookJ_l0003ooo]Z00Cooo]Z0_l000000ooonf[o0000o`000007
oookJP05o`000?oonf[o0000oookJ_l000000_oonfX3o`000003oookJ_l0003ooo]Z00Oooo]Z00?o
0000oookJ_oonfX01?oonfX01?l0003ooo]ZoookJ_oonfX2o`0000;ooo]Z00?o0000oookJ_l00000
0_l00002oookJP03o`000?oonf[ooo]Z00Co00000_oonfX3o`0000?ooo]Z00?o0000oookJ_l00000
0_l00002oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX2o`0000;ooo]Z1?l000001?oonf[o
0000oookJ_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000004o`00
0?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00;ooo]Z0_l00006oookJP;o000000Cooo]Zo`000?l0003o00001OoonfX4o`00
0003oookJ_l0003o000000Ko000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]ZoookJP02oook
JP;o00001ooonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oookJ_l000001ooonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX2
o`0000;ooo]Z0_l00002oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l00003oookJP04o`000?oo
nf[o0000oookJP;o00001OoonfX2o`000004oookJ_l0003ooo]ZoookJP;o000000?ooo]Zo`000?oo
nfX00_oonfX2o`000003oookJ_l0003o000000Go00001?oonfX01?l0003ooo]ZoookJ_l00006oook
JP04o`000?oonf[ooo]Zo`0000Gooo]Z0ol000000ooonf[o0000o`000002o`0000;ooo]Z00Co0000
oookJ_l0003o00000_oonfX2o`0000;ooo]Z00Go0000oookJ_l0003o0000oookJP02o`000003oook
J_l0003o000000?o000000?ooo]Zo`000?l000000_l00003oookJP03o`000?oonf[o000000Co0000
JooonfX9o`0000;ooo]Z0_l000001?oonf[o0000o`000?oonfX2o`0000;ooo]Z00?o0000oookJ_oo
nfX00_oonfX2o`0000;ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP02oookJP;o
00000_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0:oookJPGo
000000Cooo]Zo`000?l0003o00000_oonfX2o`0000;ooo]Z1_l00002oookJP03o`000?oonf[o0000
00;o000000?ooo]Zo`000?l000000ooonfX7o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX0
0ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000000ooonf[o0000oookJP02
oookJP;o000000?ooo]Zo`000?oonfX01?l000000ooonf[o0000oookJP04oookJP;o00001ooonfX0
1ol0003ooo]Zo`000?l0003ooo]Zo`000?oonfX00_l00002oookJP03o`000?oonf[o000000;o0000
0_oonfX4o`0000Cooo]Z0ol00002oookJP?o00000ooonfX2o`000003oookJ_l0003o000000Co0000
0_oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[o0000o`000?oonfX00_l00004oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00Ol000000003o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_l000001?oonfX01?l0003ooo]Zo`000?l00003oookJP;o000000Cooo]Zo`000?l0
003o00001_oonfX3o`0000;ooo]Z00Go0000oookJ_oonf[o0000oookJP04o`0000;ooo]Z0_l00000
0ooonf[o0000oookJP03o`0000Kooo]Z1Ol000001Ooonf[o0000oookJ_oonf[o000000Gooo]Z00Co
0000oookJ_l0003o00001?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z
00Wo0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonfX00_l00002oookJP;o000000Cooo]Z
o`000?oonf[o00001_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co
0000oookJ_oonf[ooo]Z0_l000001?oonf[o0000o`000?oonfX2o`000004oookJ_l0003o0000o`00
00;ooo]Z0_l000000ooonf[o0000oookJP03o`0000Sooo]Z0ol00003oookJP03o`000?oonf[ooo]Z
00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00000
0ooonf[o0000oookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000000_oonfX2
o`000003oookJ_l0003o000000;ooo]Z0_l00002oookJP;o000000?ooo]Zo`000?l000000ol0001Y
oookJP?o000000?ooo]Zo`000?oonfX01?l000001?oonf[o0000oookJ_oonfX2o`000004oookJ_l0
003ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]Zo`000?l00002oookJP03
o`000?oonf[o000000;o00000ooonfX01?l0003ooo]Zo`000?l00002oookJP;o00000_oonfX00ol0
003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000000_oonfX4o`00
0003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000_oonfX2o`000003oookJ_l0003o0000
00;o00001_oonfX3o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP;o00000_oonfX4
o`0000Gooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP;o00000_oonfX00ol0003ooo]Zoook
JP02o`0000;ooo]Z00Co0000oookJ_oonf[o00000ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00Co
000000Cooo]Zo`000?l0003o00000_oonfX2o`0000[ooo]Z0_l000000ooonf[o0000o`00000<o`00
0003oookJ_l0003o000000?o00000_oonfX00ol0003ooo]ZoookJP02o`0000Oooo]Z00?o0000oook
J_l000000ooonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o000000?ooo]Zo`000?l000001?oo
nfX1o`00000000?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
000000?ooo]Z0ol00006oookJP;o00000_oonfX3o`0000;ooo]Z0_l000000ooonf[o0000o`000004
o`0000;ooo]Z1Ol00003oookJP03o`000?oonf[o000000;ooo]Z1Ol00005oookJP05o`000?oonf[o
oo]ZoookJ_l000000ooonfX01?l0003ooo]Zo`000?l0000;oookJP?o000000?ooo]Zo`000?l00000
1OoonfX3o`0000;ooo]Z0ol000000ooonf[o0000oookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX00_l00002oookJP03o`000?oonf[o000000;o000000?ooo]Zo`000?l00000
1?l000001?oonf[o0000oookJ_oonfX9o`0000Gooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003o
oo]ZoookJ_l00003oookJP05o`000?oonf[o0000oookJ_l000001OoonfX2o`0000?ooo]Z00Oo0000
oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z0ol00002oookJP06o`000?oonf[ooo]Zo`000?oo
nf[o00000_oonfX00ol0003ooo]Zo`000003o`000003oookJ_l0003ooo]Z00?o000000?ooo]Zo`00
0?l000001Ol0001WoookJPKo000000?ooo]Zo`000?l000000_oonfX00ol0003ooo]Zo`000003o`00
0003oookJ_l0003ooo]Z00;ooo]Z0_l000001_oonf[o0000oookJ_l0003ooo]Zo`0000Cooo]Z00?o
0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP03o`000003oookJ_l0003o000000;o000000?o
oo]Zo`000?l000000ooonfX2o`0000;ooo]Z00?o0000oookJ_oonfX01ooonfX01?l0003ooo]Zo`00
0?oonfX:o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Co
oo]Z0_l000000ooonf[o0000oookJP07oookJP;o000000Cooo]Zo`000?oonf[o00000ooonfX00ol0
003ooo]Zo`000004oookJP;o00000_oonfX01?l0003ooo]ZoookJ_l00002oookJPCo00001OoonfX0
1?l0003ooo]ZoookJ_l00004oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00Co0000oookJ_oonf[o
00001_oonfX2o`000003oookJ_l0003o000000?o000000Cooo]Zo`000?oonf[o00000ooonfX00ol0
003ooo]ZoookJP07o`0000;ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00;o00000_oonfX3o`00
00;ooo]Z00Co0000oookJ_oonf[o00001?oonfX01_l0003ooo]Zo`000?l0003ooo]Zo`0000;ooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000001_l0003ooo]Zo`000?oo
nf[o0000oookJP?o000000?ooo]Zo`000?l000000_l000001Ooonf[o0000oookJ_l0003ooo]Z00;o
00000_oonfX2o`0000Kooo]Z0_l000002?oonf[o0000o`000?oonf[o0000oookJ_l0003ooo]Z0_l0
0002oookJP03o`000?oonf[o000000;o00000ooonfX00ol0003ooo]Zo`000003o`000003oookJ_l0
003ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?l00005oookJP05o`000?oonf[o0000oookJ_l00000
0ooonfX01?l0003ooo]ZoookJ_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]Zo`000003oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l00002oookJP;o00000_oonfX01?l0
003ooo]ZoookJ_l00004oookJP03o`000?oonf[o000000?ooo]Z1_l00002oookJP03o`000?oonf[o
oo]Z00?ooo]Z1_l00002oookJP?o000000Gooo]Zo`000?l0003o0000oookJP02o`0000;ooo]Z00Go
0000oookJ_oonf[ooo]Zo`000005oookJP03o`000?oonf[o000000;o00000_oonfX01ol0003ooo]Z
oookJ_l0003ooo]Zo`000?oonfX00ol00007oookJPCo000000?ooo]Zo`000?l000000_l000001Ooo
nf[o0000oookJ_l0003ooo]Z00?o00001OoonfX3o`000003oookJ_l0003o000000[o0000I_oonfX6
o`0000?ooo]Z00Go0000oookJ_l0003o0000oookJP02o`000004oookJ_l0003o0000o`0000?ooo]Z
0_l00006oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00?ooo]Z00?o0000oookJ_l000000_l00002oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX01OoonfX6o`000007oookJ_l0003ooo]Zo`000?oonf[o0000oookJP04o`000003oookJ_l0
003ooo]Z00;o000000Cooo]Zo`000?l0003o00000_oonfX2o`0000?ooo]Z00?o0000oookJ_l00000
0_oonfX00ol0003ooo]ZoookJP05oookJP05o`000?oonf[o0000oookJ_l000000_oonfX01_l0003o
oo]ZoookJ_oonf[o0000oookJP;o00000_oonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oo
nf[ooo]Z00;o000000Kooo]Zo`000?oonf[ooo]Zo`000?oonfX3o`0000;ooo]Z00?o0000oookJ_oo
nfX01_oonfX3o`0000Gooo]Z00?o0000oookJ_l000000ol00002oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_l000001?l000001_oonf[o0000o`000?oonf[o0000oookJP?o00001?oonfX0
0ol0003ooo]Zo`000003oookJP;o00001ooonfX00ol0003ooo]ZoookJP03o`0000Cooo]Z0Ol00000
0007o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_l000001OoonfX00ol0003ooo]Zo`000006oookJP?o00000_oonfX3o`000006oookJ_l0
003ooo]ZoookJ_l0003ooo]Z0_l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000;o
00002ooonfX00ol0003ooo]Zo`000003o`0000Gooo]Z00Co0000oookJ_oonf[o00000_oonfX2o`00
0005oookJ_l0003o0000oookJ_l000001?oonfX3o`0000Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0004oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l000001?oonf[o0000o`000?l00002oookJP04o`00
0?oonf[o0000oookJP;o00001OoonfX01?l0003ooo]Zo`000?oonfX3o`0000;ooo]Z2_l00005oook
JP04o`000?oonf[ooo]ZoookJP;o00001OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
000000Gooo]Z0ol000001?oonf[o0000oookJ_oonfX2o`0000Cooo]Z1Ol000001?oonf[o0000oook
J_l00002oookJP03o`000?oonf[ooo]Z00?o000000?ooo]Zo`000?l000001Ol000000ooonf[o0000
o`000002o`0006Gooo]Z1?l000000ooonf[o0000o`000003oookJP03o`000?oonf[o000000;o0000
00Cooo]Zo`000?oonf[o00000_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o00000_oonfX2o`00
00;ooo]Z00?o0000oookJ_l000001ooonfX2o`0000Gooo]Z00Co0000oookJ_l0003o00001ooonfX2
o`000006oookJ_l0003ooo]Zo`000?oonf[o00000ooonfX2o`0000?ooo]Z1?l00003oookJP?o0000
0ooonfX3o`000003oookJ_l0003o000000;ooo]Z0_l000000ooonf[o0000oookJP06oookJPGo0000
0_oonfX02Ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[o
000000;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?oonf[ooo]Z1Ol0
0004oookJP;o000000?ooo]Zo`000?oonfX01?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00Kooo]Z2_l00002oookJP;o000000Oooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z00;o
00001?oonfX2o`000005oookJ_l0003ooo]ZoookJ_l000001?oonfX01Ol0003ooo]ZoookJ_oonf[o
000000;ooo]Z00?o0000oookJ_oonfX02OoonfX1o`00000000Co0000oookJ_oonf[o00000_oonfX0
0ol0003ooo]ZoookJP03oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0ol000001?oonf[o0000
o`000?l00006oookJP;o00002?oonfX2o`000003oookJ_l0003o000000;ooo]Z1_l000001?oonf[o
0000o`000?l00003oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP02
oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000_oonfX01?l0003ooo]Zo`000?oonfX2o`000004
oookJ_l0003ooo]Zo`0000?ooo]Z00?o0000oookJ_l000000_oonfX2o`0000?ooo]Z00Go0000oook
J_oonf[ooo]Zo`000003oookJP03o`000?oonf[o000000;o000000Cooo]Zo`000?oonf[o00000_oo
nfX00ol0003ooo]ZoookJP02oookJPKo000000?ooo]Zo`000?l000000_oonfX00ol0003ooo]Zoook
JP03o`0000Oooo]Z0_l000000ooonf[o0000oookJP02o`0000?ooo]Z0_l00005oookJP04o`000?oo
nf[ooo]ZoookJP;o00002?oonfX00ol0003ooo]ZoookJP06oookJP;o00002OoonfX5o`0000?ooo]Z
00Co0000oookJ_l0003ooo]Z0ol000001Ooonf[o0000oookJ_l0003ooo]Z00?o000000?ooo]Zo`00
0?l000001?l000000ooonf[o0000o`000002o`0006Cooo]Z2Ol000001?oonf[o0000o`000?l00002
oookJP03o`000?oonf[ooo]Z00;o00001?oonfX01?l0003ooo]Zo`000?l00005oookJP?o000000?o
oo]Zo`000?l000000_oonfX00ol0003ooo]Zo`000002oookJP;o00000ooonfX01ol0003ooo]Zo`00
0?oonf[o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`00
00Gooo]Z0_l000001?oonf[o0000o`000?l00002oookJP;o00000_oonfX5o`0000;ooo]Z00?o0000
oookJ_l000001Ol00003oookJP;o000000?ooo]Zo`000?oonfX00_oonfX2o`0000;ooo]Z0_l00000
2?oonf[o0000o`000?l0003ooo]Zo`000?oonf[o00000_oonfX01_l0003ooo]Zo`000?oonf[o0000
oookJP;o00000_oonfX00ol0003ooo]ZoookJP04oookJP04o`000?oonf[ooo]ZoookJP;o00002_oo
nfX2o`0000;ooo]Z00?o0000oookJ_l000000ol00003oookJP04o`000?oonf[ooo]ZoookJPCo0000
00Cooo]Zo`000?oonf[o00000_oonfX7o`0000?ooo]Z00?o0000oookJ_oonfX01_l00002oookJP03
o`000?oonf[ooo]Z00Gooo]Z0_l00003oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z0ol00004oook
JP7o000000002?l0003ooo]Zo`000?l0003ooo]Zo`000?oonf[o00001?oonfX01?l0003ooo]Zoook
J_l00007oookJP;o00001_oonfX2o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?oonf[o
00000ooonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oonf[o000000;o000000?ooo]Zo`00
0?l000002?oonfX00ol0003ooo]Zo`000002oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oook
JP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP;o000000?ooo]Zo`000?oonfX00ol00003oook
JP;o00001OoonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[o0000oookJ_l000000_oonfX0
0ol0003ooo]Zo`000003oookJP05o`000?oonf[o0000o`000?oonfX00_l000000ooonf[o0000o`00
0003oookJP03o`000?oonf[o000000Ko000000?ooo]Zo`000?l000001_l000000ooonf[o0000oook
JP03oookJP;o00000_oonfX2o`0000;ooo]Z0ol00003oookJP;o00001ooonfX2o`0000;ooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000002o`0000;ooo]Z00?o0000oookJ_oonfX01?oo
nfX2o`000003oookJ_l0003ooo]Z00Co000000Gooo]Zo`000?oonf[o0000oookJP02o`000005oook
J_l0003o0000o`000?oonfX02?l0001QoookJPSo000000?ooo]Zo`000?l000000ooonfX4o`0000?o
oo]Z1?l000000ooonf[o0000oookJP03oookJP;o000000?ooo]Zo`000?oonfX04ooonfX00ol0003o
oo]ZoookJP02oookJP;o00003_oonfX00ol0003ooo]ZoookJP03oookJPWo00000ooonfX4o`000004
oookJ_l0003ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00_l00004oookJP;o00000_oonfX00ol0
003ooo]ZoookJP04o`0000?ooo]Z00Go0000oookJ_l0003ooo]Zo`000003oookJPCo00001?oonfX0
0ol0003ooo]ZoookJP02oookJP08o`000?oonf[o0000o`000?oonf[o0000oookJ_l00002oookJP03
o`000?oonf[o000000?ooo]Z0_l00007oookJP04o`000?oonf[ooo]ZoookJPCo000000?ooo]Zo`00
0?l000000_oonfX01?l0003ooo]ZoookJ_l00004oookJP;o00001OoonfX3o`000004oookJ_l0003o
oo]ZoookJP;o00000ooonfX4o`00017ooo]Z00?o0000oookJ_oonfX00Ol000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00?ooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJPOo00001_oonfX3o`000003oookJ_l0003o
oo]Z00?ooo]Z00?o0000oookJ_oonfX00ol00004oookJPCo00000_oonfX4o`0000Wooo]Z00Oo0000
oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_l000001OoonfX01_l0003ooo]Z
o`000?oonf[o0000oookJP;o00001?oonfX2o`0000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00006
oookJP03o`000?oonf[o000000;ooo]Z0ol00003oookJPOo00000ooonfX01Ol0003ooo]ZoookJ_l0
003ooo]Z00Co000000Kooo]Zo`000?oonf[ooo]Zo`000?oonfX7o`0000_ooo]Z00?o0000oookJ_oo
nfX00ooonfX01?l0003ooo]ZoookJ_oonfX4o`0000?ooo]Z00Co0000oookJ_oonf[o00000_oonfX3
o`000003oookJ_l0003ooo]Z00;ooo]Z00Co0000oookJ_l0003ooo]Z0_l00003oookJP;o000000?o
oo]Zo`000?oonfX01?oonfX00ol0003ooo]Zo`000002o`0000;ooo]Z1?l000001Ooonf[o0000oook
J_l0003ooo]Z00?o000000?ooo]Zo`000?l00000H?oonfX3o`00000<oookJ_l0003o0000oookJ_l0
003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z0_l000001?oonf[o0000o`000?oonfX5o`000003
oookJ_l0003ooo]Z00;o00000ooonfX01?l0003ooo]ZoookJ_l00004oookJP;o00003OoonfX2o`00
00Gooo]Z00Go0000oookJ_l0003ooo]Zo`000009oookJP04o`000?oonf[ooo]ZoookJPGo00000_oo
nfX2o`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000;ooo]Z0_l00002oookJP07o`000?oo
nf[ooo]ZoookJ_l0003ooo]Zo`000004oookJP04o`000?oonf[o0000oookJP;o000000?ooo]Zo`00
0?oonfX00_oonfX00ol0003ooo]ZoookJP03oookJPCo00000_oonfX2o`0000;ooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX3
o`000003oookJ_l0003ooo]Z00;ooo]Z00Wo0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJ_l0
00000_oonfX00ol0003ooo]Zo`000003oookJPKo000000Kooo]Zo`000?oonf[ooo]Zo`000?oonfX3
o`0000;ooo]Z00?o0000oookJ_l000000_l00003oookJP?o000000Kooo]Zo`000?l0003o0000oook
J_l00002oookJP;o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]ZoookJP01o`00000000Co
0000oookJ_l0003o00000_oonfX00ol0003ooo]ZoookJP04o`000005oookJ_l0003ooo]ZoookJ_l0
00000_oonfX00ol0003ooo]ZoookJP02o`0000Kooo]Z0_l000000ooonf[o0000oookJP02o`000003
oookJ_l0003ooo]Z00Co000000?ooo]Zo`000?oonfX00_l000000ooonf[o0000o`000002oookJP;o
00000_oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP03o`0000?o
oo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]Zoook
J_l000000ooonfX4o`0000Cooo]Z00Go0000oookJ_oonf[o0000oookJP05o`0000;ooo]Z0_l00003
oookJP03o`000?oonf[ooo]Z00;o00000ooonfX2o`0000?ooo]Z1?l00003oookJPGo00000_oonfX4
o`0000?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[o
0000o`0000_ooo]Z00Co0000oookJ_oonf[o00000_oonfX2o`0000Sooo]Z0_l00002oookJP03o`00
0?oonf[o000000;o000000?ooo]Zo`000?l000001OoonfX2o`000004oookJ_l0003o0000o`0000?o
oo]Z0_l000000ooonf[o0000oookJP02o`000003oookJ_l0003ooo]Z00;o0000GooonfX5o`000004
oookJ_l0003o0000oookJP?o00002_oonfX3o`000007oookJ_l0003ooo]ZoookJ_l0003ooo]Zo`00
0004oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_l00004oookJP08o`000?oo
nf[ooo]Zo`000?oonf[o0000oookJ_l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oook
J_oonf[o00003?oonfX9o`0000;ooo]Z0_l00004oookJP?o00000_oonfX2o`000004oookJ_l0003o
oo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Co
oo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000?ooo]Z00Co0000oookJ_oonf[o00000_oonfX0
0ol0003ooo]ZoookJP08oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Ko0000oookJ_oonf[ooo]Z
o`000?oonfX3o`0000?ooo]Z00?o0000oookJ_l000000ooonfX4o`0000Kooo]Z00Co0000oookJ_l0
003ooo]Z0_l000001?oonf[o0000o`000?oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]Zo`000002oookJP;o00001?oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000gooo]Z
0Ol000000003o`000?oonf[ooo]Z00?o000000Cooo]Zo`000?l0003o00001_oonfX00ol0003ooo]Z
o`000005oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00;ooo]Z
00Ko0000oookJ_l0003ooo]Zo`000?oonfX2o`0000;ooo]Z0_l00002oookJPCo000000?ooo]Zo`00
0?oonfX00_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000_oonfX01Ol0003ooo]Zo`00
0?oonf[o000000Gooo]Z1_l00002oookJP?o000000Cooo]Zo`000?oonf[ooo]Z0_l00002oookJP03
o`000?oonf[o000000Co00000_oonfX01?l0003ooo]ZoookJ_l00005oookJP;o000000Oooo]Zo`00
0?oonf[ooo]Zo`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX01?l000001?oonf[o0000o`00
0?oonfX2o`000003oookJ_l0003o000000Co00000ooonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_l00003oookJP;o00001?oonfX2o`0000;ooo]Z
00?o0000oookJ_oonfX00_l00003oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_l00000
1OoonfX01?l0003ooo]Zo`000?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX02ol0001NoookJP_o
000000?ooo]Zo`000?l000000_oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o000000Cooo]Zo`00
0?oonf[o00001_oonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[o0000o`000?oonfX00_l0
0002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000000_oonfX01_l0003ooo]Zo`00
0?oonf[o0000oookJP;o00000ooonfX01_l0003ooo]Zo`000?oonf[o0000oookJP;o00001_oonfX2
o`000003oookJ_l0003ooo]Z00Co000000Gooo]Zo`000?l0003o0000oookJP03o`0000;ooo]Z0_l0
0006oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]Zoook
J_l00002oookJP03o`000?oonf[o000000Wooo]Z00Co0000oookJ_l0003o00000_oonfX2o`000005
oookJ_l0003ooo]ZoookJ_l000000_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o000000Wooo]Z
o`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l000000ooonfX4o`0000;ooo]Z00?o0000oookJ_oo
nfX01?l000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l00005
oookJP?o00000_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[o000000;ooo]Z0ol00002
oookJP;o00001ooonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003
o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000002o`000004
oookJ_l0003o0000oookJPCo00001_oonfX3o`000003oookJ_l0003o000000;o00000ooonfX3o`00
0008oookJ_l0003o0000o`000?oonf[o0000oookJ_l00003oookJP03o`000?oonf[o000000Co0000
2?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z00Co0000oookJ_oonf[o00001?oonfX02?l0
003ooo]ZoookJ_l0003ooo]Zo`000?oonf[o00000ooonfX00ol0003ooo]ZoookJP05oookJP;o0000
0ooonfX00ol0003ooo]Zo`00000:oookJP08o`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l00002
oookJP05o`000?oonf[o0000o`000?oonfX00ol000001_oonf[o0000oookJ_oonf[o0000oookJPCo
00001?oonfX00ol0003ooo]ZoookJP04oookJP;o00001?oonfX2o`000003oookJ_l0003o000000;o
oo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?o
oo]Z00Co0000oookJ_oonf[o00000ooonfX3o`000003oookJ_l0003ooo]Z00Cooo]Z00Co0000oook
J_oonf[ooo]Z3Ol0001MoookJPGo000000Gooo]Zo`000?l0003o0000oookJP04o`0000;ooo]Z0ol0
0002oookJP;o00001?oonfX00ol0003ooo]ZoookJP03o`0000Sooo]Z0ol000001?oonf[o0000oook
J_l00002oookJP03o`000?oonf[o000000[ooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]Z
oookJP04oookJP;o00000_oonfX00ol0003ooo]Zo`000003o`000003oookJ_l0003o000000;o0000
0_oonfX4o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l00003oookJPGo000000Gooo]Zo`000?oo
nf[ooo]Zo`000005oookJP03o`000?oonf[o000000;o00000_oonfX01?l0003ooo]Zo`000?l00004
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX3o`0000;ooo]Z00?o0000
oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Co0000oookJ_oonf[ooo]Z
0_l00002oookJP04o`000?oonf[ooo]ZoookJP;o00001?oonfX00ol0003ooo]ZoookJP02o`000006
oookJ_l0003ooo]Zo`000?oonf[o00001?oonfX3o`0000;ooo]Z00Co0000oookJ_oonf[o00000ooo
nfX01?l0003ooo]Zo`000?l00005oookJP;o00000ooonfX2o`0000Cooo]Z0Ol000000007o`000?oo
nf[ooo]ZoookJ_l0003ooo]Zo`000003oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00?o0000oook
J_oonfX00_l00006oookJP;o000000?ooo]Zo`000?oonfX00ooonfX4o`000005oookJ_l0003o0000
oookJ_l000000ooonfX3o`000003oookJ_l0003ooo]Z00;ooo]Z0ol000001Ooonf[o0000oookJ_oo
nf[o000000?ooo]Z00?o0000oookJ_l000001?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oookJP?o00000_oonfX01?l0003ooo]Z
oookJ_l00004oookJP;o000000?ooo]Zo`000?l000000_oonfX00ol0003ooo]Zo`000006oookJP;o
00000_oonfX4o`0000;ooo]Z1Ol00002oookJP04o`000?oonf[ooo]ZoookJP;o000000?ooo]Zo`00
0?l000000_l00002oookJP04o`000?oonf[o0000o`0000?ooo]Z00Oo0000oookJ_oonf[ooo]Zo`00
0?oonf[o000000?ooo]Z00Go0000oookJ_l0003ooo]Zo`000004oookJP06o`000?oonf[ooo]Zo`00
0?oonf[o00000ooonfX2o`0000Gooo]Z0_l000000ooonf[o0000o`000005oookJP;o00001OoonfX2
o`0000;ooo]Z1?l00003oookJP03o`000?oonf[o000000?o00000_oonfX7o`0005_ooo]Z2?l00000
1Ooonf[o0000o`000?oonf[o000000;ooo]Z1?l000000ooonf[o0000o`000002o`0000?ooo]Z1?l0
00001Ooonf[o0000o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX01?oonfX3o`000003oook
J_l0003ooo]Z00Cooo]Z0_l00005oookJP;o00003OoonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[o000000?o00000_oonfX00ol0003ooo]ZoookJP02o`000004oookJ_l0003ooo]Zo`0000?o
oo]Z00?o0000oookJ_oonfX01?l00003oookJP?o00000_oonfX2o`000003oookJ_l0003ooo]Z00?o
oo]Z00Oo0000oookJ_l0003ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP04oookJPCo00000ooonfX2o`0000_ooo]Z1_l000001Ooonf[o0000oookJ_l0
003ooo]Z00;o000000Cooo]Zo`000?oonf[o00000ooonfX01?l0003ooo]Zo`000?l00005oookJP04
o`000?oonf[o0000oookJP;o000000?ooo]Zo`000?oonfX01_oonfX3o`0000Cooo]Z00Ko0000oook
J_l0003o0000oookJ_l00006oookJP7o000000001_l0003ooo]ZoookJ_oonf[o0000oookJP;o0000
0_oonfX01?l0003ooo]ZoookJ_l00006oookJP03o`000?oonf[ooo]Z00;o00001_oonfX00ol0003o
oo]ZoookJP02oookJP;o00000ooonfX01?l0003ooo]ZoookJ_oonfX2o`000005oookJ_l0003o0000
oookJ_l000000ooonfX00ol0003ooo]Zo`000005o`0000_ooo]Z00Co0000oookJ_oonf[o00001Ooo
nfX2o`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Kooo]Z0_l00002oookJP03o`000?oo
nf[ooo]Z00Co00001_oonfX3o`000004oookJ_l0003o0000o`0000?ooo]Z0ol00002oookJP?o0000
00?ooo]Zo`000?oonfX00ooonfX00ol0003ooo]Zo`000006o`0000Cooo]Z00Go0000oookJ_oonf[o
oo]Zo`000003oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Go
oo]Z00Co0000oookJ_l0003ooo]Z0_l00003oookJP;o00000ooonfX2o`000003oookJ_l0003ooo]Z
00;ooo]Z0_l000000ooonf[o0000oookJP03oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000
oookJ_l000000ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000;ooo]Z1Ol0001J
oookJPKo00000ooonfX2o`000006oookJ_l0003ooo]ZoookJ_l0003ooo]Z0ol00002oookJP;o0000
1?oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX01?oonfX2o`000003oookJ_l0003o000000Wooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP;o00001_oonfX01?l0003ooo]Z
oookJ_l00002oookJP;o00001ooonfX3o`0000?ooo]Z0_l000000ooonf[o0000o`000002oookJP04
o`000?oonf[o0000o`0000Cooo]Z0_l000001?oonf[o0000o`000?l00002oookJP;o000000?ooo]Z
o`000?oonfX01_oonfX2o`00000;oookJ_l0003ooo]ZoookJ_l0003ooo]Zo`000?oonf[o0000oook
J_l000000_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001OoonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003o00000ooonfX00ol0003ooo]Z
oookJP04o`000004oookJ_l0003o0000oookJP?o00000_oonfX3o`000003oookJ_l0003o000000?o
00001OoonfX2o`0000Oooo]Z00?o0000oookJ_l000000_l000000ooonf[o0000oookJP07oookJP04
o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_l000001OoonfX1o`00000000Go0000oookJ_oo
nf[o0000oookJP02o`000005oookJ_l0003o0000oookJ_l000000ooonfX5o`000005oookJ_l0003o
oo]ZoookJ_l000001_oonfX2o`0000Kooo]Z0_l00002oookJP04o`000?oonf[o0000oookJP;o0000
1?oonfX2o`000004oookJ_l0003ooo]ZoookJPKo000000Cooo]Zo`000?oonf[o00001?oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_l000001OoonfX00ol0
003ooo]ZoookJP09oookJP?o000000Cooo]Zo`000?l0003ooo]Z0_l000000ooonf[o0000oookJP05
oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[o
000000?o000000Gooo]Zo`000?oonf[o0000oookJP03o`000003oookJ_l0003o000000?o00000_oo
nfX2o`0000Cooo]Z00?o0000oookJ_l000001OoonfX01Ol0003ooo]Zo`000?oonf[o000000cooo]Z
00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX00ooonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oookJ_l000001ooonfX5o`00
0003oookJ_l0003o000000?ooo]Z1Ol0001IoookJPSo000000Cooo]Zo`000?l0003ooo]Z1Ol00000
0ooonf[o0000oookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00000ooo
nfX00ol0003ooo]ZoookJP03o`0000Sooo]Z00Go0000oookJ_l0003ooo]Zo`00000@oookJP03o`00
0?oonf[ooo]Z00Sooo]Z0_l00006oookJP?o00000_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`00
00?ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[o
oo]Zo`0000;ooo]Z1Ol00005oookJP?o00000ooonfX00ol0003ooo]Zo`000005oookJP03o`000?oo
nf[ooo]Z00;o00001ooonfX00ol0003ooo]ZoookJP08oookJP05o`000?oonf[ooo]ZoookJ_l00000
0ooonfX2o`000004oookJ_l0003o0000oookJP;o00000_oonfX01?l0003ooo]Zo`000?oonfX5o`00
00;ooo]Z0ol000000ooonf[o0000oookJP02o`0000;ooo]Z00?o0000oookJ_oonfX00_l000000ooo
nf[o0000o`000002oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_l0003o00000_oonfX0
1ol0003ooo]ZoookJ_l0003ooo]Zo`000?oonfX00Ol000000003o`000?oonf[ooo]Z0?oooo]Zoooo
nfXnoookJP7o000000000ol0003ooo]ZoookJP09oookJP;o00001?oonfX01?l0003ooo]ZoookJ_oo
nfX3o`0000Kooo]Z2Ol00002oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0ol000001_oonf[o
0000oookJ_l0003ooo]Zo`0000Cooo]Z1Ol00002oookJP03o`000?oonf[o000000Cooo]Z00Oo0000
oookJ_oonf[ooo]Zo`000?oonf[o000000?ooo]Z0_l000000ooonf[o0000oookJP0CoookJP04o`00
0?oonf[ooo]ZoookJP;o00000ooonfX01?l0003ooo]Zo`000?l00005oookJP04o`000?oonf[ooo]Z
oookJP;o00000_oonfX2o`000004oookJ_l0003ooo]Zo`0000;ooo]Z0_l000000ooonf[o0000o`00
0002oookJP?o00000ooonfX3o`0000Cooo]Z00Co0000oookJ_oonf[o00001?oonfX01?l0003ooo]Z
oookJ_l00007oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00;o
oo]Z1?l000001?oonf[o0000oookJ_l00003oookJP?o000000Cooo]Zo`000?l0003ooo]Z0_l00004
oookJP04o`000?oonf[o0000o`0000;ooo]Z00Go0000oookJ_l0003o0000oookJP06o`0005Sooo]Z
0_l000000ooonf[o0000o`000004o`0000;ooo]Z0ol000000ooonf[o0000o`000002o`0000;ooo]Z
00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00002oookJPCo000000Oooo]Zo`000?l0
003ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01OoonfX2o`000004oookJ_l0003o
0000o`0000Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00?ooo]Z1ol000000ooonf[o0000oookJP02oookJP03o`000?oonf[o000000Cooo]Z00?o
0000oookJ_oonfX00ol00002oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00002oookJP03o`000?oo
nf[o000000Cooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Zo`000002o`0000?ooo]Z
00?o0000oookJ_oonfX00_l00004oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o
00000ooonfX2o`000007oookJ_l0003ooo]Zo`000?oonf[o0000oookJP08o`0000;ooo]Z0ol00005
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000000_oonfX2o`0000Cooo]Z1?l00000
1Ooonf[o0000oookJ_oonf[o000000Kooo]Z00?o0000oookJ_l000000_oonfX01_l0003ooo]Zoook
J_l0003ooo]Zo`0000Cooo]Z0Ol000000005o`000?oonf[o0000oookJ_l000001?oonfX00ol0003o
oo]ZoookJP07oookJP04o`000?oonf[ooo]ZoookJP;o00001_oonfX2o`0000Sooo]Z0_l000000ooo
nf[o0000o`000005oookJP08o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonfX6o`0000Sooo]Z
00Go0000oookJ_oonf[ooo]Zo`000002oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0
003ooo]Zo`000002oookJP?o00001?oonfX01Ol0003ooo]Zo`000?oonf[o000000?ooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z00Sooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP05o`000?oo
nf[o0000oookJ_l000001_oonfX3o`000004oookJ_l0003o0000o`0000;ooo]Z00Co0000oookJ_oo
nf[o00003_oonfX2o`0000Gooo]Z0_l000000ooonf[o0000oookJP05oookJP03o`000?oonf[ooo]Z
00;ooo]Z0_l00002oookJP04o`000?oonf[o0000oookJP;o00000ooonfX00ol0003ooo]ZoookJP04
oookJP;o000000?ooo]Zo`000?oonfX00_l000000ooonf[o0000o`000005oookJP?o000000Gooo]Z
o`000?l0003o0000oookJP02o`000003oookJ_l0003o000000;o0000E_oonfX3o`000004oookJ_l0
003ooo]ZoookJPOo000000?ooo]Zo`000?oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP06o`00
0?oonf[o0000o`000?oonf[o00002OoonfX4o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oook
J_l000000_oonfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000
oookJ_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00?o0000oookJ_l000000ol0
00000ooonf[o0000oookJP02o`000003oookJ_l0003o000000;ooo]Z00?o0000oookJ_l000000_l0
00001?oonf[o0000oookJ_l00002oookJP;o00000_oonfX00ol0003ooo]Zo`000002o`000003oook
J_l0003ooo]Z00?ooo]Z0_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX01OoonfX2o`0000Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
o`000003oookJP;o00000ooonfX5o`0000Kooo]Z00Co0000oookJ_l0003o00000ooonfX2o`000003
oookJ_l0003ooo]Z00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP04o`000?oonf[ooo]Z
oookJP;o00000_oonfX2o`000004oookJ_l0003ooo]Zo`0000?ooo]Z0_l000001ooonf[o0000o`00
0?oonf[o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02oookJP7o000000001?l0003ooo]Z
oookJ_l00003oookJP;o00000ooonfX3o`000006oookJ_l0003ooo]Zo`000?oonf[o00000ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_l0003o00000ooo
nfX00ol0003ooo]ZoookJP02oookJP;o000000Cooo]Zo`000?l0003ooo]Z0_l00002oookJP04o`00
0?oonf[ooo]ZoookJPGo00001?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;o
oo]Z00So0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`0000Cooo]Z00Co0000oookJ_l0003o0000
1?oonfX00ol0003ooo]Zo`000002oookJP?o00001?oonfX2o`0000;ooo]Z0_l000000ooonf[o0000
oookJP02oookJP03o`000?oonf[o000000Gooo]Z1?l000000ooonf[o0000o`000004oookJPWo0000
00Cooo]Zo`000?oonf[o00003ooonfX00ol0003ooo]Zo`000002oookJP05o`000?oonf[o0000o`00
0?oonfX00_l00002oookJP;o000000?ooo]Zo`000?oonfX01?l000001_oonf[o0000oookJ_oonf[o
0000oookJP;o00000_oonfX2o`0000?ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_l000000_oonfX8o`0000Kooo]Z1_l0001EoookJPSo000000?ooo]Zo`000?l000000_oo
nfX01?l0003ooo]Zo`000?l00007oookJPCo00000_oonfX00ol0003ooo]Zo`000009oookJP05o`00
0?oonf[ooo]ZoookJ_l000001ooonfX00ol0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00Go
oo]Z0_l000000ooonf[o0000oookJP04oookJP06o`000?oonf[ooo]Zo`000?oonf[o00001_oonfX3
o`000006oookJ_l0003ooo]Zo`000?oonf[o00001?oonfX00ol0003ooo]ZoookJP02o`0000gooo]Z
0_l00002oookJP04o`000?oonf[ooo]ZoookJP;o00001?oonfX00ol0003ooo]Zo`000003oookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_l00002oookJP;o00001?oonfX2o`0000;o
oo]Z0_l0000:oookJPCo000000Cooo]Zo`000?oonf[ooo]Z0ol000000ooonf[o0000o`000003oook
JP;o00000_oonfX01?l0003ooo]Zo`000?l00003oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0_l0
0002oookJP;o00000ooonfX02Ol0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000002oook
JP?o00001ooonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?oonfX5o`0000Cooo]Z0ol00007oookJPCo0000
0_oonfX00ol0003ooo]Zo`000003oookJP06o`000?oonf[o0000oookJ_l0003ooo]Z1_l00002oook
JPGo00000ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o000000cooo]Z00?o0000oook
J_l000001ooonfX00ol0003ooo]Zo`000004o`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX3o`00
00?ooo]Z00?o0000oookJ_l000001ooonfX2o`0000;ooo]Z00Ko0000oookJ_l0003ooo]Zo`000?oo
nfX2o`0000?ooo]Z0ol00008oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000001_oo
nfX2o`0000?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP02oookJP;o00000_oo
nfX01ol0003ooo]Zo`000?oonf[o0000oookJ_l000000ooonfX01?l0003ooo]ZoookJ_l00004oook
JP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP06o`000?oonf[o0000o`000?oonf[o
00000_oonfX6o`000005oookJ_l0003ooo]Zo`000?oonfX01?l0001DoookJPSo00000_oonfX01?l0
003ooo]Zo`000?oonfX3o`0000Cooo]Z0_l00005oookJP05o`000?oonf[ooo]ZoookJ_l000000_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00;ooo]Z
00Co0000oookJ_oonf[o00002_oonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[o0000o`00
00[ooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00;o000000?ooo]Zo`000?l000000ooonfX3
o`000003oookJ_l0003ooo]Z00;ooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP;o00001?oo
nfX3o`0000Cooo]Z00?o0000oookJ_l000001OoonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o0000
1OoonfX00ol0003ooo]ZoookJP02o`0000Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP03oookJP04o`000?oonf[o0000oookJP;o000000?ooo]Zo`000?l000000ol000000ooonf[o
0000oookJP02o`0000Cooo]Z0_l00005oookJP;o00001OoonfX01_l0003ooo]ZoookJ_l0003ooo]Z
o`0000;ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?oonf[ooo]Z0ol0
0003oookJP7o000000001Ol0003ooo]ZoookJ_l0003ooo]Z00;o000000?ooo]Zo`000?oonfX00_l0
0003oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX2o`0000Kooo]Z0_l00002oookJP03o`00
0?oonf[ooo]Z00;ooo]Z0ol00003oookJP?o00001?oonfX01?l0003ooo]ZoookJ_l00003oookJPSo
00002?oonfX01?l0003ooo]ZoookJ_l00002oookJP;o00000_oonfX00ol0003ooo]ZoookJP04oook
JP;o00004?oonfX00ol0003ooo]Zo`000002oookJP05o`000?oonf[ooo]Zo`000?oonfX01?l00000
0ooonf[o0000o`000002o`0000;ooo]Z00?o0000oookJ_l000000_oonfX2o`000007oookJ_l0003o
0000oookJ_l0003ooo]Zo`000002oookJPSo00003?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Oo
oo]Z00Co0000oookJ_oonf[o00001ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Cooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Gooo]Z0ol00004oookJP03o`000?oo
nf[o000000;o000000?ooo]Zo`000?l000000ooonfX00ol0003ooo]Zo`000009o`0005?ooo]Z1Ol0
00000ooonf[o0000o`000002o`0000;ooo]Z00Co0000oookJ_l0003o00000_oonfX2o`000005oook
J_l0003ooo]ZoookJ_l000001?oonfX00ol0003ooo]ZoookJP03oookJP?o000000Gooo]Zo`000?oo
nf[ooo]Zo`000002oookJP08o`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l00004oookJP03o`00
0?oonf[o000000?o00000ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o000000;ooo]Z
00[o0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z0ol000001Ooonf[o0000oook
J_oonf[o000000;ooo]Z0_l00002oookJP;o00000ooonfX00ol0003ooo]Zo`000004oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]Zo`000002oookJP;o0000
1_oonfX01?l0003ooo]Zo`000?l00005oookJP;o00000_oonfX01?l0003ooo]ZoookJ_oonfX2o`00
00Gooo]Z0ol00009oookJP?o00001?oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oook
J_oonfX00_l000000ooonf[o0000oookJP04o`0000Cooo]Z00?o0000oookJ_oonfX00_l000001?oo
nf[o0000oookJ_oonfX1o`00000000?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000002oook
JP03o`000?oonf[ooo]Z00?ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oook
J_oonf[ooo]Z0ol00004oookJP04o`000?oonf[o0000o`0000Cooo]Z00?o0000oookJ_l000001?oo
nfX00ol0003ooo]Zo`000002o`0000;ooo]Z1Ol000000ooonf[o0000oookJP02oookJP06o`000?oo
nf[ooo]Zo`000?oonf[o00000ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP?o00000ooonfX00ol0003ooo]ZoookJP02oook
JP06o`000?oonf[o0000o`000?oonf[o00000_oonfX01?l0003ooo]ZoookJ_oonfX3o`0000;ooo]Z
0ol000001?oonf[o0000o`000?l00002oookJP03o`000?oonf[o000000Gooo]Z0_l00002oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01ooonfX2o`0000Gooo]Z0ol00002oookJP?o
00000ooonfX00ol0003ooo]Zo`000002o`0000;ooo]Z00?o0000oookJ_l000000_oonfX2o`0000;o
oo]Z1Ol000000ooonf[o0000o`000002o`0000;ooo]Z0_l000000ooonf[o0000o`00000;o`00057o
oo]Z1Ol000001Ooonf[o0000oookJ_l0003ooo]Z00?o00000ooonfX2o`000003oookJ_l0003ooo]Z
00;ooo]Z00?o0000oookJ_l000000ooonfX01Ol0003ooo]Zo`000?l0003ooo]Z00Ko00003OoonfX2
o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z
00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oo
nfX01?oonfX2o`000003oookJ_l0003o000000Go000000Cooo]Zo`000?l0003ooo]Z0ol00004oook
JP04o`000?oonf[ooo]Zo`0000?ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Zo`00
0006oookJP03o`000?oonf[o000000;ooo]Z0_l000000ooonf[o0000oookJP04oookJP03o`000?oo
nf[ooo]Z00?ooo]Z0_l00005oookJP;o00001OoonfX3o`0000Gooo]Z0_l00002oookJP03o`000?oo
nf[o000000;o00002?oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00Co00001?oonfX01?l0003ooo]Z
oookJ_oonfX2o`0000Gooo]Z0_l00004oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l000000ooonf[o
0000oookJP02oookJP03o`000?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z
?_oonfX1o`00000000Oo0000oookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z0_l00004oookJP05
o`000?oonf[ooo]Zo`000?oonfX00_l000000ooonf[o0000o`000006oookJP;o000000Cooo]Zo`00
0?oonf[ooo]Z1Ol00004oookJP;o000000Wooo]Zo`000?l0003o0000oookJ_l0003ooo]Zo`000?oo
nfX00ol000001ooonf[o0000o`000?l0003ooo]Zo`000?oonfX00_l00005oookJP04o`000?oonf[o
oo]Zo`0000?ooo]Z00?o0000oookJ_l000000ooonfX2o`0000Cooo]Z00Go0000oookJ_l0003ooo]Z
o`000002oookJP04o`000?oonf[o0000o`0000?ooo]Z00Co0000oookJ_oonf[o00001?oonfX6o`00
0006oookJ_l0003ooo]Zo`000?oonf[o00001?oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o0000
00?ooo]Zo`000?oonfX01Ol00002oookJP?o000000?ooo]Zo`000?oonfX01OoonfX01?l0003ooo]Z
o`000?l00003oookJP;o00000_oonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Gooo]Z00Co0000oookJ_l0003o00000ooonfX0
1Ol0003ooo]Zo`000?l0003ooo]Z00;o00000_oonfX2o`000003oookJ_l0003o000000;o00001?oo
nfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o000000Cooo]Zo`000?oonf[ooo]Z2Ol000000ooonf[o
0000o`000002o`00057ooo]Z1_l000001_oonf[o0000o`000?l0003ooo]Zo`0000;ooo]Z0_l00002
oookJP04o`000?oonf[o0000o`0000;ooo]Z00?o0000oookJ_oonfX00_l00002oookJP?o00002?oo
nfX2o`0000;ooo]Z0_l00005oookJP?o00001?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00_l0000:oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0
00001ooonf[o0000oookJ_l0003ooo]Zo`000?oonfX00_l00004oookJP05o`000?oonf[ooo]Zoook
J_l000000_oonfX3o`000003oookJ_l0003o000000;ooo]Z0ol00007oookJP?o00000_oonfX00ol0
003ooo]Zo`000002o`000008oookJ_l0003ooo]ZoookJ_l0003ooo]Zo`000?oonfX4o`0000?ooo]Z
00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]Zo`000002oookJP?o00000_oonfX00ol0003o
oo]Zo`000005o`0000;ooo]Z00Co0000oookJ_l0003o00000_oonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[o000000Wooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP;o00001?oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX00Ol00000
0005o`000?oonf[ooo]ZoookJ_l000002ooonfX00ol0003ooo]ZoookJP02o`000004oookJ_l0003o
oo]Zo`0000Kooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000000ol0
00001?oonf[o0000o`000?l00002oookJPOo00000_oonfX7o`0000Oooo]Z0_l000001?oonf[o0000
oookJ_l00008oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00002OoonfX00ol0
003ooo]ZoookJP04oookJP;o000000Cooo]Zo`000?l0003ooo]Z0_l00003oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX4o`000003oookJ_l0003ooo]Z00;o00001ooonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00gooo]Z00Co0000oookJ_oonf[o00000_oo
nfX01ol0003ooo]Zo`000?oonf[o0000oookJ_l000003?oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Cooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`000002oookJP08o`000?oonf[ooo]Z
oookJ_l0003ooo]Zo`000?oonfX3o`000003oookJ_l0003ooo]Z00;ooo]Z2Ol000000ooonf[o0000
oookJP1>oookJQ3o00000ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP09oookJP;o00002_oonfX01ol0003ooo]ZoookJ_oonf[o0000
oookJ_l000000_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00_ooo]Z00Co0000
oookJ_l0003o00000ooonfX4o`000003oookJ_l0003o000000;ooo]Z0_l000000ooonf[o0000o`00
0002o`000004oookJ_l0003ooo]Zo`0000?ooo]Z0_l000001?oonf[o0000o`000?oonfX2o`0000Go
oo]Z00Co0000oookJ_oonf[ooo]Z1?l00005oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX03OoonfX2o`0000Gooo]Z00?o0000oookJ_oonfX02Ol00002oookJP04o`000?oonf[ooo]Z
o`0000Gooo]Z0ol00004oookJP?o000000Kooo]Zo`000?l0003o0000oookJ_l00005oookJP0;o`00
0?oonf[o0000o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonfX00_l00002oookJP03o`000?oo
nf[ooo]Z00Wooo]Z0Ol000000006o`000?oonf[ooo]Zo`000?oonf[o00000ooonfX2o`0000;ooo]Z
00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02oookJP;o00001_oonfX01ol0003ooo]Z
oookJ_oonf[o0000oookJ_l000000ooonfX2o`0000Cooo]Z1?l000001?oonf[o0000oookJ_l00002
oookJP04o`000?oonf[o0000oookJPKo000000Gooo]Zo`000?oonf[ooo]Zo`00000?oookJP;o0000
0ooonfX00ol0003ooo]Zo`000002oookJP05o`000?oonf[o0000oookJ_l000000ooonfX01_l0003o
oo]Zo`000?l0003ooo]Zo`0000Wooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJPKo00000_oo
nfX4o`000003oookJ_l0003o000000;o00001ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP;o000000Cooo]Zo`000?oonf[o
00002?oonfX4o`000003oookJ_l0003o000000?ooo]Z1ol00002oookJP03o`000?oonf[ooo]Z00;o
000000?ooo]Zo`000?l00000C_oonfX2o`000004oookJ_l0003o0000oookJP?o00000ooonfX00ol0
003ooo]ZoookJP03o`000003oookJ_l0003ooo]Z00Kooo]Z00?o0000oookJ_oonfX00ooonfX2o`00
00Cooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX00ooo
nfX01?l0003ooo]ZoookJ_l00002oookJP04o`000?oonf[ooo]ZoookJP?o00002ooonfX01?l0003o
oo]Zo`000?l00004oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX5o`000003oookJ_l0003o
000000;ooo]Z1?l000000ooonf[o0000o`000003o`000004oookJ_l0003ooo]ZoookJPCo00000ooo
nfX00ol0003ooo]ZoookJP02o`000004oookJ_l0003ooo]ZoookJP;o000000Cooo]Zo`000?oonf[o
00001?oonfX00ol0003ooo]ZoookJP0<oookJP?o000000Cooo]Zo`000?l0003o00000_oonfX01?l0
003ooo]ZoookJ_oonfX3o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000002OoonfX0
1?l0003ooo]Zo`000?l00004oookJP?o000000Kooo]Zo`000?l0003o0000oookJ_l00003oookJP09
o`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z00?o000000Gooo]Zo`000?l0003ooo]Z
o`000003oookJP;o00001OoonfX1o`00000000Co0000oookJ_l0003o00000ooonfX00ol0003ooo]Z
oookJP03oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00Co0000oookJ_l0003o00001_oonfX2o`00
00Gooo]Z0_l00004oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX2o`000003oookJ_l0003o
oo]Z00Kooo]Z0ol000001?oonf[o0000o`000?l00003oookJP05o`000?oonf[ooo]ZoookJ_l00000
0ooonfX00ol0003ooo]ZoookJP05oookJP?o000000Cooo]Zo`000?l0003o00002?oonfX2o`0000Co
oo]Z00?o0000oookJ_oonfX00_oonfX4o`000003oookJ_l0003ooo]Z00;ooo]Z00Go0000oookJ_l0
003ooo]Zo`000002oookJP;o000000Cooo]Zo`000?l0003o00000ooonfX6o`000003oookJ_l0003o
oo]Z00Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP02oookJP;o000000?ooo]Z
o`000?oonfX00ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00Co00001OoonfX00ol0003ooo]Zoook
JP06oookJP;o00001?oonfX00ol0003ooo]Zo`000002oookJP05o`000?oonf[o0000oookJ_l00000
0_oonfX01?l0003ooo]Zo`000?l00002oookJP?o00000_oonfX01Ol0003ooo]Zo`000?l0003ooo]Z
00?o000000?ooo]Zo`000?l000000ol000001?oonf[o0000o`000?oonfX2o`0004gooo]Z1Ol00000
1ooonf[o0000oookJ_l0003ooo]Zo`000?oonfX00ol000000ooonf[o0000oookJP02o`000003oook
J_l0003ooo]Z00?ooo]Z00Ko0000oookJ_l0003o0000oookJ_l00002oookJP03o`000?oonf[o0000
00?ooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000oookJ_l0003ooo]Zo`000003
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00ooonfX01ol0003ooo]ZoookJ_oo
nf[o0000oookJ_l000001?oonfX3o`000003oookJ_l0003ooo]Z00Ko000000?ooo]Zo`000?l00000
1?oonfX00ol0003ooo]ZoookJP03o`000005oookJ_l0003ooo]ZoookJ_l000001?oonfX00ol0003o
oo]ZoookJP02oookJP;o00001?oonfX2o`0000Wooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX01ooonfX2o`000003oookJ_l0003ooo]Z00;o00001OoonfX3o`000004
oookJ_l0003o0000o`0000Gooo]Z0ol000000ooonf[o0000oookJP05o`0000Sooo]Z00Go0000oook
J_oonf[ooo]Zo`00000:oookJP;o00000ooonfX00ol0003ooo]ZoookJP02oookJP7o000000000ol0
003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX01?oonfX2o`0000?o
oo]Z00?o0000oookJ_l000001OoonfX01Ol0003ooo]Zo`000?oonf[o000000Kooo]Z1_l00002oook
JP04o`000?oonf[ooo]ZoookJP?o00000_oonfX3o`0000?ooo]Z00Ko0000oookJ_l0003ooo]Zo`00
0?oonfX2o`000003oookJ_l0003ooo]Z00?o000000?ooo]Zo`000?oonfX01OoonfX00ol0003ooo]Z
o`000005oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000002?oonfX01?l0003ooo]Z
oookJ_oonfX2o`0000Gooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oookJP07o`000?oonf[ooo]Z
o`000?oonf[o0000oookJP02o`0000?ooo]Z0_l000000ooonf[o0000o`000002oookJPCo00001?oo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oo
nfX01?l0003ooo]Zo`000?l00002oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z0_l000001Ooonf[o
0000oookJ_oonf[o000000kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02oook
JP04o`000?oonf[o0000o`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000004
o`000005oookJ_l0003ooo]ZoookJ_l000001?oonfX2o`000003oookJ_l0003o000000Go0000Booo
nfX?o`000004oookJ_l0003ooo]Zo`0000Cooo]Z0_l00002oookJP05o`000?oonf[ooo]ZoookJ_l0
00001?oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000?ooo]Z0_l00005oookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX02OoonfX01?l0003ooo]Zo`000?oonfX2o`0000;ooo]Z0_l0
0002oookJP06o`000?oonf[ooo]Zo`000?oonf[o00001_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00;ooo]Z0ol00002oookJP;o00001?oonfX02?l0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Z
0_l000000ooonf[o0000oookJP02oookJP?o00001_oonfX01_l0003ooo]Zo`000?l0003ooo]Zo`00
00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[o000000Wooo]Z00?o0000
oookJ_oonfX00_oonfX4o`000003oookJ_l0003o000000;o00000ooonfX01?l0003ooo]ZoookJ_l0
0003oookJP03o`000?oonf[o000000Gooo]Z0_l00006oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000Co
oo]Z00?o0000oookJ_l000001_oonfX1o`00000000?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
o`000002oookJP;o000000?ooo]Zo`000?l000001?l00003oookJP03o`000?oonf[ooo]Z00_ooo]Z
0_l0000:oookJP04o`000?oonf[o0000o`0000Kooo]Z0_l000000ooonf[o0000oookJP02oookJP?o
000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX0
0ol0003ooo]ZoookJP03oookJP;o00000_oonfX00ol0003ooo]ZoookJP03oookJP;o00000ooonfX0
0ol0003ooo]Zo`000002oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l0
00000ooonf[o0000o`000006oookJP;o000000Cooo]Zo`000?oonf[o00000_oonfX3o`0000;ooo]Z
00Co0000oookJ_oonf[o00002ooonfX01?l0003ooo]ZoookJ_l0000AoookJP;o000000Cooo]Zo`00
0?oonf[o00001OoonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00Gooo]Z00Go0000
oookJ_l0003ooo]Zo`000003oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z0_l00003oookJP03o`00
0?oonf[ooo]Z00;o000000Gooo]Zo`000?l0003o0000oookJP06o`0004[ooo]Z1ol000000ooonf[o
0000oookJP03o`000003oookJ_l0003ooo]Z00Co000000?ooo]Zo`000?l000000_l000001?oonf[o
0000o`000?l00005oookJP;o00005OoonfX00ol0003ooo]ZoookJP03oookJP;o00002OoonfX2o`00
00Gooo]Z00Co0000oookJ_l0003o00001_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Oooo]Z
1Ol00003oookJP?o00000_oonfX00ol0003ooo]Zo`000005oookJP;o00000ooonfX00ol0003ooo]Z
o`000004o`0000;ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002oookJP;o000000Cooo]Zo`00
0?oonf[ooo]Z0_l00007oookJP04o`000?oonf[ooo]ZoookJPGo00001OoonfX2o`0000;ooo]Z1?l0
00000ooonf[o0000o`000002oookJP;o00000ooonfX00ol0003ooo]ZoookJP03o`000004oookJ_l0
003ooo]ZoookJP?o00001_oonfX2o`000003oookJ_l0003ooo]Z00Sooo]Z0ol00006oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00Co0000oookJ_oonf[ooo]Z0Ol000000004o`000?oonf[ooo]Zo`0000So
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Co
oo]Z0_l00002oookJP03o`000?oonf[o000000;ooo]Z1?l000001Ooonf[o0000o`000?oonf[o0000
00Cooo]Z00Co0000oookJ_l0003ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00000
1?oonf[o0000oookJ_l00004oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX2o`0000Kooo]Z
00Co0000oookJ_l0003ooo]Z0ol000000ooonf[o0000oookJP02oookJP;o00000ooonfX01Ol0003o
oo]ZoookJ_oonf[o000000Kooo]Z1_l000000ooonf[o0000o`000002oookJPGo00000_oonfX2o`00
00kooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00000ooonfX2
o`0000Cooo]Z00So0000oookJ_l0003o0000oookJ_l0003ooo]Zo`0000Gooo]Z00Co0000oookJ_oo
nf[o00001?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX00_l00002oookJP03o`000?oonf[o000000;o00000_oonfX3o`0000;ooo]Z0ol00004oook
JPCo00000_oonfX00ol0003ooo]Zo`000003o`0004Wooo]Z2?l000001?oonf[o0000o`000?l00005
oookJPCo000000?ooo]Zo`000?oonfX00ol00004oookJP;o00000_oonfX2o`000003oookJ_l0003o
oo]Z00Oooo]Z0ol00004oookJP03o`000?oonf[o000000Oooo]Z00Co0000oookJ_oonf[o00000_oo
nfX2o`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?oonfX01OoonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[o000000;o000000?ooo]Zo`000?l000000ol000000ooonf[o0000oook
JP03oookJP03o`000?oonf[o000000Gooo]Z00Ko0000oookJ_l0003o0000oookJ_l00002oookJP;o
000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00Co0000oookJ_l0003o00000_oonfX3o`0000Gooo]Z00Co0000oookJ_l0003ooo]Z0ol00000
0ooonf[o0000o`000002o`0000?ooo]Z0_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[o
oo]Z00?o00000ooonfX2o`0000Gooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_l0
003ooo]Z00;o00000_oonfX00ol0003ooo]ZoookJP02o`000006oookJ_l0003ooo]Zo`000?oonf[o
00000_oonfX00ol0003ooo]ZoookJP02oookJP;o00000OoonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o000000;ooo]Z0ol000000ooonf[o0000oook
JP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_l0003o00001_oonfX2o`000004oook
J_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_oonfX2o`00
00;ooo]Z0_l000000ooonf[o0000o`000002o`000003oookJ_l0003o000000?o000000Cooo]Zo`00
0?l0003o00000_oonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Go00000_oonfX0
0ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX01?l0003ooo]Zo`00
0?oonfX2o`0000?ooo]Z0_l000000ooonf[o0000oookJP03oookJPKo000000Kooo]Zo`000?oonf[o
oo]Zo`000?oonfX2o`000003oookJ_l0003o000000Sooo]Z00?o0000oookJ_l000001_oonfX00ol0
003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00Wooo]Z00Co0000oookJ_oonf[o00000ooonfX0
0ol0003ooo]Zo`000003o`000003oookJ_l0003ooo]Z00;o00000ooonfX3o`000009oookJ_l0003o
oo]Zo`000?oonf[o0000oookJ_l0003ooo]Z00Co000000Gooo]Zo`000?l0003ooo]Zo`000004oook
JPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000003oookJP?o000000?ooo]Zo`00
0?l000000ol00018oookJP?o000000Cooo]Zo`000?oonf[ooo]Z1?l000000ooonf[o0000oookJP03
oookJP03o`000?oonf[ooo]Z00_ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP?o000000Go
oo]Zo`000?oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;o00002_oonfX00ol0003ooo]Z
o`000002oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]ZoookJP0>oookJP;o
000000?ooo]Zo`000?oonfX01?oonfX01Ol0003ooo]Zo`000?oonf[o000000?ooo]Z0_l000000ooo
nf[o0000oookJP02o`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]Zo`000?oonf[o
000000;ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
000000Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP08o`000?oonf[o
0000oookJ_l0003ooo]Zo`000?oonfX9o`000006oookJ_l0003ooo]Zo`000?oonf[o00000_oonfX0
1Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00007oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00000_oonfX4o`0000;ooo]Z00Ko0000oookJ_oo
nf[ooo]Zo`000?oonfX3o`0000?ooo]Z0Ol000000003o`000?oonf[o000000?ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP?o000000Cooo]Zo`000?oonf[o00001_oonfX0
0ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000000_oonfX0
0ol0003ooo]Zo`000007oookJP04o`000?oonf[o0000oookJPCo00000_oonfX2o`000003oookJ_l0
003o000000;o000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJP;o00000ooonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX00_l00004oookJP;o0000
0_oonfX00ol0003ooo]ZoookJP03oookJP?o00000_oonfX01?l0003ooo]Zo`000?l00003oookJP03
o`000?oonf[o000000?o00000_oonfX2o`0000?ooo]Z00?o0000oookJ_l000002ooonfX00ol0003o
oo]ZoookJP0BoookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP05oookJP;o00000_oonfX2o`000005oookJ_l0003ooo]Zo`000?oonfX00_l00003
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_l000000ooonfX2o`000003oookJ_l0003o
000000;o000000?ooo]Zo`000?l000000ol00017oookJP?o000000?ooo]Zo`000?l000002?l00000
1?oonf[o0000o`000?l00003oookJP03o`000?oonf[o000000Ko00000ooonfX5o`0000?ooo]Z0_l0
0003oookJP;o00001?oonfX3o`000004oookJ_l0003ooo]ZoookJP;o00000_oonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX05?oonfX01?l0003ooo]Z
o`000?oonfX6o`0000Kooo]Z0_l00002oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oo
nfX00ooonfX2o`0000cooo]Z00?o0000oookJ_oonfX01OoonfX5o`000003oookJ_l0003o000000?o
oo]Z0_l00007oookJPGo000000Cooo]Zo`000?l0003ooo]Z0_l000001?oonf[o0000oookJ_l00002
oookJP08o`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l00005oookJP03o`000?oonf[ooo]Z00;o
00001?oonfX01?l0003ooo]ZoookJ_l00002oookJP04o`000?oonf[o0000oookJP;o00003OoonfX0
0ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z007o000000001Ol0003ooo]ZoookJ_oonf[o
000000?ooo]Z00?o0000oookJ_oonfX03?oonfX2o`0000Kooo]Z0_l00002oookJP03o`000?oonf[o
oo]Z00?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l000001?oonf[o0000o`000?oonfX5o`0000Wooo]Z
1Ol000001?oonf[o0000o`000?l0000;oookJP06o`000?oonf[o0000o`000?oonf[o00001_oonfX0
1?l0003ooo]Zo`000?l0000:oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX3o`0000;ooo]Z
0_l000000ooonf[o0000o`000002oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z0ol00002oookJP?o
00002_oonfX00ol0003ooo]ZoookJP09oookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX3o`00
00cooo]Z00Co0000oookJ_oonf[o00000ooonfX01?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0
003o000000Cooo]Z00?o0000oookJ_l000001?oonfX2o`0000;ooo]Z00Co0000oookJ_oonf[o0000
0ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[o000000;ooo]Z0_l000001?oonf[o0000
o`000?oonfX6o`0004Kooo]Z1Ol000000ooonf[o0000o`000005oookJP?o000000Cooo]Zo`000?l0
003o00001?oonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00Co0000oookJ_l0003o00001?oonfX2
o`0000Kooo]Z00?o0000oookJ_oonfX00ooonfX2o`000003oookJ_l0003ooo]Z00?ooo]Z00Co0000
oookJ_l0003o00001OoonfX00ol0003ooo]ZoookJP02o`000003oookJ_l0003o000000Gooo]Z00?o
0000oookJ_l000000ooonfX01?l0003ooo]ZoookJ_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0
1_oonfX4o`0000;ooo]Z0_l000000ooonf[o0000oookJP09oookJP03o`000?oonf[ooo]Z00;ooo]Z
00Co0000oookJ_oonf[o00001ooonfX2o`0000;ooo]Z00?o0000oookJ_l000001OoonfX2o`0000?o
oo]Z0_l00004oookJP?o000000?ooo]Zo`000?l000000ol000001?oonf[o0000oookJ_oonfX3o`00
00;ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000;ooo]Z0ol000000ooonf[o0000oookJP02o`00
00Gooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP06oookJP;o00002?oonfX00ol0
003ooo]Zo`000004oookJP;o00002OoonfX00ol0003ooo]ZoookJP01o`00000000?o0000oookJ_oo
nfX0oooonf[ooookJSkooo]Z0Ol000000004o`000?oonf[ooo]ZoookJP;o00000ooonfX2o`0000Go
oo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00?o
000000?ooo]Zo`000?l000000_oonfX01?l0003ooo]Zo`000?l00004oookJP03o`000?oonf[ooo]Z
00;o000000?ooo]Zo`000?oonfX00_oonfX4o`000004oookJ_l0003ooo]ZoookJPGo00000_oonfX0
0ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX0
1Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP09oookJPOo00000_oonfX00ol0003ooo]ZoookJP02oookJP;o000000Sooo]Zo`000?oonf[ooo]Z
o`000?oonf[o0000oookJPCo00002OoonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00Co
0000oookJ_oonf[o00001?oonfX4o`000006oookJ_l0003ooo]ZoookJ_l0003ooo]Z0ol00008oook
JP03o`000?oonf[o000000Gooo]Z0_l00007oookJP03o`000?oonf[o000000;ooo]Z00?o0000oook
J_l000000ooonfX00ol0003ooo]ZoookJP03o`0000;ooo]Z00?o0000oookJ_l000000ol00015oook
JPGo00000_oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0
003ooo]Zo`000?l00003oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00?o0000oookJ_oonfX01_oo
nfX2o`0000;ooo]Z00Co0000oookJ_l0003o00001OoonfX00ol0003ooo]Zo`000002o`0000oooo]Z
00?o0000oookJ_oonfX01OoonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00Go0000oookJ_l0003ooo]Zo`000003oookJP;o00000ooonfX01?l0003ooo]ZoookJ_l00003
oookJP;o00000_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Gooo]Z00Co0000oookJ_oonf[o
00001_oonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[o000000;o00001ooonfX00ol0003o
oo]Zo`000007oookJPOo000000?ooo]Zo`000?l000000_oonfX01?l0003ooo]Zo`000?oonfX2o`00
00;ooo]Z0ol000000ooonf[o0000o`000003oookJP03o`000?oonf[ooo]Z00?ooo]Z00Oo0000oook
J_oonf[o0000oookJ_l0003ooo]Z00Co000000?ooo]Zo`000?oonfX04?oonfX01?l0003ooo]Zoook
J_l00002oookJP04o`000?oonf[ooo]ZoookJP7o000000001?l0003ooo]ZoookJ_l00007oookJP03
o`000?oonf[ooo]Z00;ooo]Z1Ol00002oookJP;o00001_oonfX2o`0000Cooo]Z0ol000001?oonf[o
0000o`000?l00002oookJP;o00001?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00Co0000
oookJ_oonf[o00000_oonfX00ol0003ooo]ZoookJP05o`0000[ooo]Z00?o0000oookJ_oonfX01?oo
nfX01Ol0003ooo]Zo`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX00_l00004oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00Oo0000oookJ_l0003o0000oookJ_l0003ooo]Z00;o000000?ooo]Zo`00
0?l000001?oonfX2o`0000;ooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP06oookJP?o00001ooonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[o00001OoonfX01_l0003ooo]ZoookJ_l0
003ooo]Zo`0000Cooo]Z0_l00002oookJP03o`000?oonf[o000000Gooo]Z0_l00002oookJP;o0000
1?oonfX3o`0000?ooo]Z00Co0000oookJ_l0003ooo]Z1?l000001?oonf[o0000o`000?l00002oook
JPKo0000@ooonfX4o`000004oookJ_l0003ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX01OoonfX2
o`0000?ooo]Z00?o0000oookJ_l000000ol00002oookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000
oookJ_oonf[o0000oookJP02o`0000Kooo]Z00?o0000oookJ_l000001OoonfX01?l0003ooo]Zoook
J_oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP04o`00
0?oonf[ooo]Zo`0000Oooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]Zo`000?oonfX3o`00
0007oookJ_l0003o0000oookJ_l0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;o000000Go
oo]Zo`000?oonf[ooo]Zo`000002oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000_oonfX2o`00
00?ooo]Z00Co0000oookJ_l0003ooo]Z0_l000000ooonf[o0000oookJP03o`0000Cooo]Z0ol00006
oookJP03o`000?oonf[o000000?ooo]Z2Ol000000ooonf[o0000o`000007oookJP04o`000?oonf[o
oo]ZoookJP;o00001?oonfX01?l0003ooo]ZoookJ_l0000:oookJP04o`000?oonf[ooo]Zo`0000;o
oo]Z00?o0000oookJ_oonfX00ooonfX3o`0000;ooo]Z00?o0000oookJ_l000002ooonfX1o`000000
00?o0000oookJ_oonfX01?oonfX3o`000004oookJ_l0003ooo]ZoookJP;o00001?oonfX01Ol0003o
oo]Zo`000?oonf[o000000Sooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP?o000000Cooo]Z
o`000?l0003ooo]Z0_l00004oookJPGo000000Kooo]Zo`000?oonf[o0000oookJ_l00003oookJP03
o`000?oonf[o000000;o00001OoonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z0ol00003oookJP;o00000ooonfX2o`0000?ooo]Z0ol00003oookJP;o00000ooonfX2o`00
0003oookJ_l0003o000000Gooo]Z0_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[o0000
00Co00000ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o000000Cooo]Z00?o0000oook
J_oonfX00_oonfX3o`0000?ooo]Z00So0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`0000?ooo]Z
00?o0000oookJ_oonfX01?oonfX5o`0000?ooo]Z0_l000001_oonf[o0000o`000?l0003ooo]Zo`00
00Kooo]Z00So0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJP;o00000_oonfX01_l0003ooo]Z
oookJ_oonf[o0000oookJPGo000000?ooo]Zo`000?oonfX01Ol00013oookJPWo00000_oonfX2o`00
0003oookJ_l0003o000000;ooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJPCo00000ooonfX0
1ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP03o`0000;ooo]Z
00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00Gooo]Z00Co0000oookJ_oo
nf[o00001ooonfX2o`000003oookJ_l0003ooo]Z00Oooo]Z0_l000000ooonf[o0000o`000003o`00
0003oookJ_l0003ooo]Z00;o000000Sooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`0000;ooo]Z
00Ko0000oookJ_oonf[o0000oookJ_l00002oookJP03o`000?oonf[o000000;ooo]Z00?o0000oook
J_oonfX00_oonfX2o`000006oookJ_l0003ooo]Zo`000?oonf[o00001OoonfX01Ol0003ooo]Zoook
J_oonf[o000000?ooo]Z0_l00005oookJP;o000000Cooo]Zo`000?oonf[ooo]Z0ol00002oookJPCo
00000_oonfX00ol0003ooo]ZoookJP04o`0000Gooo]Z0_l00003oookJP05o`000?oonf[ooo]Zoook
J_l000000_oonfX01?l0003ooo]Zo`000?oonfX4o`000003oookJ_l0003ooo]Z00Gooo]Z00Wo0000
oookJ_oonf[ooo]Zo`000?oonf[o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP01o`000000
00Co0000oookJ_oonf[o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0ol00002oook
JP03o`000?oonf[ooo]Z00;ooo]Z0_l00006oookJP;o00000ooonfX2o`0000;ooo]Z00?o0000oook
J_oonfX01ooonfX01ol0003ooo]Zo`000?l0003ooo]Zo`000?oonfX00_l00003oookJP05o`000?oo
nf[ooo]Zo`000?oonfX00_l000002_oonf[o0000o`000?l0003ooo]Zo`000?oonf[o0000oookJ_l0
0006oookJP04o`000?oonf[o0000oookJP;o00001ooonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`00
00?ooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]Zo`000?oonf[o000000gooo]Z0ol00005
oookJP03o`000?oonf[o000000;o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01ooonfX01?l0003ooo]ZoookJ_oo
nfX2o`0000Oooo]Z00?o0000oookJ_oonfX03_oonfX2o`000003oookJ_l0003ooo]Z00?o000000Go
oo]Zo`000?oonf[ooo]Zo`000002oookJPWo000000?ooo]Zo`000?oonfX00ol000000ooonf[o0000
o`000007o`00047ooo]Z2Ol000001?oonf[o0000oookJ_l00002oookJP03o`000?oonf[ooo]Z00?o
000000Cooo]Zo`000?l0003o00000ooonfX4o`000008oookJ_l0003ooo]Zo`000?oonf[o0000oook
J_l00005oookJP03o`000?oonf[ooo]Z00;ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02o`00
00;ooo]Z00So0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJP;o000000Cooo]Zo`000?oonf[o
00001OoonfX00ol0003ooo]ZoookJP02o`000004oookJ_l0003o0000o`0000Oooo]Z1?l000000ooo
nf[o0000oookJP03oookJP03o`000?oonf[o000000Go000000?ooo]Zo`000?oonfX00ooonfX2o`00
0004oookJ_l0003o0000o`0000Gooo]Z1Ol00004oookJP;o00000_oonfX00ol0003ooo]Zo`000003
oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX01Ol0003ooo]Zo`000?oonf[o000000;ooo]Z
00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[ooo]Z00?o
oo]Z0_l000000ooonf[o0000o`000002oookJP03o`000?oonf[o000000;ooo]Z1Ol00004oookJP03
o`000?oonf[ooo]Z00Cooo]Z0_l000000ooonf[o0000oookJP08oookJP05o`000?oonf[ooo]Zoook
J_l000000ooonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000005o`00
0?oonf[ooo]ZoookJ_l000001ooonfX2o`000003oookJ_l0003ooo]Z00Cooo]Z00Co0000oookJ_l0
003o00001_oonfX2o`000006oookJ_l0003o0000oookJ_l0003ooo]Z0_l00003oookJP;o000000[o
oo]Zo`000?l0003o0000oookJ_l0003ooo]Zo`000?oonf[o00001?oonfX2o`000007oookJ_l0003o
0000o`000?oonf[o0000oookJP03o`0000;ooo]Z0_l000000ooonf[o0000oookJP02oookJP06o`00
0?oonf[o0000o`000?oonf[o00002?oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z
00?ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00;o00000_oonfX00ol0003ooo]ZoookJP02oook
JP;o000000?ooo]Zo`000?oonfX00_oonfX2o`0000?ooo]Z00?o0000oookJ_l000000ol000000ooo
nf[o0000oookJP04oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000003oookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_l0000:oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0000;ooo]Z0ol00004oookJP03o`00
0?oonf[o000000cooo]Z00Co0000oookJ_l0003o00000_oonfX4o`000003oookJ_l0003ooo]Z00?o
oo]Z1Ol000001?oonf[o0000o`000?l00011oookJPSo000000Cooo]Zo`000?l0003ooo]Z1ol00000
1?oonf[o0000oookJ_l00005oookJPCo00002ooonfX00ol0003ooo]ZoookJP04oookJP05o`000?oo
nf[ooo]ZoookJ_l000000ooonfX01?l0003ooo]ZoookJ_oonfX2o`000004oookJ_l0003ooo]Zo`00
00Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z
00Co000000?ooo]Zo`000?oonfX02OoonfX00ol0003ooo]Zo`000002oookJP;o00001OoonfX2o`00
00Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP02o`000003oookJ_l0003ooo]Z
00Cooo]Z00?o0000oookJ_l000001?oonfX2o`000003oookJ_l0003ooo]Z00;o000000Kooo]Zo`00
0?oonf[o0000oookJ_l00006oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX0
0ooonfX2o`000005oookJ_l0003ooo]Zo`000?oonfX00ol000000ooonf[o0000oookJP07oookJP05
o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]ZoookJP05oookJP7o000000000ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_l0003o00002ooonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Kooo]Z00Ko0000oookJ_oonf[ooo]Zo`000?oo
nfX2o`000005oookJ_l0003o0000o`000?oonfX00_l000001_oonf[o0000oookJ_l0003ooo]Zo`00
00?ooo]Z0_l000000ooonf[o0000o`000004oookJP03o`000?oonf[ooo]Z017ooo]Z0_l000001?oo
nf[o0000oookJ_l00002oookJP;o00001?oonfX00ol0003ooo]ZoookJP03oookJP?o00001OoonfX2
o`0000Gooo]Z00?o0000oookJ_oonfX00ol00008oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP05o`000?oonf[ooo]ZoookJ_l000001Ooo
nfX01?l0003ooo]Zo`000?l00003oookJP;o00001?oonfX00ol0003ooo]ZoookJP02oookJP;o0000
1ooonfX00ol0003ooo]Zo`00000;oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_l0003o
0000oookJP03o`0000?ooo]Z0ol00002oookJPKo0000?ooonfX4o`000003oookJ_l0003o000000Co
00000ooonfX2o`000003oookJ_l0003ooo]Z00Cooo]Z00Co0000oookJ_l0003ooo]Z0_l000000ooo
nf[o0000oookJP05oookJP03o`000?oonf[ooo]Z00Wooo]Z00Go0000oookJ_oonf[ooo]Zo`000007
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000Kooo]Z00Co0000oookJ_oonf[o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000[o
oo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000o`000003o`0000Gooo]Z00Co0000oookJ_l0
003o00000_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_l000001_oonfX01?l0003ooo]ZoookJ_oo
nfX3o`000004oookJ_l0003o0000oookJP?o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z00;o000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_l000002OoonfX2o`0000Cooo]Z00?o0000oookJ_oo
nfX00ol00003oookJP03o`000?oonf[ooo]Z007o000000000ol0003ooo]Zo`000002oookJP;o0000
3ooonfX3o`0000Kooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol00004oookJP;o0000
0ooonfX2o`000003oookJ_l0003o000000Kooo]Z2?l00002oookJP?o00001_oonfX3o`0000;ooo]Z
00Go0000oookJ_oonf[ooo]Zo`000003oookJP09o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oo
nf[o000000?ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Oooo]Z00?o0000oookJ_oo
nfX01ooonfX01_l0003ooo]Zo`000?oonf[o0000oookJP?o00003?oonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX04OoonfX01Ol0003ooo]ZoookJ_oo
nf[o000000Gooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]ZoookJP;o000000Wooo]Zo`000?oonf[o
oo]Zo`000?oonf[o0000oookJ_l000000ooonfX2o`000004oookJ_l0003ooo]ZoookJPGo000000Go
oo]Zo`000?l0003o0000oookJP03o`000003oookJ_l0003o000003kooo]Z2?l000000ooonf[o0000
oookJP03oookJPCo00000_oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000;ooo]Z
0_l0000=oookJP?o00000_oonfX00ol0003ooo]ZoookJP05oookJP;o000000?ooo]Zo`000?oonfX0
1?oonfX00ol0003ooo]Zo`00000:oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003o
oo]ZoookJP09oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000;o
oo]Z0_l000000ooonf[o0000oookJP03o`0000;ooo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0
003ooo]ZoookJP04oookJP07o`000?oonf[ooo]Zo`000?oonf[o0000oookJP05o`0000;ooo]Z0_l0
0007oookJP;o000000?ooo]Zo`000?oonfX01?oonfX5o`0000;ooo]Z1Ol00004oookJP;o00000_oo
nfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`000?oonfX0
0_l000001Ooonf[o0000oookJ_l0003ooo]Z00;o00002OoonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[o000000;o00000ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Go
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000001?l0003ooo]Zo`00
0?l00002oookJP03o`000?oonf[ooo]Z00Kooo]Z00Go0000oookJ_l0003o0000oookJP02o`0000;o
oo]Z00?o0000oookJ_oonfX01ooonfX01Ol0003ooo]ZoookJ_oonf[o000000_ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP07o`0000Cooo]Z0ol000001?oonf[o0000o`000?oonfX3
o`0000?ooo]Z00?o0000oookJ_oonfX03?oonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oo
nf[ooo]Z00;ooo]Z0ol000000ooonf[o0000oookJP03oookJP;o00001_oonfX2o`000003oookJ_l0
003o000000Co000000Cooo]Zo`000?l0003ooo]Z0ol00003oookJP03o`000?oonf[ooo]Z00Oooo]Z
1?l00009oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[o0000oookJP02o`0000;o
oo]Z00?o0000oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oook
J_l000000ooonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00_o0000oookJ_oonf[o0000oook
J_l0003ooo]Zo`000?oonf[o0000oookJP02o`000006oookJ_l0003ooo]Zo`000?oonf[o00000_oo
nfX4o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?oonfX01Ol000000ooonf[o0000oook
JP02o`0003gooo]Z1_l000001_oonf[o0000oookJ_l0003ooo]Zo`0000;ooo]Z00Co0000oookJ_l0
003o00000ooonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]Zo`000003o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o
000000Cooo]Z00?o0000oookJ_oonfX00_oonfX3o`0000?ooo]Z00Oo0000oookJ_oonf[ooo]Zo`00
0?oonf[o000000_ooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000;ooo]Z00Go0000oookJ_oonf[o
oo]Zo`000004oookJP;o00001_oonfX4o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?oo
nfX00_oonfX3o`0000?ooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP04oook
JP05o`000?oonf[ooo]ZoookJ_l000002?oonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oo
nf[ooo]Z00;ooo]Z1_l000001Ooonf[o0000o`000?oonf[o000000?ooo]Z00Co0000oookJ_l0003o
00000_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o000000?ooo]Zo`000?l000001?oonfX2o`00
0004oookJ_l0003o0000oookJP;o00000_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP7o000000000ol0
003ooo]ZoookJP04oookJP?o00001_oonfX00ol0003ooo]ZoookJP04oookJP;o00001_oonfX2o`00
00;ooo]Z00Co0000oookJ_l0003o00000_oonfX2o`0000;ooo]Z0_l00009oookJP;o000000?ooo]Z
o`000?l000000ol000001?oonf[o0000o`000?oonfX3o`0000?ooo]Z1Ol000000ooonf[o0000oook
JP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP02oookJPKo000000Cooo]Zo`000?l0003o00001?oonfX01Ol0003ooo]Zo`000?oonf[o000000?o
oo]Z00Oo0000oookJ_l0003o0000oookJ_l0003ooo]Z00Ko00002OoonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03
o`0000gooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP06oookJP06o`000?oonf[o
oo]ZoookJ_l0003ooo]Z0_l00007oookJP?o00001?oonfX3o`000005oookJ_l0003ooo]Zo`000?oo
nfX00_l00002oookJPCo00001?oonfX00ol0003ooo]Zo`000002o`000003oookJ_l0003o000000Go
0000??oonfX6o`0000?ooo]Z0_l000000ooonf[o0000o`000002o`0000?ooo]Z0ol00004oookJP;o
00001_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Gooo]Z0ol00002oookJP03o`000?oonf[o
oo]Z00;o00001?oonfX3o`0000Sooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP04o`000?oo
nf[ooo]ZoookJP?o00001ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z0_l00002oookJP04
o`000?oonf[ooo]Zo`0000Kooo]Z0_l000001?oonf[o0000oookJ_oonfX2o`0000;ooo]Z0ol00002
oookJPCo000000Cooo]Zo`000?oonf[o00000_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Co
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00_o
oo]Z1Ol00003oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oook
JP;o000000Gooo]Zo`000?oonf[ooo]Zo`000004oookJP03o`000?oonf[o000000Cooo]Z00?o0000
oookJ_l000000ol00006oookJPCo00002ooonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Cooo]Z
0Ol000000003o`000?oonf[o000000;o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP02oookJP;o000000?ooo]Zo`000?oonfX0
0ooonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z0ol000001Ooonf[o0000oookJ_l0003ooo]Z00;o
00001_oonfX2o`0000;ooo]Z0_l00002oookJPGo00000_oonfX00ol0003ooo]Zo`000003oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03o`0000;o
oo]Z0_l00002oookJP;o00001?oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Ko0000oook
J_l0003o0000oookJ_l00003oookJP05o`000?oonf[o0000o`000?oonfX00_l00003oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000;o
oo]Z00?o0000oookJ_oonfX01ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o00002?oonfX01?l0
003ooo]ZoookJ_l00004oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02_oonfX0
1Ol0003ooo]Zo`000?oonf[o000000;ooo]Z0ol000001Ooonf[o0000o`000?oonf[o000000Oooo]Z
00?o0000oookJ_oonfX01Ol00004oookJP03o`000?oonf[o000000;ooo]Z1Ol0000koookJPOo0000
00Cooo]Zo`000?l0003ooo]Z1?l00003oookJP;o00000_oonfX2o`0000;ooo]Z00Oo0000oookJ_oo
nf[ooo]Zo`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX00_l000001?oonf[o0000oookJ_l0
0004oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00002oookJP;o000000?ooo]Zo`000?oonfX01?oo
nfX00ol0003ooo]Zo`000004oookJP;o00001ooonfX00ol0003ooo]Zo`000004oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00?ooo]Z1?l000000ooonf[o0000o`000002o`000004oookJ_l0003o0000oookJP;o0000
0_oonfX00ol0003ooo]Zo`000006oookJP?o000000?ooo]Zo`000?oonfX01ooonfX2o`0000Gooo]Z
0ol00005oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00003oookJP;o000000Cooo]Zo`000?l0003o
00000_oonfX00ol0003ooo]Zo`000003oookJP05o`000?oonf[o0000oookJ_l000000_oonfX3o`00
0004oookJ_l0003o0000o`0000;ooo]Z0_l000000ooonf[o0000o`000002oookJP;o00001?oonfX0
0ol0003ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02_oonfX1
o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000005o`000?oonf[ooo]Zoook
J_l000000ooonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o000000?ooo]Zo`000?oonfX01?oonfX0
0ol0003ooo]Zo`000006oookJP?o000000?ooo]Zo`000?oonfX00_oonfX2o`0000Cooo]Z0ol00005
oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Oooo]Z1?l00003
oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00002oookJP;o000000?ooo]Zo`000?l000002_oonfX0
1?l0003ooo]ZoookJ_l00005oookJP;o00000_oonfX3o`000003oookJ_l0003ooo]Z00;o00000_oo
nfX2o`000004oookJ_l0003o0000o`0000Cooo]Z00Co0000oookJ_oonf[o00001ooonfX01Ol0003o
oo]ZoookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z00;ooo]Z0_l00005oookJP03o`000?oonf[o000000Gooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oook
J_oonf[ooo]Zo`000002oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003o00000_oo
nfX2o`000003oookJ_l0003o000000[o0000>_oonfX3o`000006oookJ_l0003o0000oookJ_l0003o
oo]Z1?l000000ooonf[o0000oookJP02o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oook
JP04o`000?oonf[ooo]ZoookJP?o000000Cooo]Zo`000?oonf[o00001OoonfX00ol0003ooo]Zoook
JP02oookJPCo00000ooonfX3o`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX2o`000004oookJ_l0
003ooo]Zo`0000_ooo]Z00?o0000oookJ_oonfX01ooonfX2o`0000Oooo]Z00?o0000oookJ_oonfX0
3ooonfX4o`000003oookJ_l0003ooo]Z00;ooo]Z00Go0000oookJ_oonf[o0000oookJP02o`0000;o
oo]Z0_l000001?oonf[o0000oookJ_oonfX2o`0000Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000004
oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Go
oo]Z00?o0000oookJ_l000000_l00003oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`000005oook
JP;o00001?oonfX02?l0003ooo]ZoookJ_l0003ooo]Zo`000?oonf[o00000ooonfX01ol0003ooo]Z
oookJ_oonf[o0000oookJ_l000000ooonfX01ol0003ooo]ZoookJ_l0003ooo]Zo`000?oonfX01?l0
0004oookJP04o`000?oonf[o0000o`0000;ooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003o
oo]ZoookJP01o`00000000?o0000oookJ_oonfX01?oonfX2o`000003oookJ_l0003ooo]Z00Sooo]Z
0_l000000ooonf[o0000o`000009oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z1?l000001_oonf[o
0000oookJ_oonf[o0000oookJP;o00000_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000Cooo]Z00Go
0000oookJ_l0003o0000oookJP02o`000004oookJ_l0003o0000oookJPCo00001?oonfX2o`0000;o
oo]Z00Co0000oookJ_l0003o00000_oonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z
00;ooo]Z0ol00002oookJP;o00000_oonfX3o`000003oookJ_l0003o000000;ooo]Z00?o0000oook
J_oonfX00ooonfX3o`000006oookJ_l0003o0000o`000?oonf[o00000ooonfX01?l0003ooo]Zoook
J_l0000DoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX01_l0003ooo]Z
oookJ_oonf[o0000oookJP;o00000ooonfX3o`0000Kooo]Z00Co0000oookJ_l0003ooo]Z0_l00000
1?oonf[o0000o`000?oonfX4o`0000;ooo]Z00Co0000oookJ_l0003o00001_oonfX00ol0003ooo]Z
o`000007o`0003Wooo]Z1ol00002oookJP?o000000?ooo]Zo`000?l000000_oonfX4o`000003oook
J_l0003ooo]Z00;ooo]Z00Co0000oookJ_l0003o00000ooonfX2o`000003oookJ_l0003o000000Oo
oo]Z0_l00008oookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX01_l0000BoookJP04
o`000?oonf[ooo]ZoookJP;o00001ooonfX00ol0003ooo]Zo`000005oookJP07o`000?oonf[ooo]Z
oookJ_l0003ooo]Zo`000002oookJP;o000000Gooo]Zo`000?l0003ooo]Zo`000003oookJP04o`00
0?oonf[o0000oookJP;o00000_oonfX01?l0003ooo]ZoookJ_l00005oookJPCo00000_oonfX01_l0
003ooo]ZoookJ_oonf[o0000oookJP;o000000?ooo]Zo`000?l000000_oonfX00ol0003ooo]Zo`00
0006oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z0_l00002oookJP05o`000?oonf[o0000oookJ_l0
00001OoonfX00ol0003ooo]ZoookJP02oookJP;o00000_oonfX3o`000003oookJ_l0003ooo]Z00;o
oo]Z00?o0000oookJ_oonfX01_l000000ooonf[o0000oookJP04oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z00Co0000oookJ_oonf[o00000_oonfX3o`0000Kooo]Z00Co0000oookJ_l0003o00001?oo
nfX1o`00000000?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP02oookJP06o`000?oonf[o
oo]Zo`000?oonf[o00002_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX01?oonfX6o`0000;ooo]Z
0_l00002oookJP04o`000?oonf[o0000o`0000;ooo]Z00Co0000oookJ_oonf[o00000_oonfX3o`00
00Cooo]Z00?o0000oookJ_l000000ol00002oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX0
1_l0003ooo]ZoookJ_l0003ooo]Zo`0000Gooo]Z00?o0000oookJ_l000000ooonfX2o`0000Kooo]Z
00Ko0000oookJ_l0003ooo]Zo`000?oonfX2o`000005oookJ_l0003o0000oookJ_l000000ooonfX2
o`0000;ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z00Ko0000oookJ_oonf[o0000oook
J_l00003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol00005oookJP03o`000?oonf[o000000?o
oo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[o000000;ooo]Z00Oo0000oook
J_oonf[ooo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ooonfX01Ol0003ooo]Zo`00
0?l0003ooo]Z00;o00000_oonfX00ol0003ooo]Zo`000004o`000003oookJ_l0003o000000?o0000
>?oonfX6o`000003oookJ_l0003o000000?o00000_oonfX3o`000003oookJ_l0003ooo]Z00Cooo]Z
00?o0000oookJ_oonfX00ooonfX3o`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000;ooo]Z
00?o0000oookJ_oonfX00_l00002oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_oo
nfX00ooonfX3o`000003oookJ_l0003ooo]Z00Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP06oookJP04o`000?oonf[ooo]ZoookJP;o00001OoonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00Gooo]Z1?l000001_oonf[o0000oookJ_l0003ooo]Zo`0000Gooo]Z0_l0
0003oookJP04o`000?oonf[ooo]ZoookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJP03
o`000?oonf[ooo]Z00;o00000_oonfX3o`000003oookJ_l0003ooo]Z00Gooo]Z00?o0000oookJ_l0
00001?oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o000000Cooo]Zo`000?oonf[o00001?oonfX2
o`0000Gooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP04o`000004oookJ_l0003o
oo]Zo`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[o000000;ooo]Z
00Co0000oookJ_oonf[o00000_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX02_oonfX1o`000000
00?o0000oookJ_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z1?l00002oookJP;o
00000ooonfX2o`0000Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJPCo00002_oonfX01_l0
003ooo]Zo`000?oonf[o0000oookJPKo00000ooonfX01?l0003ooo]Zo`000?l00002oookJPCo0000
0_oonfX2o`0000oooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP?o00000_oonfX01_l0003o
oo]Zo`000?oonf[o0000oookJP;o000000?ooo]Zo`000?oonfX00ol000000ooonf[o0000oookJP04
oookJP;o000000?ooo]Zo`000?oonfX00_l0000:oookJP03o`000?oonf[o000000Oooo]Z00?o0000
oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00003oookJP05o`000?oonf[ooo]ZoookJ_l00000
1OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[o
00000_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000006oookJP03o`000?oonf[o000000Cooo]Z00Co0000oookJ_oonf[o00000ooonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?o000000Cooo]Zo`000?l0003ooo]Z0_l0
00000ooonf[o0000o`00000goookJPKo000000?ooo]Zo`000?l000000ol00005oookJP03o`000?oo
nf[ooo]Z00;ooo]Z0_l000001?oonf[o0000oookJ_oonfX4o`0000gooo]Z00Co0000oookJ_oonf[o
00000ooonfX2o`0000?ooo]Z00Go0000oookJ_l0003ooo]Zo`000004oookJP?o00001?oonfX00ol0
003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ol00003oook
JP04o`000?oonf[ooo]Zo`0000Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oo
nf[ooo]Z00Sooo]Z0_l00006oookJP03o`000?oonf[ooo]Z00?o000000?ooo]Zo`000?oonfX00ol0
0007oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP05oookJP;o000000Gooo]Zo`000?oonf[o0000oookJP02o`0000Kooo]Z0_l000000ooonf[o0000
oookJP03oookJP03o`000?oonf[ooo]Z00Oooo]Z1?l00002oookJP;o00000ooonfX02?l0003ooo]Z
o`000?l0003ooo]Zo`000?oonf[o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o0000013ooo]Z00?o
0000oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol00000
0004o`000?oonf[ooo]Zo`0000gooo]Z00Co0000oookJ_oonf[ooo]Z0_l000000ooonf[o0000oook
JP05oookJPCo00000_oonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]ZoookJP;o0000
0_oonfX3o`000003oookJ_l0003ooo]Z00?ooo]Z0ol000000ooonf[o0000oookJP02o`000003oook
J_l0003o000000;ooo]Z00?o0000oookJ_oonfX01?l000000ooonf[o0000oookJP03oookJP03o`00
0?oonf[ooo]Z00;ooo]Z0_l0000<oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l000000ooonf[o
0000oookJP02oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l000000_l000000ooonf[o
0000oookJP02o`00017ooo]Z00Co0000oookJ_l0003o00000ooonfX01Ol0003ooo]ZoookJ_oonf[o
000000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00003oookJP03o`000?oonf[o000000;o00000ooo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00003oookJP?o00002Ooo
nfX00ol0003ooo]Zo`000004o`0000Cooo]Z0ol000000ooonf[o0000o`000002oookJP05o`000?oo
nf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z
0_l000000ooonf[o0000o`000004o`0003Kooo]Z1Ol000000ooonf[o0000o`000004o`0000?ooo]Z
0_l000000ooonf[o0000oookJP02o`0000Kooo]Z00Co0000oookJ_oonf[o00002?oonfX2o`0000[o
oo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000?ooo]Z0_l00006oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX00_l0000:oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000
oookJ_oonf[ooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00cooo]Z0ol00002oookJP07o`000?oo
nf[o0000oookJ_l0003ooo]Zo`000004oookJP;o00000ooonfX2o`0000?ooo]Z0ol00004oookJP04
o`000?oonf[o0000o`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00006
oookJPGo000000?ooo]Zo`000?oonfX01?l000000ooonf[o0000oookJP02o`000003oookJ_l0003o
oo]Z00?ooo]Z00?o0000oookJ_l000001?oonfX3o`000003oookJ_l0003ooo]Z00;o000000Gooo]Z
o`000?l0003o0000oookJP03o`0000Gooo]Z0_l00005oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z
0_l000000ooonf[o0000oookJP09oookJP7o000000001?l0003ooo]ZoookJ_l00005oookJP;o0000
1OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Wooo]Z00Go0000oookJ_l0003o
oo]Zo`000004oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_l00003oookJP03
o`000?oonf[ooo]Z00?ooo]Z0_l000001?oonf[o0000oookJ_l00004oookJP03o`000?oonf[ooo]Z
00Go000000?ooo]Zo`000?oonfX00_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000_oo
nfX01?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[ooo]Z00;o00002?oonfX01?l0003ooo]Z
oookJ_l00003oookJP;o000000?ooo]Zo`000?l000000ol00002oookJP;o00001OoonfX00ol0003o
oo]ZoookJP02oookJP;o00001ooonfX00ol0003ooo]ZoookJP07oookJP05o`000?oonf[ooo]Zoook
J_l000000_oonfX4o`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000?ooo]Z0_l00009oook
JP;o00000ooonfX00ol0003ooo]Zo`000003oookJP06o`000?oonf[ooo]Zo`000?oonf[o00001Ooo
nfX01Ol0003ooo]Zo`000?oonf[o000000Sooo]Z1?l00003oookJP04o`000?oonf[o0000oookJPCo
00000_oonfX6o`0003Gooo]Z1ol000001_oonf[o0000o`000?oonf[o0000oookJP?o00000_oonfX0
1?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003ooo]Z00;o000000Cooo]Zo`000?oonf[o0000
0ooonfX3o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l000000ooonf[o0000oookJP02oookJP04
o`000?oonf[ooo]Zo`0000;ooo]Z00Co0000oookJ_oonf[o00001ooonfX00ol0003ooo]Zo`000003
oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00004oookJP;o00000ooonfX01?l0003ooo]ZoookJ_l0
0003oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]Z
o`000005oookJPGo00000_oonfX3o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l000001Ooonf[o
0000oookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX02OoonfX01_l0003ooo]Zo`000?l0003o
oo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_oonfX2o`000003oook
J_l0003o000000Co00000ooonfX2o`0000;ooo]Z00Ko0000oookJ_l0003o0000oookJ_l00002oook
JP06o`000?oonf[ooo]Zo`000?oonf[o00000ooonfX00ol0003ooo]ZoookJP05oookJP07o`000?oo
nf[o0000o`000?oonf[o0000oookJP02o`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Oooo]Z0Ol000000005o`000?oonf[ooo]ZoookJ_l0
00001_oonfX3o`0000;ooo]Z00Go0000oookJ_l0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z
00Cooo]Z0_l00003oookJP;o000000Cooo]Zo`000?oonf[o00001OoonfX2o`0000?ooo]Z00Go0000
oookJ_oonf[ooo]Zo`000007oookJP?o000000Cooo]Zo`000?l0003o00001?oonfX2o`000003oook
J_l0003ooo]Z00Co00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000;o0000
00?ooo]Zo`000?oonfX00ooonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00_l00003oookJPCo0000
1OoonfX2o`000005oookJ_l0003ooo]Zo`000?oonfX00ol00004oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0000=oookJP03o`000?oonf[ooo]Z
00?ooo]Z0_l00004oookJP03o`000?oonf[o000000?o000000?ooo]Zo`000?oonfX00_l00002oook
JP03o`000?oonf[o000000Cooo]Z1?l00002oookJPCo000000Kooo]Zo`000?l0003ooo]Zo`000?oo
nfX5o`0003Cooo]Z0ol000001_oonf[o0000oookJ_oonf[o0000oookJP?o00001?oonfX01Ol0003o
oo]ZoookJ_oonf[o000000Gooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0000=oookJP;o00001_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00Co0000oookJ_oonf[o00000_oonfX01?l0003o
oo]ZoookJ_l00005oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Z
o`0000Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJPCo00000ooonfX3
o`00000:oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`0000;ooo]Z0_l000000ooo
nf[o0000oookJP0:oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_l000000_oonfX0
0ol0003ooo]ZoookJP03o`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_l0
003ooo]Z00Co000000?ooo]Zo`000?oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[o000000_ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00[ooo]Z
00Go0000oookJ_oonf[ooo]Zo`000005oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z
?_oonfX1o`00000000?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00003oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00006oookJP05o`000?oonf[ooo]Zoook
J_l000001?oonfX02?l0003ooo]Zo`000?l0003ooo]Zo`000?oonf[o00000_oonfX3o`0000?ooo]Z
00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`000007oookJP?o000000Gooo]Zo`000?l0003o
oo]Zo`000002oookJP;o00001?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000Ko
oo]Z0_l00002oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000ooonfX00ol0003ooo]Zo`000005
oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000_oonfX5o`0001?ooo]Z0_l00009oookJP04o`00
0?oonf[ooo]Zo`0000cooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l0
00000_oonfX00ol0003ooo]Zo`000002o`0000?ooo]Z0_l00004oookJP03o`000?oonf[o000000Co
oo]Z00?o0000oookJ_l000000ol00002oookJP06o`000?oonf[o0000o`000?oonf[o00000_oonfX0
0ol0003ooo]ZoookJP02oookJP04o`000?oonf[o0000oookJP;o00000_oonfX01_l0003ooo]Zo`00
0?l0003ooo]Zo`0000;ooo]Z0ol0000doookJP_o000000?ooo]Zo`000?oonfX01?l000000ooonf[o
0000o`000002oookJP?o00003_oonfX00ol0003ooo]Zo`00000:oookJP;o00001OoonfX2o`0000Co
oo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Co
oo]Z00Co0000oookJ_oonf[o00001OoonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Gooo]Z00?o
0000oookJ_oonfX01OoonfX2o`000003oookJ_l0003ooo]Z00?o000000Wooo]Zo`000?l0003ooo]Z
o`000?oonf[o0000oookJ_l000004_oonfX01?l0003ooo]Zo`000?l00006oookJP03o`000?oonf[o
000000Gooo]Z0_l00002oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000_oonfX2o`000008oook
J_l0003ooo]Zo`000?oonf[o0000oookJ_l00005oookJP03o`000?oonf[o000000?ooo]Z00Co0000
oookJ_oonf[ooo]Z0ol00003oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP07
o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00004
oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00Ol000000007o`000?oonf[o
oo]ZoookJ_l0003ooo]Zo`000004oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z0_l00002oookJP03
o`000?oonf[ooo]Z00Cooo]Z1?l00004oookJP03o`000?oonf[o000000;o00000ooonfX01Ol0003o
oo]Zo`000?oonf[o000000?ooo]Z1?l00004oookJP04o`000?oonf[o0000o`0000?ooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04o`0000;ooo]Z00?o0000oookJ_l000001_oonfX0
1?l0003ooo]ZoookJ_oonfX2o`0000;ooo]Z00?o0000oookJ_l000002OoonfX3o`0000?ooo]Z00Co
0000oookJ_l0003o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oookJ_oo
nfX02?oonfX01?l0003ooo]Zo`000?l00005oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[o0000oookJP;o000000?ooo]Z
o`000?l000000_oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000002?oo
nfX00ol0003ooo]Zo`000002oookJP05o`000?oonf[o0000oookJ_l000000ooonfX01Ol0003ooo]Z
o`000?oonf[o000000Oooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02oookJP;o
00000_oonfX4o`000006oookJ_l0003o0000oookJ_l0003ooo]Z1?l000000ooonf[o0000o`000002
oookJPKo0000<_oonfX4o`000003oookJ_l0003ooo]Z00Gooo]Z0ol000001Ooonf[o0000oookJ_oo
nf[o000000;ooo]Z0ol00002oookJP04o`000?oonf[o0000oookJPGo00000_oonfX00ol0003ooo]Z
oookJP02o`0000Gooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000;ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
2?oonfX3o`0000;ooo]Z00?o0000oookJ_l000000ol000000ooonf[o0000o`000002oookJP;o0000
0_oonfX00ol0003ooo]ZoookJP02oookJP;o00001_oonfX00ol0003ooo]ZoookJP05oookJP;o0000
1ooonfX2o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?oonfX01?oonfX01?l0003ooo]Z
oookJ_l00002oookJP;o00000ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o00002OoonfX00ol0
003ooo]ZoookJP02o`0000?ooo]Z0_l00002oookJP03o`000?oonf[o0000017ooo]Z00Co0000oook
J_l0003ooo]Z0_l00002oookJP7o00000OoonfX1o`00000000Co0000oookJ_oonf[o00000_oonfX0
0ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0_l0000<oookJP;o00001Ooo
nfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[o000000?o00001OoonfX00ol0003ooo]Zo`00
0003oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l000001?oonf[o0000o`000?oonfX3o`0000;ooo]Z
00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`000002oookJPCo00000_oonfX00ol0003ooo]Z
oookJP02oookJP;o00001?oonfX00ol0003ooo]ZoookJP03oookJP07o`000?oonf[ooo]ZoookJ_l0
003ooo]Zo`000004oookJP;o000000Cooo]Zo`000?l0003o00002OoonfX2o`0001[ooo]Z00?o0000
oookJ_oonfX00_oonfX2o`0000;ooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]Zo`00
0009oookJP;o00001ooonfX3o`000006oookJ_l0003ooo]Zo`000?oonf[o00002OoonfX2o`0000?o
oo]Z00Co0000oookJ_oonf[o00000_oonfX6o`000003oookJ_l0003o000000;o00000_oonfX4o`00
0003oookJ_l0003o000000Co0000<OoonfX:o`000009oookJ_l0003o0000oookJ_l0003ooo]Zo`00
0?oonf[o000000Gooo]Z00Co0000oookJ_l0003o00000ooonfX01?l0003ooo]ZoookJ_oonfX3o`00
00?ooo]Z00Go0000oookJ_l0003ooo]Zo`000003oookJP03o`000?oonf[o000000?o00001?oonfX2
o`0000Oooo]Z00?o0000oookJ_oonfX03OoonfX2o`000003oookJ_l0003o000000Wooo]Z00Co0000
oookJ_oonf[o00003OoonfX00ol0003ooo]ZoookJP0<oookJP;o000000?ooo]Zo`000?oonfX01ooo
nfX5o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP06o`000?oonf[ooo]Zo`000?oo
nf[o00001?oonfX2o`000003oookJ_l0003o000000;ooo]Z00Co0000oookJ_oonf[ooo]Z1ol00000
0ooonf[o0000oookJP03oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP04oookJP?o000000?ooo]Zo`000?oonfX01_oonfX01?l0003ooo]ZoookJ_oo
nfX2o`000003oookJ_l0003o000000;ooo]Z0_l00003oookJP03o`000?oonf[o000000Oooo]Z0ol0
0005oookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol000000005o`000?oonf[ooo]ZoookJ_l000001Ooo
nfX00ol0003ooo]ZoookJP02oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000ooonfX00ol0003o
oo]ZoookJP04oookJP;o00001?oonfX3o`0000Kooo]Z00Co0000oookJ_l0003o00001?oonfX2o`00
00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP04o`000?oonf[ooo]ZoookJPGo00000ooo
nfX5o`00013ooo]Z00?o0000oookJ_oonfX01ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03o`000003oookJ_l0003o000000cooo]Z
0ol00004oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX00ol0003ooo]ZoookJP04oookJP06
o`000?oonf[ooo]Zo`000?oonf[o00001_oonfX00ol0003ooo]Zo`000007oookJP;o000000Cooo]Z
o`000?oonf[o00001_oonfX00ol0003ooo]ZoookJP0:oookJP;o00001OoonfX00ol0003ooo]Zoook
JP02o`0000?ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]ZoookJP03o`000004oook
J_l0003o0000o`0000Cooo]Z00?o0000oookJ_oonfX01Ol0000`oookJPCo000000?ooo]Zo`000?oo
nfX01ol00002oookJP?o000000?ooo]Zo`000?oonfX00_l00005oookJP?o000000Cooo]Zo`000?oo
nf[o00000_oonfX00ol0003ooo]Zo`000005oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`000005
oookJP;o000000?ooo]Zo`000?oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP;o00001?oonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Sooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0007oookJP04o`000?oonf[o0000o`0000?ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o0000
00Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z
00Kooo]Z0_l000000ooonf[o0000oookJP03o`000003oookJ_l0003o000000;ooo]Z00?o0000oook
J_oonfX01OoonfX01ol0003ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX01_l0003ooo]Zo`00
0?l0003ooo]Zo`0000cooo]Z00Go0000oookJ_l0003ooo]Zo`000003oookJP;o000000?ooo]Zo`00
0?oonfX01_oonfX00ol0003ooo]ZoookJP03o`0000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000005
oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oo
nfX01?oonfX2o`000003oookJ_l0003ooo]Z00?ooo]Z0ol000000ooonf[o0000oookJP04oookJP03
o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z
00?o00001_oonfX00ol0003ooo]ZoookJP02o`0000Cooo]Z00?o0000oookJ_l000000ol000001?oo
nf[o0000oookJ_l00002oookJP03o`000?oonf[ooo]Z00Co00000_oonfX2o`0000_ooo]Z1?l00005
oookJP?o000000?ooo]Zo`000?l000000_oonfX01?l0003ooo]Zo`000?oonfX2o`000003oookJ_l0
003ooo]Z00;o00000_oonfX2o`000003oookJ_l0003o000000;o00000_oonfX2o`0000kooo]Z00Co
0000oookJ_oonf[o00000_oonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oonf[ooo]Z00Co
oo]Z0_l0000>oookJP;o00001?oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zoook
JP;o00000_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Cooo]Z0_l00002oookJP03o`000?oo
nf[ooo]Z00?ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00004oookJP04o`000?oo
nf[o0000o`0000Cooo]Z0ol00002oookJPKo0000;ooonfX9o`000006oookJ_l0003o0000oookJ_l0
003ooo]Z0_l000001?oonf[o0000oookJ_l00002oookJP;o000000Cooo]Zo`000?l0003o00000_oo
nfX00ol0003ooo]ZoookJP08oookJP04o`000?oonf[o0000o`0000Sooo]Z00?o0000oookJ_oonfX0
1OoonfX2o`0000Cooo]Z00?o0000oookJ_l000001_oonfX2o`0000?ooo]Z0_l0000?oookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z00;o000000Cooo]Zo`000?l0003o00000_oonfX00ol0003ooo]Zo`000002oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_l000000_l000000ooonf[o0000oookJP02oookJP;o
000000?ooo]Zo`000?l000001?oonfX01?l0003ooo]Zo`000?oonfX2o`000003oookJ_l0003ooo]Z
00Cooo]Z00Co0000oookJ_oonf[ooo]Z0_l00003oookJP;o00001OoonfX00ol0003ooo]Zo`000005
oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000003oookJP?o000000?ooo]Zo`000?oonfX0
1?oonfX01?l0003ooo]ZoookJ_l00004oookJP7o000000001?l0003ooo]Zo`000?oonfX2o`000004
oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`000008oook
JPCo00001?oonfX3o`000004oookJ_l0003ooo]Zo`0000Kooo]Z00Co0000oookJ_l0003ooo]Z0_l0
00000ooonf[o0000oookJP02oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Co0000oookJ_oonf[o
oo]Z0_l000000ooonf[o0000o`000002oookJP;o000000?ooo]Zo`000?oonfX01?l00007oookJP04
o`000?oonf[o0000oookJP;o00002_oonfX2o`0000?ooo]Z00?o0000oookJ_l000000_l00002oook
JP03o`000?oonf[ooo]Z00Co00003_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Wooo]Z00Go0000
oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_l0003ooo]Z
0_l0000:oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]Z
oookJP02o`0000?ooo]Z00Go0000oookJ_l0003ooo]Zo`000003oookJP04o`000?oonf[ooo]Zoook
JP;o00001_oonfX01_l0003ooo]Zo`000?l0003ooo]Zo`0000Cooo]Z00Ko0000oookJ_oonf[ooo]Z
o`000?oonfX3o`0000;ooo]Z00Oo0000oookJ_oonf[o0000oookJ_l0003ooo]Z00Ko0000;_oonfX3
o`000004oookJ_l0003o0000oookJP;o00000ooonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z
0_l0000:oookJP;o000000Oooo]Zo`000?oonf[ooo]Zo`000?oonf[o000000cooo]Z00?o0000oook
J_oonfX03?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o000000?ooo]Z0_l0000Hoook
JP03o`000?oonf[ooo]Z00Wooo]Z0_l0000=oookJPCo000000?ooo]Zo`000?l000000ol00005oook
JP04o`000?oonf[ooo]ZoookJP;o000000Cooo]Zo`000?oonf[o00000_oonfX01?l0003ooo]Zoook
J_l00009oookJP03o`000?oonf[ooo]Z00;ooo]Z00So0000oookJ_l0003ooo]Zo`000?oonf[o0000
oookJPGo00000_oonfX01?l0003ooo]Zo`000?oonfX2o`0000Kooo]Z0ol000000ooonf[o0000oook
JP03oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00Co0000oookJ_oonf[o00001ooonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Kooo]Z00?o0000oookJ_oonfX00Ol000000003o`000?oonf[ooo]Z00Cooo]Z0_l00003oookJP03
o`000?oonf[o000000Oooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP02oook
JP;o000000?ooo]Zo`000?oonfX00ooonfX01?l0003ooo]ZoookJ_l00002oookJP04o`000?oonf[o
oo]Zo`0000?ooo]Z1Ol000001Ooonf[o0000oookJ_l0003ooo]Z00;o000000Cooo]Zo`000?l0003o
00000_oonfX01?l0003ooo]Zo`000?l00002oookJPKo00000_oonfX2o`0000;ooo]Z00?o0000oook
J_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z00Co0000oookJ_oonf[ooo]Z1?l0
0007oookJP05o`000?oonf[o0000oookJ_l000002?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?o
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP06oookJP;o00000_oonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000:oookJP;o000000Kooo]Zo`000?oo
nf[o0000oookJ_l00007oookJP;o000000?ooo]Zo`000?l000000ooonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00002oookJP04o`000?oonf[o0000oookJP;o000000?o
oo]Zo`000?l000002?l0000]oookJP?o000000?ooo]Zo`000?l000001Ol000000ooonf[o0000oook
JP05o`000003oookJ_l0003ooo]Z00Co00002ooonfX2o`000003oookJ_l0003ooo]Z00Kooo]Z0_l0
0005oookJP;o00000_oonfX01?l0003ooo]ZoookJ_l00004oookJP06o`000?oonf[ooo]Zo`000?oo
nf[o00000ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`00
0?oonfX04_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l000001_oo
nf[o0000o`000?l0003ooo]Zo`0000?ooo]Z0_l000000ooonf[o0000oookJP02o`0000Cooo]Z00?o
0000oookJ_oonfX01?oonfX01Ol0003ooo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]Zo`000005o`0000;ooo]Z0_l00002oookJP03o`000?oonf[o000000;o0000
2ooonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z0ol00004oookJP;o00001?oonfX00ol0003ooo]Z
o`000005oookJP;o00002OoonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]Zo`000003oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP04oookJP06o`000?oonf[o
oo]Zo`000?oonf[o00000_oonfX01?l0003ooo]ZoookJ_l00007oookJP07o`000?oonf[ooo]Zoook
J_l0003ooo]Zo`000002oookJP03o`000?oonf[o000000;ooo]Z0_l00006oookJP;o00000ooonfX0
0ol0003ooo]Zo`000002o`000004oookJ_l0003ooo]Zo`0000?ooo]Z00Go0000oookJ_l0003o0000
oookJP04o`0000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[o000000?o
oo]Z0_l00002oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0ol00004oookJP;o00000_oonfX00ol0
003ooo]ZoookJP02o`0000?ooo]Z0_l00003oookJP;o00001OoonfX3o`0001Sooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000;ooo]Z00Co0000oook
J_oonf[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l000001Ooonf[o0000oookJ_oo
nf[o000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00;ooo]Z
0ol000000ooonf[o0000oookJP03o`0000?ooo]Z1Ol000000ooonf[o0000oookJP0:o`0002gooo]Z
1Ol000000ooonf[o0000o`000006o`000003oookJ_l0003o000000;o000000Gooo]Zo`000?oonf[o
oo]Zo`000006oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0_l000000ooonf[o0000o`00000:
oookJP;o00000ooonfX01?l0003ooo]Zo`000?l00007oookJP;o00001_oonfX02?l0003ooo]Zoook
J_oonf[o0000oookJ_l0003ooo]Z0_l0000?oookJP03o`000?oonf[o000000Cooo]Z0_l000000ooo
nf[o0000oookJP04oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`000005oookJP03o`000?oonf[o
oo]Z00?ooo]Z0_l00002oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0_l00006oookJP05o`00
0?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o000000Go
oo]Z00Co0000oookJ_oonf[ooo]Z1ol000000ooonf[o0000oookJP03oookJP04o`000?oonf[ooo]Z
o`0000?ooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z0ol00002
oookJP?o00000ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;o00000ooonfX2
o`000003oookJ_l0003o000000;ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zo`000004
oookJP03o`000?oonf[ooo]Z007o000000000ol0003ooo]Zo`000007oookJP;o00000ooonfX6o`00
00Kooo]Z0_l00003oookJP03o`000?oonf[o000000Cooo]Z0_l000001?oonf[o0000oookJ_oonfX3
o`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX4o`000003oookJ_l0003ooo]Z00Go00000ooonfX2
o`0000?ooo]Z00?o0000oookJ_l000000_l000002?oonf[o0000o`000?oonf[o0000oookJ_l0003o
oo]Z0_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP02oookJP;o00000_oonfX6o`0001Gooo]Z00?o0000oookJ_oo
nfX01?oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP03oookJP;o
00000ooonfX2o`0000Gooo]Z00?o0000oookJ_l000000_oonfX2o`0000?ooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP02oookJP0:o`000?oonf[o0000o`000?oonf[o0000oookJ_l0
003ooo]Zo`0000Gooo]Z00?o0000oookJ_l000000_l000001?oonf[o0000o`000?oonfX4o`000005
oookJ_l0003o0000oookJ_l000000_oonfX2o`000005oookJ_l0003o0000o`000?oonfX02ol0000[
oookJPCo000000?ooo]Zo`000?l000001?oonfX5o`0000Kooo]Z00?o0000oookJ_l000000ooonfX2
o`000004oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX02?oonfX01_l0003ooo]Zoook
J_l0003ooo]Zo`0000Cooo]Z00Go0000oookJ_l0003ooo]Zo`00000:oookJP03o`000?oonf[ooo]Z
00Gooo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0003ooo]ZoookJP07oookJP;o00001_oonfX0
1ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001?oonfX00ol0003ooo]Zo`000002oookJP04o`00
0?oonf[ooo]ZoookJP;o00001ooonfX5o`0000cooo]Z0_l00003oookJP;o00000_oonfX00ol0003o
oo]Zo`000003oookJP?o00002_oonfX5o`000004oookJ_l0003o0000oookJP?o00000_oonfX01Ol0
003ooo]Zo`000?l0003ooo]Z00;o00000_oonfX00ol0003ooo]Zo`000002oookJP05o`000?oonf[o
oo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP02oookJP?o00002OoonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00006oookJP;o00000ooonfX01?l0003ooo]Zo`00
0?l00003oookJP7o000000001_l0003ooo]ZoookJ_l0003ooo]Zo`0000?ooo]Z00?o0000oookJ_l0
00002OoonfX01_l0003ooo]Zo`000?oonf[o0000oookJP;o00000_oonfX01_l0003ooo]ZoookJ_oo
nf[o0000oookJP;o00003?oonfX2o`0000?ooo]Z00Co0000oookJ_oonf[o00001?oonfX2o`0000Co
oo]Z00?o0000oookJ_oonfX00_oonfX2o`0000?ooo]Z00?o0000oookJ_l000001?l00004oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Gooo]Z00?o0000oookJ_l000000_l00005oookJP03o`000?oonf[ooo]Z00?o00001_oonfX00ol0
003ooo]ZoookJP03o`0000oooo]Z00Co0000oookJ_oonf[o00001OoonfX01ol0003ooo]ZoookJ_oo
nf[o0000oookJ_l000003_oonfX00ol0003ooo]ZoookJP02oookJP?o00000_oonfX00ol0003ooo]Z
oookJP03oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000;o
oo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0003ooo]Zo`000002o`0000;ooo]Z0_l00002oook
JP03o`000?oonf[ooo]Z00Cooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00;o00000_oonfX8
o`0002[ooo]Z1?l000000ooonf[o0000o`000003o`0000Cooo]Z0_l000001?oonf[o0000oookJ_l0
0003oookJP;o000000?ooo]Zo`000?l000002Ol000001?oonf[o0000oookJ_oonfX2o`0000oooo]Z
00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX01OoonfX2o`000003oookJ_l0003ooo]Z00Sooo]Z00?o0000oookJ_l000001ooonfX00ol0003o
oo]ZoookJP0;oookJP;o00002_oonfX4o`0000;ooo]Z00So0000oookJ_oonf[o0000oookJ_l0003o
oo]Zo`0000Oooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003ooo]ZoookJP02oookJP;o0000
1OoonfX00ol0003ooo]Zo`000003oookJP;o000000?ooo]Zo`000?l000000_oonfX01?l0003ooo]Z
o`000?oonfX4o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_l000000_l000000ooonf[o
0000o`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l000000ooonf[o0000o`000002o`0000Go
oo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[o000000Cooo]Z00?o0000oook
J_oonfX00_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX01?l00002oookJP03o`000?oonf[o0000
00?ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000001_l0003ooo]Z
o`000?l0003ooo]Zo`0000Sooo]Z00?o0000oookJ_l000000_l00003oookJP05o`000?oonf[ooo]Z
o`000?oonfX00_l00002oookJP?o000000Cooo]Zo`000?l0003o00002_oonfX01Ol0003ooo]Zo`00
0?oonf[o000000_ooo]Z1?l000000ooonf[o0000oookJP02o`0000?ooo]Z0_l000001?oonf[o0000
oookJ_l00002oookJPGo00001?oonfX01?l0003ooo]Zo`000?l00004oookJP03o`000?oonf[ooo]Z
00?ooo]Z0ol00002oookJP?o00001OoonfX2o`000005oookJ_l0003o0000o`000?oonfX00ol00005
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Wooo]Z00?o0000
oookJ_oonfX02OoonfX01?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003o000000Sooo]Z00Go
0000oookJ_oonf[ooo]Zo`00000?oookJP04o`000?oonf[o0000oookJP?o00000_oonfX2o`0000Go
oo]Z0_l000002_oonf[o0000o`000?l0003ooo]Zo`000?oonf[o0000oookJ_l00002oookJP03o`00
0?oonf[ooo]Z00Gooo]Z0_l000001_oonf[o0000oookJ_oonf[o0000oookJPGo000000?ooo]Zo`00
0?l000000_l0000YoookJPSo000000Kooo]Zo`000?oonf[ooo]Zo`000?oonfX2o`000003oookJ_l0
003ooo]Z00;o000000Cooo]Zo`000?l0003o00000_oonfX4o`0000Cooo]Z00Go0000oookJ_oonf[o
oo]Zo`000005oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP05oookJP05o`000?oonf[ooo]Zoook
J_l000002ooonfX00ol0003ooo]ZoookJP02o`0000Gooo]Z00?o0000oookJ_oonfX00_l00002oook
JP03o`000?oonf[o000000oooo]Z00So0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`0000;ooo]Z
00?o0000oookJ_l000002OoonfX02?l0003ooo]ZoookJ_l0003ooo]Zo`000?oonf[o00000_oonfX0
1?l0003ooo]ZoookJ_l00008oookJP?o000000Sooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`00
00Sooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00003oookJP03o`000?oonf[o000000?ooo]Z00?o
0000oookJ_oonfX04OoonfX03?l0003ooo]ZoookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0003o
oo]Zo`0000gooo]Z00Go0000oookJ_l0003ooo]Zo`000004oookJP7o000000000ol0003ooo]Zoook
JP03oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Wo
oo]Z0_l0000:oookJP05o`000?oonf[o0000oookJ_l000001?oonfX4o`000004oookJ_l0003ooo]Z
oookJP;o00000_oonfX2o`000003oookJ_l0003ooo]Z00Cooo]Z00?o0000oookJ_l000000ooonfX3
o`0000;ooo]Z0_l000001_oonf[o0000oookJ_l0003ooo]Zo`0000Cooo]Z0_l00003oookJP;o0000
0ooonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z0_l00002oookJP?o00000_oonfX01?l0003ooo]Z
oookJ_oonfX3o`000003oookJ_l0003o000000;o00000_oonfX3o`0000;ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00_ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oo
nf[o000000Kooo]Z00Co0000oookJ_l0003o00006?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0
0_oonfX01Ol0003ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]Zo`000002o`000003oookJ_l0003ooo]Z00Ko00000ooonfX2o`0000;ooo]Z00Go0000oookJ_oo
nf[o0000oookJP0:o`0002Sooo]Z1Ol000000ooonf[o0000o`000003o`000004oookJ_l0003o0000
o`0000?ooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?o00001_oo
nfX01?l0003ooo]ZoookJ_l00002oookJP;o000000?ooo]Zo`000?oonfX03OoonfX01?l0003ooo]Z
oookJ_l00003oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP07oookJP;o00005_oonfX00ol0003ooo]ZoookJP05oookJP;o00000_oonfX3o`0000?o
oo]Z00?o0000oookJ_oonfX00_l00003oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`000?l0
00000ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[o000000Gooo]Z1_l00006oookJPCo
00000_oonfX00ol0003ooo]ZoookJP03oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`000006oook
JP03o`000?oonf[ooo]Z00?o00000ooonfX00ol0003ooo]ZoookJP02oookJP;o00001?oonfX01?l0
003ooo]ZoookJ_oonfX3o`0001Oooo]Z0Ol000000003o`000?oonf[o000000;ooo]Z0_l00002oook
JP03o`000?oonf[ooo]Z00Oooo]Z00So0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJP;o0000
0_oonfX2o`000003oookJ_l0003ooo]Z00Gooo]Z1Ol00003oookJP03o`000?oonf[ooo]Z00;o0000
00?ooo]Zo`000?oonfX02OoonfX01?l0003ooo]Zo`000?l00002oookJP?o00000ooonfX4o`0000Co
oo]Z0_l000000ooonf[o0000o`00000;oookJP;o00000_oonfX00ol0003ooo]Zo`000002o`000003
oookJ_l0003o000000;o00001?oonfX3o`000003oookJ_l0003o000000?o00000_oonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Go
oo]Z00Co0000oookJ_oonf[o00002OoonfX00ol0003ooo]Zo`000004oookJP04o`000?oonf[o0000
o`0000;ooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Kooo]Z0_l00009oookJP03o`000?oonf[o
oo]Z00;o00000ooonfX01?l0003ooo]ZoookJ_l00005oookJPCo00001ooonfX2o`0000Cooo]Z00?o
0000oookJ_l000000ol00004oookJPGo00009ooonfX5o`000004oookJ_l0003o0000o`0000Gooo]Z
00Go0000oookJ_oonf[o0000oookJP02o`000003oookJ_l0003o000000;ooo]Z00Co0000oookJ_oo
nf[ooo]Z0_l000000ooonf[o0000o`000002oookJP?o00000ooonfX3o`0000Wooo]Z0ol00005oook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02ooonfX2o`0000kooo]Z0_l00005oook
JP04o`000?oonf[ooo]ZoookJP;o00001OoonfX00ol0003ooo]Zo`000007oookJP03o`000?oonf[o
oo]Z00?ooo]Z1?l000001?oonf[o0000o`000?l00005oookJPGo00001?oonfX3o`000003oookJ_l0
003ooo]Z00;o000000?ooo]Zo`000?l000000ooonfX3o`0000;ooo]Z00Go0000oookJ_l0003ooo]Z
o`000002oookJP;o00001OoonfX3o`0000?ooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000?o
oo]Z0_l00003oookJP;o000000Cooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]ZoookJP02oook
JPCo00002?oonfX1o`00000000Co0000oookJ_oonf[o00003_oonfX01?l0003ooo]Zo`000?l00005
oookJP;o00000_oonfX02Ol0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000009oookJP03
o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_l0003ooo]Z0_l00004oookJP03o`000?oonf[o0000
00Gooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z0_l00002oookJP?o00001_oonfX0
0ol0003ooo]Zo`000003oookJPCo000000?ooo]Zo`000?oonfX00ooonfX2o`000003oookJ_l0003o
oo]Z00?ooo]Z00Oo0000oookJ_l0003o0000oookJ_l0003ooo]Z00;o00001?oonfX3o`000003oook
J_l0003ooo]Z01?ooo]Z00?o0000oookJ_oonfX02ooonfX01?l0003ooo]Zo`000?l00005oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02?oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Gooo]Z0_l00002oookJP03o`000?oonf[o000000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000:
oookJP04o`000?oonf[o0000oookJP;o000000?ooo]Zo`000?oonfX01?oonfX00ol0003ooo]Zoook
JP04o`0000;ooo]Z0_l000000ooonf[o0000oookJP06o`0002Oooo]Z2Ol00002oookJP03o`000?oo
nf[o000000Co00000_oonfX01?l0003ooo]Zo`000?oonfX3o`000003oookJ_l0003ooo]Z00?ooo]Z
00?o0000oookJ_l000002?oonfX01Ol0003ooo]ZoookJ_oonf[o000000cooo]Z00?o0000oookJ_oo
nfX02_oonfX01?l0003ooo]ZoookJ_l00007oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX08?oonfX01?l0003ooo]ZoookJ_oonfX4o`000003oookJ_l0003o000000;o000000Cooo]Z
o`000?l0003ooo]Z0ol000000ooonf[o0000o`000002oookJP07o`000?oonf[ooo]ZoookJ_l0003o
oo]Zo`000006oookJPOo000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJP08o`000?oonf[ooo]Z
o`000?oonf[o0000oookJ_l00003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00So0000oookJ_oo
nf[o0000oookJ_l0003ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX01ol0003ooo]Zoook
J_oonf[o0000oookJ_l000001ooonfX2o`000003oookJ_l0003ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX02OoonfX1o`00007ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000
00000ol0003ooo]ZoookJP04oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Go0000oookJ_l0003o
oo]Zo`000005oookJP04o`000?oonf[o0000oookJP;o00000ooonfX2o`0000;ooo]Z00Go0000oook
J_oonf[ooo]Zo`000002oookJP;o000000?ooo]Zo`000?l000000ooonfX2o`0000Cooo]Z00?o0000
oookJ_l000000_oonfX00ol0003ooo]Zo`000006oookJP05o`000?oonf[o0000o`000?oonfX01?l0
00000ooonf[o0000o`000004o`000003oookJ_l0003ooo]Z00Sooo]Z00Go0000oookJ_oonf[ooo]Z
o`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol00004oookJPCo00000ooonfX3o`0000oooo]Z
00?o0000oookJ_oonfX01?oonfX2o`0000Cooo]Z00?o0000oookJ_l000003_oonfX2o`0000Oooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`00000:oookJP03o`000?oonf[ooo]Z00;ooo]Z
00Go0000oookJ_oonf[ooo]Zo`00000:oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l000001ooonf[o
0000oookJ_l0003ooo]Zo`000?oonfX01?l000001Ooonf[o0000oookJ_l0003ooo]Z00;o000000Co
oo]Zo`000?l0003o00000_oonfX<o`0002Gooo]Z2_l000001Ooonf[o0000oookJ_oonf[o000000Co
oo]Z00?o0000oookJ_oonfX00ol00002oookJP03o`000?oonf[o000000?o00000_oonfX01ol0003o
oo]ZoookJ_oonf[o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP03oookJP;o00000_oonfX0
1?l0003ooo]Zo`000?l00003oookJP06o`000?oonf[ooo]Zo`000?oonf[o00002?oonfX2o`0000Ko
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP;o00002?oonfX2o`000003
oookJ_l0003o000000gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP08oookJP?o
00001?oonfX3o`0000?ooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP07oookJP;o
00001ooonfX00ol0003ooo]Zo`000003o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?oo
nf[o00000_oonfX6o`000004oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX0
1?l0003ooo]ZoookJ_l00008oookJP03o`000?oonf[ooo]Z00;o00001OoonfX01?l0003ooo]Zoook
J_l00005oookJP04o`000?oonf[o0000o`0000Kooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0
003ooo]ZoookJP02o`0000?ooo]Z0Ol000000004o`000?oonf[ooo]Zo`0000Cooo]Z0ol000000ooo
nf[o0000o`000008oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l00002oookJP03o`000?oonf[o
oo]Z00?ooo]Z0_l000000ooonf[o0000oookJP03oookJP;o00000ooonfX00ol0003ooo]ZoookJP02
oookJP04o`000?oonf[o0000oookJP;o000000?ooo]Zo`000?l000000_oonfX5o`0000?ooo]Z00Ko
0000oookJ_oonf[ooo]Zo`000?oonfX2o`000003oookJ_l0003ooo]Z00Ko000000?ooo]Zo`000?oo
nfX00_oonfX01Ol0003ooo]Zo`000?oonf[o000000;ooo]Z00Go0000oookJ_oonf[o0000oookJP02
o`0000Oooo]Z0ol00003oookJP03o`000?oonf[o000000;o00004?oonfX00ol0003ooo]ZoookJP05
oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX02ooonfX01?l0003ooo]Zoook
J_l00007oookJP05o`000?oonf[o0000oookJ_l000003_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z
00;o00000_oonfX00ol0003ooo]Zo`000004oookJP04o`000?oonf[o0000o`0000Gooo]Z0ol00003
oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l00002oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z1?l0
00000ooonf[o0000oookJP09o`0002Gooo]Z1Ol00002oookJP;o000000?ooo]Zo`000?l000001Ol0
00001ooonf[o0000o`000?l0003ooo]Zo`000?oonfX00ol000001Ooonf[o0000oookJ_l0003ooo]Z
00;o000000Gooo]Zo`000?oonf[o0000oookJP02o`0000Cooo]Z00?o0000oookJ_l000001?oonfX3
o`0000Cooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000[ooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0007oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_l00003oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP06oookJP04o`000?oo
nf[ooo]ZoookJPCo00000_oonfX01Ol0003ooo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_oo
nfX00_oonfX01?l0003ooo]ZoookJ_l00006oookJP;o00001ooonfX3o`0000Cooo]Z00?o0000oook
J_l000000_oonfX3o`000003oookJ_l0003o000000;ooo]Z00Oo0000oookJ_l0003ooo]Zo`000?oo
nf[o000000;ooo]Z00?o0000oookJ_oonfX00_l000001?oonf[o0000o`000?oonfX2o`000006oook
J_l0003o0000o`000?oonf[o00001_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Wooo]Z0ol000001?oonf[o0000oookJ_l00002
oookJP7o000000002Ol0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000002oookJP;o0000
0ooonfX00ol0003ooo]ZoookJP08oookJP;o00000_oonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z
00?o0000oookJ_oonfX01OoonfX2o`0000Gooo]Z00Go0000oookJ_l0003ooo]Zo`000005oookJP;o
00000ooonfX01ol0003ooo]ZoookJ_l0003ooo]Zo`000?oonfX00ol00002oookJP;o000000?ooo]Z
o`000?l000000_oonfX2o`000003oookJ_l0003o000000Oooo]Z00Co0000oookJ_oonf[ooo]Z0_l0
00001?oonf[o0000oookJ_oonfX2o`000004oookJ_l0003o0000oookJP;o00000_oonfX00ol0003o
oo]Zo`000003oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX02_oonfX2o`000003
oookJ_l0003ooo]Z00Wooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000;ooo]Z0_l00005oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oookJP;o
000000?ooo]Zo`000?oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[o000000_ooo]Z00Co0000oook
J_l0003o00000ooonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000_oonfX01?l0003ooo]Z
oookJ_oonfX3o`0000;ooo]Z0_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[o000000Oo
00008ooonfX=o`000003oookJ_l0003ooo]Z00Co000000Gooo]Zo`000?l0003ooo]Zo`000004oook
JP03o`000?oonf[o000000?o000000?ooo]Zo`000?oonfX00_oonfX2o`0000;ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP;o00001OoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z00cooo]Z0_l00002oookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX2
o`0000Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z00Wooo]Z0ol00006oookJP03o`000?oonf[o000000?o000000Cooo]Zo`000?l0003o00000ooo
nfX2o`0000;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP;o000000Co
oo]Zo`000?l0003o00001ooonfX01?l0003ooo]Zo`000?oonfX2o`000003oookJ_l0003ooo]Z00;o
00000ooonfX01?l0003ooo]ZoookJ_l00006oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00002oook
JP?o00001ooonfX03?l0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oook
JP;o00001OoonfX01?l0003ooo]ZoookJ_l00003oookJP04o`000?oonf[ooo]ZoookJP7o00000000
0ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000Oo0000oookJ_oonf[ooo]Zo`000?oo
nf[o000000Oooo]Z00?o0000oookJ_l000001Ol000001Ooonf[o0000oookJ_l0003ooo]Z00;o0000
0ooonfX00ol0003ooo]ZoookJP06oookJP;o00001?oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o
000000Cooo]Zo`000?l0003o00000_oonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[o
000000;o00000ooonfX00ol0003ooo]ZoookJP03oookJP;o000000?ooo]Zo`000?l000000_oonfX0
0ol0003ooo]ZoookJP03o`0000kooo]Z0ol00007oookJP;o00000ooonfX3o`0000_ooo]Z00?o0000
oookJ_oonfX01ooonfX01Ol0003ooo]ZoookJ_oonf[o000000cooo]Z00Go0000oookJ_oonf[ooo]Z
o`00000JoookJP05o`000?oonf[o0000oookJ_l000001OoonfX00ol0003ooo]Zo`000002oookJP05
o`000?oonf[o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP05o`000?oonf[o0000oookJ_l000001?oo
nfX00ol0003ooo]Zo`000003oookJP?o00001OoonfX3o`000004oookJ_l0003o0000o`0000;ooo]Z
0_l0000SoookJPWo000000Cooo]Zo`000?l0003ooo]Z0_l000000ooonf[o0000o`000002oookJP;o
00000_oonfX00ol0003ooo]ZoookJP02oookJP;o000000?ooo]Zo`000?l000001?oonfX01?l0003o
oo]Zo`000?l00009oookJP05o`000?oonf[o0000oookJ_l000001ooonfX2o`0000Sooo]Z0ol0000;
oookJP03o`000?oonf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0EoookJP;o000000Oo
oo]Zo`000?l0003ooo]Zo`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003ooo]Z0ol00002oook
JP;o000000?ooo]Zo`000?oonfX00ooonfX3o`0000Cooo]Z0ol00003oookJPCo00001?oonfX2o`00
00;ooo]Z00Co0000oookJ_l0003ooo]Z1_l00006oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00000
0ooonf[o0000oookJP05oookJP03o`000?oonf[o000000Oooo]Z0ol00003oookJP04o`000?oonf[o
oo]Zo`0000;ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z007o000000000ol0003ooo]ZoookJP04oookJP;o00000_oonfX01?l0003ooo]ZoookJ_l0
0003oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_l0003o00000_oonfX01?l0003ooo]Z
o`000?oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX02OoonfX2o`000003oookJ_l0003ooo]Z00;o
00000_oonfX01?l0003ooo]Zo`000?oonfX2o`0000Sooo]Z0ol00002oookJP07o`000?oonf[o0000
o`000?oonf[o0000oookJP02o`0000Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000000_l00002oookJP03o`000?oo
nf[ooo]Z00?o00002?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00Co0000oookJ_oonf[o
00002_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP03oookJP?o00002?oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02o`0000Gooo]Z0_l000000ooo
nf[o0000o`000007oookJP;o00000ooonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000?ooo]Z0ol0
00000ooonf[o0000oookJP02o`000003oookJ_l0003o000000co00008OoonfX8o`000005oookJ_l0
003o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]ZoookJP?o
00001_oonfX3o`000006oookJ_l0003ooo]Zo`000?oonf[o00001_oonfX3o`0000Gooo]Z00?o0000
oookJ_oonfX02?oonfX2o`0000Cooo]Z00Go0000oookJ_l0003ooo]Zo`000005oookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_l000001OoonfX01?l0003ooo]Zo`000?l0000FoookJP03o`00
0?oonf[ooo]Z017ooo]Z0ol00002oookJP;o000000Gooo]Zo`000?l0003ooo]Zo`000002oookJP03
o`000?oonf[o000000[ooo]Z00?o0000oookJ_oonfX01?oonfX9o`0000;ooo]Z00?o0000oookJ_l0
00001_oonfX2o`0000Oooo]Z00Ko0000oookJ_l0003o0000oookJ_l00002oookJP04o`000?oonf[o
oo]Zo`0000;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oo
nf[o0000oookJ_l000001?oonfX2o`000003oookJ_l0003o000000;o00003OoonfX01?l0003ooo]Z
oookJ_oonfX2o`0000;ooo]Z0Ol000000003o`000?oonf[o000000Kooo]Z00Oo0000oookJ_oonf[o
oo]Zo`000?oonf[o000000Cooo]Z00Co0000oookJ_l0003o00000ooonfX2o`0000;ooo]Z0_l00000
1ooonf[o0000oookJ_oonf[o0000oookJ_l000001?oonfX01?l0003ooo]ZoookJ_oonfX2o`000003
oookJ_l0003o000000Sooo]Z0ol00002oookJP04o`000?oonf[ooo]ZoookJP?o000000Cooo]Zo`00
0?oonf[o00000_oonfX00ol0003ooo]ZoookJP05oookJPGo00000_oonfX2o`0000Oooo]Z00Go0000
oookJ_oonf[ooo]Zo`000003oookJP;o00001ooonfX3o`000003oookJ_l0003ooo]Z00Oooo]Z0_l0
000=oookJP;o00001?oonfX2o`0000_ooo]Z00?o0000oookJ_oonfX02?oonfX01ol0003ooo]Zoook
J_oonf[o0000oookJ_l000001?oonfX01?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003ooo]Z
00Wooo]Z00Co0000oookJ_oonf[o00001_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l00000
0_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00_l00005oookJP03o`000?oonf[ooo]Z00;ooo]Z
00Co0000oookJ_l0003o00000_oonfX00ol0003ooo]Zo`000002oookJPKo000000?ooo]Zo`000?l0
00001_l0000QoookJPOo000000Cooo]Zo`000?l0003ooo]Z1ol00008oookJP?o000000Cooo]Zo`00
0?oonf[ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00?o000000?ooo]Zo`000?l000000ol00002
oookJP03o`000?oonf[o000000?o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]ZoookJP0;
oookJP;o00000ooonfX01Ol0003ooo]Zo`000?oonf[o000000Cooo]Z0_l0000:oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00Sooo]Z0_l00003oookJPGo00000ooonfX2o`000004oookJ_l0003ooo]ZoookJP;o0000
2?oonfX01?l0003ooo]ZoookJ_l00006oookJPOo00001?oonfX2o`000007oookJ_l0003o0000o`00
0?oonf[o0000oookJP02o`0000?ooo]Z0_l00004oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`00
0005oookJP03o`000?oonf[o000000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`00
0?oonf[ooo]Z00;ooo]Z0ol000001?oonf[o0000oookJ_l00004oookJP03o`000?oonf[ooo]Z00Go
oo]Z0_l000001?oonf[o0000oookJ_l00006oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oo
oo]Z?_oonfX1o`00000000?o0000oookJ_oonfX04_oonfX01_l0003ooo]ZoookJ_oonf[o0000oook
JP;o00003?oonfX01?l0003ooo]Zo`000?oonfX2o`000003oookJ_l0003o000000Kooo]Z00?o0000
oookJ_oonfX00_oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z0_l00005oookJP08o`000?oonf[o
oo]Zo`000?oonf[o0000oookJ_l00004oookJP03o`000?oonf[o000000;o00000ooonfX2o`0000Co
oo]Z00?o0000oookJ_l000000_l000001Ooonf[o0000oookJ_oonf[o000000Cooo]Z0ol00002oook
JP03o`000?oonf[o000000;o00000_oonfX2o`0000kooo]Z00?o0000oookJ_oonfX01OoonfX3o`00
00Kooo]Z0ol00003oookJP;o00002OoonfX01?l0003ooo]ZoookJ_l00003oookJP;o000000?ooo]Z
o`000?l000000ooonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[o0000oookJ_l000000ooo
nfX01?l0003ooo]ZoookJ_l00005oookJP;o00001?oonfX01?l0003ooo]ZoookJ_oonfX2o`000003
oookJ_l0003ooo]Z00?o00000_oonfX00ol0003ooo]ZoookJP06o`0000;ooo]Z0_l000001ooonf[o
0000o`000?l0003ooo]Zo`000?oonfX01Ol000001?oonf[o0000oookJ_oonfX5o`000003oookJ_l0
003o000001oooo]Z3?l000000ooonf[o0000oookJP03o`000003oookJ_l0003o000000;o000000Co
oo]Zo`000?l0003o00001OoonfX01?l0003ooo]Zo`000?l00002oookJP;o00000_oonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000:oookJP05o`000?oonf[ooo]Zoook
J_l000000_oonfX00ol0003ooo]ZoookJP04oookJP;o00002ooonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z01Cooo]Z1Ol000000ooonf[o0000o`000002oookJP03o`000?oonf[o
oo]Z00;ooo]Z0_l0000@oookJPCo000000Cooo]Zo`000?l0003o00000_oonfX01?l0003ooo]Zoook
J_oonfX4o`0000Oooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP04o`000?oonf[ooo]Zo`00
00Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000002oookJP;o000000Kooo]Zo`00
0?oonf[o0000oookJ_l00003oookJP03o`000?oonf[ooo]Z00;o000000Gooo]Zo`000?oonf[ooo]Z
o`000004oookJP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000?o
0000oookJ_l000001?oonfX2o`0000Kooo]Z00Go0000oookJ_l0003ooo]Zo`000007oookJP;o0000
0_oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[o0000oookJ_l000000ooonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_l000001?oonfX00ol0003o
oo]ZoookJP04o`0000Cooo]Z0ol000000ooonf[o0000o`000002o`0000Cooo]Z2?l00006oookJP03
o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[o0000
00?o000000?ooo]Zo`000?l000001?oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z
00;o00002_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Cooo]Z00?o0000oookJ_l000004Ooo
nfX00ol0003ooo]Zo`000002oookJP04o`000?oonf[o0000oookJP;o000000?ooo]Zo`000?oonfX0
0ooonfX01?l0003ooo]ZoookJ_oonfX2o`0000;ooo]Z0_l00004oookJP05o`000?oonf[ooo]Zoook
J_l000000_oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;o00000ooonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00Oo0000oookJ_l0003o0000oookJ_l0
003ooo]Z00;o00001OoonfXAo`0001oooo]Z1Ol000000ooonf[o0000o`000002o`0000Gooo]Z00Go
0000oookJ_l0003ooo]Zo`00000:oookJP;o00000ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o
00000ooonfX01?l0003ooo]Zo`000?l00007oookJP;o00001?oonfX2o`000003oookJ_l0003ooo]Z
00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX00_oonfX01?l0003ooo]Zo`000?l00003oookJP05o`000?oonf[ooo]ZoookJ_l00000
0_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP07oookJP04o`000?oonf[ooo]ZoookJPCo000000Gooo]Zo`000?l0
003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00002oookJP03o`000?oonf[o0000
00?ooo]Z00?o0000oookJ_l000000ooonfX4o`0000Gooo]Z00?o0000oookJ_oonfX00ol00003oook
JP03o`000?oonf[ooo]Z00Kooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ol00003oookJP05o`000?oonf[ooo]ZoookJ_l00000
1_oonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP02oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00Co0000oookJ_oonf[ooo]Z0Ol000000003
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00006oook
JP07o`000?oonf[ooo]Zo`000?oonf[o0000oookJP02o`0000;ooo]Z0_l00002oookJP;o000000?o
oo]Zo`000?oonfX00ooonfX01_l0003ooo]Zo`000?l0003ooo]Zo`0000;ooo]Z0_l000000ooonf[o
0000o`000002o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP;o
000000Wooo]Zo`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX2o`000003oookJ_l0
003o000000Cooo]Z0ol00009oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`000006oookJP?o0000
0_oonfX2o`0000kooo]Z00?o0000oookJ_oonfX02OoonfX01?l0003ooo]ZoookJ_l00007oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP02oookJP;o
00001ooonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00ol00004oookJP;o00001ooonfX00ol0003o
oo]ZoookJP02o`000003oookJ_l0003ooo]Z00;ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00So
oo]Z0_l000000ooonf[o0000o`000004oookJP;o000000Cooo]Zo`000?l0003o00000_oonfX=o`00
01kooo]Z1Ol000000ooonf[o0000o`000002oookJP03o`000?oonf[o000000Co00001?oonfX4o`00
00;ooo]Z0ol000000ooonf[o0000oookJP03oookJP;o000000Cooo]Zo`000?l0003o00000ooonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000Cooo]Z0_l00002oookJP03o`000?oonf[o
oo]Z00Kooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oo
nf[o0000o`0000Kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[o000000;o00001OoonfX8o`000004oookJ_l0003o0000o`0000?ooo]Z0_l00002oookJP?o
000000Cooo]Zo`000?l0003ooo]Z0_l000000ooonf[o0000oookJP02oookJP04o`000?oonf[o0000
oookJP;o000000Cooo]Zo`000?l0003ooo]Z0_l00002oookJP?o00001?oonfX01?l0003ooo]Zoook
J_l00007oookJP03o`000?oonf[o000000;ooo]Z00Go0000oookJ_oonf[o0000oookJP02o`0000Ko
oo]Z0_l00004oookJP06o`000?oonf[ooo]Zo`000?oonf[o00003?oonfX00ol0003ooo]Zo`000002
oookJP04o`000?oonf[ooo]ZoookJP7o000000001Ol0003ooo]ZoookJ_l0003ooo]Z00;o00001Ooo
nfX2o`0000;ooo]Z00?o0000oookJ_l000001_oonfX01?l0003ooo]Zo`000?l00004oookJP;o0000
0_oonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000;o
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05o`0000?ooo]Z00?o0000oookJ_l0
00000_l00009oookJP03o`000?oonf[o000000Oo00000ooonfX00ol0003ooo]Zo`000003oookJP03
o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00000_oonfX2o`0000;ooo]Z00?o0000oook
J_l000001?l0000<oookJP03o`000?oonf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000006
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oo
nf[o000000?ooo]Z00?o0000oookJ_l000003?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z
00?o0000oookJ_l000000ooonfX2o`0000Sooo]Z0_l000000ooonf[o0000o`000004o`0000;ooo]Z
0_l00004oookJP03o`000?oonf[o000000Co000000?ooo]Zo`000?oonfX01Ol0000MoookJP?o0000
00Kooo]Zo`000?oonf[ooo]Zo`000?oonfX2o`000007oookJ_l0003ooo]Zo`000?oonf[o0000oook
JP06o`000003oookJ_l0003ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Kooo]Z00_o
0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000005oookJP03o`000?oonf[o
oo]Z00;ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002oookJP05o`000?oonf[ooo]ZoookJ_l0
00002OoonfX00ol0003ooo]ZoookJP02oookJP;o00001OoonfX01Ol0003ooo]ZoookJ_oonf[o0000
00kooo]Z00Co0000oookJ_oonf[o00002?oonfX01?l0003ooo]ZoookJ_l00006oookJP04o`000?oo
nf[ooo]Zo`0000Cooo]Z00?o0000oookJ_l000001OoonfX2o`0000Gooo]Z00Oo0000oookJ_oonf[o
oo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP02oook
JP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0_l00008oookJP;o00000_oonfX01Ol0003ooo]Zoook
J_oonf[o000000;ooo]Z0ol00004oookJP05o`000?oonf[o0000oookJ_l000002?oonfX2o`0000oo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Co
oo]Z0_l00002oookJP03o`000?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z
?_oonfX1o`00000000?o0000oookJ_oonfX00_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]Zo`000003oookJP;o00001?oonfX2o`0000;ooo]Z0_l00006oookJP;o000000?o
oo]Zo`000?l000002?oonfX2o`000003oookJ_l0003ooo]Z00Kooo]Z00Co0000oookJ_oonf[o0000
2OoonfX:o`0000Gooo]Z00Ko0000oookJ_l0003ooo]Zo`000?oonfX2o`0000;ooo]Z00Go0000oook
J_l0003ooo]Zo`000007oookJPGo00000ooonfX2o`00017ooo]Z0_l000000ooonf[o0000oookJP0C
oookJP04o`000?oonf[o0000oookJP;o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z
00Go0000oookJ_oonf[ooo]Zo`000005oookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX3o`00
00_ooo]Z00?o0000oookJ_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00Ko0000
oookJ_l0003ooo]Zo`000?oonfX4o`000003oookJ_l0003ooo]Z00Gooo]Z0_l00003oookJP;o0000
00?ooo]Zo`000?l000000_oonfX4o`0000;ooo]Z1_l0000LoookJP_o000000?ooo]Zo`000?l00000
0_l000000ooonf[o0000oookJP07o`0000;ooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000
o`00000=oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX01ol0003ooo]Zo`000?oonf[o0000
oookJ_l000002OoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000002
oookJP03o`000?oonf[ooo]Z00cooo]Z00Ko0000oookJ_l0003ooo]Zo`000?oonfX2o`0001Wooo]Z
00?o0000oookJ_oonfX00_l000000ooonf[o0000o`000002oookJP03o`000?oonf[o000000?o0000
00?ooo]Zo`000?oonfX01?oonfX00ol0003ooo]ZoookJP06oookJP?o000000?ooo]Zo`000?oonfX0
0ol000001?oonf[o0000o`000?l00002oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oo
nf[o00000_oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000o`000002oook
JP03o`000?oonf[ooo]Z00?ooo]Z0_l00003oookJP;o00000ooonfX00ol0003ooo]ZoookJP0<oook
JP06o`000?oonf[o0000o`000?oonf[o00002OoonfX1o`00000000?o0000oookJ_oonfX01_oonfX4
o`0000?ooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP04o`000?oonf[o0000oookJP;o0000
0_oonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0_l000000ooonf[o
0000o`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Co
oo]Z0ol000001Ooonf[o0000oookJ_l0003ooo]Z00Co00000_oonfX00ol0003ooo]Zo`000003oook
JP?o00000ooonfX2o`0000Kooo]Z0_l00002oookJP;o00001?oonfX00ol0003ooo]ZoookJP02oook
JP05o`000?oonf[o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z00Oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z00Cooo]Z0_l00002oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]Zo`00
0002oookJP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`00
0002oookJP;o00001OoonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]Zo`000?oonfX0
0_l000002Ooonf[o0000o`000?oonf[o0000oookJ_l0003ooo]Zo`000004oookJPGo000000?ooo]Z
o`000?l000001?l0000KoookJP[o00000_oonfX01?l0003ooo]Zo`000?oonfX2o`0000Cooo]Z0ol0
00001?oonf[o0000oookJ_oonfX4o`0000;ooo]Z00?o0000oookJ_l000000ol00006oookJP03o`00
0?oonf[o000000Gooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Kooo]Z00?o0000oook
J_l000000_oonfX00ol0003ooo]ZoookJP02oookJP;o00000_oonfX02?l0003ooo]ZoookJ_l0003o
oo]Zo`000?oonf[o00000ooonfX01Ol0003ooo]Zo`000?oonf[o000000kooo]Z0_l0000FoookJP;o
00000_oonfX01?l0003ooo]ZoookJ_l00008oookJP04o`000?oonf[ooo]ZoookJP;o000000?ooo]Z
o`000?oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000001?oo
nfX00ol0003ooo]Zo`000004o`000003oookJ_l0003ooo]Z00?ooo]Z0_l000000ooonf[o0000oook
JP03oookJP;o00000_oonfX01ol0003ooo]Zo`000?oonf[o0000oookJ_l000002ooonfX2o`0000Co
oo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]Zo`000?oonf[o000000Sooo]Z0_l00008oook
JP;o00000_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oook
J_oonf[ooo]Z0Ol000000003o`000?oonf[ooo]Z00Cooo]Z0ol00002oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]Zo`000?l00007oookJP03o`000?oonf[o
oo]Z00Wooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol00002oookJP;o00001?oonfX0
0ol0003ooo]ZoookJP03o`0000Cooo]Z00?o0000oookJ_oonfX00_l00007oookJP?o00000_oonfX0
1?l0003ooo]Zo`000?l00008oookJP03o`000?oonf[ooo]Z00Cooo]Z1?l000000ooonf[o0000oook
JP02oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP0AoookJP04o`000?oonf[ooo]ZoookJP;o00001?oonfX00ol0003ooo]ZoookJP02oookJP04o`00
0?oonf[o0000oookJPGo00001OoonfX01?l0003ooo]ZoookJ_l00005oookJP;o00000ooonfX00ol0
003ooo]Zo`000003o`000004oookJ_l0003o0000o`0000?ooo]Z00?o0000oookJ_l000001_l0000J
oookJP?o000000?ooo]Zo`000?l000000ol000001?oonf[o0000o`000?oonfX2o`0000;ooo]Z00?o
0000oookJ_l000000ol000001ooonf[o0000o`000?l0003ooo]Zo`000?oonfX00_l00007oookJP03
o`000?oonf[ooo]Z00;o00000_oonfX00ol0003ooo]ZoookJP02oookJP?o000000Cooo]Zo`000?oo
nf[o00000_oonfX2o`0000?ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Cooo]Z00Go
0000oookJ_oonf[ooo]Zo`000003oookJP;o00003ooonfX00ol0003ooo]ZoookJP0<oookJP07o`00
0?oonf[ooo]ZoookJ_l0003ooo]Zo`000009oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oook
J_l0003o00002?oonfX00ol0003ooo]Zo`000003o`0000Gooo]Z1_l00003oookJP03o`000?oonf[o
oo]Z00Oooo]Z0ol000001Ooonf[o0000o`000?oonf[o000000Oooo]Z0ol00007oookJP04o`000?oo
nf[ooo]ZoookJP;o00001_oonfX00ol0003ooo]ZoookJP02o`000005oookJ_l0003ooo]ZoookJ_l0
00003ooonfX00ol0003ooo]Zo`00000>oookJP;o000000?ooo]Zo`000?oonfX00_l00002oookJP03
o`000?oonf[ooo]Z00?ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000
00000ol0003ooo]Zo`000007oookJP;o00000_oonfX2o`000005oookJ_l0003ooo]ZoookJ_l00000
0_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000;ooo]Z1Ol000001?oonf[o0000oookJ_l00004oook
JP03o`000?oonf[ooo]Z00Sooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP05o`000?oonf[o
0000oookJ_l000002_oonfX2o`000004oookJ_l0003ooo]ZoookJP?o00000ooonfX3o`000003oook
J_l0003o000000;o00000ooonfX00ol0003ooo]ZoookJP02oookJP;o00001?oonfX2o`000003oook
J_l0003o000000;ooo]Z1Ol00002oookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP06oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX2o`000003oookJ_l0003ooo]Z
00Cooo]Z0_l000000ooonf[o0000oookJP02oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000
oookJ_oonfX00ol00002oookJP03o`000?oonf[o000000?ooo]Z0_l000001?oonf[o0000oookJ_l0
0002oookJP04o`000?oonf[ooo]ZoookJP;o000000?ooo]Zo`000?l000002Ol000000ooonf[o0000
o`000002o`0001Wooo]Z2Ol000001?oonf[o0000o`000?l00004oookJP04o`000?oonf[o0000oook
JP?o00000_oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o00000_oonfX00ol0003ooo]Zo`000003
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_l000002Ooonf[o0000oookJ_oo
nf[o0000oookJ_l0003ooo]Zo`000004oookJP;o00000_oonfX00ol0003ooo]Zo`000004oookJP?o
00001?oonfX00ol0003ooo]Zo`00000:oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z013ooo]Z00Co0000oookJ_oo
nf[ooo]Z1_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP05oookJPGo000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJP06o`000?oonf[o
oo]Zo`000?oonf[o00000_oonfX00ol0003ooo]Zo`000003oookJP05o`000?oonf[ooo]ZoookJ_l0
00000ooonfX01?l0003ooo]Zo`000?l00007oookJP04o`000?oonf[ooo]ZoookJP;o00005_oonfX0
1_l0003ooo]Zo`000?l0003ooo]Zo`0000;ooo]Z0_l00002oookJP04o`000?oonf[o0000oookJP;o
00001?oonfX1o`00000000Co0000oookJ_l0003o00001?oonfX00ol0003ooo]ZoookJP03oookJP05
o`000?oonf[ooo]ZoookJ_l000000_oonfX2o`0000;ooo]Z00Co0000oookJ_l0003o00001_oonfX0
1?l0003ooo]Zo`000?l00002oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]Z
o`000004oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJPGo
00000_oonfX2o`000003oookJ_l0003o000000Cooo]Z00Go0000oookJ_l0003o0000oookJP05o`00
00[ooo]Z0_l00002oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX3o`000006oookJ_l0003o
oo]Zo`000?oonf[o00002?oonfX00ol0003ooo]ZoookJP0FoookJP04o`000?oonf[ooo]Zo`0000Ko
oo]Z00?o0000oookJ_oonfX01OoonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]Zo`000008oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP04oookJP;o00000ooonfX00ol0003ooo]Zo`000004oookJP04o`000?oonf[ooo]Z
o`0000;ooo]Z00?o0000oookJ_l000000_oonfX01?l0003ooo]ZoookJ_oonfX2o`000005oookJ_l0
003o0000o`000?oonfX00_l000000ooonf[o0000o`000002o`000003oookJ_l0003o000000[o0000
6OoonfX;o`000003oookJ_l0003ooo]Z00;o00000_oonfX3o`0000Oooo]Z00Co0000oookJ_l0003o
00000_oonfX01?l0003ooo]ZoookJ_l00002oookJP;o000000?ooo]Zo`000?l000000_oonfX01?l0
003ooo]ZoookJ_l00004oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z0_l00008oookJP05o`00
0?oonf[ooo]ZoookJ_l000002ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00Co0000oook
J_oonf[o00000ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX00_oonfX4o`0000;ooo]Z00So0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJP;o
000000Gooo]Zo`000?oonf[ooo]Zo`000005oookJP?o000000Gooo]Zo`000?l0003ooo]Zo`000002
oookJP;o00000_oonfX00ol0003ooo]Zo`000002o`000003oookJ_l0003ooo]Z00;ooo]Z00Go0000
oookJ_oonf[ooo]Zo`000003oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]Z
o`000004oookJP04o`000?oonf[ooo]ZoookJPGo000000?ooo]Zo`000?oonfX00_l00002oookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z00;ooo]Z0Ol000000003o`000?oonf[o000000;o000000?ooo]Zo`000?oonfX0
2?oonfX00ol0003ooo]ZoookJP08oookJP;o00000_oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX0
0ooonfX01?l0003ooo]ZoookJ_oonfX2o`0000;ooo]Z00Co0000oookJ_oonf[o00001?oonfX2o`00
00Kooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000?ooo]Z00Co0000oookJ_oonf[ooo]Z1_l0
00000ooonf[o0000o`000005oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0_l00005oookJP04
o`000?oonf[ooo]ZoookJP?o00000_oonfX4o`0000Oooo]Z00?o0000oookJ_oonfX01ooonfX2o`00
00_ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00gooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003ooo]ZoookJP05oookJP;o00000_oonfX0
1?l0003ooo]Zo`000?oonfX2o`0000kooo]Z00?o0000oookJ_l000000ooonfX4o`0000Oooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[o000000;ooo]Z00Co
0000oookJ_oonf[ooo]Z0_l00003oookJP;o000000?ooo]Zo`000?l000002Ol0000GoookJPCo0000
00?ooo]Zo`000?l000000_l000000ooonf[o0000oookJP02o`000005oookJ_l0003ooo]ZoookJ_l0
00002_oonfX2o`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?l000002?oonfX2o`0000Co
oo]Z00?o0000oookJ_oonfX01_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00?o0000oook
J_oonfX01?oonfX01?l0003ooo]ZoookJ_l00008oookJP03o`000?oonf[ooo]Z00?o00003?oonfX0
0ol0003ooo]ZoookJP03oookJP;o00001_oonfX00ol0003ooo]ZoookJP03oookJPCo00001OoonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Gooo]Z1?l000000ooonf[o0000oookJP03
oookJP;o00000ooonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[o0000oookJP;o00000_oo
nfX01?l0003ooo]Zo`000?l00004oookJP;o000000?ooo]Zo`000?oonfX00ol000000ooonf[o0000
o`000004oookJP?o00001?oonfX00ol0003ooo]ZoookJP07oookJP;o000000Cooo]Zo`000?oonf[o
00001ooonfX01?l0003ooo]Zo`000?l00008oookJP05o`000?oonf[o0000oookJ_l000000ooonfX0
0ol0003ooo]ZoookJP0=oookJP;o00000_oonfX1o`00000000Co0000oookJ_oonf[ooo]Z0_l00002
oookJP;o00000ooonfX00ol0003ooo]ZoookJP07oookJP04o`000?oonf[o0000oookJP;o00000_oo
nfX00ol0003ooo]ZoookJP06oookJP;o00001ooonfX01?l0003ooo]ZoookJ_l00004oookJP;o0000
1_oonfX3o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP;o000000Cooo]Zo`000?oo
nf[o00000_oonfX6o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?oonfX00_oonfX02Ol0
003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000003oookJP05o`000?oonf[ooo]ZoookJ_l0
00003_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP06oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00000AoookJP;o0000
1ooonfX2o`000005oookJ_l0003ooo]Zo`000?oonfX00_l00002oookJP05o`000?oonf[o0000oook
J_l000001?oonfX01?l0003ooo]ZoookJ_oonfX2o`000005oookJ_l0003ooo]Zo`000?oonfX00_l0
0003oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z2?l00003oookJPGo00005ooonfX6o`000003
oookJ_l0003o000000Go000000?ooo]Zo`000?l000000ol000001Ooonf[o0000o`000?l0003ooo]Z
00Go00000_oonfX01ol0003ooo]Zo`000?l0003ooo]Zo`000?oonfX00ol00006oookJP04o`000?oo
nf[o0000o`00017ooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]Zo`00000AoookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0@oookJP05o`00
0?oonf[o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Ko
oo]Z0_l00002oookJPGo000000Cooo]Zo`000?l0003o00000ooonfX01Ol0003ooo]ZoookJ_oonf[o
000000Cooo]Z0_l000000ooonf[o0000o`000002o`000003oookJ_l0003ooo]Z00?ooo]Z0_l00003
oookJP?o000000?ooo]Zo`000?oonfX00_l00004oookJP04o`000?oonf[ooo]ZoookJP?o000000Go
oo]Zo`000?oonf[ooo]Zo`000002oookJP03o`000?oonf[o000000Gooo]Z0ol00002oookJP03o`00
0?oonf[ooo]Z00;o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000001Sooo]Z00?o0000oookJ_oo
nfX00Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000001Ol0003ooo]Zoook
J_oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ooonfX01ol0003ooo]ZoookJ_oonf[o0000oook
J_l000001OoonfX01?l0003ooo]Zo`000?l00005oookJP?o00000_oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol00002oookJP05o`000?oonf[o0000o`000?oonfX00_l0
0003oookJP;o00001_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00Co00000ooonfX3o`000003oook
J_l0003ooo]Z00Cooo]Z0_l00002oookJP;o00000_oonfX2o`0000?ooo]Z0ol000000ooonf[o0000
oookJP03oookJP03o`000?oonf[o000000gooo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]Z
o`000006oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0000?
oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP04oookJP04o`000?oonf[o0000o`0000?ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003o
oo]Zo`000003oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003o00001_oonfX00ol0
003ooo]ZoookJP05o`0000;ooo]Z00?o0000oookJ_l000000ol00002oookJP[o00005OoonfX:o`00
00;ooo]Z0_l000000ooonf[o0000oookJP02o`000003oookJ_l0003o000000[ooo]Z0ol00005oook
JP04o`000?oonf[ooo]ZoookJP?o000000Gooo]Zo`000?oonf[ooo]Zo`00000FoookJP03o`000?oo
nf[ooo]Z00;ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0000?oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00Co0000oookJ_oonf[o00002ooonfX2o`0000Kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP04oookJP04o`000?oonf[ooo]ZoookJP;o000000?ooo]Zo`000?l000000_oonfX2
o`0000;ooo]Z0_l00004oookJP;o000000Kooo]Zo`000?l0003o0000oookJ_l00002oookJP;o0000
1?oonfX2o`0000?ooo]Z0_l00002oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000003oook
JP05o`000?oonf[ooo]ZoookJ_l000001ooonfX2o`0000cooo]Z00?o0000oookJ_oonfX00_l00004
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]Zo`000007
oookJP03o`000?oonf[o000000;ooo]Z0Ol000000003o`000?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX01?oonfX2o`0000Gooo]Z0_l00002oookJP?o00001ooonfX2o`000005oookJ_l0003o0000
oookJ_l000000ooonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Cooo]Z0ol000000ooonf[o0000
oookJP02o`0000?ooo]Z00Co0000oookJ_oonf[o00000_oonfX2o`0000;ooo]Z00?o0000oookJ_oo
nfX00ooonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o000000Kooo]Zo`000?l0003ooo]Zo`000?oo
nfX3o`0000?ooo]Z2Ol00002oookJP;o00001OoonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z
0_l00002oookJP;o00003?oonfX00ol0003ooo]ZoookJP0IoookJP;o00002OoonfX2o`0001?ooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[o000000?ooo]Z
00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00002oookJPKo
00000_oonfX2o`0000Gooo]Z00?o0000oookJ_l000000ol000000ooonf[o0000o`000002o`0001Go
oo]Z1_l000000ooonf[o0000o`000003o`0000;ooo]Z00Go0000oookJ_l0003ooo]Zo`000003oook
JP04o`000?oonf[o0000o`0000Gooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP02
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l0
0004oookJP03o`000?oonf[ooo]Z00;o000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJP05o`00
0?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_l0000PoookJP04o`000?oonf[ooo]Z
oookJP;o000000?ooo]Zo`000?oonfX01ooonfX00ol0003ooo]Zo`000005oookJP04o`000?oonf[o
0000o`0000?ooo]Z00?o0000oookJ_l000001ol00002oookJP;o00001OoonfX2o`0000;ooo]Z1?l0
00000ooonf[o0000oookJP03oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Ko0000oookJ_l0003o
0000oookJ_l00004oookJP06o`000?oonf[o0000o`000?oonf[o00000ooonfX2o`0000Gooo]Z00Ko
0000oookJ_l0003ooo]Zo`000?oonfX3o`000004oookJ_l0003ooo]Zo`0000Sooo]Z00?o0000oook
J_oonfX00_l00004oookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol000000003o`000?oonf[o000000ko
oo]Z0_l00003oookJP;o000000?ooo]Zo`000?oonfX00_l00002oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_l000001?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oook
J_oonfX00ol00004oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000000ooonf[o0000oookJP02oook
JP;o000000?ooo]Zo`000?oonfX01OoonfX01?l0003ooo]Zo`000?l00002oookJPGo000000Kooo]Z
o`000?l0003ooo]Zo`000?oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]Z
o`000?l00004oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP04oookJP05o`000?oonf[o0000oookJ_l000000_oonfX00ol0003ooo]Zo`000005
oookJP04o`000?oonf[o0000o`0000[ooo]Z00Co0000oookJ_oonf[o00000ooonfX7o`0000;ooo]Z
0_l000000ooonf[o0000o`000004oookJP;o00000ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o
00000_oonfX:o`0001Cooo]Z2_l000001?oonf[o0000o`000?l00003oookJPCo000000?ooo]Zo`00
0?l000000ooonfX00ol0003ooo]Zo`000004oookJP;o000000?ooo]Zo`000?l000000_oonfX00ol0
003ooo]ZoookJP04oookJP04o`000?oonf[o0000o`0000?ooo]Z0_l00005oookJP05o`000?oonf[o
oo]ZoookJ_l000000_oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]Zoook
J_oonf[o000000?ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00_ooo]Z00Co0000oookJ_oonf[o
00000_oonfX00ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX01?l0
003ooo]ZoookJ_oonfX2o`0000cooo]Z00Co0000oookJ_oonf[ooo]Z1Ol000000ooonf[o0000oook
JP04o`0000?ooo]Z00?o0000oookJ_oonfX01?oonfX2o`000003oookJ_l0003ooo]Z00;o000000Co
oo]Zo`000?oonf[ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_l0003o
00000_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Gooo]Z00?o0000oookJ_oo
nfX00ol00003oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_l000000ooonfX00ol0003o
oo]ZoookJP05oookJP04o`000?oonf[ooo]ZoookJP?o00000ooonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00Gooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o
000000000ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00002oookJP;o0000
2_oonfX2o`0000?ooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]Zo`00000:oookJP03o`00
0?oonf[o000000;ooo]Z00Oo0000oookJ_l0003ooo]Zo`000?oonf[o000000Cooo]Z1Ol00003oook
JP04o`000?oonf[ooo]Zo`0000Cooo]Z0_l000001?oonf[o0000o`000?oonfX3o`000004oookJ_l0
003o0000o`0000Gooo]Z00Go0000oookJ_oonf[o0000oookJP03o`0000;ooo]Z00Co0000oookJ_l0
003ooo]Z0ol000001?oonf[o0000o`000?l0000NoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX00ooonfX2o`0000Sooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z013ooo]Z0_l000000ooonf[o0000oookJP03oookJP?o00001?oonfX2
o`0000;ooo]Z0_l00003oookJP?o000000Wooo]Zo`000?l0003o0000oookJ_l0003ooo]Zo`000?oo
nfX02?l0000CoookJPKo000000Cooo]Zo`000?oonf[ooo]Z1ol00004oookJP;o000000Cooo]Zo`00
0?l0003o00001?oonfX00ol0003ooo]ZoookJP05oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`00
0005oookJP;o00000ooonfX00ol0003ooo]ZoookJP02o`0000_ooo]Z00Co0000oookJ_oonf[ooo]Z
0_l00005oookJP03o`000?oonf[o000000?ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX01_oonfX01Ol0003ooo]ZoookJ_oonf[o000000[ooo]Z00Co0000oookJ_oo
nf[o00005OoonfX3o`0000Oooo]Z1?l000001Ooonf[o0000oookJ_oonf[o000000Cooo]Z00Co0000
oookJ_l0003o00000ooonfX4o`000003oookJ_l0003ooo]Z00;ooo]Z00Co0000oookJ_l0003o0000
0_oonfX3o`0000Kooo]Z0ol00002oookJP?o00000_oonfX01_l0003ooo]Zo`000?l0003ooo]Zo`00
00;ooo]Z00?o0000oookJ_l000000_l000001?oonf[o0000oookJ_l00007oookJP05o`000?oonf[o
oo]Zo`000?oonfX00_l000000ooonf[o0000oookJP07oookJP08o`000?oonf[ooo]Zo`000?oonf[o
0000oookJ_l0000;oookJP04o`000?oonf[ooo]ZoookJP7o000000001Ol0003ooo]ZoookJ_oonf[o
000000[ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP04o`000?oonf[o0000oookJP;o0000
0_oonfX01?l0003ooo]ZoookJ_oonfX2o`000004oookJ_l0003ooo]ZoookJP;o000000?ooo]Zo`00
0?l000000ol000001Ooonf[o0000o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]Zo`000006oookJP04o`000?oonf[ooo]ZoookJP?o000000?ooo]Zo`000?oonfX01?l0
0002oookJP?o00000_oonfX3o`0000?ooo]Z00Co0000oookJ_l0003ooo]Z0_l000000ooonf[o0000
o`000002oookJP;o000000?ooo]Zo`000?l000001OoonfX00ol0003ooo]Zo`00000:oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02OoonfX01?l0003ooo]ZoookJ_l0000:oookJP03
o`000?oonf[ooo]Z00Oooo]Z00Wo0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJ_l000000_oo
nfX01?l0003ooo]ZoookJ_l0000<oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX0
0_oonfX2o`000003oookJ_l0003ooo]Z00;o00002?oonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[o000000;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP;o0000
00?ooo]Zo`000?l000000_oonfX01ol0003ooo]Zo`000?l0003ooo]Zo`000?oonfX01ol000001?oo
nf[o0000o`000?l0000BoookJPOo000000Cooo]Zo`000?l0003ooo]Z0ol000001Ooonf[o0000oook
J_l0003ooo]Z00?o000000?ooo]Zo`000?oonfX00_l00002oookJPCo00001OoonfX00ol0003ooo]Z
oookJP02oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000?o
oo]Z00?o0000oookJ_oonfX00_l00003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Go0000oook
J_oonf[ooo]Zo`000006oookJP;o000000Wooo]Zo`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l0
00002?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l0
00004?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z1ol000000ooonf[o
0000o`000002o`0000;ooo]Z0_l00002oookJP?o000000?ooo]Zo`000?l000000_l00006oookJP04
o`000?oonf[ooo]Zo`0000Oooo]Z00Go0000oookJ_oonf[o0000oookJP02o`000003oookJ_l0003o
000000;ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_l000000_oonfX0
0ol0003ooo]ZoookJP02o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP07oookJP;o00000_oonfX1o`00000000?o0000oookJ_oonfX00_oonfX2o`00
000:oookJ_l0003o0000o`000?oonf[o0000oookJ_l0003ooo]Zo`0000?ooo]Z0_l00005oookJP;o
00001_oonfX00ol0003ooo]Zo`000008oookJP03o`000?oonf[o000000;o000000?ooo]Zo`000?oo
nfX00ooonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[o0000oookJP?o00000ooonfX2o`00
00;ooo]Z00?o0000oookJ_l000000ooonfX6o`0000;ooo]Z00Go0000oookJ_l0003ooo]Zo`000003
oookJP;o00000ooonfX2o`0000?ooo]Z0_l00002oookJPCo00004ooonfX00ol0003ooo]Zo`00000?
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP08
oookJP;o000000?ooo]Zo`000?oonfX00ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[o
oo]Z00;o00003?oonfX00ol0003ooo]Zo`000002oookJP04o`000?oonf[ooo]ZoookJP;o000000So
oo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`0000Cooo]Z00?o0000oookJ_l000000_oonfX4o`00
0003oookJ_l0003ooo]Z00[o00001?oonfX8o`00017ooo]Z2Ol00002oookJP?o00000_oonfX00ol0
003ooo]ZoookJP07o`000004oookJ_l0003ooo]Zo`0000Oooo]Z0_l00004oookJP04o`000?oonf[o
0000o`0000;ooo]Z00Go0000oookJ_l0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00gooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00oooo]Z
00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000001_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]Zo`000002o`0000Kooo]Z00?o0000oookJ_oonfX00_l000001?oonf[o0000oookJ_oonfX9
o`000004oookJ_l0003ooo]Zo`0000Cooo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0003ooo]Z
o`000002o`000004oookJ_l0003ooo]ZoookJP;o00000_oonfX00ol0003ooo]ZoookJP03oookJP04
o`000?oonf[ooo]Zo`0000Gooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_l000003?oonfX2o`0000;ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00Sooo]Z0Ol000000003
o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000001?l0003ooo]Zo`000?l00003oookJP;o
000000?ooo]Zo`000?l000003OoonfX01?l0003ooo]Zo`000?l00002oookJP?o00001OoonfX01_l0
003ooo]Zo`000?oonf[o0000oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP;o000000?o
oo]Zo`000?oonfX00_oonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX00_l00009oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000000ol0
0002oookJP?o00000_oonfX4o`0000;ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX03?oonfX01?l0003ooo]ZoookJ_l0000=oookJP07o`000?oonf[ooo]ZoookJ_l0
003ooo]Zo`00000?oookJP03o`000?oonf[ooo]Z00Gooo]Z00Oo0000oookJ_l0003ooo]Zo`000?oo
nf[o000000Cooo]Z00?o0000oookJ_oonfX01?oonfX4o`0000;ooo]Z00Co0000oookJ_l0003o0000
0_oonfX2o`000004oookJ_l0003ooo]ZoookJP;o00000_oonfX00ol0003ooo]ZoookJP09o`000004
oookJ_l0003ooo]ZoookJP_o00004OoonfX2o`000003oookJ_l0003o000000Ko000000?ooo]Zo`00
0?oonfX00_l000001Ooonf[o0000oookJ_oonf[o000000Cooo]Z0_l000000ooonf[o0000o`000002
o`000003oookJ_l0003o000000;ooo]Z0_l00002oookJP;o000000Cooo]Zo`000?oonf[o00000_oo
nfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o000000Oooo]Z00Co0000oookJ_l0003o0000
0ooonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX02?oonfX5o`0000;ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?l0
003o00000_oonfX2o`000004oookJ_l0003o0000o`0000Cooo]Z00Co0000oookJ_l0003o00000_oo
nfX2o`0000;ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0000:oookJP?o00001?oonfX01ol0003o
oo]ZoookJ_oonf[o0000oookJ_l000001OoonfX3o`0000cooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP0:oookJP7o000000000ol0003ooo]ZoookJP02oookJP03o`000?oonf[o0000
00;ooo]Z00Co0000oookJ_oonf[o00000ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o000000?o
oo]Zo`000?oonfX00_l00002oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Co0000oookJ_oonf[o
00000_oonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[o0000o`0000Cooo]Z00?o0000oook
J_oonfX00ooonfX4o`0000;ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00Cooo]Z1Ol00002oook
JP03o`000?oonf[o000000;o000000?ooo]Zo`000?oonfX01Ol00002oookJP04o`000?oonf[ooo]Z
oookJP;o00001?oonfX01?l0003ooo]Zo`000?l0000<oookJP04o`000?oonf[o0000o`0000?ooo]Z
0ol00006oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP05oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z00?o0000oookJ_l000000_oonfX3o`000004
oookJ_l0003ooo]ZoookJP;o00000_oonfX00ol0003ooo]ZoookJP03oookJP;o000000?ooo]Zo`00
0?oonfX01OoonfX00ol0003ooo]ZoookJP02o`0000Cooo]Z0_l00002oookJP05o`000?oonf[o0000
o`000?oonfX02?l00002oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Co0000oookJ_oonf[o0000
0ooonfX2o`0000;ooo]Z4?l0000?oookJPgo000000?ooo]Zo`000?l000001Ol00002oookJP?o0000
00Gooo]Zo`000?oonf[o0000oookJP02o`000003oookJ_l0003o000000?ooo]Z0ol0000:oookJP;o
000000Cooo]Zo`000?oonf[o00000ooonfX2o`0000cooo]Z00Co0000oookJ_oonf[o00003?oonfX0
1?l0003ooo]ZoookJ_l00004oookJPCo00004_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP07o`000?oo
nf[ooo]ZoookJ_l0003ooo]Zo`000005oookJP;o00000ooonfX00ol0003ooo]Zo`000002o`0000So
oo]Z00?o0000oookJ_l000000_l000001?oonf[o0000oookJ_l00002oookJPCo000000?ooo]Zo`00
0?l000001OoonfX00ol0003ooo]ZoookJP06oookJP;o00000ooonfX00ol0003ooo]Zo`000004oook
JP03o`000?oonf[ooo]Z00?ooo]Z0_l00004oookJP?o00000_oonfX2o`000004oookJ_l0003ooo]Z
o`0000Kooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]Zo`000002o`000003oookJ_l0
003ooo]Z00?ooo]Z0_l00004oookJP7o000000000ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000008oookJP;o00002?oonfX00ol0003ooo]Zo`00
0008oookJP03o`000?oonf[ooo]Z00Wooo]Z00Co0000oookJ_oonf[o00000ooonfX2o`0000;ooo]Z
0_l00003oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;o0000
0_oonfX00ol0003ooo]ZoookJP03oookJPGo00001?oonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z
0_l00004oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02OoonfX01?l0003ooo]Z
oookJ_l00003oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000@oookJPCo000000?ooo]Zo`000?oo
nfX00_l00002oookJP03o`000?oonf[ooo]Z00?o00000_oonfX2o`000008oookJ_l0003ooo]Zo`00
0?oonf[o0000oookJ_l00004oookJP;o00000_oonfX2o`000005oookJ_l0003o0000o`000?oonfX0
1ol0000?oookJPgo000000Oooo]Zo`000?l0003o0000oookJ_l0003ooo]Z00?o000000?ooo]Zo`00
0?oonfX00_oonfX3o`0000Cooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02oook
JP04o`000?oonf[o0000oookJP;o000000Kooo]Zo`000?oonf[o0000oookJ_l00003oookJP05o`00
0?oonf[o0000o`000?oonfX00ol00004oookJP05o`000?oonf[o0000oookJ_l000001_oonfX01?l0
003ooo]ZoookJ_l0000:oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[o000000Kooo]Z0_l000000ooonf[o0000o`000002
o`0000;ooo]Z0_l000000ooonf[o0000o`000003o`000003oookJ_l0003ooo]Z00?ooo]Z0_l00003
oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00_o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000002
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00;o00000_oonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oo
nf[o000000;ooo]Z00?o0000oookJ_oonfX01_oonfX1o`00000000?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP02oookJP09o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000?oonf[o000000?o
oo]Z00Co0000oookJ_l0003o00000_oonfX2o`0000;ooo]Z0_l00005oookJP06o`000?oonf[ooo]Z
o`000?oonf[o00001OoonfX01Ol0003ooo]Zo`000?l0003ooo]Z00?o00000_oonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l000000ooonf[o0000oookJP03oookJP?o0000
0_oonfX2o`0000;ooo]Z1?l00003oookJP03o`000?oonf[ooo]Z00Go00000_oonfX00ol0003ooo]Z
o`000002oookJP03o`000?oonf[ooo]Z01Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP07
o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00005
oookJP03o`000?oonf[ooo]Z01Sooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP03o`000?oo
nf[o000000Gooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[o0000
1OoonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o00000ooonfX2o`000003oookJ_l0003o0000
00Gooo]Z1?l000000ooonf[o0000o`000009o`0000gooo]Z1_l000001?oonf[o0000o`000?oonfX4
o`0000Kooo]Z00Co0000oookJ_l0003ooo]Z0_l000000ooonf[o0000oookJP03oookJP?o00001?oo
nfX2o`0000;ooo]Z0_l00004oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l000001ooonf[o0000o`00
0?l0003ooo]Zo`000?oonfX00_l000000ooonf[o0000o`000004oookJP03o`000?oonf[o000000So
oo]Z00?o0000oookJ_oonfX01_oonfX3o`0000Gooo]Z0_l00002oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP03o`0000?ooo]Z00?o0000
oookJ_oonfX00_l0000<oookJP;o00002?oonfX00ol0003ooo]ZoookJP06oookJP;o00000_oonfX5
o`00000;oookJ_l0003ooo]ZoookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000000ooonfX01?l0
003ooo]ZoookJ_oonfX3o`000003oookJ_l0003ooo]Z00Gooo]Z00?o0000oookJ_l000001OoonfX0
0ol0003ooo]ZoookJP03oookJP07o`000?oonf[o0000oookJ_l0003ooo]Zo`000005oookJP;o0000
0_oonfX2o`0000;ooo]Z0_l000001Ooonf[o0000oookJ_l0003ooo]Z00?o00000ooonfX00ol0003o
oo]ZoookJP04oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_l000001?oonfX01_l0
003ooo]Zo`000?l0003ooo]Zo`0000;ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXn
oookJP7o000000000ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_l000000_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000Cooo]Z00?o0000oookJ_l000000_oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[o000000;ooo]Z00Ko0000oookJ_oonf[o0000oook
J_l00002oookJP05o`000?oonf[ooo]ZoookJ_l000002_oonfX02Ol0003ooo]Zo`000?oonf[o0000
oookJ_l0003ooo]Zo`000002oookJP04o`000?oonf[ooo]ZoookJP;o000000Cooo]Zo`000?l0003o
00000_oonfX2o`0000Cooo]Z00?o0000oookJ_l000000ol000001?oonf[o0000o`000?l0000Joook
JP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX04OoonfX3o`0000;ooo]Z00Co0000oook
J_oonf[o00001?oonfX01?l0003ooo]ZoookJ_l00002oookJP05o`000?oonf[o0000oookJ_l00000
1ooonfX00ol0003ooo]Zo`000009oookJP03o`000?oonf[o000000Cooo]Z0ol000001Ooonf[o0000
oookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00;o000000Kooo]Zo`000?oonf[ooo]Zo`000?oonfX2o`0000Cooo]Z00?o0000
oookJ_oonfX01?l000000ooonf[o0000o`000002oookJPGo000000?ooo]Zo`000?l000000ol0000=
oookJPOo000000?ooo]Zo`000?oonfX01?l00004oookJPOo000000?ooo]Zo`000?oonfX00_oonfX2
o`000003oookJ_l0003o000000?ooo]Z00?o0000oookJ_oonfX02_oonfX3o`0000Gooo]Z00?o0000
oookJ_l000001ooonfX01Ol0003ooo]ZoookJ_oonf[o000000_ooo]Z00Co0000oookJ_oonf[ooo]Z
0_l000000ooonf[o0000o`000005oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l00007oookJP;o0000
2?oonfX00ol0003ooo]ZoookJP0PoookJP;o00001?oonfX00ol0003ooo]ZoookJP05o`000004oook
J_l0003ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX01_l0003ooo]ZoookJ_l0003ooo]Z
o`0000;ooo]Z0_l00003oookJP;o000000Cooo]Zo`000?oonf[ooo]Z0ol000000ooonf[o0000o`00
0003oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l00006oookJP06o`000?oonf[o0000oookJ_l0003o
oo]Z0_l0000CoookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX2o`0000?ooo]Z0Ol000000007
o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00Cooo]Z00Go0000
oookJ_oonf[o0000oookJP02o`0000;ooo]Z0_l000000ooonf[o0000oookJP03oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_l000001?oonfX01?l0003ooo]Zo`000?l00002oookJP;o0000
0_oonfX00ol0003ooo]Zo`000004oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003o
oo]ZoookJP02oookJP;o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]ZoookJP04o`000004
oookJ_l0003o0000o`0000Oooo]Z00?o0000oookJ_l000000ol00005oookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0AoookJP;o000000Gooo]Zo`00
0?oonf[ooo]Zo`000005oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000007oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP;o0000
1ooonfX2o`0000?ooo]Z00?o0000oookJ_l000000_l00002oookJPKo000000?ooo]Zo`000?oonfX0
0ol00002oookJPSo00002ooonfX:o`000004oookJ_l0003o0000o`0000;ooo]Z1?l000001Ooonf[o
0000o`000?oonf[o000000;ooo]Z0ol00003oookJPCo00000_oonfX01Ol0003ooo]Zo`000?oonf[o
000000Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000009oookJP04o`000?oonf[o
oo]ZoookJP?o00002_oonfX01?l0003ooo]ZoookJ_l00004oookJP;o00000_oonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l0000FoookJPGo00000ooonfX00ol0003ooo]Z
oookJP04o`000006oookJ_l0003ooo]ZoookJ_l0003ooo]Z1ol000000ooonf[o0000o`000002o`00
00?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000006oookJP05o`000?oonf[ooo]Z
oookJ_l000000_oonfX01?l0003ooo]ZoookJ_oonfX2o`000004oookJ_l0003ooo]ZoookJP;o0000
0_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000_oonfX01_l0003ooo]Zo`000?oonf[o
0000oookJP;o000000Sooo]Zo`000?l0003o0000oookJ_l0003ooo]Zo`0000kooo]Z00?o0000oook
J_oonfX00Ol000000004o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX01?l0
003ooo]Zo`000?l00008oookJP04o`000?oonf[o0000o`0000;ooo]Z00?o0000oookJ_oonfX00ooo
nfX01?l0003ooo]Zo`000?oonfX2o`000003oookJ_l0003ooo]Z00Cooo]Z0_l00002oookJP07o`00
0?oonf[ooo]Zo`000?oonf[o0000oookJP03o`0000;ooo]Z0_l00003oookJP04o`000?oonf[o0000
o`0000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJPGo000000Gooo]Zo`000?oonf[ooo]Z
o`000002oookJP03o`000?oonf[o000000;o000000?ooo]Zo`000?l000001?oonfX4o`0000?ooo]Z
00Co0000oookJ_oonf[o00004_oonfX00ol0003ooo]ZoookJP0:oookJP06o`000?oonf[ooo]Zoook
J_l0003ooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z00Wooo]Z00Oo0000oookJ_oonf[ooo]Zo`00
0?oonf[o000000Cooo]Z00Co0000oookJ_oonf[o00000_oonfX01?l0003ooo]ZoookJ_l00002oook
JP04o`000?oonf[ooo]Zo`0000;ooo]Z0_l0000<oookJP;o00000_oonfX01?l0003ooo]ZoookJ_l0
0003oookJP04o`000?oonf[ooo]ZoookJP;o00001?oonfX01?l0003ooo]ZoookJ_l00002oookJP?o
00000_oonfX6o`000003oookJ_l0003o000000[o00002ooonfX5o`000005oookJ_l0003o0000o`00
0?oonfX00ol000000ooonf[o0000o`000002oookJPCo00001OoonfX3o`000003oookJ_l0003o0000
00?o00000ooonfX2o`000006oookJ_l0003ooo]ZoookJ_l0003ooo]Z1ol000000ooonf[o0000oook
JP05oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`000?oonfX01?oonfX00ol0003ooo]Zo`00
0002oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0;oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z00[ooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003ooo]Z
o`000002oookJP03o`000?oonf[o000000Oooo]Z0ol000000ooonf[o0000o`000003o`0000;ooo]Z
00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o000000?o
oo]Z0_l00004oookJP03o`000?oonf[o000000;ooo]Z0_l000000ooonf[o0000oookJP05oookJP;o
00003ooonfX2o`0000Gooo]Z0_l00003oookJP;o00001ooonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000005o`000?oonf[o0000oookJ_l000000_oonfX01?l0003ooo]Z
oookJ_oonfX2o`000006oookJ_l0003o0000o`000?oonf[o00000_oonfX00ol0003ooo]Zo`000003
oookJP;o00001ooonfX2o`0000;ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP03
o`0000;ooo]Z00?o0000oookJ_oonfX00ol00002oookJP05o`000?oonf[o0000oookJ_l000000_oo
nfX2o`000003oookJ_l0003ooo]Z00;o000000Cooo]Zo`000?l0003o00000ooonfX00ol0003ooo]Z
oookJP08o`000004oookJ_l0003ooo]ZoookJP;o000000?ooo]Zo`000?oonfX00_l000001Ooonf[o
0000oookJ_oonf[o000000Gooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_oonfX2
o`0000gooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP04o`000?oonf[o
oo]Zo`0000?ooo]Z00?o0000oookJ_oonfX02ooonfX2o`0000;ooo]Z00Ko0000oookJ_l0003o0000
oookJ_l00003oookJP03o`000?oonf[o000000?o000000?ooo]Zo`000?l000002ooonfX00ol0003o
oo]ZoookJP03oookJP04o`000?oonf[ooo]ZoookJP;o000000?ooo]Zo`000?l000001OoonfX00ol0
003ooo]ZoookJP02o`000003oookJ_l0003o000000Co00001?oonfX5o`000003oookJ_l0003o0000
00Ko00002_oonfX5o`000003oookJ_l0003o000000So000000Cooo]Zo`000?l0003ooo]Z0ol00002
oookJP03o`000?oonf[o000000;ooo]Z1?l00002oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Z
o`000004oookJP04o`000?oonf[ooo]ZoookJP;o00000ooonfX00ol0003ooo]ZoookJP0AoookJP05
o`000?oonf[o0000oookJ_l000001ooonfX00ol0003ooo]Zo`000003oookJP05o`000?oonf[ooo]Z
oookJ_l000004OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o000000Wooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Gooo]Z1_l00005
oookJP03o`000?oonf[o000000;ooo]Z0ol000000ooonf[o0000oookJP02oookJP05o`000?oonf[o
oo]Zo`000?oonfX00_l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o0000
1OoonfX00ol0003ooo]Zo`000005oookJP05o`000?oonf[o0000oookJ_l000000_oonfX01?l0003o
oo]ZoookJ_l00002oookJP04o`000?oonf[o0000o`0000?ooo]Z00?o0000oookJ_l000000_oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0000:oookJP04o`000?oonf[o
oo]ZoookJP7o000000000ol0003ooo]ZoookJP0>oookJP04o`000?oonf[o0000o`0000Cooo]Z00Co
0000oookJ_l0003o00000_oonfX2o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z0ol000000ooonf[o
0000oookJP02oookJP;o00000ooonfX01?l0003ooo]ZoookJ_l00002oookJP;o000000Cooo]Zo`00
0?oonf[o00001ooonfX4o`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Cooo]Z00Co0000
oookJ_l0003ooo]Z0_l000001?oonf[o0000oookJ_oonfX4o`0000;ooo]Z00?o0000oookJ_oonfX0
0ol000000ooonf[o0000o`00000KoookJP?o00001?oonfX00ol0003ooo]ZoookJP03oookJP;o0000
0_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01_oonfX3o`000004oookJ_l0003ooo]Zo`0000;o
oo]Z00?o0000oookJ_oonfX00ooonfX3o`0000?ooo]Z0_l00003oookJP04o`000?oonf[ooo]Zo`00
00?ooo]Z1Ol000000ooonf[o0000oookJP04o`000003oookJ_l0003ooo]Z00Go000000[ooo]Zo`00
0?l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z1_l000000ooonf[o0000o`000004o`0000Wo
oo]Z1_l000001_oonf[o0000o`000?l0003ooo]Zo`0000;ooo]Z1?l00002oookJP?o00002?oonfX2
o`0000Gooo]Z00?o0000oookJ_l000000ooonfX01?l0003ooo]ZoookJ_l00009oookJP04o`000?oo
nf[ooo]ZoookJP?o000000Kooo]Zo`000?oonf[o0000oookJ_l00004oookJP04o`000?oonf[o0000
o`0000Cooo]Z0ol000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX02?oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]Z
oookJ_oonf[o000000Sooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX02?oonfX01?l0003ooo]ZoookJ_l00002oookJP;o00000_oonfX00ol0003ooo]ZoookJP02o`00
00Wooo]Z2ol000000ooonf[o0000oookJP02oookJP;o000000Kooo]Zo`000?oonf[o0000oookJ_l0
0002oookJP;o00000_oonfX2o`000003oookJ_l0003ooo]Z00;o00000ooonfX00ol0003ooo]Zo`00
000;oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00002oookJP05o`000?oonf[ooo]ZoookJ_l00000
0ooonfX3o`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`00
00;ooo]Z00?o0000oookJ_oonfX00ooonfX1o`00000000Go0000oookJ_oonf[ooo]Zo`000007oook
JP;o00000ooonfX01?l0003ooo]ZoookJ_l00006oookJP;o00001?oonfX2o`0000Wooo]Z0ol00000
0ooonf[o0000oookJP03oookJP;o00001?oonfX3o`0000?ooo]Z0ol00003oookJP?o00000_oonfX3
o`0000?ooo]Z0_l000000ooonf[o0000o`000002o`0000Kooo]Z00?o0000oookJ_l000000_l00000
1?oonf[o0000o`000?l00004oookJP;o000000?ooo]Zo`000?l000003OoonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX01?l0003ooo]Zoook
J_l00006oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z00?o0000oookJ_l000001ooonfX00ol0003o
oo]ZoookJP04oookJP;o00000ooonfX00ol0003ooo]ZoookJP03o`0000Wooo]Z00Co0000oookJ_l0
003ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00003oookJP07o`000?oonf[ooo]Z
oookJ_l0003ooo]Zo`000002oookJPCo00000_oonfX2o`0000?ooo]Z1?l000000ooonf[o0000oook
JP04o`0000;ooo]Z0_l000000ooonf[o0000o`000002o`000003oookJ_l0003o000000Ko00002?oo
nfX6o`000003oookJ_l0003ooo]Z00Co000000Gooo]Zo`000?l0003ooo]Zo`000002oookJPGo0000
1?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oonfX00ooonfX3o`000005
oookJ_l0003ooo]ZoookJ_l000001ooonfX2o`000003oookJ_l0003o000000;ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000_oo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_l000000_l0
0004oookJP04o`000?oonf[ooo]Zo`0000[ooo]Z00?o0000oookJ_oonfX05?oonfX01Ol0003ooo]Z
oookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX02OoonfX01?l0003ooo]Zo`000?oonfX3o`00
00;ooo]Z1ol00002oookJP03o`000?oonf[ooo]Z00?ooo]Z1?l00002oookJP03o`000?oonf[ooo]Z
00;ooo]Z0_l00004oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Co0000oookJ_oonf[o00000_oo
nfX2o`0000;ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP03o`0000?ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX00_oonfX2o`0000cooo]Z0_l00002oookJP04o`000?oonf[ooo]ZoookJP7o0000
00000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000Co0000oookJ_l0003o00001Ooo
nfX3o`0000[ooo]Z0_l000000ooonf[o0000oookJP02o`0000;ooo]Z00?o0000oookJ_oonfX01?oo
nfX01?l0003ooo]ZoookJ_oonfX2o`0000?ooo]Z00Co0000oookJ_oonf[o00000_oonfX01_l0003o
oo]ZoookJ_l0003ooo]Zo`0000Gooo]Z0_l000000ooonf[o0000o`000002o`0000?ooo]Z00?o0000
oookJ_oonfX01?oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX2o`000004oookJ_l0003o
oo]Zo`0000;ooo]Z00?o0000oookJ_l000000_l00002oookJPKo000000?ooo]Zo`000?oonfX01ooo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04?oo
nfX00ol0003ooo]ZoookJP02oookJP;o00001?oonfX01?l0003ooo]ZoookJ_l00007oookJP;o0000
4?oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Sooo]Z00?o0000oookJ_oonfX00_oonfX3o`00
00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00002
oookJP;o000000?ooo]Zo`000?oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o
0000oookJ_l000001Ol000000ooonf[o0000o`000005o`0000Oooo]Z0_l000000ooonf[o0000o`00
0004o`000003oookJ_l0003o000000;ooo]Z00?o0000oookJ_l000001Ol00002oookJPCo000000Ko
oo]Zo`000?oonf[o0000oookJ_l00004oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l0
00000ooonfX01?l0003ooo]Zo`000?l00002oookJP;o00000_oonfX2o`0000;ooo]Z00Co0000oook
J_oonf[ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP0<oookJP;o000000?ooo]Zo`000?oonfX02ooonfX00ol0003ooo]ZoookJP09
oookJP;o00001_oonfX00ol0003ooo]Zo`00000>oookJP03o`000?oonf[o000000Cooo]Z1?l00000
1?oonf[o0000o`000?l00002oookJP04o`000?oonf[o0000o`0000?ooo]Z0_l000000ooonf[o0000
o`000002oookJP04o`000?oonf[ooo]ZoookJP;o00000ooonfX01Ol0003ooo]Zo`000?oonf[o0000
00?ooo]Z00Co0000oookJ_oonf[o00002?oonfX3o`0000Oooo]Z0_l00002oookJP04o`000?oonf[o
oo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Wooo]Z0ol00005oookJP;o00001?oo
nfX1o`00000000?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o
oo]Z00?ooo]Z0_l00002oookJP;o00000_oonfX00ol0003ooo]Zo`00000=oookJP04o`000?oonf[o
0000oookJP?o00000ooonfX3o`0000Sooo]Z00Co0000oookJ_l0003o00001?oonfX01?l0003ooo]Z
o`000?l00004oookJP?o000000Gooo]Zo`000?l0003o0000oookJP03o`000006oookJ_l0003o0000
o`000?oonf[o00000ooonfX3o`0000Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z00_ooo]Z00Co0000oookJ_oonf[o00001ooonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP02oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z0_l000000ooonf[o0000oookJP0;oookJP05
o`000?oonf[o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP07oookJP07o`000?oonf[ooo]Z
oookJ_l0003ooo]Zo`000005oookJP;o00000_oonfX00ol0003ooo]Zo`000002o`0000;ooo]Z00?o
0000oookJ_oonfX00ooonfX3o`0000;ooo]Z0_l000001?oonf[o0000oookJ_oonfX9o`000003oook
J_l0003o000000?o00001ooonfX@o`0000?ooo]Z1?l00006oookJP;o000000Gooo]Zo`000?oonf[o
oo]Zo`000003oookJP;o00002ooonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[o0000o`00
00Gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP04o`000?oonf[ooo]ZoookJP;o000000?o
oo]Zo`000?oonfX00_l000000ooonf[o0000oookJP02oookJP05o`000?oonf[ooo]ZoookJ_l00000
1OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_l0003o
oo]Zo`00000GoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol000000ooonf[o0000oookJP07o`0000?o
oo]Z1Ol000000ooonf[o0000oookJP02oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`000004oook
JP03o`000?oonf[ooo]Z00;ooo]Z0_l00003oookJP;o00000_oonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP03o`00
0004oookJ_l0003ooo]Zo`0000?ooo]Z00?o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP04
oookJP;o00000ooonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z0Ol000000003o`000?oonf[o0000
00;ooo]Z0_l000000ooonf[o0000oookJP02o`000004oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000
oookJ_oonfX01?oonfX01?l0003ooo]Zo`000?l00005oookJP?o00001_oonfX00ol0003ooo]Zo`00
0003oookJP;o00003ooonfX3o`000005oookJ_l0003ooo]Zo`000?oonfX00_l00003oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00So0000oookJ_l0003o0000oookJ_l0003ooo]Zo`0000?ooo]Z0_l00002
oookJP03o`000?oonf[ooo]Z00;o00000_oonfX01?l0003ooo]Zo`000?oonfX2o`000003oookJ_l0
003ooo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00?ooo]Z
00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oo
nf[o00000ooonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00Co00002ooonfX0
0ol0003ooo]ZoookJP09oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX02ooo
nfX2o`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00Go0000oookJ_l0003ooo]Zo`000005oookJP06o`000?oonf[o0000o`000?oo
nf[o00000_oonfX5o`0000Cooo]Z1?l000001?oonf[o0000o`000?oonfX9o`0000Gooo]Z2Ol00000
1Ooonf[o0000oookJ_l0003ooo]Z00Ko00001?oonfX2o`000003oookJ_l0003ooo]Z00?ooo]Z00?o
0000oookJ_l000000_oonfX01?l0003ooo]Zo`000?oonfX2o`0000Gooo]Z0_l000000ooonf[o0000
o`000003oookJP03o`000?oonf[o000000;ooo]Z1?l000001?oonf[o0000o`000?l00003oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000gooo]Z00Co0000oookJ_oo
nf[ooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_l000005?oonfX00ol0
003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]Zo`000007
o`000003oookJ_l0003ooo]Z00Gooo]Z0ol000000ooonf[o0000o`000004o`0000?ooo]Z00?o0000
oookJ_oonfX01_oonfX2o`0000?ooo]Z00?o0000oookJ_l000001?oonfX2o`0000?ooo]Z00Co0000
oookJ_oonf[o00002ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX01OoonfX2o`0000Kooo]Z0Ol000000003o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX01?oonfX01?l0003ooo]Zo`000?oonfX3o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z
0_l00002oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_l000001_oonfX01?l0003ooo]Z
o`000?l00005oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000000_oonfX00ol0
003ooo]ZoookJP03o`0000?ooo]Z00?o0000oookJ_l000001?oonfX01Ol0003ooo]ZoookJ_l0003o
oo]Z00;o000000Cooo]Zo`000?oonf[o00000_oonfX3o`000005oookJ_l0003o0000o`000?oonfX0
0_l000000ooonf[o0000o`000002o`0001Cooo]Z00?o0000oookJ_oonfX03?oonfX01_l0003ooo]Z
oookJ_l0003ooo]Zo`0000Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP05o`000?oonf[o
oo]ZoookJ_l000002_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000?ooo]Z0_l00007oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]Zo`000?oonf[o0000
00;ooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX2o`00
00Kooo]Z1?l00002oookJPCo00001OoonfX5o`000003oookJ_l0003o000000oo00001OoonfXBo`00
00;ooo]Z00?o0000oookJ_l000000_oonfX4o`0000?ooo]Z00?o0000oookJ_oonfX00_l00003oook
JP;o00001?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Oooo]Z00?o0000oookJ_oonfX02OoonfX2
o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0:
oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000000ooonfX01Ol0003ooo]Zoook
J_oonf[o000000Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000007oookJP;o0000
1?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00003oookJP;o0000
00?ooo]Zo`000?l000000ooonfX00ol0003ooo]ZoookJP03oookJP;o000000Cooo]Zo`000?oonf[o
00001?oonfX00ol0003ooo]Zo`000004oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00Go0000oook
J_l0003ooo]Zo`000002oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]Zoook
JP02oookJP;o00000_oonfX01?l0003ooo]Zo`000?l00002oookJP;o000000?ooo]Zo`000?l00000
0_l00004oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000?o0000oookJ_oonfX00ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP;o00000ooonfX00ol0003ooo]Zoook
JP04oookJP04o`000?oonf[o0000o`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000Kooo]Z00?o0000oookJ_l000001?oonfX2o`0000;ooo]Z00Co0000oookJ_oo
nf[o00000ooonfX00ol0003ooo]Zo`000002oookJP04o`000?oonf[o0000o`0000Kooo]Z0ol00002
oookJPOo000000?ooo]Zo`000?l000007OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX01_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z0_l0
0002oookJP03o`000?oonf[ooo]Z00Oooo]Z00Co0000oookJ_l0003o00000ooonfX00ol0003ooo]Z
oookJP06oookJP04o`000?oonf[o0000o`0000?ooo]Z00?o0000oookJ_oonfX02?oonfX3o`000004
oookJ_l0003ooo]Zo`0000Oooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[o
oo]Z00;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol000000ooonf[o0000o`000002o`000007oookJ_l0
003ooo]Zo`000?oonf[o0000oookJP03o`0000;ooo]Z3?l00003oookJPCo000000?ooo]Zo`000?l0
00001?l00002oookJP;o000000?ooo]Zo`000?l000001_l00003oookJP03o`000?oonf[ooo]Z00Co
oo]Z0_l00006oookJP?o00001?oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Go0000oook
J_oonf[ooo]Zo`000002oookJP?o00001_oonfX01?l0003ooo]ZoookJ_l00004oookJP;o00001ooo
nfX4o`000005oookJ_l0003ooo]ZoookJ_l000001_oonfX01?l0003ooo]ZoookJ_l0000>oookJP;o
00006ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00006oookJPWo
00000_oonfX00ol0003ooo]Zo`000002o`0000;ooo]Z0_l00003oookJP03o`000?oonf[o000000;o
00000ooonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00Go0000oookJ_l0003ooo]Zo`000004
oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z0ol00004oookJP03o`000?oonf[o000001[ooo]Z0_l0
0004oookJP;o000000?ooo]Zo`000?oonfX02_oonfX1o`00000000Ko0000oookJ_oonf[o0000oook
J_l00002oookJP;o00001ooonfX01?l0003ooo]ZoookJ_oonfX2o`0000;ooo]Z00Co0000oookJ_l0
003o00000_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;o00000_oonfX6o`00
00Wooo]Z00?o0000oookJ_oonfX01?oonfX4o`0000;ooo]Z00Co0000oookJ_oonf[o00001?oonfX0
0ol0003ooo]Zo`000003oookJPGo00000_oonfX00ol0003ooo]ZoookJP02oookJP;o000000?ooo]Z
o`000?l000000ol000000ooonf[o0000o`000002o`000003oookJ_l0003ooo]Z00;ooo]Z0_l0000<
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP04
oookJP;o000000?ooo]Zo`000?oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z00;ooo]Z0_l000000ooonf[o0000o`00000=oookJP03o`000?oonf[o000000?ooo]Z0_l0000:
oookJP?o00001_oonfX01?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003o000000Gooo]Z00Go
0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol000001?oonf[o0000oookJ_l00003oookJP03o`000?oonf[o000000So000000?ooo]Zo`00
0?l000003_l00003oookJPCo000000Kooo]Zo`000?l0003ooo]Zo`000?oonfX3o`000007oookJ_l0
003o0000o`000?oonf[o0000oookJP03o`000003oookJ_l0003o000000Gooo]Z0_l00006oookJP04
o`000?oonf[ooo]Zo`0000;ooo]Z0ol00008oookJPCo00001?oonfX2o`0000Cooo]Z0_l00003oook
JP03o`000?oonf[ooo]Z00;o00000ooonfX00ol0003ooo]Zo`000008oookJP;o00001?oonfX00ol0
003ooo]ZoookJP0=oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Oo0000oookJ_oonf[ooo]Zo`00
0?oonf[o000000Sooo]Z00?o0000oookJ_l000000_l0000?oookJP03o`000?oonf[ooo]Z013ooo]Z
1Ol000001Ooonf[o0000o`000?oonf[o000000Gooo]Z0_l000000ooonf[o0000oookJP02o`0000;o
oo]Z00Co0000oookJ_oonf[ooo]Z0_l000000ooonf[o0000o`000005oookJP;o00001?oonfX00ol0
003ooo]ZoookJP03oookJP;o000000?ooo]Zo`000?oonfX02OoonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_l000000ooonfX01?l0003ooo]ZoookJ_l00007
oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX1o`00000000?o0000oookJ_l000000_oonfX0
0ol0003ooo]ZoookJP04oookJP05o`000?oonf[o0000oookJ_l000001_oonfX01?l0003ooo]Zoook
J_oonfX2o`0000Gooo]Z0_l000000ooonf[o0000oookJP0;oookJPCo00001ooonfX02Ol0003ooo]Z
oookJ_oonf[o0000oookJ_l0003ooo]Zo`000002oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00Oo
0000oookJ_oonf[ooo]Zo`000?oonf[o000000Cooo]Z00Go0000oookJ_l0003ooo]Zo`000002oook
JP03o`000?oonf[o000000Go00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0<oookJP04o`000?oonf[ooo]Z
o`0000?ooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]Zo`000009oookJP07o`000?oonf[o
0000oookJ_l0003ooo]Zo`000002oookJP05o`000?oonf[o0000oookJ_l000002ooonfX01?l0003o
oo]ZoookJ_l00004oookJP04o`000?oonf[o0000oookJP;o000000Cooo]Zo`000?l0003ooo]Z0_l0
00000ooonf[o0000o`00000;oookJP04o`000?oonf[o0000oookJPCo00000_oonfX00ol0003ooo]Z
o`000003o`000003oookJ_l0003ooo]Z00?o00000_oonfX3o`0000;ooo]Z2ol00002oookJPWo0000
00?ooo]Zo`000?l000001?l000001?oonf[o0000oookJ_oonfX4o`000003oookJ_l0003o000000Co
000000?ooo]Zo`000?l000001?oonfX00ol0003ooo]ZoookJP05o`000003oookJ_l0003ooo]Z00;o
oo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0003ooo]ZoookJP02o`000003oookJ_l0003ooo]Z
013ooo]Z0ol00005oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX2o`00
01;ooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00Sooo]Z00Go0000oookJ_oonf[ooo]Zo`000005
oookJP03o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[o0000oookJP02o`000003oookJ_l0
003ooo]Z00?o00000ooonfX3o`000006oookJ_l0003o0000o`000?oonf[o00000_oonfX00ol0003o
oo]ZoookJP02oookJP?o000000Cooo]Zo`000?oonf[ooo]Z0_l00002oookJP04o`000?oonf[o0000
o`0000Kooo]Z00Co0000oookJ_l0003ooo]Z0_l000000ooonf[o0000oookJP03oookJP;o00001_oo
nfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX01Ol0003ooo]Z
o`000?oonf[o000000Kooo]Z00?o0000oookJ_l000001OoonfX3o`0000;ooo]Z00?o0000oookJ_oo
nfX00Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000001Ol0003ooo]Zoook
J_oonf[o000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000=oookJP06o`000?oonf[o0000oook
J_l0003ooo]Z0_l00002oookJP;o000000?ooo]Zo`000?oonfX00_l000000ooonf[o0000oookJP04
oookJP09o`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000017ooo]Z0ol000001Ooonf[o
0000oookJ_oonf[o000000;ooo]Z0_l000000ooonf[o0000oookJP04o`000003oookJ_l0003o0000
00;o000000?ooo]Zo`000?oonfX00ooonfX2o`000003oookJ_l0003o000000Cooo]Z00?o0000oook
J_l000006?oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX0
1?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04_oo
nfX4o`0000Cooo]Z0_l000000ooonf[o0000oookJP06oookJP;o000000Cooo]Zo`000?oonf[o0000
1?oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000002_oonfX02?l0003ooo]Zo`000?l0003o
oo]Zo`000?oonf[o00000_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]ZoookJPOo
000000Gooo]Zo`000?l0003o0000oookJP03o`000003oookJ_l0003o000000co000000?ooo]Zo`00
0?l000002?l000000ooonf[o0000o`000009o`0000Cooo]Z00Go0000oookJ_oonf[o0000oookJP03
o`000003oookJ_l0003o000000?ooo]Z0ol00002oookJP;o00000_oonfX00ol0003ooo]Zo`000006
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP02
oookJP;o000000Cooo]Zo`000?oonf[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX04ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o00008_oonfX5o`000004oook
J_l0003ooo]ZoookJP?o00000_oonfX00ol0003ooo]ZoookJP02o`000003oookJ_l0003ooo]Z00Co
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02o`000003oookJ_l0003o000000;o
00001?oonfX00ol0003ooo]ZoookJP02o`000006oookJ_l0003ooo]ZoookJ_l0003ooo]Z0_l00005
oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000;ooo]Z00?o0000
oookJ_l000001_oonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_oonfX2o`000005oookJ_l0003ooo]ZoookJ_l0
00000_oonfX00ol0003ooo]ZoookJP03o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003o
oo]ZoookJ_l00003oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX00ol0003ooo]ZoookJP02
o`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?l000001Ol0000=oookJP04o`000?oonf[o
oo]Zo`0000gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP04o`000?oo
nf[ooo]ZoookJP;o00000ooonfX00ol0003ooo]ZoookJP0;oookJP;o00000ooonfX2o`0000;ooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP09oookJP;o00000ooonfX01_l0003ooo]Z
o`000?l0003ooo]Zo`0000Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP02o`00
00?ooo]Z00?o0000oookJ_oonfX01?oonfX2o`000003oookJ_l0003o000000;ooo]Z0_l00003oook
JP?o000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000004o`000003oookJ_l0003o0000
00[o000000?ooo]Zo`000?oonfX01?l000000ooonf[o0000o`000004oookJP?o00000ooonfX01_l0
003ooo]ZoookJ_oonf[o0000oookJP;o000000?ooo]Zo`000?l000001_oonfX01?l0003ooo]Zoook
J_l00002oookJP?o000000Gooo]Zo`000?l0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00?o
00000_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000;oookJP05o`000?oonf[o0000oookJ_l000001_oonfX00ol0003ooo]Zo`00000D
oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP02
oookJPKo00000_oonfX7o`0000Kooo]Z00?o0000oookJ_oonfX01ooonfX2o`0000?ooo]Z0ol00000
1?oonf[o0000o`000?l00003oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00Co0000oookJ_oonf[o
oo]Z0_l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_l0003o00001OoonfX00ol0
003ooo]ZoookJP05oookJP7o000000001ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001OoonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000;o000000Kooo]Zo`000?oonf[o0000oook
J_l00007oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000000_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ol00008oookJP;o00001OoonfX01?l0003o
oo]ZoookJ_oonfX2o`000004oookJ_l0003o0000o`0000;ooo]Z0ol000001_oonf[o0000o`000?oo
nf[o0000oookJP;o000000?ooo]Zo`000?oonfX00_oonfX5o`0001Gooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP0GoookJP;o000000?ooo]Zo`000?oonfX01OoonfX00ol0003ooo]Z
o`000002o`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_l00007oookJP03
o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX00_l000002_oonf[o0000oookJ_oonf[o0000
oookJ_l0003ooo]Zo`000?oonfX6o`0000Cooo]Z0_l00004oookJPCo000000?ooo]Zo`000?l00000
0_oonfX00ol0003ooo]ZoookJP03oookJPCo000000?ooo]Zo`000?l000006?l000000ooonf[o0000
o`000002o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000ol00002oookJP;o0000
00Gooo]Zo`000?l0003o0000oookJP02o`0000;ooo]Z1?l00002oookJP;o000000?ooo]Zo`000?oo
nfX00_l00005oookJP04o`000?oonf[ooo]ZoookJP;o00001ooonfX2o`0000Sooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z00Go0000
oookJ_oonf[ooo]Zo`000002oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z00?o0000oookJ_oonfX0
1_oonfX2o`0000gooo]Z00Go0000oookJ_oonf[ooo]Zo`00000AoookJP03o`000?oonf[o000000Wo
oo]Z00Co0000oookJ_l0003ooo]Z2Ol000001?oonf[o0000o`000?oonfX2o`000005oookJ_l0003o
0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX0
0_oonfX01Ol0003ooo]Zo`000?oonf[o000000Sooo]Z0_l000001_oonf[o0000oookJ_l0003ooo]Z
o`0000?ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zo`000002o`0000?ooo]Z0Ol00000
0003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP02oookJP04
o`000?oonf[o0000oookJP;o00001?oonfX2o`000003oookJ_l0003ooo]Z00Gooo]Z00Co0000oook
J_l0003ooo]Z0_l000001?oonf[o0000oookJ_l00004oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX0
0_oonfX01?l0003ooo]ZoookJ_l00002oookJP08o`000?oonf[o0000o`000?oonf[o0000oookJ_l0
0003oookJPCo00000_oonfX2o`000005oookJ_l0003o0000oookJ_l000000ooonfX3o`0000;ooo]Z
0_l000000ooonf[o0000oookJP03o`0000cooo]Z00?o0000oookJ_l000005_oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
o`000003o`0000Oooo]Z00Oo0000oookJ_l0003ooo]Zo`000?oonf[o000000Kooo]Z0ol00007oook
JP;o000000?ooo]Zo`000?oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Co0000
oookJ_oonf[o00000ooonfX00ol0003ooo]ZoookJP02o`000003oookJ_l0003o000000?ooo]Z1?l0
00000ooonf[o0000o`00000@o`000003oookJ_l0003o000000Ko00000_oonfX2o`000005oookJ_l0
003o0000o`000?oonfX00_l000000ooonf[o0000o`000002o`0000?ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP03o`0000?ooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000Kooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04oookJPCo00001ooonfX00ol0003ooo]Z
oookJP08oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00Co0000oookJ_oonf[o00003?oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[o00002ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]Zo`000004o`000003oookJ_l0003ooo]Z00;ooo]Z0_l000001?oonf[o0000o`000?oo
nfX6o`000004oookJ_l0003ooo]Zo`0000Cooo]Z0_l000001?oonf[o0000o`000?l00002oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l000000_oonfX2o`0000;ooo]Z00Ko0000oookJ_oo
nf[o0000oookJ_l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX0
1?l0003ooo]ZoookJ_l00004oookJP;o00000_oonfX2o`0000Cooo]Z00?o0000oookJ_l000001Ooo
nfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z0Ol000000003o`000?oonf[ooo]Z00Kooo]Z00Go
0000oookJ_l0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l00000
1OoonfX3o`000004oookJ_l0003ooo]Zo`0000[ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]Zo`000002oookJP05o`000?oonf[ooo]ZoookJ_l000002_oonfX3o`0000Gooo]Z00Go0000oook
J_oonf[ooo]Zo`000004oookJP05o`000?oonf[o0000o`000?oonfX01Ol000000ooonf[o0000o`00
0002o`0000Kooo]Z00?o0000oookJ_l000003OoonfX2o`0000[ooo]Z0_l00008oookJP05o`000?oo
nf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]Zo`0000So
oo]Z0_l00007oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_l000002ooonfX00ol0003o
oo]ZoookJP03oookJP05o`000?oonf[o0000oookJ_l000000_oonfX01_l0003ooo]ZoookJ_l0003o
oo]Zo`0000?ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol00004oookJPKo000000?o
oo]Zo`000?oonfX00_oonfX2o`000003oookJ_l0003o000000;o00000_oonfXGo`000004oookJ_l0
003o0000oookJPGo000000?ooo]Zo`000?oonfX00ooonfX2o`000007oookJ_l0003o0000oookJ_l0
003ooo]Zo`000002oookJP?o00000ooonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o
0000oookJ_oonfX03OoonfX01?l0003ooo]ZoookJ_l0000;oookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX00ol00009oookJP;o00002OoonfX00ol0003ooo]ZoookJP03oookJP04o`00
0?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000004?oonfX2o`000003oookJ_l0003ooo]Z00;o
000000Cooo]Zo`000?l0003ooo]Z1?l000000ooonf[o0000oookJP03o`0000;ooo]Z00?o0000oook
J_oonfX00_oonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o000000Cooo]Zo`000?oonf[o0000
0_oonfX00ol0003ooo]ZoookJP03oookJP06o`000?oonf[ooo]Zo`000?oonf[o00002_oonfX01?l0
003ooo]ZoookJ_l00003oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX01Ol0003ooo]Zoook
J_oonf[o000000;ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP04oookJP7o0000
00000ol0003ooo]ZoookJP02o`0000[ooo]Z00?o0000oookJ_l000000ooonfX02?l0003ooo]Zo`00
0?oonf[o0000oookJ_l0003ooo]Z0_l000000ooonf[o0000oookJP06oookJP04o`000?oonf[o0000
oookJP;o00001?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z0_l00008oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_l000000_l00002oookJP03o`000?oonf[ooo]Z00;o00000_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ooonfX4o`000007oook
J_l0003o0000oookJ_l0003ooo]Zo`000008oookJP03o`000?oonf[o000000Oooo]Z0_l000000ooo
nf[o0000oookJP09oookJP03o`000?oonf[ooo]Z00;o00002?oonfX01?l0003ooo]ZoookJ_l00003
oookJP03o`000?oonf[ooo]Z00;o00001?oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX05_oonfX0
1?l0003ooo]Zo`000?l00003oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP06
o`000?oonf[o0000o`000?oonf[o00001ooonfX00ol0003ooo]ZoookJP02oookJP;o00001?oonfX0
0ol0003ooo]Zo`000003oookJP07o`000?oonf[o0000o`000?oonf[o0000oookJP02o`000006oook
J_l0003o0000oookJ_l0003ooo]Z4ol000000ooonf[o0000o`00000:o`000003oookJ_l0003o0000
00?o00000_oonfX00ol0003ooo]Zo`000004o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l00000
1Ooonf[o0000oookJ_oonf[o000000?ooo]Z1?l000001?oonf[o0000oookJ_l00003oookJP;o0000
0ooonfX00ol0003ooo]Zo`00000:oookJP03o`000?oonf[o000001?ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[o0000oookJP;o00008OoonfX00ol0003o
oo]ZoookJP0:oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000004oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_l000001Ol000000ooonf[o0000o`000003oookJP;o000000Cooo]Z
o`000?l0003o00001OoonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000_oonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000003ooonfX02Ol0003o
oo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000004oookJP05o`000?oonf[o0000oookJ_l00000
2ooonfX01Ol0003ooo]Zo`000?oonf[o000000gooo]Z0Ol000000003o`000?oonf[o000000Oooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP04oookJP04o`000?oonf[o0000o`0000;o
oo]Z0_l00002oookJP?o000000?ooo]Zo`000?oonfX01_oonfX01?l0003ooo]ZoookJ_oonfX2o`00
00Gooo]Z0_l00002oookJP;o00003OoonfX2o`0000;ooo]Z00Ko0000oookJ_l0003ooo]Zo`000?oo
nfX2o`0000;ooo]Z1?l000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z00Ko0000oookJ_l0003o
0000oookJ_l00007oookJP;o00000_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00;ooo]Z00Co0000oookJ_oonf[o00002_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[o
oo]Zo`0001[ooo]Z00Co0000oookJ_oonf[ooo]Z0_l000000ooonf[o0000oookJP07oookJP03o`00
0?oonf[o000000Cooo]Z00?o0000oookJ_l000001ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Ko
oo]Z00?o0000oookJ_oonfX01OoonfX2o`0000;ooo]Z1?l00007oookJP08o`000?oonf[o0000o`00
0?oonf[o0000oookJ_l00004oookJPCo00000_oonfX00ol0003ooo]Zo`000002o`000003oookJ_l0
003o000000go00000_oonfX7o`000005oookJ_l0003o0000oookJ_l000000_oonfX5o`000003oook
J_l0003ooo]Z00;o000000Gooo]Zo`000?l0003ooo]Zo`000002oookJP03o`000?oonf[o000000;o
oo]Z0_l00005oookJP;o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP04
o`000?oonf[ooo]Zo`0000;ooo]Z0_l000000ooonf[o0000oookJP06oookJP03o`000?oonf[o0000
00Oooo]Z0_l000000ooonf[o0000oookJP0>oookJP;o00001OoonfX00ol0003ooo]ZoookJP04oook
JP04o`000?oonf[ooo]Zo`0001Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP08
oookJPOo000000?ooo]Zo`000?l000000_oonfX00ol0003ooo]Zo`000002oookJP;o000000Gooo]Z
o`000?l0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?o00000_oonfX00ol0003ooo]Zo`00
0002oookJPCo00000ooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000_ooo]Z0_l0
0007oookJP;o000000?ooo]Zo`000?oonfX00_l00005oookJP03o`000?oonf[o000000[ooo]Z00?o
0000oookJ_oonfX01?oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol00000
0005o`000?oonf[ooo]ZoookJ_l000002OoonfX01?l0003ooo]ZoookJ_oonfX2o`0000;ooo]Z00So
0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX01_oonfX2o`00
00;ooo]Z00Co0000oookJ_l0003o00001?oonfX2o`000003oookJ_l0003o000000;o00001OoonfX0
0ol0003ooo]ZoookJP02oookJP?o000000Cooo]Zo`000?oonf[o00001?oonfX01?l0003ooo]Zoook
J_oonfX2o`0000?ooo]Z0_l00002oookJP05o`000?oonf[ooo]Zo`000?oonfX01Ol000001?oonf[o
0000o`000?l00004oookJP;o00002OoonfX01Ol0003ooo]Zo`000?oonf[o000000Gooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o000000?ooo]Z0_l00003
oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000000ooonf[o0000oookJP04oookJP03o`000?oonf[o
oo]Z00Wooo]Z0_l0000;oookJP04o`000?oonf[ooo]ZoookJP;o000000Cooo]Zo`000?oonf[o0000
1?oonfX2o`0000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[o000000Co
oo]Z0_l000001_oonf[o0000oookJ_oonf[o0000oookJP;o00000ooonfX3o`0000;ooo]Z3?l00003
oookJPCo000000?ooo]Zo`000?l000003?l000001ooonf[o0000oookJ_oonf[o0000oookJ_l00000
0_oonfX6o`000004oookJ_l0003ooo]ZoookJP;o000000?ooo]Zo`000?oonfX02OoonfX4o`0000;o
oo]Z0_l000000ooonf[o0000oookJP03oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0CoookJP;o00001?oonfX2o`0000?ooo]Z00?o0000oookJ_oo
nfX00_l0000<oookJP06o`000?oonf[ooo]Zo`000?oonf[o00001ooonfX2o`0000;ooo]Z00?o0000
oookJ_l000001_oonfX2o`0000_ooo]Z1?l000000ooonf[o0000oookJP05o`0000Gooo]Z00?o0000
oookJ_oonfX00_oonfX4o`0000?ooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP?o00000_oo
nfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Co0000oookJ_oonf[o
oo]Z0_l00004oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[o
oo]Z00Wooo]Z00Go0000oookJ_oonf[o0000oookJP01o`00000000?o0000oookJ_oonfX00ooonfX3
o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP06o`000?oonf[o
oo]ZoookJ_l0003ooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z00?o0000oookJ_oo
nfX00_oonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o00000_oonfX01?l0003ooo]Zo`000?l0
0002oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00004oookJP03o`000?oonf[o000000Cooo]Z0_l0
0007oookJP;o00000_oonfX2o`0000?ooo]Z2_l000000ooonf[o0000oookJP02o`0001;ooo]Z00?o
0000oookJ_oonfX03_oonfX01Ol0003ooo]ZoookJ_oonf[o000001?ooo]Z00?o0000oookJ_oonfX0
4_oonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o00001_oonfX00ol0003ooo]ZoookJP08oook
JP05o`000?oonf[ooo]ZoookJ_l000000ooonfX3o`0000?ooo]Z00So0000oookJ_oonf[o0000oook
J_l0003ooo]Zo`0000;ooo]Z00Oo0000oookJ_oonf[o0000oookJ_l0003ooo]Z00;o000000Sooo]Z
o`000?l0003ooo]Zo`000?oonf[o0000oookJPOo000000Cooo]Zo`000?l0003ooo]Z1?l000001?oo
nf[o0000oookJ_oonfX:o`0000?ooo]Z1?l000000ooonf[o0000o`000005o`000003oookJ_l0003o
oo]Z00Co000000?ooo]Zo`000?l000001?oonfX01?l0003ooo]Zo`000?l00003oookJP;o00000_oo
nfX00ol0003ooo]Zo`000002o`000003oookJ_l0003ooo]Z00Co00001?oonfX01?l0003ooo]Zoook
J_l00002oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP?o00001OoonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00003ooonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_l000001?oonfX01Ol0003o
oo]ZoookJ_oonf[o000000Wooo]Z00Co0000oookJ_oonf[ooo]Z0ol00004oookJP03o`000?oonf[o
oo]Z00;ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00003oookJPOo000000Oooo]Z
o`000?oonf[ooo]Zo`000?oonf[o000000Gooo]Z0_l00003oookJP04o`000?oonf[ooo]Zo`0000Co
oo]Z0ol00003oookJP;o00001OoonfX6o`0000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l000000ooo
nf[o0000o`000002oookJPGo00001_oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z
00Sooo]Z00Co0000oookJ_oonf[o00002?oonfX1o`00000000?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Kooo]Z00Wo0000oookJ_oonf[ooo]Zo`000?oo
nf[o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP03oookJP;o000000Gooo]Zo`000?oonf[o
oo]Zo`000007oookJP;o00000_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Gooo]Z00Co0000
oookJ_l0003o00000_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000;ooo]Z00Co0000oookJ_oonf[o
oo]Z1_l00002oookJP;o000000?ooo]Zo`000?l000002_l0000;oookJP03o`000?oonf[ooo]Z00go
oo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP;o00002ooonfX01ol0003ooo]ZoookJ_oonf[o
0000oookJ_l000001_oonfX2o`000006oookJ_l0003ooo]Zo`000?oonf[o00001_oonfX00ol0003o
oo]ZoookJP06oookJP09o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000?oonf[o000000?ooo]Z00?o
0000oookJ_oonfX01?oonfX01?l0003ooo]ZoookJ_l00002oookJP;o00000_oonfX2o`000003oook
J_l0003ooo]Z00Gooo]Z0_l000000ooonf[o0000oookJP02oookJPCo00001?oonfX01Ol0003ooo]Z
o`000?l0003ooo]Z00So00001OoonfX3o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l0
00001_l00005oookJPKo000000Gooo]Zo`000?oonf[o0000oookJP04o`0000;ooo]Z00?o0000oook
J_l000001_l000000ooonf[o0000o`000004oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`00
0?oonfX01_oonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00Co0000oookJ_oonf[o00000_oonfX0
0ol0003ooo]ZoookJP03o`000003oookJ_l0003ooo]Z00cooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00001_oo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04?oo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX02_oo
nfX2o`0000;ooo]Z00?o0000oookJ_l000001ol00003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z
00Co0000oookJ_oonf[ooo]Z0_l000001?oonf[o0000oookJ_oonfX2o`0000Gooo]Z0_l00004oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000000ol00003oookJP04o`000?oonf[ooo]Z
o`0000?ooo]Z00?o0000oookJ_oonfX00_l00002oookJP03o`000?oonf[o000000;o000000?ooo]Z
o`000?oonfX02_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00ooo
nfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z
00Gooo]Z0_l000001Ooonf[o0000oookJ_l0003ooo]Z00;o00000ooonfX00ol0003ooo]ZoookJP02
oookJP04o`000?oonf[o0000oookJP;o00000_oonfX2o`0000;ooo]Z00Co0000oookJ_l0003o0000
0_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000_oonfX5o`0000Cooo]Z0_l000000ooo
nf[o0000oookJP02o`0000;ooo]Z0_l000001_oonf[o0000o`000?oonf[o0000oookJP;o000000Go
oo]Zo`000?oonf[ooo]Zo`000002oookJPCo000000Sooo]Zo`000?oonf[ooo]Zo`000?oonf[o0000
oookJPKo000000Cooo]Zo`000?l0003ooo]Z0ol000000ooonf[o0000o`000003oookJP03o`000?oo
nf[ooo]Z00Oooo]Z0_l00004oookJP;o00001?oonfX00ol0003ooo]ZoookJP03oookJP;o00001?oo
nfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[o0000o`0000[ooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP02o`0000Oooo]Z00Ko0000oookJ_oonf[ooo]Zo`000?oonfX2o`00
0003oookJ_l0003ooo]Z00Wooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00005
oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l000000ooonf[o0000o`00
0002o`0000;ooo]Z0ol00002oookJP04o`000?oonf[ooo]ZoookJP?o00001?oonfX2o`000003oook
J_l0003o000000;ooo]Z3ol00005oookJPSo000000?ooo]Zo`000?l000000ol00002oookJP07o`00
0?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP;o000000Cooo]Zo`000?l0003o00000_oonfX2
o`0000Kooo]Z00Co0000oookJ_l0003o00001OoonfX4o`0000;ooo]Z00?o0000oookJ_oonfX00ooo
nfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX02?oonfX4o`0000?ooo]Z
00?o0000oookJ_oonfX00ooonfX4o`000003oookJ_l0003o000000?o00001OoonfX01?l0003ooo]Z
oookJ_oonfX3o`0000Gooo]Z0ol00008oookJP?o000000Cooo]Zo`000?oonf[o00000ooonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00;o00001?oonfX00ol0003ooo]Zo`000005oook
JP;o00000ooonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000ooonfX00ol0003ooo]Zoook
JP02oookJP7o000000000ol0003ooo]Zo`000007oookJP03o`000?oonf[o000000;ooo]Z00Ko0000
oookJ_l0003o0000oookJ_l00002oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP02oook
JP04o`000?oonf[o0000o`0000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP;o00001Ooo
nfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o00000_oonfX00ol0003ooo]ZoookJP02oookJP;o0000
00Gooo]Zo`000?l0003ooo]Zo`000002oookJP03o`000?oonf[o000000;o00001?oonfX4o`0000Ko
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o000000So
oo]Z0_l00008oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l00006oookJP;o00000ooonfX01Ol0003o
oo]Zo`000?oonf[o000000Cooo]Z0_l000000ooonf[o0000oookJP02o`0000;ooo]Z00?o0000oook
J_oonfX00_l00005oookJP04o`000?oonf[o0000oookJP?o00002?oonfX02Ol0003ooo]ZoookJ_oo
nf[o0000oookJ_l0003ooo]Zo`000003oookJP;o000000Cooo]Zo`000?l0003ooo]Z0_l00002oook
JPCo000000?ooo]Zo`000?l000001_l00007oookJPOo000000?ooo]Zo`000?l000000_l000000ooo
nf[o0000o`000004o`000003oookJ_l0003o000000;ooo]Z00?o0000oookJ_l000000_oonfX00ol0
003ooo]Zo`000002oookJPCo000000?ooo]Zo`000?oonfX00ooonfX2o`0000?ooo]Z0_l00002oook
JP03o`000?oonf[o000000?ooo]Z0_l000001Ooonf[o0000o`000?oonf[o000000;ooo]Z1?l00004
oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l0000>oookJP03o`000?oo
nf[o000000Gooo]Z0_l000001?oonf[o0000o`000?l00002oookJP04o`000?oonf[o0000o`0000Oo
oo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_oonfX2o`000005oookJ_l0003ooo]Z
oookJ_l000000_oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00gooo]Z00Co0000oookJ_oonf[o00001_oo
nfX1o`00000000Ko0000oookJ_oonf[o0000oookJ_l0000=oookJP04o`000?oonf[ooo]Zo`0000;o
oo]Z00Co0000oookJ_l0003ooo]Z0_l00004oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l00003
oookJP?o00001OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z00?o000000?ooo]Zo`000?oonfX00_l00008oookJP?o000000?ooo]Z
o`000?l000001_l000001Ooonf[o0000o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00;o00002_oonfX00ol0003ooo]Zoook
JP04oookJP04o`000?oonf[ooo]ZoookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP04o`00
0?oonf[o0000o`0001Gooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02o`0000Co
oo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP06o`000?oonf[o0000o`000?oonf[o00001ooo
nfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0_l000000ooonf[o0000
o`000002oookJP04o`000?oonf[o0000oookJP;o000000Gooo]Zo`000?l0003o0000oookJP02o`00
0005oookJ_l0003o0000o`000?oonfX03ol00007oookJP;o000000Kooo]Zo`000?l0003ooo]Zo`00
0?oonfX6o`000003oookJ_l0003o000000?o000000Gooo]Zo`000?l0003o0000oookJP03o`0000;o
oo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003o
oo]Zo`000?l00005oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]Zo`000002oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX2o`0000?ooo]Z00Co0000
oookJ_oonf[ooo]Z0_l0000;oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000003Ooo
nfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00000:oook
JP03o`000?oonf[ooo]Z00;o00002ooonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[o
000000;ooo]Z1_l000000ooonf[o0000o`000003oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z00Oooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Gooo]Z
00?o0000oookJ_oonfX01OoonfX4o`0000?ooo]Z0_l000000ooonf[o0000o`000002o`000004oook
J_l0003ooo]Zo`0000;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l000000ooonf[o0000o`000007oook
JP03o`000?oonf[ooo]Z00Kooo]Z0Ol000000006o`000?oonf[ooo]Zo`000?oonf[o00000_oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_oonf[o00001Ooo
nfX01?l0003ooo]Zo`000?l00003oookJP;o00000_oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[o000000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l00003oookJP03o`000?oonf[o000000?o
oo]Z0ol000000ooonf[o0000oookJP02oookJP;o000000?ooo]Zo`000?oonfX00_l000001ooonf[o
0000oookJ_oonf[o0000oookJ_l000000_oonfX2o`0000?ooo]Z0_l00003oookJP;o000000?ooo]Z
o`000?oonfX00_l00003oookJP?o000000?ooo]Zo`000?oonfX01ooonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02OoonfX01?l0003ooo]ZoookJ_oonfX2o`0000?ooo]Z
0_l00003oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00Co0000oookJ_oonf[ooo]Z0_l00004oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02OoonfX8o`0000?ooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP03o`0000?ooo]Z00So0000oookJ_oonf[ooo]Zo`000?oo
nf[o0000oookJPGo000000?ooo]Zo`000?oonfX01?l000000ooonf[o0000o`000006o`0000Sooo]Z
2Ol000000ooonf[o0000o`000005o`000005oookJ_l0003o0000oookJ_l000000ooonfX2o`0000;o
oo]Z00go0000oookJ_l0003o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z00;o
00002ooonfX2o`0000;ooo]Z00Co0000oookJ_l0003o00002OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00[ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00008oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00003OoonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[o0000013ooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_oonfX3o`000006
oookJ_l0003ooo]Zo`000?oonf[o00000ooonfX4o`0000Oooo]Z00?o0000oookJ_oonfX01?oonfX0
1?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_l000001?oo
nfX2o`000004oookJ_l0003ooo]Zo`0000Sooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]Z
oookJ_l00002oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_l000000ooonfX01Ol0003o
oo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000002oook
JP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_l00000
1OoonfX01?l0003ooo]Zo`000?l0000;oookJP07o`000?oonf[o0000oookJ_l0003ooo]Zo`000002
oookJP04o`000?oonf[ooo]ZoookJP;o00000ooonfX2o`0000Gooo]Z00?o0000oookJ_oonfX00_l0
0002oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l000000ooonf[o0000oookJP03oookJP04o`000?oo
nf[ooo]Zo`0000Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP05o`000?oonf[ooo]Zoook
J_l000000ooonfX2o`0000;ooo]Z0_l00006oookJP03o`000?oonf[o000000;o00003?oonfX2o`00
00Cooo]Z0ol00002oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000>oookJP03o`000?oonf[ooo]Z00;o00001_oonfX2
o`0000;ooo]Z0ol000001_oonf[o0000o`000?l0003ooo]Zo`0000[ooo]Z0_l00008oookJP;o0000
2OoonfX00ol0003ooo]ZoookJP03o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
1OoonfX3o`000003oookJ_l0003ooo]Z00;o00000_oonfX01_l0003ooo]ZoookJ_oonf[o0000oook
JQGo00002OoonfX7o`000003oookJ_l0003o000000;o000000Kooo]Zo`000?l0003ooo]Zo`000?oo
nfX2o`000003oookJ_l0003ooo]Z00;o000000Gooo]Zo`000?l0003o0000oookJP02o`000003oook
J_l0003ooo]Z00;o00000_oonfX01?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003o000000;o
oo]Z0_l000000ooonf[o0000oookJP03oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?oo
nf[o00001ooonfX01?l0003ooo]ZoookJ_l00007oookJP03o`000?oonf[o000000?ooo]Z00Co0000
oookJ_oonf[o00001?oonfX2o`000004oookJ_l0003ooo]ZoookJP;o00002ooonfX00ol0003ooo]Z
oookJP05oookJP;o00000ooonfX00ol0003ooo]Zo`00000<oookJP03o`000?oonf[ooo]Z01Cooo]Z
0_l000001Ooonf[o0000oookJ_l0003ooo]Z00Ko00000_oonfX3o`000006oookJ_l0003o0000oook
J_l0003ooo]Z0_l00002oookJP?o000000Gooo]Zo`000?oonf[o0000oookJP02o`000003oookJ_l0
003o000000?ooo]Z00Co0000oookJ_l0003o00000_oonfX3o`000003oookJ_l0003o000000?ooo]Z
0_l000001?oonf[o0000oookJ_oonfX2o`0000Wooo]Z1Ol000001Ooonf[o0000o`000?oonf[o0000
00Wooo]Z00?o0000oookJ_oonfX01OoonfX3o`0000Sooo]Z0Ol000000003o`000?oonf[o000000?o
oo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Cooo]Z00Co0000oookJ_l0003o00000_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l00000
1OoonfX01?l0003ooo]ZoookJ_l00005oookJP04o`000?oonf[ooo]Zo`0000cooo]Z00?o0000oook
J_oonfX00_oonfX01?l0003ooo]ZoookJ_l00003oookJP;o00000_oonfX2o`000003oookJ_l0003o
oo]Z00Cooo]Z00Go0000oookJ_l0003o0000oookJP03o`000006oookJ_l0003ooo]ZoookJ_l0003o
oo]Z0ol000000ooonf[o0000oookJP0:oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX03?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX00_oonfX01ol0003ooo]Zo`000?oonf[o0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03ooonfX01?l0003ooo]ZoookJ_l0
0003oookJP;o000000Gooo]Zo`000?oonf[o0000oookJP02o`00000<oookJ_l0003ooo]ZoookJ_l0
003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z0ol00003oookJP;o00000ooonfX<o`0000[ooo]Z
2Ol000000ooonf[o0000o`000003o`000004oookJ_l0003o0000oookJPCo00001?oonfX2o`0000Co
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP03o`000004oookJ_l0003ooo]Zo`00
00;ooo]Z00?o0000oookJ_l000002?oonfX01?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0001;ooo]Z0_l00006oookJP;o00002OoonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_l000000_oonfX0
0ol0003ooo]ZoookJP03o`000005oookJ_l0003o0000oookJ_l000000ooonfX3o`000004oookJ_l0
003o0000oookJP?o00000_oonfX00ol0003ooo]ZoookJP02o`000005oookJ_l0003ooo]ZoookJ_l0
00000_oonfX01?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003ooo]Z00Kooo]Z00?o0000oook
J_oonfX00_l00004oookJP04o`000?oonf[ooo]ZoookJP;o000000?ooo]Zo`000?oonfX01OoonfX0
0ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX01?oo
nfX01?l0003ooo]ZoookJ_l00008oookJP;o00002OoonfX1o`00000000?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0<oookJP08o`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l00005oook
JP03o`000?oonf[ooo]Z00Kooo]Z0_l00009oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z0_l00003
oookJP?o000000?ooo]Zo`000?l000000_oonfX00ol0003ooo]ZoookJP03o`0000;ooo]Z0_l00002
oookJPKo000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJPCo000000?ooo]Zo`000?oonfX00_oo
nfX01?l0003ooo]ZoookJ_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP02oookJP;o00004OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000Oooo]Z
00?o0000oookJ_oonfX02?oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z0_l00007oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Gooo]Z0_l00006oookJP04o`00
0?oonf[ooo]ZoookJPCo00001?oonfX00ol0003ooo]ZoookJP03oookJP?o000000?ooo]Zo`000?oo
nfX00_l000000ooonf[o0000oookJP04o`000004oookJ_l0003ooo]ZoookJP?o00001_oonfX2o`00
0004oookJ_l0003o0000oookJPKo00002ooonfX7o`000003oookJ_l0003o000000Oo000000?ooo]Z
o`000?l000000_l000001?oonf[o0000o`000?l00003oookJP?o000000?ooo]Zo`000?l000000_oo
nfX01Ol0003ooo]Zo`000?l0003ooo]Z00?o00000ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o
00000ooonfX4o`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Wooo]Z00?o0000oookJ_l000001OoonfX01?l0003ooo]ZoookJ_l00003oookJP04o`000?oonf[o
oo]Zo`0000Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP04o`000?oonf[ooo]ZoookJP;o
00000_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX04?oonfX3o`0000?ooo]Z0_l000001?oonf[o0000oookJ_oonfX5o`000003oookJ_l0003ooo]Z
00?o00001?oonfX3o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX2o`0000Oooo]Z00Co0000
oookJ_oonf[o00000_oonfX2o`000003oookJ_l0003o000000Oooo]Z0_l00002oookJP05o`000?oo
nf[ooo]ZoookJ_l000002_oonfX3o`0000;ooo]Z0_l0000AoookJP05o`000?oonf[ooo]ZoookJ_l0
00000_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000005o`000?oo
nf[ooo]ZoookJ_l000000_oonfX01?l0003ooo]ZoookJ_l00005oookJP;o000000_ooo]Zo`000?l0
003o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJP02o`000004oookJ_l0003ooo]Zo`0000Co
oo]Z0_l000000ooonf[o0000oookJP05oookJP;o000000?ooo]Zo`000?oonfX00ooonfX2o`000003
oookJ_l0003ooo]Z00Co000000Gooo]Zo`000?l0003o0000oookJP02o`000003oookJ_l0003ooo]Z
00Cooo]Z0ol00003oookJP04o`000?oonf[o0000oookJP;o00000ooonfX2o`0000?ooo]Z0_l00005
oookJP;o00000_oonfX01?l0003ooo]ZoookJ_l0000CoookJP03o`000?oonf[o000000gooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00[ooo]Z00Co
0000oookJ_oonf[o00001ooonfX01?l0003ooo]ZoookJ_l00004oookJP04o`000?oonf[o0000o`00
00Kooo]Z00Co0000oookJ_oonf[ooo]Z0_l00004oookJPCo00002_oonfX01?l0003ooo]ZoookJ_oo
nfX4o`000005oookJ_l0003o0000o`000?oonfX00_l00002oookJP04o`000?oonf[o0000o`0000Co
oo]Z1?l000001Ooonf[o0000o`000?l0003ooo]Z00ko00002ooonfX5o`000004oookJ_l0003o0000
o`0000;ooo]Z00Go0000oookJ_oonf[o0000oookJP06o`0000Cooo]Z00?o0000oookJ_l000000ooo
nfX2o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[o000000Cooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`000002oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003ooo]ZoookJ_l0000CoookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oookJP;o
00001OoonfX00ol0003ooo]ZoookJP0EoookJP;o00000ooonfX00ol0003ooo]ZoookJP06oookJP?o
00000_oonfX3o`0000Gooo]Z0_l000000ooonf[o0000o`000003o`0000Kooo]Z00Ko0000oookJ_oo
nf[ooo]Zo`000?oonfX4o`0000Wooo]Z0_l00006oookJP;o00001OoonfX2o`0000Kooo]Z0_l00009
oookJP;o00000ooonfX3o`0000?ooo]Z0_l000000ooonf[o0000oookJP03oookJP;o00002?oonfX0
0ol0003ooo]ZoookJP03oookJP7o000000000ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00;o000000Cooo]Zo`000?oonf[o00002OoonfX01?l0003ooo]Zo`000?l00007oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00Ko0000oookJ_oonf[ooo]Zo`000?oonfX2o`0000Kooo]Z1?l00002oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000004oookJP03
o`000?oonf[ooo]Z00;o000000?ooo]Zo`000?oonfX00_oonfX2o`0000;ooo]Z1_l00004oookJP03
o`000?oonf[o000000;o00000ooonfX2o`000003oookJ_l0003ooo]Z00Kooo]Z00?o0000oookJ_l0
00003ooonfX2o`0000Oooo]Z00Co0000oookJ_oonf[o00002?oonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]Zo`000004oook
JP;o00001ooonfX01?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_l000000ooonfX2o`0000Cooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP02
oookJP;o000000?ooo]Zo`000?l000001?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z00;o000000?ooo]Zo`000?oonfX00_l000001_oonf[o0000oookJ_oonf[o0000oookJP;o0000
00?ooo]Zo`000?l000001_l0000=oookJPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000
o`000005o`0000?ooo]Z0_l000001?oonf[o0000o`000?l00002oookJPCo000000?ooo]Zo`000?l0
00001OoonfX01?l0003ooo]ZoookJ_l00003oookJP?o00000_oonfX01?l0003ooo]ZoookJ_l00002
oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?oonf[ooo]Z0_l00002oookJP?o000000?o
oo]Zo`000?l000001OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000Kooo]Z00Co
0000oookJ_oonf[o00001_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o000000Co0000
00Cooo]Zo`000?oonf[ooo]Z1?l00002oookJPCo00000_oonfX2o`000006oookJ_l0003o0000oook
J_l0003ooo]Z0ol00002oookJP;o00000ooonfX2o`0000;ooo]Z00?o0000oookJ_l000001?oonfX2
o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Co
0000oookJ_oonf[o00000ooonfX01?l0003ooo]ZoookJ_l00005oookJP05o`000?oonf[o0000oook
J_l000001?oonfX2o`0000;ooo]Z0ol00002oookJP;o00000_oonfX2o`000003oookJ_l0003ooo]Z
00?ooo]Z0Ol000000003o`000?oonf[ooo]Z00;o00002OoonfX01ol0003ooo]ZoookJ_oonf[o0000
oookJ_l000001?oonfX01Ol0003ooo]Zo`000?oonf[o000000Gooo]Z0_l000000ooonf[o0000oook
JP02o`0000;ooo]Z00?o0000oookJ_oonfX01_l000000ooonf[o0000oookJP02oookJP;o000000?o
oo]Zo`000?oonfX00ol00002oookJP;o00000ooonfX01Ol0003ooo]Zo`000?oonf[o000000;ooo]Z
00Wo0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX01?l0003ooo]ZoookJ_oo
nfX2o`0000;ooo]Z0_l000001?oonf[o0000o`000?l00002oookJP05o`000?oonf[ooo]Zo`000?oo
nfX01Ol0000SoookJP;o000000?ooo]Zo`000?oonfX05OoonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00Oooo]Z00Go0000oookJ_l0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]Z
o`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX01ol0003ooo]Zo`000?l0003ooo]Zo`000?oonfX0
0ol00002oookJP;o00000ooonfX01_l0003ooo]Zo`000?oonf[o0000oookJP;o000000Kooo]Zo`00
0?l0003ooo]Zo`000?oonfX5o`0000gooo]Z1?l000000ooonf[o0000o`000002o`000004oookJ_l0
003o0000o`0000?ooo]Z00?o0000oookJ_l000001?l000001Ooonf[o0000oookJ_l0003ooo]Z00?o
00001?oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_l000000ol0000>oookJP05
o`000?oonf[ooo]ZoookJ_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o0000
oookJ_oonfX00_l000001_oonf[o0000oookJ_l0003ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000008oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX03?oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z1ol00002oookJP04o`000?oonf[o
oo]Zo`0000?ooo]Z1Ol00002oookJP;o000000?ooo]Zo`000?l000000_oonfX2o`0000?ooo]Z00?o
0000oookJ_l000000_l000001?oonf[o0000oookJ_oonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0
0_oonfX01Ol0003ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01_oonfX01?l0003o
oo]ZoookJ_l00002oookJP?o00001_oonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_l000001_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSko
oo]Z0Ol000000003o`000?oonf[ooo]Z00;o00000ooonfX00ol0003ooo]ZoookJP0:oookJP03o`00
0?oonf[o000000?ooo]Z00Go0000oookJ_l0003o0000oookJP04o`00017ooo]Z00Oo0000oookJ_oo
nf[ooo]Zo`000?oonf[o000000;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l000000ooonf[o0000o`00
0003oookJP?o00000_oonfX00ol0003ooo]Zo`000003oookJP04o`000?oonf[o0000oookJPOo0000
00Kooo]Zo`000?l0003o0000oookJ_l00002oookJPKo000000Cooo]Zo`000?oonf[ooo]Z0ol00007
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oo
nf[o000000Oooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]Zo`000?l0000=oookJP;o0000
1ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
1ooonfX01?l0003ooo]Zo`000?l0000;oookJP03o`000?oonf[o000000Cooo]Z0_l00002oookJP;o
000000?ooo]Zo`000?oonfX00ooonfX2o`0000?ooo]Z00?o0000oookJ_l000001?oonfX3o`000003
oookJ_l0003ooo]Z00co00003ooonfX3o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l0
00001ol00004oookJP07o`000?oonf[o0000oookJ_l0003ooo]Zo`000005oookJP;o00001ooonfX2
o`000003oookJ_l0003o000000Oooo]Z00Co0000oookJ_oonf[o00001?oonfX01Ol0003ooo]Zoook
J_oonf[o000000[ooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_l000002OoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o000000;o
00000_oonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[o000000?o00000_oonfX3o`000003
oookJ_l0003o000000?o000000Cooo]Zo`000?l0003o00000_oonfX5o`000003oookJ_l0003ooo]Z
00Oooo]Z00?o0000oookJ_oonfX01?oonfX01ol0003ooo]Zo`000?l0003ooo]Zo`000?oonfX01?l0
00000ooonf[o0000oookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z00Co0000oookJ_oonf[o0000
1_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Oooo]Z0Ol000000004o`000?oo
nf[ooo]ZoookJP;o000000?ooo]Zo`000?oonfX00_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX0
1?oonfX02?l0003ooo]ZoookJ_l0003ooo]Zo`000?oonf[o00001ooonfX01Ol0003ooo]ZoookJ_l0
003ooo]Z00;o00003?oonfX00ol0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00;o00001Ooo
nfX00ol0003ooo]ZoookJP03o`000003oookJ_l0003o000000;o00002?oonfX00ol0003ooo]Zo`00
0003o`000003oookJ_l0003o000000?ooo]Z00?o0000oookJ_l000001_l0000EoookJP;o00002Ooo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01Ooo
nfX01Ol0003ooo]Zo`000?oonf[o000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP03
o`000?oonf[ooo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zo`000009oookJP04o`000?oonf[ooo]Z
o`0000Gooo]Z00?o0000oookJ_l000001OoonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0_l0
00000ooonf[o0000o`000002o`000003oookJ_l0003ooo]Z00Co000000Cooo]Zo`000?l0003o0000
0_oonfX2o`000003oookJ_l0003o000000Oo00003ooonfX=o`000003oookJ_l0003ooo]Z00Co0000
00?ooo]Zo`000?l000000_oonfX00ol0003ooo]ZoookJP03o`0000;ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o000000?ooo]Z0_l000001Ooonf[o0000
oookJ_oonf[o000000Oooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000?ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000=oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000000ooonfX01Ol0
003ooo]ZoookJ_oonf[o000000[ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`000004
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000;ooo]Z1?l000000ooonf[o0000o`000002oookJP;o00001_oonfX2o`0000Cooo]Z00Co
0000oookJ_l0003o00000_oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]Zo`000?oo
nfX00ol000001_oonf[o0000oookJ_oonf[o0000oookJP;o000000?ooo]Zo`000?oonfX00ooonfX2
o`0000Sooo]Z00?o0000oookJ_oonfX00ol00003oookJP;o000000Gooo]Zo`000?oonf[o0000oook
JP02o`0000Cooo]Z0ol00003oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000001?oo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000?ooo]Z0Ol000000003o`000?oonf[o
000000?ooo]Z00Co0000oookJ_l0003o00004OoonfX01?l0003ooo]Zo`000?l00006oookJP05o`00
0?oonf[ooo]ZoookJ_l000000ooonfX2o`0000;ooo]Z00Co0000oookJ_oonf[o00000_oonfX01_l0
003ooo]ZoookJ_oonf[o0000oookJP;o000000?ooo]Zo`000?oonfX00_oonfX2o`0000Kooo]Z00?o
0000oookJ_oonfX00_l00003oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX<o`000006oook
J_l0003o0000oookJ_l0003ooo]Z1_l0000?oookJP;o00002_oonfX00ol0003ooo]ZoookJP02o`00
00Cooo]Z0_l00004oookJP?o00001ooonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP06oookJP05o`000?oonf[ooo]Z
o`000?oonfX00_l00002oookJP03o`000?oonf[ooo]Z00Cooo]Z1?l00008oookJP04o`000?oonf[o
oo]Zo`0000Kooo]Z0_l00004oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_l000000ol0
00001?oonf[o0000o`000?l00003oookJPWo00004OoonfX4o`000005oookJ_l0003o0000o`000?oo
nfX01_l00002oookJP[o000000?ooo]Zo`000?l000000_l000001?oonf[o0000o`000?l00003oook
JP?o00000_oonfX02Ol0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000006oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP04o`00
0?oonf[ooo]Zo`0000Cooo]Z0_l00002oookJP04o`000?oonf[ooo]Zo`0000_ooo]Z0_l00007oook
JP03o`000?oonf[o000000Gooo]Z00Co0000oookJ_l0003o00003ooonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00004oookJP;o00000ooonfX2o`0000[ooo]Z1_l00004
oookJP03o`000?oonf[o000000;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_oonfX2o`0000Cooo]Z00Co0000oookJ_oonf[o0000
0_oonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z00Ko0000oookJ_oo
nf[ooo]Zo`000?oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_oo
nfX2o`000003oookJ_l0003ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ooonfX1o`00000000?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP;o00000_oonfX01?l0003ooo]Zo`000?l0
0002oookJP07o`000?oonf[o0000oookJ_l0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]Zo`000?l00002oookJP;o00000ooonfX2o`00
0003oookJ_l0003ooo]Z00Cooo]Z0_l00002oookJP07o`000?oonf[o0000o`000?oonf[o0000oook
JP02o`0000;ooo]Z0_l000001?oonf[o0000o`000?l00002oookJPKo000000?ooo]Zo`000?l00000
0_l00007oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_l000001?oonf[o0000
oookJ_l00007oookJP;o00001?oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01OoonfX3o`0000Go
oo]Z00?o0000oookJ_oonfX01ooonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o00002OoonfX0
0ol0003ooo]ZoookJP05oookJP;o00001ooonfX2o`0000;ooo]Z00Co0000oookJ_l0003o00000_oo
nfX2o`000004oookJ_l0003ooo]Zo`0000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l000002?oonf[o
0000oookJ_oonf[o0000oookJ_l0003ooo]Z0_l00002oookJPgo00004OoonfX@o`0000?ooo]Z00?o
0000oookJ_oonfX00_l00004oookJP;o00000_oonfX2o`0000Cooo]Z0_l00003oookJP04o`000?oo
nf[ooo]Zo`0000Kooo]Z0_l000001?oonf[o0000o`000?l0000:oookJP?o00000ooonfX00ol0003o
oo]ZoookJP04oookJP06o`000?oonf[o0000o`000?oonf[o00000_oonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02?oonfX01Ol0003ooo]ZoookJ_l0
003ooo]Z00;o00000_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o00000_oonfX00ol0003ooo]Z
o`00000FoookJP;o000000Gooo]Zo`000?l0003o0000oookJP02o`000005oookJ_l0003o0000o`00
0?oonfX00_l000000ooonf[o0000o`000004o`000003oookJ_l0003o000000?ooo]Z00Go0000oook
J_oonf[ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ooonfX2
o`0000;ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00003oookJPCo000000?ooo]Zo`000?oonfX0
2?oonfX3o`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?l000001_oonfX2o`0000Gooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP;o00000_oonfX1o`00000000?o
0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z0_l00002oookJP;o00000_oonfX4
o`000004oookJ_l0003o0000o`0000[ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oookJP;o0000
0_oonfX01?l0003ooo]Zo`000?l0000>oookJPCo000000Cooo]Zo`000?oonf[ooo]Z0_l00002oook
JP;o000000Cooo]Zo`000?l0003o00001?oonfX00ol0003ooo]Zo`000005oookJP04o`000?oonf[o
0000oookJPCo00002_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Wooo]Z00Ko
0000oookJ_oonf[o0000oookJ_l00006oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX00ooonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX00_oonfX2o`0000?ooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_l000000_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?o000000Cooo]Zo`00
0?oonf[ooo]Z0_l00002oookJPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000008
o`0001;ooo]Z1_l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000?o00000_oonfX5
o`0000Gooo]Z00Go0000oookJ_l0003o0000oookJP02o`0000;ooo]Z00?o0000oookJ_l000002?oo
nfX01?l0003ooo]ZoookJ_l00006oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o000000?ooo]Z0ol00003oookJP03o`00
0?oonf[ooo]Z00;ooo]Z0_l00003oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000004oook
JP03o`000?oonf[o000000;ooo]Z0_l00002oookJP?o000000?ooo]Zo`000?l000000ooonfX6o`00
0004oookJ_l0003ooo]Zo`0000Cooo]Z00Co0000oookJ_oonf[o00002_oonfX00ol0003ooo]Zoook
JP07oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000Go
oo]Z0ol00004oookJP03o`000?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP02oookJP04o`00
0?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000003oookJP05
o`000?oonf[ooo]ZoookJ_l000000_oonfX2o`0000gooo]Z0_l00005oookJP04o`000?oonf[ooo]Z
oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`00000?oookJP06o`000?oonf[o0000o`000?oonf[o
00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Go0000oookJ_oonf[o0000oookJP02
o`0000Gooo]Z0_l000000ooonf[o0000oookJP02oookJP?o00000_oonfX3o`0000cooo]Z00Co0000
oookJ_oonf[o00000ooonfX00ol0003ooo]ZoookJP09oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z
00?o0000oookJ_oonfX00_oonfX02?l0003ooo]ZoookJ_l0003ooo]Zo`000?oonf[o00000_oonfX0
0ol0003ooo]ZoookJP04oookJP;o00000_oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX00ooonfX0
2Ol0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000005oookJP07o`000?oonf[ooo]Zo`00
0?oonf[o0000oookJP02o`000004oookJ_l0003o0000oookJP;o00000_oonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol000000ooonf[o0000oookJP03o`000003oookJ_l0003ooo]Z00;o000000Cooo]Zo`000?l0
003ooo]Z2Ol0000CoookJPco000000Gooo]Zo`000?l0003o0000oookJP02o`0000;ooo]Z0_l00000
0ooonf[o0000o`000002oookJP;o000000?ooo]Zo`000?l000002OoonfX01?l0003ooo]ZoookJ_l0
0004oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ooonfX2o`000003oookJ_l0
003o000000Cooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]Zo`000006oookJP03o`000?oo
nf[ooo]Z017ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]Zo`00000:oookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP03oookJPCo00001?oo
nfX00ol0003ooo]Zo`000004oookJP?o000000Oooo]Zo`000?l0003o0000oookJ_l0003ooo]Z00;o
000000?ooo]Zo`000?l000000_l00003oookJP03o`000?oonf[o000000?ooo]Z00Co0000oookJ_oo
nf[o00000_oonfX3o`0000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00003oookJP;o00000ooonfX0
0ol0003ooo]ZoookJP02o`0000Cooo]Z00?o0000oookJ_oonfX01_oonfX01_l0003ooo]ZoookJ_l0
003ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX04ooonfX1o`00000000?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP02oookJP06o`000?oonf[ooo]Zo`000?oonf[o00001ooonfX01?l0003o
oo]Zo`000?l00002oookJP09o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z
1Ol00002oookJP;o00001?oonfX00ol0003ooo]ZoookJP07oookJP;o000000?ooo]Zo`000?oonfX0
0ooonfX4o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX2o`0000Cooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]Zo`000003o`000003oookJ_l0003ooo]Z00Gooo]Z0_l000000ooonf[o
0000oookJP05oookJP;o00001OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oook
J_l000002?oonfX00ol0003ooo]ZoookJP02oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000ooo
nfX2o`0000?ooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP07oookJP04o`000?oo
nf[ooo]Zo`0000Gooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`000?l00000
0_oonfX00ol0003ooo]Zo`000003o`000003oookJ_l0003o000000Ko00005?oonfX7o`000003oook
J_l0003o000000Go000000?ooo]Zo`000?l000000ooonfX00ol0003ooo]ZoookJP03o`0000;ooo]Z
0_l00002oookJPCo000000Cooo]Zo`000?oonf[o00000ooonfX2o`0000;ooo]Z00Oo0000oookJ_oo
nf[ooo]Zo`000?oonf[o000000_ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000[ooo]Z
00Co0000oookJ_oonf[o00001OoonfX00ol0003ooo]Zo`00000FoookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP05oookJP;o00002_oonfX01?l0003o
oo]ZoookJ_oonfX2o`0000?ooo]Z00Co0000oookJ_oonf[o00000_oonfX4o`0000Gooo]Z0ol00000
1?oonf[o0000oookJ_oonfX3o`000005oookJ_l0003o0000oookJ_l000000_oonfX3o`0000?ooo]Z
0_l00005oookJP04o`000?oonf[o0000o`0000Kooo]Z00Co0000oookJ_l0003o00000ooonfX2o`00
00?ooo]Z00?o0000oookJ_oonfX03?oonfX01?l0003ooo]Zo`000?l00007oookJP03o`000?oonf[o
000000Cooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]Zo`000005oookJP7o000000000ol0
003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_l000000ooonfX01?l0003o
oo]ZoookJ_l00002oookJP;o00000_oonfX00ol0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z
00;o00000ooonfX00ol0003ooo]ZoookJP06oookJP07o`000?oonf[ooo]Zo`000?oonf[o0000oook
JP03o`000003oookJ_l0003ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP02oookJP;o000000Sooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`0000;ooo]Z1Ol000000ooo
nf[o0000o`00000:oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX3o`00013ooo]Z00?o0000
oookJ_oonfX01OoonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]Zo`00000BoookJP03o`000?oonf[ooo]Z00oooo]Z0_l00006oookJPGo00000_oo
nfX00ol0003ooo]ZoookJP08oookJP04o`000?oonf[ooo]ZoookJP;o00001?oonfX2o`0000Sooo]Z
00Co0000oookJ_oonf[ooo]Z1?l00002oookJPOo000000?ooo]Zo`000?l000001_l0000EoookJPWo
00001?oonfX4o`000003oookJ_l0003ooo]Z00;ooo]Z0_l000001Ooonf[o0000oookJ_oonf[o0000
00;ooo]Z00Co0000oookJ_l0003o00000_oonfX00ol0003ooo]Zo`000003oookJP?o00001_oonfX2
o`0000?ooo]Z00Co0000oookJ_oonf[o00001_oonfX2o`0000Cooo]Z0_l00003oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000002oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oookJP03o`000?oonf[o000000Cooo]Z
00?o0000oookJ_l000000_l00008oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l00002oookJP03o`00
0?oonf[o000000;ooo]Z1?l00002oookJP;o00001OoonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z
0_l00002oookJP03o`000?oonf[o000000gooo]Z1?l00007oookJP;o000000Cooo]Zo`000?oonf[o
00001_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000;ooo]Z00Ko0000oookJ_oo
nf[ooo]Zo`000?oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX02?oonfX2o`000004oookJ_l0003o
oo]ZoookJP7o000000000ol0003ooo]ZoookJP04oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00Co
0000oookJ_oonf[ooo]Z0ol00003oookJP;o00000_oonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_l000001ooonfX01?l0003ooo]ZoookJ_oonfX2o`000003
oookJ_l0003o000000;ooo]Z00?o0000oookJ_l000001?l000000ooonf[o0000oookJP02o`0000?o
oo]Z00Ko0000oookJ_oonf[ooo]Zo`000?oonfX2o`0000;ooo]Z00Ko0000oookJ_l0003o0000oook
J_l00002oookJP03o`000?oonf[ooo]Z00?o00000_oonfX4o`0000;ooo]Z0ol000000ooonf[o0000
oookJP03oookJP03o`000?oonf[ooo]Z00gooo]Z0_l000000ooonf[o0000oookJP0@oookJP03o`00
0?oonf[o000000Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP05o`00
0?oonf[o0000oookJ_l000000ooonfX2o`0000?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0
003ooo]Zo`000?oonf[o000000?ooo]Z0_l000001?oonf[o0000o`000?oonfX2o`000003oookJ_l0
003ooo]Z00;o00000_oonfX01?l0003ooo]Zo`000?oonfX2o`000004oookJ_l0003ooo]ZoookJP;o
000000?ooo]Zo`000?oonfX02Ol0000FoookJPWo000000?ooo]Zo`000?l000001?oonfX2o`000005
oookJ_l0003ooo]Zo`000?oonfX00_l00003oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l00000
1?oonf[o0000o`000?l00006oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX00ol0003ooo]Z
oookJP02o`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Oooo]Z00?o0000oookJ_l00000
1?oonfX00ol0003ooo]ZoookJP02o`000004oookJ_l0003ooo]Zo`0000;ooo]Z0_l0000>oookJP04
o`000?oonf[ooo]Zo`0000Oooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Gooo]Z00Go0000oook
J_l0003ooo]Zo`000005oookJP03o`000?oonf[o000000Cooo]Z0ol00002oookJP03o`000?oonf[o
oo]Z00?o00000_oonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[o0000oookJP;o000000?o
oo]Zo`000?l000000_l00003oookJP05o`000?oonf[o0000o`000?oonfX00ol00003oookJP03o`00
0?oonf[ooo]Z00;o000000Cooo]Zo`000?l0003o00000ooonfX01?l0003ooo]ZoookJ_oonfX3o`00
00;ooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o00000ooonfX0
1?l0003ooo]Zo`000?l00005oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_l0003o0000
0_oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX00ooonfX1o`00000000Co0000oookJ_l0003o0000
3OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;o00000_oonfX01_l0003ooo]Z
oookJ_l0003ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Cooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z00?o0000oookJ_l000000_oonfX00ol0
003ooo]Zo`000003oookJP03o`000?oonf[o000000?ooo]Z2ol00002oookJP?o000000?ooo]Zo`00
0?oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`00
0?oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP;o00003?oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zo`000002o`00
00Oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP08oookJP;o00000_oonfX2o`00
00;ooo]Z00Wo0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000001?oonfX00ol0003ooo]Z
o`000002o`000004oookJ_l0003o0000o`0000Sooo]Z00Co0000oookJ_oonf[o00000ooonfX2o`00
0004oookJ_l0003o0000o`0000;ooo]Z1?l000001ooonf[o0000o`000?oonf[o0000oookJ_l00000
0_oonfX7o`0001Oooo]Z2Ol000001_oonf[o0000o`000?oonf[o0000oookJP;o000000Oooo]Zo`00
0?oonf[ooo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]Zoook
J_l00006oookJP07o`000?oonf[o0000oookJ_l0003ooo]Zo`000006oookJP?o00003_oonfX3o`00
00cooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00003oookJP03o`000?oonf[ooo]Z00Sooo]Z00Co
0000oookJ_oonf[o00002_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00;ooo]Z
00Co0000oookJ_oonf[o00001OoonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o00000ooonfX0
1?l0003ooo]Zo`000?l00006oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z1_l000000ooonf[o0000
o`000002o`0000Gooo]Z0_l000000ooonf[o0000o`000003oookJP04o`000?oonf[ooo]Zo`0000;o
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX01_oonfX2o`0000Wooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]Zo`000002oookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX00Ol000000003o`00
0?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP05oookJP07o`000?oo
nf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l000000ooo
nf[o0000o`000002oookJP;o00001_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX2o`00
0003oookJ_l0003o000000;ooo]Z00Co0000oookJ_oonf[o00001?oonfX01Ol0003ooo]Zo`000?l0
003ooo]Z00;o000000Gooo]Zo`000?l0003o0000oookJP02o`000005oookJ_l0003o0000oookJ_l0
00000ooonfX5o`000004oookJ_l0003o0000oookJP?o00001?oonfX00ol0003ooo]ZoookJP02oook
JP;o00001_oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_l000000_oonfX01Ol0
003ooo]ZoookJ_oonf[o000000kooo]Z00Go0000oookJ_oonf[ooo]Zo`000007oookJP05o`000?oo
nf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o000000Oooo]Z
00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP02oookJP;o000000?ooo]Zo`000?oonfX0
0ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o000000Oooo]Z0ol00003oookJP;o0000
0_oonfX01?l0003ooo]ZoookJ_l00002oookJP;o00000ooonfX00ol0003ooo]Zo`000005oookJP05
o`000?oonf[o0000oookJ_l000000_oonfX01?l0003ooo]ZoookJ_oonfX7o`0000;ooo]Z0_l00000
0ooonf[o0000o`000003o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`000003oookJ_l0003o
oo]Z00;o000000?ooo]Zo`000?l000000_l00002oookJP;o000000?ooo]Zo`000?oonfX01ooonfX2
o`0000cooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00;o00000ooonfX01_l0003ooo]ZoookJ_oo
nf[o0000oookJP;o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]Zo`000009oookJP;o0000
2OoonfX00ol0003ooo]ZoookJP09oookJP04o`000?oonf[o0000o`0000Wooo]Z00?o0000oookJ_oo
nfX03OoonfX00ol0003ooo]ZoookJP04oookJP04o`000?oonf[ooo]Zo`0000Sooo]Z0ol000000ooo
nf[o0000oookJP09oookJP06o`000?oonf[o0000o`000?oonf[o00000ooonfX2o`000003oookJ_l0
003o000000;ooo]Z0ol000000ooonf[o0000o`000002oookJPGo00002OoonfX00ol0003ooo]Zo`00
0005oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?oonf[o00000_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000?ooo]Z0_l00002oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l000001_oonf[o
0000oookJ_oonf[o0000oookJP7o000000001?l0003ooo]ZoookJ_oonfX2o`0000Gooo]Z00Co0000
oookJ_oonf[o00000ooonfX01?l0003ooo]ZoookJ_l00003oookJP;o00000_oonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00005oookJP03o`000?oonf[o000000?ooo]Z
0_l00003oookJP;o00001_oonfX00ol0003ooo]Zo`000002oookJP06o`000?oonf[o0000o`000?oo
nf[o00001OoonfX3o`000004oookJ_l0003o0000oookJP;o000000Cooo]Zo`000?l0003ooo]Z0_l0
000;oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o
000000Kooo]Zo`000?oonf[o0000oookJ_l0000:oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]Zo`000002oookJP05o`000?oonf[ooo]ZoookJ_l000002?oo
nfX01_l0003ooo]ZoookJ_oonf[o0000oookJP?o00001OoonfX00ol0003ooo]ZoookJP06oookJP;o
00000_oonfX01?l0003ooo]ZoookJ_oonfX3o`0000?ooo]Z1?l00003oookJP03o`000?oonf[o0000
00Gooo]Z00?o0000oookJ_l000001?oonfX3o`000005oookJ_l0003ooo]Zo`000?oonfX01ol0000I
oookJPOo000000?ooo]Zo`000?l000000_l00002oookJP03o`000?oonf[o000000;o00000ooonfX0
1Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z00Go0000oookJ_oonf[o0000oookJP02o`0000;ooo]Z
00Ko0000oookJ_l0003ooo]Zo`000?oonfX2o`0000;ooo]Z0_l000000ooonf[o0000oookJP04oook
JP;o00002ooonfX01?l0003ooo]ZoookJ_l00007oookJP04o`000?oonf[o0000o`0000cooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX00_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX03?oonfX2o`0000?ooo]Z0_l0
00001Ooonf[o0000o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX02OoonfX6o`000005oook
J_l0003ooo]Zo`000?oonfX01?l000001_oonf[o0000oookJ_oonf[o0000oookJP;o000000Kooo]Z
o`000?oonf[ooo]Zo`000?oonfX2o`0000Oooo]Z00Co0000oookJ_oonf[ooo]Z0_l000000ooonf[o
0000o`000002o`0000Cooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003ooo]ZoookJP03oook
JP04o`000?oonf[ooo]Zo`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oo
nf[ooo]Z00?o00000ooonfX00ol0003ooo]ZoookJP05oookJP7o000000001?l0003ooo]ZoookJ_l0
0002oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_l0003o00000ooonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00;o00000_oonfX01Ol0003ooo]Zo`000?oonf[o000000;o
oo]Z0_l00002oookJP03o`000?oonf[o000000Kooo]Z0_l00002oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z0_l00002oookJP?o00001?oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0_l00000
1Ooonf[o0000o`000?l0003ooo]Z00?o00000_oonfX3o`0000Gooo]Z0_l00007oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00Go0000oookJ_l0003o0000oookJP02o`0000gooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP08oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00Ko0000oookJ_oo
nf[o0000oookJ_l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00002?oo
nfX02?l0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Z0_l00003oookJP03o`000?oonf[o0000
00Cooo]Z00?o0000oookJ_oonfX00_oonfX2o`000003oookJ_l0003o000000?ooo]Z00Go0000oook
J_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_l00003
oookJP07o`000?oonf[o0000o`000?oonf[o0000oookJP05o`000003oookJ_l0003ooo]Z00Oo0000
6OoonfX9o`000004oookJ_l0003o0000o`0000Cooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o
0000o`000003oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01?oonfX01_l0
003ooo]ZoookJ_l0003ooo]Zo`0000;ooo]Z00Co0000oookJ_oonf[o00001ooonfX01Ol0003ooo]Z
oookJ_oonf[o000000_ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00003oook
JP03o`000?oonf[o000000Co000000Cooo]Zo`000?oonf[ooo]Z0ol00002oookJP05o`000?oonf[o
0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02o`000003oookJ_l0003o000000Kooo]Z0_l0
0002oookJP06o`000?oonf[o0000oookJ_l0003ooo]Z0_l000000ooonf[o0000o`000004oookJP04
o`000?oonf[o0000o`0000?ooo]Z0_l00003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Go0000
oookJ_oonf[ooo]Zo`000003oookJP04o`000?oonf[ooo]ZoookJPCo00001ooonfX00ol0003ooo]Z
oookJP02oookJP;o000000?ooo]Zo`000?oonfX00ol000001?oonf[o0000oookJ_oonfX2o`0000?o
oo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000Co0000oookJ_oonf[o00000ooonfX3o`0000Wo
oo]Z00Ko0000oookJ_oonf[ooo]Zo`000?oonfX2o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0005oookJP04o`000?oonf[o0000oookJP?o00000_oonfX00ol0003ooo]ZoookJP05oookJP;o0000
00Kooo]Zo`000?oonf[o0000oookJ_l00004oookJP08o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00
0?oonfX2o`0000;ooo]Z0_l00002oookJP03o`000?oonf[o000000;o00000_oonfX4o`0000;ooo]Z
00?o0000oookJ_l000001ooonfX3o`0000;ooo]Z00?o0000oookJ_l000000ol000001?oonf[o0000
oookJ_l00006oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l00008oookJP03o`000?oonf[ooo]Z01[o
oo]Z00Co0000oookJ_oonf[ooo]Z0_l00004oookJP03o`000?oonf[ooo]Z00Gooo]Z00Oo0000oook
J_oonf[ooo]Zo`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX00ooonfX01Ol0003ooo]Zoook
J_oonf[o000000Kooo]Z0_l000000ooonf[o0000oookJP02oookJP;o00000_oonfX01Ol0003ooo]Z
oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?oonfX00ol000001_oonf[o0000oookJ_l0003ooo]Z
o`0000Cooo]Z00?o0000oookJ_l000001?l000000ooonf[o0000o`000009o`0001[ooo]Z2Ol00002
oookJP03o`000?oonf[o000000;o000000?ooo]Zo`000?oonfX00_oonfX2o`000004oookJ_l0003o
oo]Zo`0000;ooo]Z0_l00003oookJP03o`000?oonf[o000000Cooo]Z0_l00008oookJP;o00000_oo
nfX01?l0003ooo]Zo`000?oonfX2o`0000Kooo]Z0ol00002oookJP03o`000?oonf[o000000gooo]Z
00?o0000oookJ_oonfX00ooonfX01Ol0003ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Sooo]Z00Co0000oookJ_oo
nf[o00001OoonfX00ol0003ooo]ZoookJP0<oookJPCo000000?ooo]Zo`000?oonfX00ol00006oook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?l000001ooonf[o0000oookJ_oonf[o
0000oookJ_l000001?oonfX00ol0003ooo]Zo`000003oookJP;o00000_oonfX00ol0003ooo]Zo`00
0007oookJP?o00003ooonfX01?l0003ooo]ZoookJ_l00002oookJP04o`000?oonf[o0000o`0000Wo
oo]Z00Co0000oookJ_oonf[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX00Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000001Ol0003ooo]Z
o`000?oonf[o000000;ooo]Z00?o0000oookJ_l000000_l00003oookJP03o`000?oonf[o000000So
oo]Z00?o0000oookJ_oonfX00_l00003oookJP05o`000?oonf[o0000oookJ_l000000ooonfX2o`00
00?ooo]Z00?o0000oookJ_oonfX00_oonfX2o`000003oookJ_l0003o000000;ooo]Z0_l000000ooo
nf[o0000o`000004oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP;o00001?oo
nfX6o`000003oookJ_l0003o000000;o000000Gooo]Zo`000?l0003ooo]Zo`000005oookJP03o`00
0?oonf[o000000Co00000_oonfX2o`000005oookJ_l0003ooo]Zo`000?oonfX00ol00003oookJP03
o`000?oonf[o000000Kooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002oookJP03o`000?oonf[o
oo]Z00Oooo]Z00?o0000oookJ_l000002?oonfX01?l0003ooo]ZoookJ_l0000EoookJP05o`000?oo
nf[o0000oookJ_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0_l00003oookJP03
o`000?oonf[ooo]Z00Oooo]Z00Co0000oookJ_oonf[o00001OoonfX3o`0000Oooo]Z00Go0000oook
J_oonf[o0000oookJP03o`0000?ooo]Z00?o0000oookJ_l000001_l00005oookJPCo000000?ooo]Z
o`000?oonfX01Ol0000KoookJPCo000000Gooo]Zo`000?l0003o0000oookJP02o`0000;ooo]Z1?l0
0002oookJP?o000000Cooo]Zo`000?l0003ooo]Z0_l000001?oonf[o0000oookJ_l00002oookJP;o
000000Cooo]Zo`000?oonf[o00002?oonfX01?l0003ooo]ZoookJ_l00004oookJP;o00000ooonfX0
1Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_l000002OoonfX01?l0003ooo]Zoook
J_oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[o
00001OoonfX00ol0003ooo]ZoookJP08oookJP04o`000?oonf[o0000oookJP?o00000_oonfX2o`00
00Gooo]Z0_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_l000000ol00004oookJPGo000000?ooo]Zo`000?l000000ol00002oookJP05o`000?oonf[ooo]Z
oookJ_l000000_oonfX00ol0003ooo]ZoookJP03o`000004oookJ_l0003o0000oookJP;o00001?oo
nfX2o`0000?ooo]Z00Co0000oookJ_oonf[o00001?oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`00
00Cooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00;o000000Gooo]Zo`000?oonf[ooo]Zo`000006
oookJP7o000000001Ol0003ooo]Zo`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP02o`0000;ooo]Z0_l00002oookJP;o00000_oonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00003oookJP;o00001ooonfX2o`0000Kooo]Z00?o0000
oookJ_oonfX00_l00002oookJP05o`000?oonf[o0000oookJ_l000000ooonfX3o`0000;ooo]Z00Co
0000oookJ_l0003ooo]Z1?l000000ooonf[o0000o`000005oookJP?o00000ooonfX3o`000003oook
J_l0003o000000?ooo]Z0ol000001?oonf[o0000o`000?oonfX2o`0000?ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000005?oonfX3o`00
00_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_l000001ooonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000_oo
nfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o00000ooonfX5o`000003oookJ_l0003ooo]Z00;o
000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000004oookJP;o000000?ooo]Zo`000?l0
00001_l0000LoookJPWo000000Cooo]Zo`000?oonf[ooo]Z0ol00003oookJP;o00000_oonfX01ol0
003ooo]ZoookJ_oonf[o0000oookJ_l000001OoonfX01?l0003ooo]Zo`000?l00002oookJP04o`00
0?oonf[ooo]ZoookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`00
00?ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Kooo]Z0_l00002oookJP06o`000?oonf[ooo]Zo`000?oonf[o00001_oonfX01?l0003ooo]Zoook
J_l00002oookJP03o`000?oonf[ooo]Z013ooo]Z00So0000oookJ_oonf[o0000oookJ_l0003ooo]Z
o`0000cooo]Z00?o0000oookJ_l000000_l00003oookJP;o00000_oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00cooo]Z0_l000001?oonf[o0000o`000?oonfX4o`0000?ooo]Z0_l0
000=oookJP03o`000?oonf[o000000Gooo]Z00Co0000oookJ_oonf[ooo]Z0ol00002oookJP03o`00
0?oonf[ooo]Z00Gooo]Z00Ko0000oookJ_l0003o0000oookJ_l00008oookJP?o00000ooonfX00ol0
003ooo]ZoookJP0AoookJP7o000000001?l0003ooo]Zo`000?l00002oookJP03o`000?oonf[o0000
00?ooo]Z0_l000001?oonf[o0000o`000?l00002oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l0
0002oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Oooo]Z00Co
0000oookJ_oonf[ooo]Z0ol000001?oonf[o0000oookJ_l00003oookJP;o00000_oonfX00ol0003o
oo]ZoookJP0<oookJP;o00001OoonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;o
oo]Z0_l00006oookJPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000004o`0000Oo
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o000000So
oo]Z00?o0000oookJ_oonfX03_oonfX01?l0003ooo]ZoookJ_l00003oookJP04o`000?oonf[ooo]Z
o`0000gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[o
0000o`000?oonfX00_l000002Ooonf[o0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`000004oook
JP;o00000_oonfX7o`000003oookJ_l0003o000000Ko00007OoonfX6o`000007oookJ_l0003ooo]Z
o`000?oonf[o0000oookJP02o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX7o`0000?ooo]Z
0ol000000ooonf[o0000o`000002oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[o0000o`0000?ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l00007oookJP04
o`000?oonf[ooo]Zo`0000Kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP08oook
JP05o`000?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
000000Co00000_oonfX2o`0000Gooo]Z1?l000001Ooonf[o0000o`000?oonf[o000000Sooo]Z00?o
0000oookJ_oonfX00ol00003oookJP;o00002?oonfX02?l0003ooo]ZoookJ_oonf[o0000oookJ_l0
003ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol000000ooonf[o0000o`000009oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX4o`0000;ooo]Z0_l00006oook
JP06o`000?oonf[ooo]Zo`000?oonf[o00000ooonfX00ol0003ooo]ZoookJP02oookJP7o00000000
0ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000Co0000oookJ_oonf[ooo]Z0_l00007
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02
o`0000?ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00005oookJP03o`000?oonf[o000000Sooo]Z
00Go0000oookJ_l0003ooo]Zo`000002oookJP;o00000_oonfX5o`0000?ooo]Z0_l00002oookJP03
o`000?oonf[o000000Co00000ooonfX2o`000003oookJ_l0003o000000Gooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000002oookJP03o`000?oonf[o000000?ooo]Z0_l00002oookJP03o`000?oonf[o0000
00?ooo]Z0_l000000ooonf[o0000oookJP08oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003ooo]ZoookJP08oookJP04o`000?oonf[ooo]Zo`0000Sooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00[ooo]Z00Go0000
oookJ_l0003ooo]Zo`000002oookJP;o000000Oooo]Zo`000?l0003o0000oookJ_l0003ooo]Z00;o
000000Sooo]Zo`000?oonf[ooo]Zo`000?oonf[o0000oookJP?o00000_oonfX00ol0003ooo]Zoook
JP03oookJP;o000000Cooo]Zo`000?oonf[o00000_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00ko
00007_oonfX:o`000004oookJ_l0003o0000o`0000;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[o000000?o00000_oonfX2o`000005oookJ_l0003o0000
oookJ_l000001OoonfX3o`0000Cooo]Z0_l000000ooonf[o0000oookJP09oookJP03o`000?oonf[o
oo]Z00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0
00000ooonf[o0000oookJP0?oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000000_oo
nfX00ol0003ooo]ZoookJP09oookJP;o00002_oonfX6o`000003oookJ_l0003o000000;ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP;o00000_oonfX00ol0003ooo]Zoook
JP02o`0000;ooo]Z0ol00004oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX01?l0003ooo]Z
oookJ_l00006oookJP;o00001ooonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]Zo`000002o`000007oookJ_l0003o0000oookJ_l0003ooo]Zo`00
0002oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`00
0002o`0000Sooo]Z00?o0000oookJ_l000001?oonfX1o`00000000?o0000oookJ_oonfX00_oonfX0
1?l0003ooo]ZoookJ_oonfX3o`0000Oooo]Z00?o0000oookJ_l000000ooonfX2o`0000;ooo]Z00Go
0000oookJ_oonf[ooo]Zo`000006oookJP;o00001ooonfX01Ol0003ooo]Zo`000?oonf[o000000Co
oo]Z00?o0000oookJ_l000000ooonfX3o`000003oookJ_l0003ooo]Z00Cooo]Z00?o0000oookJ_l0
00001?l00005oookJPKo00000_oonfX00ol0003ooo]ZoookJP02oookJP;o00001OoonfX00ol0003o
oo]Zo`000002o`0000Oooo]Z1?l000000ooonf[o0000oookJP0LoookJP04o`000?oonf[ooo]Zo`00
00Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP04o`000?oonf[ooo]Z
o`0000?ooo]Z00Ko0000oookJ_oonf[ooo]Zo`000?oonfX2o`000004oookJ_l0003o0000oookJP;o
00000ooonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000ooonfX2o`0000?ooo]Z00Co0000
oookJ_l0003ooo]Z1?l00004oookJP?o00001?oonfX4o`000003oookJ_l0003o000000Oo000000?o
oo]Zo`000?l000000_l0000OoookJPGo00000_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000;o
oo]Z0_l000000ooonf[o0000o`000005o`0000;ooo]Z0_l00002oookJP;o000000Gooo]Zo`000?oo
nf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00;o00000_oonfX01_l0003ooo]ZoookJ_oonf[o
0000oookJP;o000000?ooo]Zo`000?oonfX00ooonfX01?l0003ooo]ZoookJ_l00006oookJP;o0000
3OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_l00000
0_oonfX00ol0003ooo]Zo`000002o`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX01?l0003ooo]Z
oookJ_l00004oookJP;o00001_oonfX2o`0000;ooo]Z0_l000000ooonf[o0000oookJP02oookJP03
o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Cooo]Z0_l000000ooonf[o
0000o`000005o`0000;ooo]Z0_l00004oookJP;o00000_oonfX02?l0003ooo]ZoookJ_l0003ooo]Z
o`000?oonf[o00001OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;o00000_oo
nfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o000000?ooo]Zo`000?oonfX00_oonfX2o`0000;o
oo]Z00?o0000oookJ_oonfX02?oonfX01?l0003ooo]Zo`000?l00005oookJP03o`000?oonf[ooo]Z
00Cooo]Z0Ol000000003o`000?oonf[ooo]Z00;ooo]Z0_l00005oookJP05o`000?oonf[o0000oook
J_l000001OoonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00_l00004oookJP;o00000ooonfX2o`00
00Kooo]Z0_l00002oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX01?l0003ooo]Zo`000?l0
0002oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000Co
oo]Z1Ol00004oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP02o`00
0003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00002
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Oooo]Z0_l00002
oookJP05o`000?oonf[ooo]ZoookJ_l000003?oonfX2o`0000Oooo]Z0ol00009oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_l000001_l000001Ooonf[o0000o`000?l0003ooo]Z00Ko0000
00Kooo]Zo`000?l0003ooo]Zo`000?oonfX4o`0001oooo]Z2_l000001?oonf[o0000oookJ_oonfX5
o`000003oookJ_l0003o000000;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX02?oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`000005
oookJP?o000000?ooo]Zo`000?oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z00Sooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z013ooo]Z00?o
0000oookJ_oonfX03ooonfX2o`000006oookJ_l0003ooo]Zo`000?oonf[o00000_oonfX3o`0000Co
oo]Z00?o0000oookJ_oonfX00_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000;ooo]Z00?o0000
oookJ_l000000_l000001Ooonf[o0000o`000?l0003ooo]Z00;o00000ooonfX01?l0003ooo]Zo`00
0?l00006oookJP03o`000?oonf[ooo]Z00;o00001?oonfX00ol0003ooo]ZoookJP02oookJP;o0000
0_oonfX01?l0003ooo]ZoookJ_oonfX3o`0000;ooo]Z0_l000001?oonf[o0000oookJ_l00004oook
JP;o000000?ooo]Zo`000?l000000ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00Sooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP7o000000000ol0003ooo]ZoookJP04oook
JP04o`000?oonf[ooo]Zo`0000Kooo]Z00Co0000oookJ_oonf[o00001?oonfX2o`0000;ooo]Z0_l0
0003oookJP;o00000_oonfX01Ol0003ooo]Zo`000?oonf[o000000?ooo]Z00Co0000oookJ_oonf[o
oo]Z0_l000001_oonf[o0000oookJ_oonf[o0000oookJP;o00000_oonfX01Ol0003ooo]Zo`000?oo
nf[o000000Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000002o`0000;ooo]Z1Ol0
0006oookJP05o`000?oonf[o0000o`000?oonfX00ol00002oookJP06o`000?oonf[ooo]Zo`000?oo
nf[o00002OoonfX3o`000003oookJ_l0003ooo]Z00[ooo]Z00Go0000oookJ_l0003ooo]Zo`000007
oookJP03o`000?oonf[ooo]Z00Oooo]Z00Co0000oookJ_oonf[o00001_oonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[o0000o`0000Kooo]Z
00?o0000oookJ_oonfX02ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o000000?ooo]Zo`000?oo
nfX00ooonfX2o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX00ol0003ooo]Zo`000002o`00
0004oookJ_l0003ooo]ZoookJP;o00000ooonfX00ol0003ooo]Zo`000002o`0000;ooo]Z00Co0000
oookJ_oonf[ooo]Z1ol00002oookJP?o00008OoonfX<o`0000;ooo]Z0ol00002oookJPCo000000Ko
oo]Zo`000?l0003ooo]Zo`000?oonfX2o`0000;ooo]Z0ol00004oookJP03o`000?oonf[ooo]Z00;o
00000_oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX01Ol0
003ooo]Zo`000?oonf[o000000;ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00005
oookJP04o`000?oonf[ooo]Zo`00017ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000So
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000008oookJP05o`000?oonf[ooo]Zoook
J_l000000ooonfX3o`0000;ooo]Z0_l0000=oookJP;o000000Oooo]Zo`000?oonf[ooo]Zo`000?oo
nf[o000000Gooo]Z00?o0000oookJ_oonfX00ol000001?oonf[o0000oookJ_oonfX2o`000003oook
J_l0003ooo]Z00Sooo]Z00?o0000oookJ_oonfX00ooonfX2o`000004oookJ_l0003ooo]Zo`0000;o
oo]Z00Ko0000oookJ_oonf[o0000oookJ_l00005oookJP03o`000?oonf[o000000;o00000ooonfX0
1Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0_l000001?oonf[o0000o`000?l00005oookJP03o`00
0?oonf[o000000;ooo]Z00Co0000oookJ_l0003o00000_oonfX00ol0003ooo]ZoookJP03oookJP7o
000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]Zo`000002o`0000[ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Z
oookJP07oookJP;o000000?ooo]Zo`000?l000000ooonfX2o`0000;ooo]Z00So0000oookJ_l0003o
0000oookJ_l0003ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX4o`000003oookJ_l0003o
000000?ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Zo`000003oookJP04o`000?oo
nf[ooo]Zo`0000_ooo]Z00?o0000oookJ_l000000ooonfX5o`0000;ooo]Z0_l00003oookJP04o`00
0?oonf[o0000o`0000?ooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP04oookJP;o00001?oonfX01_l0003ooo]ZoookJ_l0003o
oo]Zo`0000Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07oookJP;o000000Co
oo]Zo`000?oonf[o00001OoonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP?o00000_oonfX00ol0
003ooo]ZoookJP02o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_l000001?l000000ooo
nf[o0000oookJP02oookJP04o`000?oonf[o0000oookJP;o000000Cooo]Zo`000?l0003o00000ooo
nfX7o`00027ooo]Z1_l00002oookJPCo000000Cooo]Zo`000?l0003ooo]Z0ol00004oookJP04o`00
0?oonf[o0000o`0000?ooo]Z0_l000000ooonf[o0000o`000003oookJP04o`000?oonf[ooo]Zoook
JP;o00000_oonfX00ol0003ooo]ZoookJP03oookJP;o00000_oonfX2o`0000Wooo]Z00Co0000oook
J_oonf[o00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_l000003_oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`000007
oookJP04o`000?oonf[o0000o`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]Zoook
J_oonf[o000000?ooo]Z0_l000000ooonf[o0000o`000006o`00000GoookJ_l0003ooo]ZoookJ_l0
003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oo
nf[o0000oookJ_l000000ooonfX3o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP02o`0000Oooo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0003o
oo]Zo`000006oookJP;o00000ooonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]Zo`00
0?oonfX00Ol000000003o`000?oonf[ooo]Z00cooo]Z00Co0000oookJ_l0003o00000_oonfX01?l0
003ooo]Zo`000?oonfX2o`0000;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX01?oonfX01Ol0003ooo]Zo`000?oonf[o000000[ooo]Z0_l00006oookJPGo000000Ko
oo]Zo`000?l0003ooo]Zo`000?oonfX3o`000003oookJ_l0003ooo]Z00;o000000Gooo]Zo`000?l0
003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z00Ko0000oookJ_oonf[ooo]Zo`000?oo
nfX2o`0000;ooo]Z0_l00002oookJP?o000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`00
0002oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00006oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX01?oonfX2o`0000;ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000001?oonfX2o`0000?ooo]Z00?o
0000oookJ_l000001OoonfX01?l0003ooo]ZoookJ_l00004oookJP;o00000_oonfX01Ol0003ooo]Z
oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000002o`0002?o
oo]Z2_l000001?oonf[o0000oookJ_oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX2o`00
0003oookJ_l0003o000000?o00000ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l0000:oookJP05o`000?oonf[o
oo]ZoookJ_l000000ooonfX2o`0000oooo]Z00Co0000oookJ_l0003o00000ooonfX01Ol0003ooo]Z
oookJ_oonf[o000000kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP08oookJP?o
00000_oonfX6o`0000?ooo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0003ooo]ZoookJP03oook
JP04o`000?oonf[ooo]Zo`0000?ooo]Z1?l00002oookJP;o000000?ooo]Zo`000?l000000_l00000
0ooonf[o0000oookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00002oookJP;o00000_oonfX3
o`0000cooo]Z0_l000001?oonf[o0000oookJ_l00003oookJP05o`000?oonf[o0000oookJ_l00000
0_oonfX00ol0003ooo]ZoookJP03o`0000Gooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003o
oo]ZoookJP04oookJP7o000000000ol0003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00Cooo]Z
00So0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`0000;ooo]Z0_l00002oookJP03o`000?oonf[o
oo]Z00;ooo]Z0_l000000ooonf[o0000oookJP03oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o
0000oookJ_oonfX00_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ooo]Zo`00
0?oonf[o000000;ooo]Z00So0000oookJ_l0003o0000oookJ_l0003ooo]Zo`0000;ooo]Z00Co0000
oookJ_l0003ooo]Z0ol000000ooonf[o0000o`000004oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0
0003oookJP04o`000?oonf[ooo]Zo`0000[ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP;o
000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z01Go
oo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP;o00000_oonfX01?l0003ooo]Zo`000?l00003
oookJP04o`000?oonf[o0000o`0000gooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]Zo`00
0?l00005oookJP?o00000_oonfX2o`000003oookJ_l0003o000000;o00000ooonfX00ol0003ooo]Z
o`000002oookJP04o`000?oonf[o0000o`0000;ooo]Z1?l000000ooonf[o0000o`000007o`0002?o
oo]Z0ol000000ooonf[o0000o`000006o`000004oookJ_l0003o0000oookJPKo00000_oonfX00ol0
003ooo]Zo`000002o`0000Cooo]Z00Co0000oookJ_oonf[o00000ooonfX01Ol0003ooo]ZoookJ_l0
003ooo]Z00;o00001?oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX01ooonfX01?l0003ooo]Zo`00
0?oonfX2o`0000?ooo]Z00?o0000oookJ_l000002_oonfX00ol0003ooo]ZoookJP02oookJP06o`00
0?oonf[ooo]Zo`000?oonf[o00003?oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000000_oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00_ooo]Z1?l00004oookJP03o`000?oo
nf[ooo]Z00;o00000_oonfX00ol0003ooo]ZoookJP07oookJP;o00001?oonfX00ol0003ooo]Zoook
JP03oookJP04o`000?oonf[o0000o`0000;ooo]Z00Go0000oookJ_oonf[o0000oookJP02o`0000?o
oo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP04oookJP03o`000?oonf[o000000?o
oo]Z0_l000001?oonf[o0000o`000?oonfX2o`000003oookJ_l0003o000000;ooo]Z0ol00002oook
JP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000;ooo]Z0_l00008
oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00002oookJP7o000000000ol0003ooo]ZoookJP3ooook
J_oooo]Z?_oonfX1o`00000000Co0000oookJ_l0003o00001_oonfX00ol0003ooo]Zo`000006oook
JP;o00001OoonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00Go0000oookJ_oonf[o0000oookJP04
o`0000[ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP;o000000Cooo]Z
o`000?oonf[o00000_oonfX3o`0000;ooo]Z0_l00002oookJP05o`000?oonf[o0000o`000?oonfX0
0ol000001?oonf[o0000o`000?l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z00So0000oookJ_l0
003o0000oookJ_l0003ooo]Zo`0000;ooo]Z0_l000000ooonf[o0000oookJP04oookJPCo000000Ko
oo]Zo`000?oonf[o0000oookJ_l0000:oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX01OoonfX3o`0001;ooo]Z00?o0000oookJ_l000001OoonfX01?l0003ooo]Zo`000?l00002oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000000ol000000ooonf[o0000o`000007oook
JP03o`000?oonf[o000000;ooo]Z0_l00005oookJP03o`000?oonf[o000000Kooo]Z00?o0000oook
J_oonfX00_l000001?oonf[o0000oookJ_oonfX5o`0000;ooo]Z3_l0000UoookJPCo00000_oonfX8
o`0000?ooo]Z00Co0000oookJ_oonf[ooo]Z0ol00007oookJP;o00001?oonfX01?l0003ooo]Zoook
J_l00002oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00000_oonfX01?l0003o
oo]ZoookJ_l00008oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l000000ooonf[o0000o`000007oook
JP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zo`000002oook
JP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX02_oonfX01ol0003ooo]ZoookJ_oonf[o
0000oookJ_l000000ooonfX4o`0000Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP04o`00
0?oonf[ooo]ZoookJPCo000000?ooo]Zo`000?l000001?oonfX00ol0003ooo]ZoookJP03oookJPSo
000000?ooo]Zo`000?oonfX00ooonfX2o`0000?ooo]Z0ol00004oookJP05o`000?oonf[ooo]Zoook
J_l000001?oonfX01ol0003ooo]Zo`000?oonf[o0000oookJ_l000003ooonfX01?l0003ooo]Zoook
J_oonfX2o`0000kooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP02oookJP7o0000
00000ol0003ooo]ZoookJP05oookJP;o00000ooonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z00Co
0000oookJ_l0003ooo]Z0_l00002oookJP;o00001?oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o
000000Kooo]Zo`000?l0003o0000oookJ_l00002oookJP04o`000?oonf[o0000oookJP?o00000ooo
nfX00ol0003ooo]ZoookJP02o`0000;ooo]Z0_l000000ooonf[o0000oookJP02o`000007oookJ_l0
003ooo]ZoookJ_l0003ooo]Zo`000002oookJP04o`000?oonf[o0000oookJP;o00000ooonfX01?l0
003ooo]ZoookJ_oonfX7o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l00004oookJPSo00000_oo
nfX3o`0000;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zo`000008oookJP05o`000?oo
nf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00;o0000
2_oonfX00ol0003ooo]ZoookJP03oookJP;o000000?ooo]Zo`000?l000000ooonfX00ol0003ooo]Z
oookJP02o`000004oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003o
oo]ZoookJ_oonfX2o`0000Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP;o00000ooonfX0
0ol0003ooo]Zo`000002oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0_l000000ooonf[o0000
oookJP03o`0000;ooo]Z2Ol0000UoookJPKo000000Sooo]Zo`000?l0003ooo]Zo`000?oonf[o0000
oookJPCo00000_oonfX3o`000004oookJ_l0003ooo]Zo`0000;ooo]Z00Go0000oookJ_l0003ooo]Z
o`000003oookJP;o00000ooonfX2o`0000?ooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX00ooonfX2o`0000;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000?ooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000004oookJP05o`000?oonf[o0000oookJ_l0
00000ooonfX00ol0003ooo]ZoookJP09oookJPSo00004?oonfX01?l0003ooo]ZoookJ_l00005oook
JP03o`000?oonf[ooo]Z00Gooo]Z0ol00005oookJP;o000000?ooo]Zo`000?oonfX02ooonfX2o`00
00[ooo]Z1Ol000001?oonf[o0000o`000?l00003oookJP03o`000?oonf[o000000?ooo]Z00Co0000
oookJ_oonf[ooo]Z0ol00006oookJP05o`000?oonf[o0000oookJ_l000000_oonfX00ol0003ooo]Z
o`000002o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000Go0000oookJ_oonf[ooo]Z
o`000003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_l000002OoonfX01?l0003o
oo]ZoookJ_l00003oookJP;o00001_oonfX00ol0003ooo]Zo`000003oookJP05o`000?oonf[ooo]Z
oookJ_l000000ooonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP?o00001_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000;ooo]Z00Co0000oookJ_oonf[o00000ooonfX2o`000003oookJ_l0003o0000
00Gooo]Z00Go0000oookJ_l0003ooo]Zo`000003oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z00Go
0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[o000000;o000000Cooo]Zo`000?oonf[o
00003OoonfX00ol0003ooo]ZoookJP0>oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00[ooo]Z00Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]Zo`000003o`00
01?ooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000o`000005oookJP?o00001OoonfX00ol0
003ooo]Zo`000002oookJP;o000000gooo]Zo`000?l0003ooo]Zo`000?oonf[o0000oookJ_l0003o
oo]Zo`000?oonf[o000000;ooo]Z00Ko0000oookJ_l0003ooo]Zo`000?oonfX4o`0002Oooo]Z1ol0
00001?oonf[o0000oookJ_l00002oookJPGo000000?ooo]Zo`000?oonfX00ol00002oookJP?o0000
00Kooo]Zo`000?l0003ooo]Zo`000?oonfX3o`000003oookJ_l0003o000000Sooo]Z0_l000000ooo
nf[o0000oookJP02oookJP?o00000_oonfX01?l0003ooo]Zo`000?l00009oookJP;o000000Cooo]Z
o`000?oonf[o00000_oonfX00ol0003ooo]ZoookJP05oookJP05o`000?oonf[ooo]ZoookJ_l00000
0ooonfX2o`0001?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Ko
oo]Z0_l00003oookJP?o000000?ooo]Zo`000?l000000ooonfX01ol0003ooo]ZoookJ_oonf[o0000
oookJ_l000000ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[o000000Wooo]Z00?o0000
oookJ_oonfX01_l000000ooonf[o0000oookJP04oookJP04o`000?oonf[ooo]Zo`0000[ooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o000000Gooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP?o00000_oonfX01Ol0003ooo]Zoook
J_oonf[o000000;ooo]Z00Co0000oookJ_oonf[o00000ooonfX1o`00000000?o0000oookJ_oonfX0
oooonf[ooookJSkooo]Z0Ol000000004o`000?oonf[ooo]Zo`0000?ooo]Z00Ko0000oookJ_oonf[o
0000oookJ_l0000<oookJP;o00000_oonfX2o`0000;ooo]Z00?o0000oookJ_l000003?oonfX2o`00
00Wooo]Z00?o0000oookJ_oonfX00_l00003oookJP;o00000ooonfX00ol0003ooo]ZoookJP02oook
JP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0_l000001?oonf[o0000oookJ_oonfX2o`000003oook
J_l0003o000000;ooo]Z0_l000000ooonf[o0000oookJP02oookJP;o00000ooonfX01?l0003ooo]Z
o`000?l00002oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_l000000_oonfX2o`00
00?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX02_oonfX2o`0000;ooo]Z1?l00004oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z
00;ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[o000000Kooo]Z1Ol000001?oonf[o0000o`000?oonfX2
o`000003oookJ_l0003o000000Go0000:?oonfX3o`000007oookJ_l0003ooo]Zo`000?oonf[o0000
oookJP02o`000006oookJ_l0003o0000o`000?oonf[o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o
000000Cooo]Z00?o0000oookJ_oonfX01_oonfX4o`0000Gooo]Z0_l00006oookJP03o`000?oonf[o
000000Kooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000_ooo]Z00?o0000oookJ_oonfX01_oonfX2
o`0000Sooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02o`000003oookJ_l0003o
oo]Z00Kooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00004oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z00Co0000oookJ_l0003o
oo]Z0_l00003oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00Oo0000oookJ_oonf[o0000oookJ_l0
003ooo]Z00Co000000?ooo]Zo`000?oonfX00ooonfX4o`0000oooo]Z00?o0000oookJ_l000000_oo
nfX01?l0003ooo]Zo`000?l00002oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX2o`0000So
oo]Z00?o0000oookJ_oonfX00Ol000000004o`000?oonf[ooo]ZoookJP?o00000_oonfX00ol0003o
oo]ZoookJP05oookJP;o000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000002oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00ooonfX2o`000005oookJ_l0003ooo]Zoook
J_l000000ooonfX2o`000008oookJ_l0003o0000oookJ_l0003ooo]Zo`000?oonfX4o`000003oook
J_l0003o000000?ooo]Z00?o0000oookJ_l000000_l00002oookJPCo00000_oonfX2o`000003oook
J_l0003ooo]Z00?ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00002oookJP?o0000
2?oonfX3o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX3o`0000Cooo]Z
00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00002oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX00ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z00Oo0000oook
J_oonf[ooo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_l000000ooonfX01Ol0003ooo]Zoook
J_oonf[o000000?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z
0_l000000ooonf[o0000o`000002o`0002Wooo]Z1_l000000ooonf[o0000o`000002o`000003oook
J_l0003ooo]Z00;ooo]Z00?o0000oookJ_l000000_oonfX2o`0000;ooo]Z0_l00002oookJP;o0000
00?ooo]Zo`000?oonfX02?oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o000000?ooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP02o`000003oookJ_l0003ooo]Z00_ooo]Z
00Oo0000oookJ_l0003ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX00ooonfX01?l0
003ooo]ZoookJ_l00005oookJP04o`000?oonf[o0000o`0000cooo]Z00Co0000oookJ_l0003ooo]Z
0ol000000ooonf[o0000o`000002oookJP03o`000?oonf[o000000;o00000_oonfX01Ol0003ooo]Z
oookJ_l0003ooo]Z00?o00001_oonfX00ol0003ooo]ZoookJP04oookJP;o000000?ooo]Zo`000?oo
nfX01?l000001ooonf[o0000o`000?l0003ooo]Zo`000?oonfX00_l000000ooonf[o0000o`000004
oookJP;o00000_oonfX2o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_l000002?oonfX2
o`000006oookJ_l0003ooo]Zo`000?oonf[o00000_oonfX2o`000003oookJ_l0003ooo]Z00Kooo]Z
0ol00008oookJP;o000000?ooo]Zo`000?oonfX02?oonfX1o`00000000Ko0000oookJ_oonf[ooo]Z
o`000?oonfX2o`0000Gooo]Z00?o0000oookJ_l000000ooonfX2o`0000Gooo]Z00?o0000oookJ_oo
nfX00_l00003oookJP05o`000?oonf[o0000oookJ_l000001OoonfX00ol0003ooo]Zo`000003oook
JP04o`000?oonf[ooo]Zo`0000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00006oookJP;o00001Ooo
nfX00ol0003ooo]ZoookJP02o`000003oookJ_l0003o000000?o00000_oonfX00ol0003ooo]Zoook
JP03oookJP06o`000?oonf[ooo]Zo`000?oonf[o00001ooonfX2o`0000?ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]Zo`000004o`000003oookJ_l0003o000000Gooo]Z00?o0000oookJ_oo
nfX05ooonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oonfX01?oonfX3o`00
00Oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00?ooo]Z00So0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX0
0_oonfX01?l0003ooo]Zo`000?oonfX4o`0000;ooo]Z00?o0000oookJ_l000002ol0000ZoookJPCo
000000?ooo]Zo`000?l000000ol000000ooonf[o0000oookJP03o`000003oookJ_l0003o000000Go
oo]Z0_l000002?oonf[o0000o`000?l0003ooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]Zoook
JP04oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000ooonfX3o`000004oookJ_l0003ooo]Zo`00
00cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00gooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00000
0ooonf[o0000oookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00Oo0000oookJ_oonf[ooo]Zo`00
0?oonf[o000000;ooo]Z0_l000001Ooonf[o0000o`000?oonf[o000000;ooo]Z00Co0000oookJ_oo
nf[o00001?oonfX2o`0000?ooo]Z00Co0000oookJ_oonf[o00000ooonfX01_l0003ooo]Zo`000?l0
003ooo]Zo`0000Kooo]Z00Wo0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000001OoonfX2
o`0000Gooo]Z0_l000001_oonf[o0000o`000?l0003ooo]Zo`0000;ooo]Z0_l00003oookJP05o`00
0?oonf[o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000_o
oo]Z00Co0000oookJ_oonf[ooo]Z0_l00004oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00003oook
JP04o`000?oonf[ooo]ZoookJP7o000000001_l0003ooo]Zo`000?l0003ooo]Zo`0000?ooo]Z00Oo
0000oookJ_oonf[ooo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000;o
oo]Z0_l00002oookJP03o`000?oonf[o000000;ooo]Z00Go0000oookJ_l0003ooo]Zo`000002oook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000003oook
JP03o`000?oonf[o000000;o00000_oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00Co000000Gooo]Z
o`000?oonf[o0000oookJP02o`0000;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP06oookJP;o00001?oonfX01?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003ooo]Z00;o0000
0_oonfX2o`0000;ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
1?oonfX01Ol0003ooo]ZoookJ_oonf[o000000Sooo]Z00Co0000oookJ_oonf[o00000ooonfX01?l0
003ooo]ZoookJ_oonfX2o`000003oookJ_l0003ooo]Z00Cooo]Z00Ko0000oookJ_oonf[o0000oook
J_l00009oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]Z
o`000009oookJP;o000000?ooo]Zo`000?oonfX02OoonfX00ol0003ooo]Zo`000002oookJPCo0000
00?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP?o000000?ooo]Zo`000?l00000
2?l0000ZoookJPCo000000?ooo]Zo`000?l000000_oonfX2o`0000;ooo]Z00Co0000oookJ_oonf[o
00000ooonfX01?l0003ooo]ZoookJ_oonfX3o`0000;ooo]Z0_l000000ooonf[o0000o`000003o`00
00;ooo]Z0_l00003oookJP05o`000?oonf[ooo]ZoookJ_l000001ooonfX00ol0003ooo]ZoookJP05
oookJP;o000000?ooo]Zo`000?l000003_oonfX00ol0003ooo]Zo`000002oookJP07o`000?oonf[o
oo]ZoookJ_l0003ooo]Zo`000003oookJP;o00001OoonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00?ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00_ooo]Z00Go0000oookJ_l0003o
0000oookJP02o`000003oookJ_l0003ooo]Z00;o00001OoonfX00ol0003ooo]ZoookJP02oookJP06
o`000?oonf[o0000o`000?oonf[o00000ooonfX2o`0000?ooo]Z0_l00003oookJP04o`000?oonf[o
oo]Zo`0000Kooo]Z0_l000000ooonf[o0000o`000005oookJP03o`000?oonf[ooo]Z00;o000000?o
oo]Zo`000?oonfX01_oonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX00ol00003oookJP?o00000_oonfX6o`000003oookJ_l0003o000000;ooo]Z
00Co0000oookJ_oonf[ooo]Z0_l0000:oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z
?_oonfX1o`00000000?o0000oookJ_oonfX00ooonfX2o`0000?ooo]Z00Oo0000oookJ_oonf[ooo]Z
o`000?oonf[o000000;ooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z00?o0000oook
J_oonfX00ooonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o00001OoonfX02?l0003ooo]Zoook
J_l0003ooo]Zo`000?oonf[o00001OoonfX00ol0003ooo]Zo`000002o`000003oookJ_l0003ooo]Z
00;ooo]Z00Co0000oookJ_oonf[o00000_oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00Co000000Go
oo]Zo`000?oonf[ooo]Zo`000003oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oo
nfX02?oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o00001?oonfX00ol0003ooo]Zo`000003o`00
0005oookJ_l0003ooo]ZoookJ_l000002?oonfX01?l0003ooo]ZoookJ_l00009oookJP04o`000?oo
nf[o0000o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00Co
oo]Z0_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000Co
oo]Z00Co0000oookJ_oonf[o00001ooonfX01?l0003ooo]Zo`000?l00004oookJP;o00000ooonfX0
2Ol0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000005oookJP;o000000[ooo]Zo`000?oo
nf[ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z0_l00003oookJPSo0000:ooonfX4o`000003oook
J_l0003o000000?o000000?ooo]Zo`000?l000000_l000000ooonf[o0000oookJP02oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP04oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000002oookJP03o`00
0?oonf[ooo]Z00?ooo]Z0_l000000ooonf[o0000o`000004oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_l0000;oookJP05o`000?oonf[ooo]Zoook
J_l000000ooonfX2o`0000kooo]Z00?o0000oookJ_oonfX00_l00003oookJP04o`000?oonf[ooo]Z
o`0000?ooo]Z1?l00002oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX2o`0000;ooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP05oookJP;o00000_oonfX00ol0003ooo]Zo`00
0002o`0000?ooo]Z00Ko0000oookJ_l0003o0000oookJ_l00002oookJP;o000000Cooo]Zo`000?l0
003ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l000000ooonf[o0000oookJP03oook
JP;o00002?oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`00
0?oonfX01?l000001?oonf[o0000oookJ_oonfX3o`000003oookJ_l0003o000000Gooo]Z0Ol00000
0006o`000?oonf[ooo]Zo`000?oonf[o00001_oonfX00ol0003ooo]Zo`000007oookJP03o`000?oo
nf[ooo]Z00;o00000_oonfX2o`0000?ooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003ooo]Z
o`000004oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01?l00003oookJPCo0000
00Cooo]Zo`000?oonf[o00001_oonfX3o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?oo
nf[o00000ooonfX2o`0000?ooo]Z00Co0000oookJ_oonf[o00000ooonfX2o`0000Oooo]Z00Co0000
oookJ_l0003o00000_oonfX2o`000004oookJ_l0003ooo]Zo`0000?ooo]Z0_l00008oookJP05o`00
0?oonf[ooo]ZoookJ_l000000_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000_ooo]Z00?o0000
oookJ_l000000_oonfX2o`000003oookJ_l0003ooo]Z00;o00004?oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000Cooo]Z0ol00002oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000000ooonf[o0000o`000004oookJP04o`00
0?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00ol000000ooonf[o0000o`000003o`0000;o
oo]Z1ol0000/oookJP?o00000_oonfX00ol0003ooo]Zo`000005o`000005oookJ_l0003ooo]Zoook
J_l000001OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_l000001?oonfX01ol0003ooo]Zo`000?oonf[o0000oookJ_l000000_oonfX2o`0000Kooo]Z00?o
0000oookJ_oonfX00_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX02_oonfX2o`000005oookJ_l0
003ooo]ZoookJ_l000002OoonfX2o`0000Kooo]Z0_l0000=oookJP03o`000?oonf[ooo]Z00Oooo]Z
0_l000000ooonf[o0000o`000008oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000@oookJP;o0000
1OoonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o000000Cooo]Zo`000?oonf[o00000_oonfX2o`00
0003oookJ_l0003o000000;o00000_oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]Zo`000004oookJP03o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX01Ol000001_oo
nf[o0000oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP05oookJP04o`000?oonf[o0000o`0000;ooo]Z0Ol000000003o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_l000000ooonfX00ol0003ooo]Zo`000008oookJP;o00000_oonfX01ol0003ooo]Zoook
J_oonf[o0000oookJ_l000003_oonfX2o`000003oookJ_l0003o000000;ooo]Z00?o0000oookJ_oo
nfX00_oonfX2o`0000;ooo]Z00Oo0000oookJ_oonf[o0000oookJ_l0003ooo]Z00Ko000000?ooo]Z
o`000?l000000_oonfX01?l0003ooo]ZoookJ_l00002oookJP;o00001OoonfX00ol0003ooo]Zoook
JP03oookJP05o`000?oonf[o0000oookJ_l000001?oonfX01Ol0003ooo]Zo`000?oonf[o000000Co
oo]Z00?o0000oookJ_l000000ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003o
oo]ZoookJ_l00004oookJP04o`000?oonf[o0000o`0000Cooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00;ooo]Z00Ko0000oookJ_l0003o0000oook
J_l00003oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`000002oookJP04o`000?oonf[ooo]Zo`00
00Kooo]Z0ol0000;oookJP;o00001OoonfX2o`0000;ooo]Z00Co0000oookJ_oonf[o00000_oonfX0
0ol0003ooo]Zo`000003o`0000?ooo]Z1Ol000000ooonf[o0000o`000003o`0002gooo]Z2_l00000
0ooonf[o0000oookJP02o`000004oookJ_l0003ooo]ZoookJP;o000000Kooo]Zo`000?oonf[ooo]Z
o`000?oonfX3o`000003oookJ_l0003ooo]Z00;o00000_oonfX00ol0003ooo]Zo`000002oookJP;o
00000_oonfX2o`0000Wooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z00Oooo]Z0ol0000;oookJP05o`000?oonf[ooo]ZoookJ_l000002_oonfX01Ol0
003ooo]Zo`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX01ooonfX2o`000003oookJ_l0003o
oo]Z00?ooo]Z00?o0000oookJ_oonfX01ooonfX3o`000003oookJ_l0003ooo]Z00Cooo]Z00Co0000
oookJ_l0003o00001_oonfX01?l0003ooo]Zo`000?oonfX2o`0000;ooo]Z0_l00003oookJP03o`00
0?oonf[o000000;o00000_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX01?l000000ooonf[o0000
oookJP03oookJP?o000000?ooo]Zo`000?oonfX02ooonfX00ol0003ooo]Zo`000005oookJP05o`00
0?oonf[ooo]ZoookJ_l000000ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Wooo]Z00?o0000oook
J_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oonfX00Ol00000
0003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zo`000007oookJP04
o`000?oonf[ooo]Zo`0000;ooo]Z1?l00006oookJP03o`000?oonf[ooo]Z00;o00001OoonfX3o`00
00;ooo]Z00?o0000oookJ_l000000_l000000ooonf[o0000o`000004oookJP04o`000?oonf[ooo]Z
oookJP;o00002OoonfX2o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000_oonfX0
0ol0003ooo]ZoookJP03o`0000;ooo]Z1Ol00005oookJP03o`000?oonf[o000000cooo]Z00?o0000
oookJ_oonfX00_l00003oookJP04o`000?oonf[ooo]ZoookJP;o000000Gooo]Zo`000?oonf[ooo]Z
o`000004oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
o`000002oookJP04o`000?oonf[ooo]Zo`0000cooo]Z00?o0000oookJ_l000000_oonfX2o`000003
oookJ_l0003o000000Cooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP05oookJP?o
00000ooonfX00ol0003ooo]ZoookJP03oookJP;o000000Cooo]Zo`000?oonf[o00000_oonfX01Ol0
003ooo]ZoookJ_l0003ooo]Z00;o00000_oonfX7o`0002oooo]Z2Ol00002oookJP;o000000Gooo]Z
o`000?l0003ooo]Zo`000003oookJP;o000000?ooo]Zo`000?l000000_l00006oookJP;o00000ooo
nfX01?l0003ooo]ZoookJ_oonfX2o`0000cooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00Oooo]Z
00Co0000oookJ_oonf[ooo]Z0ol0000;oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oo
nf[o00001?oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;o00001_oonfX00ol0
003ooo]ZoookJP07oookJP;o000000Cooo]Zo`000?oonf[ooo]Z0ol00003oookJP?o00000ooonfX5
o`000006oookJ_l0003o0000o`000?oonf[o00001?oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000002oookJP04o`000?oonf[o0000o`0000Go
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0?oookJP06o`000?oonf[ooo]Zo`00
0?oonf[o00001OoonfX00ol0003ooo]ZoookJP02oookJP;o00000ooonfX1o`00000000Co0000oook
J_oonf[ooo]Z0_l00006oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l000000ooonf[o0000oookJP02
o`0000;ooo]Z0_l00002oookJP;o00002?oonfX4o`0000;ooo]Z0_l000000ooonf[o0000o`000002
oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l000000ooonf[o0000oookJP02o`0000;ooo]Z0_l00002
oookJP03o`000?oonf[ooo]Z00Co00001_oonfX00ol0003ooo]ZoookJP07oookJP05o`000?oonf[o
oo]ZoookJ_l000000_oonfX00ol0003ooo]Zo`000003oookJP;o00001_oonfX2o`0000?ooo]Z00Ko
0000oookJ_l0003o0000oookJ_l00003oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX01_oonfX01?l0003ooo]ZoookJ_l0000EoookJP03o`000?oonf[o000000[ooo]Z00Co0000oook
J_l0003ooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00?ooo]Z00Oo0000oookJ_oonf[ooo]Zo`00
0?oonf[o000000Cooo]Z00Co0000oookJ_oonf[ooo]Z0_l00003oookJP03o`000?oonf[o000000?o
000000Gooo]Zo`000?l0003o0000oookJP03o`0000;ooo]Z0_l000000ooonf[o0000o`000007o`00
02oooo]Z0ol000001?oonf[o0000o`000?oonfX4o`000006oookJ_l0003o0000oookJ_l0003ooo]Z
0ol00003oookJP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX00_l00009oookJP03o`00
0?oonf[o000000cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00Gooo]Z00Co0000oookJ_l0003o00000ooonfX2o`0000Cooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP07oookJP;o000000Cooo]Zo`000?oonf[ooo]Z0ol00002oookJPCo00000ooonfX2o`00
00[ooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol00004
oookJP;o000000Kooo]Zo`000?l0003ooo]Zo`000?oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX0
0ooonfX01?l0003ooo]Zo`000?oonfX3o`0000Cooo]Z0ol0000=oookJP?o000000?ooo]Zo`000?l0
00001?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o000000?o00001?oonfX1o`000000
00?o0000oookJ_oonfX01ooonfX2o`0000?ooo]Z00?o0000oookJ_l000001?oonfX01Ol0003ooo]Z
oookJ_oonf[o000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP?o000000?ooo]Zo`00
0?oonfX00_l00003oookJP04o`000?oonf[ooo]ZoookJP;o00000ooonfX02?l0003ooo]ZoookJ_l0
003ooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[o000000;o
oo]Z1?l000000ooonf[o0000oookJP02oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000?ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000004oookJP;o00000_oonfX3o`000003oookJ_l0003ooo]Z00;o00003OoonfX01Ol0
003ooo]ZoookJ_oonf[o000000?ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX00_oonfX3o`000003oookJ_l0003o000000Gooo]Z00?o0000oookJ_l000000_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0ol000000ooonf[o0000o`000002oookJPCo0000
00Gooo]Zo`000?l0003o0000oookJP05o`00033ooo]Z3?l00002oookJP08o`000?oonf[o0000oook
J_l0003ooo]Zo`000?oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP04o`0000Gooo]Z00?o0000oookJ_oonfX00_l00006oookJP07o`000?oo
nf[ooo]ZoookJ_l0003ooo]Zo`000005oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oook
J_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX01_oonfX2o`0000;ooo]Z1?l000000ooonf[o0000oookJP06oookJP05o`000?oonf[ooo]Z
oookJ_l000000_oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00008
oookJP04o`000?oonf[o0000o`0000Gooo]Z1?l000000ooonf[o0000oookJP02oookJP04o`000?oo
nf[o0000o`0000;ooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP02o`000004oook
J_l0003ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP;o
00000ooonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[o000000_ooo]Z0_l00004oookJP7o
000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000?o0000oookJ_l000001Ooo
nfX2o`0000Gooo]Z00Co0000oookJ_oonf[o00001_oonfX2o`0000;ooo]Z0_l00004oookJP05o`00
0?oonf[ooo]ZoookJ_l000000ooonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000;o
oo]Z0_l00002oookJP;o00000_oonfX2o`0000Gooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002
oookJP03o`000?oonf[o000001?ooo]Z00Go0000oookJ_oonf[o0000oookJP04o`0000;ooo]Z00Co
0000oookJ_oonf[o00000ooonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000gooo]Z00Go0000oook
J_oonf[ooo]Zo`00000FoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP04oookJP;o00001OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04oookJP04o`000?oonf[o
0000o`0000Gooo]Z1_l00002oookJP03o`000?oonf[o000000;o00000ooonfX7o`0000;ooo]Z2?l0
000aoookJPGo00000_oonfX3o`0000;ooo]Z0_l000001Ooonf[o0000o`000?l0003ooo]Z00?o0000
00?ooo]Zo`000?l000000_l00002oookJP04o`000?oonf[o0000o`0000Cooo]Z00Co0000oookJ_l0
003o00001?oonfX3o`0000_ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_l000001ooonfX2o`0000[ooo]Z0_l0000?oook
JPSo00000ooonfX4o`0000?ooo]Z0ol00004oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oook
J_oonf[ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ol00000
0ooonf[o0000oookJP02o`000005oookJ_l0003ooo]Zo`000?oonfX00_l000001?oonf[o0000o`00
0?l00005oookJP;o000000?ooo]Zo`000?oonfX00ol00004oookJP?o000000?ooo]Zo`000?oonfX0
0_l000000ooonf[o0000oookJP02oookJP05o`000?oonf[o0000o`000?oonfX00_l0000<oookJP03
o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP;o000000Cooo]Zo`00
0?oonf[ooo]Z0Ol000000003o`000?oonf[ooo]Z00Gooo]Z00Co0000oookJ_oonf[o00002OoonfX0
1?l0003ooo]Zo`000?oonfX2o`0000;ooo]Z0_l00003oookJP05o`000?oonf[ooo]ZoookJ_l00000
2ooonfX01Ol0003ooo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00_oonfX4o`0000;o
oo]Z1_l000001?oonf[o0000oookJ_oonfX5o`000003oookJ_l0003ooo]Z00;ooo]Z00Go0000oook
J_oonf[ooo]Zo`00000<oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z0ol00003oookJP03o`000?oo
nf[ooo]Z00Co00001?oonfX00ol0003ooo]Zo`000003o`0000Gooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00_l0
0003oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000_oonfX01?l0003ooo]Zo`000?l00005oook
JP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0_l000000ooonf[o0000oookJP02oookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_l000001OoonfX01Ol0003ooo]Zo`000?oonf[o000000?ooo]Z
0ol00003oookJP04o`000?oonf[ooo]ZoookJP;o00000ooonfX00ol0003ooo]ZoookJP02oookJP?o
00000ooonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z1?l0000boookJPKo00000ooonfX2o`0000;o
oo]Z00Oo0000oookJ_oonf[o0000oookJ_l0003ooo]Z00;o000000Kooo]Zo`000?oonf[ooo]Zo`00
0?oonfX4o`0000;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol00006oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00005oookJP03o`000?oonf[o0000
00Oooo]Z00Co0000oookJ_l0003o00000_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000;ooo]Z
00Oo0000oookJ_l0003ooo]Zo`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01OoonfX01?l0
003ooo]ZoookJ_l00006oookJP;o000000Oooo]Zo`000?l0003ooo]Zo`000?oonf[o000000;ooo]Z
0ol00002oookJP03o`000?oonf[o000000;ooo]Z0ol00004oookJP04o`000?oonf[ooo]Zo`0000?o
oo]Z00Co0000oookJ_l0003ooo]Z0ol000001?oonf[o0000o`000?l00003oookJP03o`000?oonf[o
000000?o00000ooonfX2o`0000;ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000
oookJ_oonf[ooo]Zo`000003oookJP;o00002OoonfX2o`000003oookJ_l0003o000000;o00000ooo
nfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000002_oonfX00ol0003ooo]Zo`000002oookJP;o
00002?oonfX1o`00000000Co0000oookJ_oonf[o00003OoonfX01?l0003ooo]Zo`000?l00005oook
JP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX01Ol000000ooonf[o0000oookJP04
oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?oonf[o00000_oonfX3o`0000?ooo]Z0_l0
00001_oonf[o0000o`000?l0003ooo]Zo`0000;ooo]Z2?l00002oookJP03o`000?oonf[o000000Go
oo]Z00Co0000oookJ_l0003o00001OoonfX3o`0000gooo]Z00Go0000oookJ_l0003ooo]Zo`000002
oookJP04o`000?oonf[ooo]ZoookJP?o00000_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Oooo]Z
00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000cooo]Z00Co0000oookJ_l0003o00001ooonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[o0000oook
JP02o`0000?ooo]Z00Ko0000oookJ_l0003ooo]Zo`000?oonfX2o`000004oookJ_l0003ooo]Zo`00
00?ooo]Z1?l00003oookJP;o000000?ooo]Zo`000?oonfX00_l000001?oonf[o0000o`000?oonfX7
o`0003Cooo]Z1Ol000000ooonf[o0000o`000002o`000005oookJ_l0003ooo]Zo`000?oonfX01?l0
00000ooonf[o0000o`000004oookJP;o00000ooonfX00ol0003ooo]ZoookJP02oookJP;o00001?oo
nfX00ol0003ooo]Zo`000004oookJP;o00001OoonfX01Ol0003ooo]ZoookJ_oonf[o000000[ooo]Z
00Go0000oookJ_oonf[ooo]Zo`000009oookJP;o000000Gooo]Zo`000?l0003o0000oookJP02o`00
00?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0AoookJP?o00000ooonfX2o`00
00Gooo]Z00Co0000oookJ_l0003ooo]Z1?l0000?oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00004
oookJP?o000000?ooo]Zo`000?oonfX01?oonfX3o`0000?ooo]Z00?o0000oookJ_oonfX01?oonfX0
1Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_l000000_oonfX2o`0000Wooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00Go
0000oookJ_l0003ooo]Zo`00000>oookJP7o000000001Ol0003ooo]Zo`000?oonf[o000000;ooo]Z
0_l00003oookJP?o00000ooonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0_l00002oookJP;o
00001?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l0
00000ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o000000?ooo]Zo`000?oonfX00_oonfX2o`00
00Gooo]Z0_l000000ooonf[o0000oookJP02o`0000_ooo]Z00Co0000oookJ_l0003o00000ooonfX0
0ol0003ooo]Zo`000003oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000001?l0
0006oookJP03o`000?oonf[ooo]Z00;ooo]Z1?l00008oookJP;o00006OoonfX01?l0003ooo]Zoook
J_l0000:oookJP;o000000?ooo]Zo`000?l000001?oonfX00ol0003ooo]Zo`000003oookJP;o0000
1ooonfX4o`000003oookJ_l0003ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00001?oonfX2o`0000Oo
oo]Z00Co0000oookJ_l0003ooo]Z2?l00002oookJP07o`000?oonf[o0000o`000?oonf[o0000oook
JP06o`0003Gooo]Z0_l00004oookJP;o000000Kooo]Zo`000?l0003ooo]Zo`000?oonfX2o`0000Go
oo]Z00Co0000oookJ_oonf[ooo]Z0ol00003oookJP;o00000_oonfX2o`0000Cooo]Z00?o0000oook
J_l000000_l00003oookJP04o`000?oonf[ooo]Zo`00013ooo]Z1?l00006oookJP03o`000?oonf[o
000000Kooo]Z00Co0000oookJ_l0003ooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z00;o00001_oo
nfX00ol0003ooo]ZoookJP05oookJPGo000000?ooo]Zo`000?l000000_l00003oookJP03o`000?oo
nf[ooo]Z00?o00001OoonfX00ol0003ooo]ZoookJP08oookJP?o00000_oonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX00_oonfX2o`0000;ooo]Z00?o0000oookJ_l000000_l000001ooonf[o0000o`00
0?l0003ooo]Zo`000?oonfX00_l000000ooonf[o0000o`000003oookJP;o00000ooonfX00ol0003o
oo]Zo`000002o`0000Oooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000Sooo]Z00Go0000
oookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z00Oo0000oookJ_oonf[ooo]Z
o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX00Ol000000003o`000?oonf[ooo]Z0?oooo]Z
oooonfXnoookJP7o000000001?l0003ooo]ZoookJ_oonfX3o`0000;ooo]Z0ol00003oookJP?o0000
0_oonfX2o`000003oookJ_l0003ooo]Z00;o00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[o00002ooonfX00ol0003ooo]ZoookJP0:oookJP08
o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000?oonfX5o`0000?ooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?l0003o0000
1_oonfX01ol0003ooo]Zo`000?oonf[o0000oookJ_l000000ooonfX2o`000003oookJ_l0003ooo]Z
00;o000000?ooo]Zo`000?oonfX01ooonfX00ol0003ooo]Zo`000002o`0000;ooo]Z00Co0000oook
J_oonf[o00000ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000
oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP02o`000004oookJ_l0003ooo]Zo`0000?ooo]Z
00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_l000000_oonfX00ol0
003ooo]ZoookJP02o`0000;ooo]Z1?l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z1?l000000ooo
nf[o0000o`000002oookJP03o`000?oonf[o000000?o00000ooonfX3o`0000;ooo]Z1ol000001?oo
nf[o0000oookJ_oonfX3o`0003Gooo]Z1Ol000000ooonf[o0000oookJP02oookJP;o000000Cooo]Z
o`000?l0003ooo]Z0ol00004oookJP;o00001OoonfX01?l0003ooo]ZoookJ_oonfX2o`000004oook
J_l0003ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX2o`000006oookJ_l0003ooo]Zo`00
0?oonf[o00001_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[o000000[ooo]Z00Go
0000oookJ_oonf[ooo]Zo`000005oookJP05o`000?oonf[ooo]ZoookJ_l000002ooonfX3o`000003
oookJ_l0003o000000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000:oookJP;o00001OoonfX00ol0
003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z
00?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l000001?oonf[o0000oookJ_oonfX2o`0000;ooo]Z0ol0
00000ooonf[o0000oookJP0:oookJP04o`000?oonf[o0000oookJP;o00001?oonfX01?l0003ooo]Z
o`000?l0000:oookJP;o00002?oonfX01_l0003ooo]Zo`000?oonf[o0000oookJP?o000000Cooo]Z
o`000?oonf[o00000_oonfX00ol0003ooo]ZoookJP03oookJP7o000000000ol0003ooo]ZoookJP03
oookJP;o000000?ooo]Zo`000?oonfX00ooonfX3o`0000?ooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP02o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02
o`000004oookJ_l0003ooo]ZoookJP;o000000Cooo]Zo`000?oonf[ooo]Z0_l00003oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00Co0000oookJ_l0003o00000_oonfX01?l0003ooo]Zo`000?oonfX2o`00
0003oookJ_l0003ooo]Z00?o000000?ooo]Zo`000?oonfX01OoonfX01Ol0003ooo]Zo`000?oonf[o
000000Gooo]Z00?o0000oookJ_l000001ooonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o
0000oookJ_oonfX00_oonfX3o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z1_l0000HoookJP05o`00
0?oonf[ooo]ZoookJ_l000002?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;o
oo]Z0_l0000BoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000000_oonfX2o`000005
oookJ_l0003o0000o`000?oonfX00ol000000ooonf[o0000o`000006oookJP?o00000_oonfX2o`00
0004oookJ_l0003ooo]Zo`0000;ooo]Z3Ol0000foookJPCo000000Cooo]Zo`000?l0003o00000ooo
nfX2o`0000Sooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;o00002OoonfX2o`0000Gooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000009oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP05oookJP06o`000?oonf[ooo]Zo`000?oonf[o
00001_oonfX2o`0000Oooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[o000000Gooo]Z00Co0000oookJ_l0003o00000_oonfX01?l0003ooo]ZoookJ_oonfX5
o`000003oookJ_l0003o000000;o00000_oonfX2o`000005oookJ_l0003o0000oookJ_l000001Ooo
nfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]ZoookJP[o00000_oonfX00ol0003ooo]Z
oookJP04o`0000Cooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0
1ooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP08oookJP7o0000
00000ol0003ooo]Zo`000002oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0_l0000;oookJP;o0000
0_oonfX2o`0000;ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol000000ooonf[o0000
o`000002oookJP;o00001?oonfX02Ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000003
oookJP03o`000?oonf[o000000?o000000Cooo]Zo`000?oonf[o00001OoonfX3o`0000_ooo]Z0ol0
0005oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z0ol00002oookJP?o00000_oonfX4o`0000;ooo]Z
2?l00009oookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[o000000?o00001OoonfX00ol0003ooo]Zo`000005oookJP;o00000ooonfX00ol0003o
oo]ZoookJP03oookJP;o00000_oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[ooo]Zoook
J_l000001_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000;ooo]Z1?l00006oook
JP04o`000?oonf[o0000o`0000;ooo]Z0ol000001?oonf[o0000o`000?l0000goookJPOo000000?o
oo]Zo`000?l000002?l00002oookJP04o`000?oonf[ooo]ZoookJPCo00000_oonfX00ol0003ooo]Z
o`000003oookJP;o00001_oonfX01?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003o000000Ko
oo]Z00Ko0000oookJ_oonf[o0000oookJ_l00005oookJP08o`000?oonf[o0000o`000?oonf[o0000
oookJ_l00004oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00008oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX2o`000005
oookJ_l0003ooo]Zo`000?oonfX00_l000000ooonf[o0000o`000002o`000004oookJ_l0003o0000
oookJP;o000000Kooo]Zo`000?oonf[o0000oookJ_l00004oookJPCo00000_oonfX2o`0000Cooo]Z
00?o0000oookJ_oonfX00_l00004oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_l0003o
oo]Z0_l00005oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP02oookJP;o00002?oonfX01?l0003ooo]ZoookJ_oonfX2o`0000?ooo]Z00?o0000oook
J_l000002OoonfX01?l0003ooo]ZoookJ_l00005oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX00Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000001?l0003o
oo]ZoookJ_oonfX4o`0000?ooo]Z00Ko0000oookJ_oonf[ooo]Zo`000?oonfX3o`000004oookJ_l0
003o0000o`0000;ooo]Z00Co0000oookJ_oonf[o00001_oonfX02_l0003ooo]ZoookJ_l0003ooo]Z
o`000?oonf[o0000oookJ_l00005oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00002oookJP;o0000
0_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o000000?ooo]Zo`000?l000001?l00002oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z00;o00000ooonfX3o`0000Gooo]Z1?l00002oookJP08o`000?oonf[ooo]Zoook
J_l0003ooo]Zo`000?oonfX4o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP;o0000
2?oonfX02_l0003ooo]ZoookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l00005oookJP03o`000?oo
nf[ooo]Z00;ooo]Z0_l000000ooonf[o0000oookJP02oookJP;o00001?oonfX01Ol0003ooo]Zoook
J_oonf[o000000Cooo]Z00[o0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o00000_oo
nfX00ol0003ooo]Zo`000004oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00Co0000oookJ_l0003o
00000_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000;ooo]Z1ol00003oookJPKo000000Cooo]Z
o`000?l0003o0000>OoonfX4o`000003oookJ_l0003o000000?o00000ooonfX2o`0000Cooo]Z00Go
0000oookJ_oonf[ooo]Zo`000002oookJP;o00000_oonfX2o`0000?ooo]Z00Ko0000oookJ_oonf[o
0000oookJ_l00002oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[ooo]Z0_l0
0002oookJP;o00000ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX00_oonfX2o`000007oookJ_l0003ooo]ZoookJ_l0003ooo]Zo`000002oookJP04
o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00_oonfX4o`0000Cooo]Z0_l000001Ooo
nf[o0000oookJ_oonf[o000000;ooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Z
o`000?oonfX00_l00004oookJP04o`000?oonf[o0000o`0000;ooo]Z00?o0000oookJ_l000001?oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o0000
00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP05o`0000;ooo]Z00Go0000oook
J_oonf[o0000oookJP02o`0000Kooo]Z0_l000000ooonf[o0000oookJP02oookJP04o`000?oonf[o
oo]ZoookJP7o000000000ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP02oookJP;o00000_oonfX2o`0000;ooo]Z00Go0000
oookJ_oonf[ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00;o00001OoonfX3o`0000Oooo]Z0ol0
0002oookJP04o`000?oonf[o0000oookJP?o000000?ooo]Zo`000?oonfX00_l000001ooonf[o0000
oookJ_oonf[o0000oookJ_l000002OoonfX3o`000004oookJ_l0003o0000o`0000Wooo]Z00?o0000
oookJ_oonfX00_l00005oookJP?o000000?ooo]Zo`000?l000001?oonfX3o`0000;ooo]Z0_l00005
oookJP;o00001?oonfX00ol0003ooo]ZoookJP07oookJP;o00003OoonfX01ol0003ooo]ZoookJ_oo
nf[o0000oookJ_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_l0
00000ooonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Wooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?o00000ooonfX00ol0003ooo]ZoookJP02
o`000003oookJ_l0003ooo]Z00;ooo]Z00Co0000oookJ_l0003o00000_oonfX3o`000003oookJ_l0
003o000000;o0000>OoonfX8o`000003oookJ_l0003ooo]Z00;o000000Gooo]Zo`000?l0003ooo]Z
o`000002oookJP;o00000_oonfX2o`000005oookJ_l0003ooo]ZoookJ_l000000ooonfX2o`0000_o
oo]Z00Co0000oookJ_oonf[o00000ooonfX3o`000003oookJ_l0003o000000?o00003?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000001_oonf[o0000oookJ_l0003o
oo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP?o00001Ooo
nfX2o`0000;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[o000000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJPCo000000Cooo]Zo`000?oonf[o
oo]Z0ol00003oookJP03o`000?oonf[o000000?ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00004
oookJP?o00000ooonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z1?l00004oookJP06o`000?oo
nf[ooo]Zo`000?oonf[o00000ooonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oook
J_oonfX00_oonfX01?l0003ooo]Zo`000?l00002oookJP7o000000000ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_l00006oookJP;o00000_oonfX2o`00
00?ooo]Z0_l000001Ooonf[o0000o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00_oonfX0
1?l0003ooo]Zo`000?l00003oookJP04o`000?oonf[ooo]ZoookJP;o00001OoonfX3o`0000;ooo]Z
0ol00002oookJP03o`000?oonf[o0000013ooo]Z1?l00009oookJP03o`000?oonf[ooo]Z00Gooo]Z
00Co0000oookJ_oonf[o00001?oonfX3o`000005oookJ_l0003o0000o`000?oonfX01?l000000ooo
nf[o0000oookJP0<oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]Zo`000007oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP03o`000004oookJ_l0003ooo]Zo`0000Cooo]Z00Co0000oookJ_oonf[ooo]Z
0_l000001?oonf[o0000o`000?l00004oookJPGo00001?oonfX3o`0000Gooo]Z0_l000001?oonf[o
0000o`000?oonfX4o`0003[ooo]Z0_l000000ooonf[o0000o`000002o`0000Cooo]Z00Co0000oook
J_oonf[ooo]Z0ol00003oookJP03o`000?oonf[o000000;o00000_oonfX00ol0003ooo]Zo`000007
oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX01?l0003ooo]ZoookJ_l00006oookJP;o0000
00?ooo]Zo`000?oonfX02ooonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00;o
00000ooonfX00ol0003ooo]Zo`000002o`0000Sooo]Z00?o0000oookJ_l000000ooonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Co00000_oonfX3o`000003oookJ_l0003ooo]Z00Co
oo]Z1?l00009oookJPCo00000_oonfX3o`0000;ooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00;o
00001?oonfX3o`000003oookJ_l0003ooo]Z00?ooo]Z00Go0000oookJ_l0003ooo]Zo`000002oook
JP;o00000ooonfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000
oookJ_oonf[o00000ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02oookJP;o00000_oonfX2o`000004oookJ_l0
003ooo]ZoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000Co0000
oookJ_oonf[o00001_oonfX3o`0000Oooo]Z0ol00003oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z
00?o0000oookJ_oonfX00_oonfX2o`000003oookJ_l0003o000000Cooo]Z00Co0000oookJ_oonf[o
00000ooonfX01ol0003ooo]Zo`000?l0003ooo]Zo`000?oonfX01Ol00002oookJP05o`000?oonf[o
oo]ZoookJ_l000000_oonfX3o`000003oookJ_l0003ooo]Z00Gooo]Z00?o0000oookJ_oonfX00ooo
nfX01?l0003ooo]ZoookJ_l00003oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_l00000
0ooonfX2o`0000;ooo]Z0_l00006oookJP;o00000ooonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`00
00;ooo]Z1_l0000:oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0
003ooo]ZoookJP03o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP02
oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP03o`000003oookJ_l0
003ooo]Z00;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000002oookJP;o00000_oo
nfX00ol0003ooo]ZoookJP03oookJP?o00000_oonfX01?l0003ooo]Zo`000?oonfX7o`000004oook
J_l0003o0000o`0003_ooo]Z1ol000000ooonf[o0000o`000005oookJP05o`000?oonf[o0000oook
J_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000cooo]Z00?o0000oookJ_oonfX00ooonfX0
1?l0003ooo]ZoookJ_oonfX2o`0000cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zo`00
0003oookJP03o`000?oonf[o000000kooo]Z00?o0000oookJ_oonfX02?oonfX01?l0003ooo]Zoook
J_l00003oookJP?o00000_oonfX3o`000004oookJ_l0003ooo]ZoookJPGo000000Sooo]Zo`000?oo
nf[ooo]Zo`000?oonf[o0000oookJP?o00001?oonfX01?l0003ooo]ZoookJ_oonfX2o`0000?ooo]Z
00?o0000oookJ_oonfX00_oonfX2o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX00ol0003o
oo]Zo`000004oookJPKo000000Kooo]Zo`000?oonf[ooo]Zo`000?oonfX2o`000003oookJ_l0003o
oo]Z00;o00001OoonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000
oookJ_oonf[ooo]Z1_l00002oookJPCo00001OoonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o0000
1OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z007o000000001?l0003ooo]Zoook
J_l00005oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z
00;o00000_oonfX2o`0000;ooo]Z00Co0000oookJ_l0003o00000ooonfX00ol0003ooo]Zo`000002
o`000007oookJ_l0003ooo]ZoookJ_l0003ooo]Zo`000005oookJP04o`000?oonf[o0000oookJP?o
00000_oonfX00ol0003ooo]Zo`000002o`0000?ooo]Z1?l00003oookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX02ooonfX3o`000003oookJ_l0003ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP02o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX4o`00
00Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP;o00002?oonfX01Ol0
003ooo]Zo`000?oonf[o000001;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02
oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`000005oookJP03o`000?oonf[o000000;ooo]Z
00?o0000oookJ_oonfX00ol00003oookJP;o00001?oonfX2o`000003oookJ_l0003o000000Cooo]Z
00Co0000oookJ_oonf[ooo]Z0_l000001Ooonf[o0000o`000?l0003ooo]Z00?o000000?ooo]Zo`00
0?l00000?OoonfX5o`000003oookJ_l0003ooo]Z00;o00000_oonfX4o`000003oookJ_l0003ooo]Z
00;ooo]Z00?o0000oookJ_oonfX00ooonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Kooo]Z00?o
0000oookJ_l000000ooonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z0_l0000;oookJPCo0000
00?ooo]Zo`000?oonfX00ooonfX00ol0003ooo]Zo`000003oookJP05o`000?oonf[ooo]ZoookJ_l0
00004OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_l0
00001?l00003oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX01_l0003ooo]ZoookJ_oonf[o
0000oookJP?o000000Cooo]Zo`000?l0003ooo]Z0ol00008oookJP04o`000?oonf[o0000o`0000?o
oo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]Zo`000003oookJP;o00000_oonfX00ol0003o
oo]ZoookJP02oookJP?o00000_oonfX9o`0000Gooo]Z00?o0000oookJ_l000001?l000000ooonf[o
0000o`000004oookJP04o`000?oonf[ooo]ZoookJP;o00000_oonfX2o`0000;ooo]Z00Go0000oook
J_l0003ooo]Zo`000004oookJP04o`000?oonf[ooo]ZoookJP;o00000_oonfX2o`0000Gooo]Z0Ol0
00000003o`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000002
o`0000?ooo]Z0_l00002oookJP;o00000ooonfX2o`0000Sooo]Z00Co0000oookJ_l0003o00000_oo
nfX01_l0003ooo]Zo`000?l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_l000000_l000001?oonf[o
0000oookJ_oonfX3o`0000?ooo]Z00Co0000oookJ_l0003o00000ooonfX00ol0003ooo]ZoookJP07
oookJP;o00000_oonfX01?l0003ooo]ZoookJ_l00002oookJP08o`000?oonf[o0000o`000?oonf[o
0000oookJ_l00002oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00_oonfX01?l0
003ooo]Zo`000?l00002oookJPGo000000Kooo]Zo`000?l0003o0000oookJ_l00002oookJP03o`00
0?oonf[o000000Wooo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP0CoookJP07o`00
0?oonf[ooo]ZoookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oook
J_oonf[o0000oookJP02o`0000?ooo]Z00?o0000oookJ_l000000_oonfX2o`000003oookJ_l0003o
oo]Z00?ooo]Z1Ol000001?oonf[o0000oookJ_l00003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z
00Co0000oookJ_oonf[o00000_oonfX9o`0003gooo]Z1_l000001ooonf[o0000o`000?l0003ooo]Z
o`000?oonfX02?l000000ooonf[o0000oookJP03oookJP04o`000?oonf[o0000o`0000Cooo]Z00?o
0000oookJ_l000001OoonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Cooo]Z0_l00005oookJP03
o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_l0003o00000ooonfX00ol0003ooo]Zo`000007oook
JP;o000000?ooo]Zo`000?oonfX02OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o0000
00;ooo]Z0ol00002oookJP;o000000Gooo]Zo`000?oonf[o0000oookJP02o`000003oookJ_l0003o
oo]Z00;o00000ooonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;o00001_oonfX01?l0003ooo]ZoookJ_oo
nfX2o`000003oookJ_l0003ooo]Z00?ooo]Z0_l000000ooonf[o0000oookJP05o`000004oookJ_l0
003ooo]ZoookJPCo00000_oonfX2o`0000?ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Z
oookJP02oookJP04o`000?oonf[ooo]Zo`0000Oooo]Z0ol00008oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJP7o000000000ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00;o00000_oonfX3o`0000Cooo]Z00Go0000oookJ_oonf[o
oo]Zo`000002oookJP03o`000?oonf[ooo]Z00Gooo]Z0ol000000ooonf[o0000oookJP03oookJP;o
000000?ooo]Zo`000?oonfX00_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000;ooo]Z00Co0000
oookJ_l0003o00000_oonfX01?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z
00Co0000oookJ_l0003o00000ooonfX2o`000008oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0
0002oookJP05o`000?oonf[o0000oookJ_l000000ooonfX00ol0003ooo]Zo`000004oookJP03o`00
0?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ooonfX02?l0003ooo]ZoookJ_oonf[o0000oook
J_l0003ooo]Z0ol00002oookJP04o`000?oonf[ooo]Zo`0000_ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000<oookJP05o`000?oo
nf[ooo]ZoookJ_l000001ooonfX2o`0000;ooo]Z00Co0000oookJ_oonf[o00001?oonfX3o`0000Co
oo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]ZoookJP04oookJPGo00000_oonfX00ol0003o
oo]Zo`000002o`0000;ooo]Z1?l0000ooookJP_o00000_oonfX00ol0003ooo]ZoookJP02oookJP;o
000000Cooo]Zo`000?oonf[ooo]Z1ol00003oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00006oook
JP03o`000?oonf[o000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP04o`000?oonf[o
oo]Zo`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000DoookJP03o`000?oonf[ooo]Z00;ooo]Z
0_l00003oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX7o`000005oook
J_l0003o0000oookJ_l000000_oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00So
oo]Z00Go0000oookJ_oonf[ooo]Zo`00000;oookJP;o00001ooonfX00ol0003ooo]ZoookJP02o`00
00Cooo]Z1ol00002oookJP04o`000?oonf[o0000o`0000?ooo]Z1_l00005oookJP;o000000?ooo]Z
o`000?l000001?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol00003
oookJP04o`000?oonf[o0000o`0000;ooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]Zo`00
0003oookJP04o`000?oonf[ooo]ZoookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000Go0000oookJ_l0003o0000oookJP03o`0000?ooo]Z00?o0000oookJ_l000001?oo
nfX00ol0003ooo]ZoookJP04oookJP;o00000_oonfX2o`0000;ooo]Z0ol00002oookJP03o`000?oo
nf[o000000_ooo]Z00?o0000oookJ_l000000_l000000ooonf[o0000o`000003oookJPGo00000_oo
nfX8o`0000Kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00[o0000oookJ_l0003o0000oookJ_l0003ooo]Zo`000?oonf[o00000_oonfX0
1Ol0003ooo]Zo`000?oonf[o000000Cooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP;o0000
2OoonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_l0003o
00000_oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z00So0000oookJ_l0
003o0000oookJ_l0003ooo]Zo`0000?ooo]Z0_l000001?oonf[o0000oookJ_l00007oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[o0000oookJP03o`0000?ooo]Z00?o0000oookJ_l0
00001?oonfX2o`0000;ooo]Z00Co0000oookJ_l0003o00001?oonfX?o`0003oooo]Z2Ol000001_oo
nf[o0000o`000?l0003ooo]Zo`0000Wooo]Z0ol000000ooonf[o0000oookJP03oookJP04o`000?oo
nf[o0000o`0000;ooo]Z00?o0000oookJ_l000001?oonfX2o`000003oookJ_l0003ooo]Z00oooo]Z
00?o0000oookJ_l000002_oonfX00ol0003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l0
00000_oonfX2o`000004oookJ_l0003ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Go0000oookJ_oonf[o0000oook
JP02o`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000?ooo]Z0_l00002oookJP03o`000?oo
nf[ooo]Z00;ooo]Z0_l0000=oookJP03o`000?oonf[o000000;ooo]Z0_l00008oookJP;o000000Go
oo]Zo`000?l0003o0000oookJP03o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX3o`0000?o
oo]Z00?o0000oookJ_oonfX00_oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Co
oo]Z00Go0000oookJ_l0003ooo]Zo`000003oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000_oo
nfX00ol0003ooo]ZoookJP03oookJP7o000000001?l0003ooo]Zo`000?oonfX2o`000004oookJ_l0
003o0000o`0000Cooo]Z0_l00004oookJP?o00000_oonfX2o`0000;ooo]Z0_l0000:oookJP03o`00
0?oonf[o000000Gooo]Z00Go0000oookJ_l0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX00_oonfX2o`000003oookJ_l0003o000000Co00001?oonfX5o`000003
oookJ_l0003ooo]Z00Sooo]Z00?o0000oookJ_oonfX01?oonfX2o`000005oookJ_l0003ooo]Zo`00
0?oonfX00_l000000ooonf[o0000oookJP02o`000003oookJ_l0003ooo]Z00?ooo]Z0_l000000ooo
nf[o0000o`000003oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX2o`0000;ooo]Z0_l00007
oookJP;o00001OoonfX00ol0003ooo]ZoookJP07oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z0ol0
000<oookJP03o`000?oonf[ooo]Z00;ooo]Z1?l000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z
00Co0000oookJ_l0003o00000_oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o000000?ooo]Zo`00
0?l000000_oonfX3o`0000?ooo]Z0_l00003oookJP;o000000?ooo]Zo`000?oonfX00_l000000ooo
nf[o0000o`000002o`000003oookJ_l0003o000000?o0000@?oonfX6o`000003oookJ_l0003o0000
00;o000000?ooo]Zo`000?oonfX00ol00004oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX0
0ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_l000000_l0
0003oookJP;o00002OoonfX3o`0000cooo]Z00Co0000oookJ_l0003o00001?oonfX2o`0000?ooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zo`00000>oookJP04o`000?oonf[o0000o`0000;o
oo]Z0ol00002oookJP03o`000?oonf[ooo]Z00;o00001ooonfX00ol0003ooo]ZoookJP02oookJP04
o`000?oonf[o0000oookJP;o00001_oonfX01?l0003ooo]ZoookJ_l00003oookJP04o`000?oonf[o
oo]ZoookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`000006oookJP03o`000?oonf[o000000;o0000
00Wooo]Zo`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l000001?oonfX00ol0003ooo]Zo`000002
o`0000;ooo]Z00?o0000oookJ_oonfX02ooonfX4o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000
oookJ_oonfX00_l00006oookJP03o`000?oonf[ooo]Z00Sooo]Z00Co0000oookJ_l0003o00000_oo
nfX1o`00000000?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z00Wooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co
0000oookJ_l0003o00000_oonfX3o`000008oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l00004
oookJP;o000000?ooo]Zo`000?oonfX01?oonfX4o`0000Gooo]Z1?l00002oookJP03o`000?oonf[o
oo]Z00Cooo]Z0_l000002?oonf[o0000o`000?oonf[o0000oookJ_l0003ooo]Z0_l00006oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000;ooo]Z0ol00005oookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol000001?oonf[o0000o`000?l00009oookJP03o`000?oonf[ooo]Z
00Kooo]Z0ol00006oookJP03o`000?oonf[ooo]Z00oooo]Z0_l00003oookJP03o`000?oonf[ooo]Z
00gooo]Z00Go0000oookJ_oonf[ooo]Zo`000008oookJP03o`000?oonf[ooo]Z00Cooo]Z00So0000
oookJ_l0003o0000oookJ_l0003ooo]Zo`0000Cooo]Z1?l000000ooonf[o0000oookJP08o`00047o
oo]Z0ol000001?oonf[o0000o`000?oonfX6o`000003oookJ_l0003o000000?ooo]Z0_l000001Ooo
nf[o0000oookJ_l0003ooo]Z00;o000000Kooo]Zo`000?oonf[ooo]Zo`000?oonfX2o`0000;ooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o000000;ooo]Z
00Go0000oookJ_oonf[ooo]Zo`000008oookJP04o`000?oonf[ooo]ZoookJP;o00001?oonfX01Ol0
003ooo]ZoookJ_oonf[o000000Kooo]Z0ol00003oookJP03o`000?oonf[ooo]Z00?o00000_oonfX8
o`000003oookJ_l0003o000000;ooo]Z00Go0000oookJ_l0003ooo]Zo`000004oookJP?o00000_oo
nfX3o`0000;ooo]Z0_l000001?oonf[o0000o`000?l00008oookJP05o`000?oonf[ooo]ZoookJ_l0
00000_oonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o00001_oonfX6o`00000<oookJ_l0003o
oo]ZoookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z1Ol00004oookJP06o`000?oonf[o
0000o`000?oonf[o00007OoonfX2o`0000;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z
0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]ZoookJP02
o`0000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP?o000000?ooo]Zo`000?oonfX01?oo
nfX2o`0000;ooo]Z0_l00002oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ooo
nfX2o`0000;ooo]Z00?o0000oookJ_l000000ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o0000
0_oonfX01?l0003ooo]Zo`000?oonfX8o`000005oookJ_l0003ooo]ZoookJ_l000000ooonfX01?l0
003ooo]Zo`000?l00007oookJP03o`000?oonf[o000000cooo]Z00?o0000oookJ_oonfX00ooonfX0
2Ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000002oookJP03o`000?oonf[o000000;o
oo]Z00Co0000oookJ_l0003o00000_oonfX6o`0000Cooo]Z0_l00005oookJP;o00001OoonfX00ol0
003ooo]ZoookJP04oookJP04o`000?oonf[ooo]Zo`0000gooo]Z00?o0000oookJ_oonfX00_l00005
oookJP;o000000Cooo]Zo`000?oonf[o00001OoonfX02Ol0003ooo]ZoookJ_oonf[o0000oookJ_l0
003ooo]Zo`000003oookJP03o`000?oonf[o000000;o00001OoonfX00ol0003ooo]ZoookJP02oook
JP05o`000?oonf[o0000o`000?oonfX00_l000001Ooonf[o0000o`000?oonf[o000000;ooo]Z1ol0
0013oookJP?o000000Cooo]Zo`000?l0003ooo]Z1?l000000ooonf[o0000oookJP02o`0000;ooo]Z
0_l00007oookJP03o`000?oonf[ooo]Z00;o00000ooonfX3o`000003oookJ_l0003ooo]Z00Gooo]Z
0ol00002oookJPGo00001?oonfX00ol0003ooo]ZoookJP02o`0000Cooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00_ooo]Z0_l00005oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_l000000_l000000ooonf[o0000o`000003oookJP;o0000
00?ooo]Zo`000?l000002OoonfX2o`000003oookJ_l0003ooo]Z00;o000000Cooo]Zo`000?oonf[o
oo]Z0_l000000ooonf[o0000oookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0
003ooo]ZoookJP03oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX00ol0003ooo]ZoookJP06
o`000005oookJ_l0003o0000oookJ_l000001?oonfX2o`000003oookJ_l0003ooo]Z00Wooo]Z00Go
0000oookJ_l0003ooo]Zo`000003oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oo
nfX01?oonfX01?l0003ooo]ZoookJ_oonfX2o`0000?ooo]Z00?o0000oookJ_l000002?oonfX1o`00
000000?o0000oookJ_l000000ooonfX01?l0003ooo]Zo`000?l0000:oookJP;o00000ooonfX2o`00
00;ooo]Z0_l00006oookJPCo000000?ooo]Zo`000?oonfX01?l00003oookJP;o00000_oonfX3o`00
0003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?l000001?oonf[o0000o`000?l0000?
oookJP04o`000?oonf[o0000oookJP?o00000_oonfX00ol0003ooo]Zo`000002o`000003oookJ_l0
003o000000;o00000ooonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[o0000o`0000;ooo]Z
00?o0000oookJ_oonfX00_oonfX4o`000004oookJ_l0003o0000o`0000;ooo]Z0_l000001?oonf[o
0000oookJ_l00002oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?l0003o00001OoonfX0
0ol0003ooo]Zo`000002oookJP03o`000?oonf[o000000Wooo]Z00?o0000oookJ_oonfX00_l00000
0ooonf[o0000o`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_l0003o00001ooo
nfX2o`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000003oookJP05o`000?oo
nf[ooo]ZoookJ_l000001_oonfX2o`000003oookJ_l0003ooo]Z00?ooo]Z0ol00002oookJP;o0000
00Cooo]Zo`000?oonf[ooo]Z1?l00013oookJPGo000000Sooo]Zo`000?oonf[ooo]Zo`000?oonf[o
0000oookJP;o000000?ooo]Zo`000?l000000_l000001_oonf[o0000o`000?l0003ooo]Zo`0000?o
oo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP02o`0000Kooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol00005oookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oookJPGo00000_oonfX3o`00
0004oookJ_l0003o0000o`0000;ooo]Z00?o0000oookJ_oonfX02_oonfX2o`000004oookJ_l0003o
oo]ZoookJP?o00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000Sooo]Z00Go
0000oookJ_l0003ooo]Zo`000002oookJP07o`000?oonf[ooo]Zo`000?oonf[o0000oookJP02o`00
00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]Zo`000002oookJP05o`000?oonf[o0000o`000?oonfX01?l0
0005oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]Zo`000002oookJP?o0000
0_oonfX01?l0003ooo]Zo`000?l00005oookJP7o00000OoonfX1o`00000000?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP08oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00004oookJP03o`000?oonf[o000000;o
oo]Z0_l00002oookJP04o`000?oonf[ooo]ZoookJPKo000000Gooo]Zo`000?oonf[o0000oookJP04
o`000003oookJ_l0003ooo]Z00;o00001_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000002oookJP08o`000?oonf[o
oo]ZoookJ_l0003ooo]Zo`000?oonfX2o`0000Oooo]Z00?o0000oookJ_l000000_oonfX00ol0003o
oo]ZoookJP02o`0000;ooo]Z1ol00005oookJP06o`000?oonf[o0000o`000?oonf[o00001_oonfX0
0ol0003ooo]ZoookJP02oookJP05o`000?oonf[o0000oookJ_l000001?oonfX01?l0003ooo]Zo`00
0?l00008oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_l000002_oonfX00ol0003ooo]Z
oookJP08oookJP;o00001ooonfX01?l0003ooo]Zo`000?l00005oookJP03o`000?oonf[o000000?o
oo]Z1?l000000ooonf[o0000o`000004o`0004Gooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z
00Co00000_oonfX00ol0003ooo]ZoookJP05o`0000Oooo]Z00?o0000oookJ_oonfX02?oonfX4o`00
00Cooo]Z0_l000000ooonf[o0000o`000002oookJP04o`000?oonf[o0000o`0000Gooo]Z00Co0000
oookJ_oonf[o00003_oonfX2o`0001;ooo]Z00?o0000oookJ_oonfX01OoonfX3o`0000?ooo]Z0_l0
00001ooonf[o0000oookJ_oonf[o0000oookJ_l000000_oonfX2o`000006oookJ_l0003ooo]Zo`00
0?oonf[o00000ooonfX00ol0003ooo]Zo`000005oookJP;o00000ooonfX2o`000003oookJ_l0003o
000000Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02o`0000Sooo]Z00Co0000
oookJ_l0003ooo]Z0_l00006oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z0ol00003oookJP03o`00
0?oonf[o000000Wooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP?o00001ooonfX2o`0000?o
oo]Z00Go0000oookJ_l0003ooo]Zo`000004oookJP03o`000?oonf[o000000?ooo]Z0Ol000000004
o`000?oonf[ooo]ZoookJP;o00001?oonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oonf[o
000000;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oookJP;o00000_oonfX00ol0003ooo]Zo`00
0002oookJP;o000000Cooo]Zo`000?oonf[o00001?oonfX2o`000005oookJ_l0003ooo]Zo`000?oo
nfX00_l000000ooonf[o0000oookJP02o`0000;ooo]Z1?l00002oookJP05o`000?oonf[o0000oook
J_l000000_oonfX2o`0000?ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol000000ooo
nf[o0000oookJP02oookJP;o00000_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00Oooo]Z00Co0000oookJ_oonf[o00001?oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX01?l00002
oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003ooo]Zoook
JP0FoookJP;o00002OoonfX00ol0003ooo]ZoookJP03oookJP;o00002_oonfX00ol0003ooo]Zoook
JP02oookJP;o000000?ooo]Zo`000?oonfX00_oonfX2o`0000Gooo]Z1?l000000ooonf[o0000o`00
0002o`000003oookJ_l0003o000000?o00000ooonfX00ol0003ooo]Zo`000003o`0004Gooo]Z1ol0
00000ooonf[o0000oookJP02oookJP?o00001OoonfX00ol0003ooo]ZoookJP05oookJP07o`000?oo
nf[o0000o`000?oonf[o0000oookJP02o`0000;ooo]Z0ol000002?oonf[o0000oookJ_oonf[o0000
oookJ_l0003ooo]Z0_l00004oookJP03o`000?oonf[o000000;o000000Wooo]Zo`000?oonf[ooo]Z
o`000?oonf[o0000oookJ_l000002?oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX00_oonfX2o`00
00?ooo]Z00Co0000oookJ_oonf[o00001_oonfX01?l0003ooo]ZoookJ_oonfX4o`000003oookJ_l0
003ooo]Z00Go00000ooonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP09oookJP05o`000?oonf[ooo]ZoookJ_l00000
0ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Oooo]Z2ol00003oookJP04o`00
0?oonf[o0000o`0000?ooo]Z00?o0000oookJ_l000000ooonfX2o`000003oookJ_l0003ooo]Z00?o
oo]Z00?o0000oookJ_oonfX01ooonfX5o`0000Cooo]Z0ol000000ooonf[o0000o`000004oookJP06
o`000?oonf[ooo]Zo`000?oonf[o00001OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0Ol000000003o`000?oonf[ooo]Z00?ooo]Z0_l00006oookJP;o000000Gooo]Zo`000?l0
003ooo]Zo`000004oookJP;o00000_oonfX2o`0000;ooo]Z0_l000000ooonf[o0000oookJP04oook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000000ol000000ooonf[o0000oookJP02oook
JP03o`000?oonf[ooo]Z00;ooo]Z1?l000000ooonf[o0000oookJP03o`0000Sooo]Z00Co0000oook
J_oonf[o00000_oonfX2o`000004oookJ_l0003ooo]ZoookJPCo000000Gooo]Zo`000?l0003ooo]Z
o`000004oookJP;o00001?oonfX2o`000003oookJ_l0003ooo]Z00?ooo]Z00Ko0000oookJ_l0003o
0000oookJ_l00004oookJP04o`000?oonf[o0000oookJPGo000000?ooo]Zo`000?l000000ol0000:
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]Zo`000004
oookJP03o`000?oonf[ooo]Z00oooo]Z0_l000001ooonf[o0000oookJ_oonf[o0000oookJ_l00000
0_oonfX2o`000003oookJ_l0003o000000?ooo]Z00Co0000oookJ_oonf[o00000_oonfX3o`000003
oookJ_l0003ooo]Z00;ooo]Z1ol00002oookJPGo000000Gooo]Zo`000?l0003o0000oookJP02o`00
0003oookJ_l0003o000004Oooo]Z1ol000000ooonf[o0000oookJP03o`0000Sooo]Z00?o0000oook
J_oonfX01_oonfX01?l0003ooo]ZoookJ_l0000<oookJP;o00002_oonfX00ol0003ooo]Zo`000002
o`000003oookJ_l0003o000000;o00001_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
000000Oooo]Z0_l0000AoookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0
00000ooonf[o0000oookJP03o`0000Cooo]Z00?o0000oookJ_l000001?oonfX01?l0003ooo]Zo`00
0?l00009oookJP;o00002OoonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00;ooo]Z
0ol00002oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX01?l0003ooo]ZoookJ_l00003oook
JP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`000?l000000_oonfX2o`0000?ooo]Z0ol00002oook
JP;o000000Cooo]Zo`000?oonf[o00001?oonfX00ol0003ooo]Zo`000006oookJP;o00001?oonfX0
0ol0003ooo]ZoookJP04oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX1o`00000000?o0000
oookJ_oonfX01_oonfX02ol0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000
00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP;o00001?oonfX01_l0003ooo]Zo`000?l0
003ooo]Zo`0000;ooo]Z0_l00003oookJP04o`000?oonf[o0000o`0000Gooo]Z00?o0000oookJ_oo
nfX00_oonfX01?l0003ooo]ZoookJ_oonfX6o`0000;ooo]Z00?o0000oookJ_oonfX00_l00002oook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Gooo]Z00Go0000oook
J_l0003ooo]Zo`000005oookJP;o00001?oonfX02ol0003ooo]Zo`000?l0003ooo]Zo`000?oonf[o
0000oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?l000001?l00002oookJP;o000000?ooo]Zo`00
0?l000000ooonfX00ol0003ooo]ZoookJP0;oookJP;o00001ooonfX02?l0003ooo]ZoookJ_l0003o
oo]Zo`000?oonf[o00001_oonfX00ol0003ooo]Zo`000008oookJP05o`000?oonf[ooo]ZoookJ_l0
00000_oonfX2o`000003oookJ_l0003ooo]Z00Gooo]Z00Co0000oookJ_oonf[o00002OoonfX00ol0
003ooo]ZoookJP04o`0000;ooo]Z0ol000001?oonf[o0000o`000?l00002oookJP03o`000?oonf[o
000000Co0000B?oonfX4o`000006oookJ_l0003o0000oookJ_l0003ooo]Z0_l000001?oonf[o0000
oookJ_l00004oookJP03o`000?oonf[ooo]Z00Oooo]Z00Go0000oookJ_l0003ooo]Zo`000002oook
JP04o`000?oonf[ooo]ZoookJP?o000000Gooo]Zo`000?l0003ooo]Zo`000002oookJP04o`000?oo
nf[o0000oookJP?o00003?oonfX00ol0003ooo]ZoookJP03oookJP;o00000_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000Wooo]Z0_l00004oookJP03o`000?oonf[o000000?ooo]Z0_l000001?oonf[o
0000o`000?oonfX3o`0000?ooo]Z0_l000001?oonf[o0000o`000?oonfX4o`0000Cooo]Z0_l0000>
oookJP04o`000?oonf[ooo]ZoookJP;o000000?ooo]Zo`000?oonfX00_oonfX2o`0000;ooo]Z00?o
0000oookJ_oonfX03OoonfX4o`0000;ooo]Z0ol00005oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0
00001?oonf[o0000oookJ_l00003oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_l0
00001OoonfX2o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ooonfX4o`0000;o
oo]Z0_l00002oookJP7o000000000ol0003ooo]Zo`000002oookJPCo000000Cooo]Zo`000?l0003o
00002?oonfX2o`0000;ooo]Z0_l00002oookJP04o`000?oonf[ooo]ZoookJP;o00000_oonfX2o`00
0003oookJ_l0003o000000;ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP02oook
JP;o000000Cooo]Zo`000?l0003o00001?oonfX01?l0003ooo]ZoookJ_oonfX3o`0000?ooo]Z00?o
0000oookJ_l000000_oonfX3o`0000Cooo]Z0_l00005oookJP06o`000?oonf[ooo]ZoookJ_l0003o
oo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Co00001OoonfX01?l0003ooo]Zo`000?oonfX3o`00
00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00Oo00002?oonfX00ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z1?l000001?oo
nf[o0000o`000?oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX01?oonfX2o`00013ooo]Z2_l00000
0ooonf[o0000oookJP04o`0004Wooo]Z0ol000001?oonf[o0000o`000?oonfX3o`0000;ooo]Z00?o
0000oookJ_l000001?l00005oookJP?o00001?oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oo
nf[ooo]Zo`0000?ooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP05oookJP;o0000
0_oonfX00ol0003ooo]ZoookJP03oookJP;o00001OoonfX01Ol0003ooo]ZoookJ_oonf[o000000?o
oo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP0:oookJPCo00002_oonfX01Ol0003o
oo]Zo`000?oonf[o000000Kooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l000000ooo
nf[o0000o`000004oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00007oookJP03o`000?oonf[o0000
00Cooo]Z1Ol00002oookJP;o00000_oonfX01?l0003ooo]Zo`000?oonfX3o`0000Cooo]Z00Co0000
oookJ_l0003o00000ooonfX01?l0003ooo]ZoookJ_l00003oookJP;o00000_oonfX01ol0003ooo]Z
oookJ_oonf[o0000oookJ_l000000ooonfX4o`00013ooo]Z0Ol00001oookJP7o000000000ol0003o
oo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000Ko0000oookJ_l0003o0000oookJ_l00002oook
JP03o`000?oonf[ooo]Z00;ooo]Z0_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[o0000
00;ooo]Z0_l00002oookJP;o00003?oonfX2o`000003oookJ_l0003o000000?ooo]Z00Co0000oook
J_oonf[o00000_oonfX00ol0003ooo]Zo`000004o`0000;ooo]Z00Go0000oookJ_l0003ooo]Zo`00
0007oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0
0002oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX01?oonfX2o`000003oookJ_l0
003ooo]Z00;o00000_oonfX2o`000003oookJ_l0003o000000Wooo]Z00Co0000oookJ_l0003o0000
0_oonfX00ol0003ooo]ZoookJP08oookJP04o`000?oonf[ooo]Zo`0000gooo]Z00Co0000oookJ_oo
nf[o00001_oonfX3o`000003oookJ_l0003ooo]Z00Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]Zo`000003oookJP03o`000?oonf[o000000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00000
1Ooonf[o0000o`000?oonf[o000000;ooo]Z0ol000002ooonf[o0000oookJ_l0003ooo]Zo`000?oo
nf[o0000oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?l000001?l0001;oookJP[o000000Gooo]Z
o`000?oonf[ooo]Zo`000002oookJP;o00000_oonfX00ol0003ooo]Zo`000005oookJP03o`000?oo
nf[ooo]Z00Co00000ooonfX2o`0000;ooo]Z00Co0000oookJ_oonf[o00001?oonfX01?l0003ooo]Z
oookJ_l00005oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX02Ol0003ooo]Zo`000?oonf[o
0000oookJ_l0003ooo]Zo`000003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_l0
00000_oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX01Ol00002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003o
oo]ZoookJ_l00004oookJP?o000000Cooo]Zo`000?l0003o00001_oonfX00ol0003ooo]ZoookJP05
oookJP04o`000?oonf[ooo]ZoookJP;o00001?oonfX01_l0003ooo]Zo`000?oonf[o0000oookJP;o
00000_oonfX00ol0003ooo]ZoookJP06oookJP;o00001?oonfX00ol0003ooo]Zo`000002o`0000;o
oo]Z0_l000000ooonf[o0000oookJP05oookJPCo00000ooonfX00ol0003ooo]Zo`000003oookJP05
o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00?ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00008oookJP7o000000001Ol0003ooo]ZoookJ_oo
nf[o000000Cooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000;ooo]Z00Co0000oookJ_oonf[ooo]Z
0_l00002oookJP;o00000_oonfX4o`000004oookJ_l0003o0000oookJP?o00000_oonfX01?l0003o
oo]ZoookJ_l00002oookJP;o00000_oonfX2o`000003oookJ_l0003ooo]Z00Co000000?ooo]Zo`00
0?oonfX00_l00002oookJP04o`000?oonf[ooo]Zo`0000Sooo]Z00?o0000oookJ_oonfX00_oonfX3
o`0000?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000005oookJP;o000000?ooo]Z
o`000?l000000ooonfX00ol0003ooo]Zo`000006oookJP05o`000?oonf[ooo]ZoookJ_l000000_oo
nfX00ol0003ooo]ZoookJP03oookJP04o`000?oonf[ooo]ZoookJPCo00004OoonfX01?l0003ooo]Z
o`000?l00009oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l000000ooonf[o0000o`000005oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP;o
000000Gooo]Zo`000?oonf[o0000oookJP03o`000006oookJ_l0003ooo]Zo`000?oonf[o00000_oo
nfX2o`000008oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l00002oookJPGo0000BooonfX4o`00
0004oookJ_l0003o0000oookJP?o00000ooonfX2o`0000;ooo]Z0_l000000ooonf[o0000o`00000=
oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00002oookJP04o`000?oonf[ooo]ZoookJP;o00000_oo
nfX00ol0003ooo]ZoookJP05oookJP05o`000?oonf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[o000000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03
o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l000000ooonf[o0000oookJP03o`00
00;ooo]Z0ol000000ooonf[o0000o`000002oookJP03o`000?oonf[o000000?ooo]Z00Oo0000oook
J_oonf[ooo]Zo`000?oonf[o000000;ooo]Z00Go0000oookJ_oonf[o0000oookJP07o`0000Gooo]Z
0ol000000ooonf[o0000oookJP02oookJP04o`000?oonf[o0000oookJP;o00002_oonfX00ol0003o
oo]ZoookJP06o`000003oookJ_l0003o000000Co00001?oonfX3o`000003oookJ_l0003ooo]Z00;o
oo]Z00?o0000oookJ_l000001OoonfX01?l0003ooo]ZoookJ_l00002oookJP04o`000?oonf[ooo]Z
oookJP?o000000?ooo]Zo`000?oonfX00_l000000ooonf[o0000oookJP03oookJP04o`000?oonf[o
oo]Zo`0000Oooo]Z0Ol00001oookJP7o000000000ol0003ooo]ZoookJP02oookJP04o`000?oonf[o
0000o`0000?ooo]Z00?o0000oookJ_l000000_oonfX01_l0003ooo]Zo`000?l0003ooo]Zo`0000?o
oo]Z00Co0000oookJ_oonf[o00002OoonfX2o`000004oookJ_l0003ooo]ZoookJP?o000000?ooo]Z
o`000?oonfX00_oonfX01?l0003ooo]Zo`000?oonfX2o`000003oookJ_l0003o000000So00001?oo
nfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_l000000ooonfX01Ol0003o
oo]ZoookJ_oonf[o000000Cooo]Z00Co0000oookJ_l0003o00000ooonfX00ol0003ooo]ZoookJP07
o`0000Cooo]Z0_l000001Ooonf[o0000o`000?l0003ooo]Z00;o000000?ooo]Zo`000?l000000_oo
nfX2o`000005oookJ_l0003o0000o`000?oonfX00_l00003oookJP03o`000?oonf[o000000Cooo]Z
00Go0000oookJ_oonf[ooo]Zo`000009oookJP03o`000?oonf[o000000[ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000007oookJP04o`000?oonf[ooo]ZoookJP;o00003?oonfX00ol0003ooo]ZoookJP03
oookJP;o00000ooonfX01Ol0003ooo]Zo`000?l0003ooo]Z00Co000000?ooo]Zo`000?l000000ooo
nfX3o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l00000COoonfX2o`000003oookJ_l0
003o000000Co000000?ooo]Zo`000?l000000_oonfX3o`000003oookJ_l0003o000000Go000000?o
oo]Zo`000?oonfX00_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000Oooo]Z00Co0000oookJ_oonf[o
00000ooonfX2o`0000;ooo]Z00?o0000oookJ_l000001_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Gooo]Z00Co0000oookJ_oonf[o00001?oonfX01?l0003ooo]ZoookJ_oonfX2o`0000oooo]Z0_l0
0002oookJP;o00001?oonfX02Ol0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000002oook
JP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00007oookJP03o`000?oonf[o000000;ooo]Z
00?o0000oookJ_l000000ooonfX2o`000003oookJ_l0003ooo]Z00Kooo]Z0ol000000ooonf[o0000
o`000005oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z1_l00004oookJP?o00000ooonfX01Ol0
003ooo]ZoookJ_oonf[o000000?ooo]Z00Co0000oookJ_oonf[o00003OoonfX01Ol0003ooo]Zo`00
0?oonf[o000000?ooo]Z0_l00002oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oo
nfX1o`00000000Co0000oookJ_oonf[o00001_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oo
nf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00_l00002oookJP;o00000ooonfX2o`0000;ooo]Z
00Co0000oookJ_l0003o00000_oonfX2o`0000;ooo]Z1Ol000000ooonf[o0000o`000002oookJP?o
000000Gooo]Zo`000?l0003ooo]Zo`000002oookJP04o`000?oonf[o0000o`0000?ooo]Z00Co0000
oookJ_oonf[ooo]Z0ol00005oookJP;o00000ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00Cooo]Z0_l00002oookJP03o`000?oonf[o000000Cooo]Z0ol000001Ooonf[o0000oook
J_oonf[o000000?ooo]Z00?o0000oookJ_oonfX00_l000001Ooonf[o0000oookJ_l0003ooo]Z00Co
00001?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_oo
nf[o00001_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000000ooo
nf[o0000o`000005o`0000Sooo]Z00?o0000oookJ_l000000_oonfX2o`0000Gooo]Z00Oo0000oook
J_oonf[ooo]Zo`000?oonf[o000000;ooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z
0_l00003oookJP?o000000Gooo]Zo`000?l0003o0000oookJP02o`0004gooo]Z1_l00004oookJP?o
00001?oonfX01?l0003ooo]Zo`000?oonfX2o`0000;ooo]Z00?o0000oookJ_l000000ooonfX00ol0
003ooo]ZoookJP02o`000003oookJ_l0003o000000Cooo]Z00Co0000oookJ_l0003ooo]Z0_l00002
oookJP;o00000_oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000;ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP0;oookJP;o00001?oo
nfX00ol0003ooo]Zo`000002o`000003oookJ_l0003o000000?o00000_oonfX01?l0003ooo]Zoook
J_oonfX5o`000005oookJ_l0003o0000o`000?oonfX00_l000000ooonf[o0000o`000008oookJP;o
00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00Co0000oookJ_oonf[o00000ooonfX0
0ol0003ooo]ZoookJP02oookJP?o000000?ooo]Zo`000?oonfX00_oonfX01?l0003ooo]ZoookJ_l0
0002oookJP03o`000?oonf[ooo]Z00Oo00001?oonfX2o`000003oookJ_l0003ooo]Z00?o000000Co
oo]Zo`000?l0003o00001ooonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00Gooo]Z
0_l00007oookJP?o00002OoonfX01?l0003ooo]ZoookJ_oonfX1o`00000000?o0000oookJ_l00000
0_oonfX00ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00Co0000oookJ_oo
nf[ooo]Z0_l00002oookJP;o00000_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000;ooo]Z00Co0000
oookJ_oonf[o00000ooonfX00ol0003ooo]Zo`000002oookJPKo000000Oooo]Zo`000?l0003o0000
oookJ_l0003ooo]Z00?o00001OoonfX2o`0000;ooo]Z00?o0000oookJ_l000002ooonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000001_oonfX02Ol0003o
oo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000002oookJP?o00000_oonfX01?l0003ooo]Zoook
J_l00002oookJP03o`000?oonf[ooo]Z00?o000000Cooo]Zo`000?l0003o00000_oonfX2o`00013o
oo]Z00Co0000oookJ_oonf[o00000_oonfX01?l0003ooo]ZoookJ_oonfX2o`0000;ooo]Z0_l00000
1Ooonf[o0000oookJ_oonf[o000000Cooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]Zoook
JP02o`000006oookJ_l0003ooo]Zo`000?oonf[o00001?oonfX01ol0003ooo]ZoookJ_oonf[o0000
oookJ_l000000ooonfX2o`000003oookJ_l0003ooo]Z00Go000000Gooo]Zo`000?l0003ooo]Zo`00
0002oookJP;o000000?ooo]Zo`000?l000000_l0001?oookJPCo000000Cooo]Zo`000?oonf[ooo]Z
0_l000001?oonf[o0000oookJ_l00002oookJPKo00000_oonfX01?l0003ooo]Zo`000?oonfX4o`00
00?ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[o0000
00;ooo]Z00?o0000oookJ_oonfX00ooonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00Co0000
oookJ_oonf[o00000ooonfX2o`0000Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP05oookJP;o00001_oonfX3o`0000;ooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP03o`00
0?oonf[ooo]Z00Go00000ooonfX00ol0003ooo]ZoookJP03oookJP;o00000_oonfX2o`000003oook
J_l0003ooo]Z00Cooo]Z0_l00004oookJP;o000000?ooo]Zo`000?l000000_oonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003o00000ooonfX3o`0000?o
oo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP?o00001?oonfX01Ol0003ooo]Zo`000?oonf[o
000000;ooo]Z00Ko0000oookJ_l0003ooo]Zo`000?oonfX2o`0000;ooo]Z00?o0000oookJ_l00000
0_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001?oonfX2o`0000;ooo]Z00?o0000oook
J_oonfX02?oonfX1o`00000000?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02o`0000;o
oo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02oookJP;o00000_oonfX2o`0000?o
oo]Z0ol00003oookJP05o`000?oonf[o0000o`000?oonfX00ol00002oookJP03o`000?oonf[ooo]Z
00;ooo]Z0_l000001?oonf[o0000oookJ_l00002oookJPGo00000_oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP04
o`0000Gooo]Z00_o0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000003oook
JP03o`000?oonf[o000000;o000000Oooo]Zo`000?l0003o0000oookJ_l0003ooo]Z00;o00000_oo
nfX2o`0000;ooo]Z0_l000000ooonf[o0000oookJP03oookJP;o000000Gooo]Zo`000?l0003ooo]Z
o`000003oookJP03o`000?oonf[o000000gooo]Z0ol00005oookJP04o`000?oonf[ooo]Zo`0000Ko
oo]Z00Co0000oookJ_oonf[o00001OoonfX01?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003o
oo]Z00;o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0_l00004oookJP04o`000?oo
nf[ooo]ZoookJP?o00000_oonfX00ol0003ooo]Zo`000004oookJPSo0000DOoonfX3o`000004oook
J_l0003o0000oookJP?o000000?ooo]Zo`000?l000000_oonfX3o`0000Cooo]Z00?o0000oookJ_oo
nfX01OoonfX3o`0000?ooo]Z00Co0000oookJ_oonf[o00001?oonfX01Ol0003ooo]ZoookJ_oonf[o
000000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000;oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0
0002oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z0_l00004oookJP03o`000?oonf[ooo]Z00Cooo]Z
2ol000000ooonf[o0000oookJP04o`0000;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[o000000;o00000ooonfX2o`0000Gooo]Z00Go0000oookJ_oonf[o
oo]Zo`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l000000ooonf[o0000oookJP0;oookJP06
o`000?oonf[ooo]ZoookJ_l0003ooo]Z0_l00003oookJP05o`000?oonf[o0000o`000?oonfX00_l0
00001Ooonf[o0000oookJ_oonf[o000000_ooo]Z1?l00002oookJP03o`000?oonf[ooo]Z00?o0000
00?ooo]Zo`000?l000002_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z
0Ol000000003o`000?oonf[o000000;o000000?ooo]Zo`000?oonfX00ol00003oookJP05o`000?oo
nf[o0000oookJ_l000000_oonfX2o`0000?ooo]Z00Co0000oookJ_oonf[o00002?oonfX00ol0003o
oo]Zo`000007oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Oo0000oookJ_oonf[o0000oookJ_l0
003ooo]Z00Ko000000Cooo]Zo`000?oonf[ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0_l00003oookJP;o
00000ooonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000?ooo]Z00So0000oookJ_oonf[ooo]Zo`00
0?oonf[o0000oookJP?o00001_oonfX2o`000003oookJ_l0003ooo]Z00?ooo]Z0_l000000ooonf[o
0000o`000003oookJP;o00000ooonfX01?l0003ooo]ZoookJ_l00006oookJP03o`000?oonf[ooo]Z
00gooo]Z00Go0000oookJ_oonf[ooo]Zo`00000=oookJP;o000000Gooo]Zo`000?l0003ooo]Zo`00
0003oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ol000000ooonf[o0000o`00
0003o`000005oookJ_l0003o0000oookJ_l000000_oonfX2o`0000;ooo]Z0_l000000ooonf[o0000
o`000003o`000004oookJ_l0003o0000o`00057ooo]Z0ol000001?oonf[o0000o`000?l00003oook
JP?o00000_oonfX01Ol0003ooo]Zo`000?oonf[o000000?ooo]Z00?o0000oookJ_oonfX00ol00002
oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z00cooo]Z1?l00003oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0
00000ooonf[o0000oookJP05oookJPGo000000?ooo]Zo`000?oonfX01?oonfX3o`0000?ooo]Z00Co
0000oookJ_oonf[o00001?oonfX00ol0003ooo]Zo`000005oookJPCo000000?ooo]Zo`000?oonfX0
0_oonfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003o
00000ooonfX01?l0003ooo]Zo`000?l0000:oookJP03o`000?oonf[o000000;ooo]Z0_l000001Ooo
nf[o0000o`000?l0003ooo]Z00;o000000Cooo]Zo`000?l0003o00001_oonfX01Ol0003ooo]Zoook
J_oonf[o000000?ooo]Z0_l000001?oonf[o0000oookJ_l00003oookJP;o000000?ooo]Zo`000?l0
00000_l000001?oonf[o0000oookJ_l00002oookJP03o`000?oonf[o000000;ooo]Z00Co0000oook
J_l0003ooo]Z0ol00002oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0Ol000000003o`000?oonf[o
oo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zo`000003oookJP;o00001_oonfX00ol0
003ooo]ZoookJP02oookJP;o00001?oonfX2o`0000;ooo]Z0_l00002oookJP?o00000_oonfX01?l0
003ooo]ZoookJ_l00002oookJP06o`000?oonf[ooo]Zo`000?oonf[o00001?oonfX01?l0003ooo]Z
o`000?oonfX4o`0000;ooo]Z0ol00008oookJP;o00002OoonfX2o`000003oookJ_l0003ooo]Z00;o
oo]Z00?o0000oookJ_l000000ooonfX2o`000004oookJ_l0003ooo]Zo`0000?ooo]Z1_l0000:oook
JP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ooonfX4o`0000;ooo]Z00Ko0000oook
J_l0003ooo]Zo`000?oonfX3o`0000[ooo]Z00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z00cooo]Z0_l000000ooonf[o0000oookJP07oookJP;o0000
00Cooo]Zo`000?oonf[o00000_oonfX01ol0003ooo]Zo`000?oonf[o0000oookJ_l000000ooonfX3
o`000006oookJ_l0003o0000o`000?oonf[o00001?oonfX2o`000003oookJ_l0003o000000?o0000
DooonfX2o`0000;ooo]Z1Ol000000ooonf[o0000o`000002o`0000;ooo]Z0_l00004oookJP;o0000
0_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP03o`0000Gooo]Z
1_l000001Ooonf[o0000o`000?l0003ooo]Z00Co00001OoonfX3o`0000Kooo]Z0_l00003oookJP;o
000000?ooo]Zo`000?oonfX00_l00005oookJP04o`000?oonf[o0000oookJP?o00001OoonfX2o`00
00;ooo]Z0ol000000ooonf[o0000oookJP02oookJP08o`000?oonf[ooo]Zo`000?oonf[o0000oook
J_l00002oookJP03o`000?oonf[o000000;o00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00001?oonfX3o`0000Gooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol000000ooonf[o
0000o`000003oookJP;o00000ooonfX00ol0003ooo]ZoookJP02oookJPCo000000?ooo]Zo`000?oo
nfX00_oonfX3o`000003oookJ_l0003ooo]Z00;o00001?oonfX00ol0003ooo]ZoookJP04o`000003
oookJ_l0003ooo]Z00?ooo]Z0ol000000ooonf[o0000o`000005oookJP04o`000?oonf[ooo]Zoook
JP7o000000000ol0003ooo]Zo`000002oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0_l00000
0ooonf[o0000o`000005oookJP04o`000?oonf[ooo]ZoookJP;o00000_oonfX2o`0000Gooo]Z00Co
0000oookJ_l0003o00000ooonfX2o`0000?ooo]Z0_l000000ooonf[o0000o`000003o`0000;ooo]Z
00Co0000oookJ_oonf[ooo]Z1?l000000ooonf[o0000oookJP0;oookJP04o`000?oonf[o0000oook
JPCo00000_oonfX00ol0003ooo]ZoookJP06oookJP;o000000?ooo]Zo`000?oonfX00_oonfX2o`00
0004oookJ_l0003o0000o`0000Gooo]Z1?l00006oookJP04o`000?oonf[ooo]ZoookJP;o00000_oo
nfX2o`000003oookJ_l0003ooo]Z00?o000000Cooo]Zo`000?oonf[o00000_oonfX2o`0000Gooo]Z
00?o0000oookJ_oonfX03_oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX00_oonfX3o`000004oook
J_l0003ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX00_l00009oookJP04o`000?oonf[o0000oook
JP;o000000?ooo]Zo`000?oonfX00ooonfX3o`000003oookJ_l0003o000000;o000000?ooo]Zo`00
0?oonfX00_oonfX3o`000003oookJ_l0003o000000Ko0000DooonfX;o`000005oookJ_l0003o0000
o`000?oonfX00ol00002oookJP?o00000_oonfX01?l0003ooo]Zo`000?oonfX2o`0000;ooo]Z00?o
0000oookJ_l000001ooonfX00ol0003ooo]ZoookJP04oookJP;o00002?oonfX2o`000004oookJ_l0
003ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0000;ooo]Z00Co0000oookJ_oonf[o
00001ooonfX4o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000ol00003oookJP;o
000000Kooo]Zo`000?oonf[o0000oookJ_l00003oookJP;o000000Gooo]Zo`000?l0003ooo]Zo`00
0003oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l000000ooonf[o0000oookJP02oookJP05o`00
0?oonf[ooo]ZoookJ_l000000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;o
000000Cooo]Zo`000?oonf[o00000_oonfX2o`000003oookJ_l0003ooo]Z00Cooo]Z00?o0000oook
J_l000000_l000000ooonf[o0000oookJP03o`0000;ooo]Z0_l00002oookJPCo000000?ooo]Zo`00
0?l000000_l000000ooonf[o0000oookJP03oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z0ol0
00000ooonf[o0000o`000003oookJP04o`000?oonf[o0000o`0000?ooo]Z0_l00002oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX1o`00000000?o0000oookJ_l000000ol0
0002oookJPCo000000?ooo]Zo`000?oonfX00_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX00_l0
0002oookJP;o00000_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX01Ol000000ooonf[o0000oook
JP02oookJP;o000000?ooo]Zo`000?oonfX00_oonfX4o`000003oookJ_l0003o000000Co00000ooo
nfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00Go0000oookJ_oonf[o
0000oookJP02o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX01ol0003o
oo]ZoookJ_oonf[o0000oookJ_l000000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Kooo]Z00?o
0000oookJ_oonfX00_oonfX2o`000003oookJ_l0003o000000;ooo]Z0ol000000ooonf[o0000o`00
0003o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000_oonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_l000000ol000000ooonf[o0000oook
JP0<oookJP06o`000?oonf[ooo]Zo`000?oonf[o00001OoonfX2o`0000;ooo]Z00?o0000oookJ_l0
00000ol000001?oonf[o0000oookJ_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z1?l00002oook
JP04o`000?oonf[o0000oookJP;o000000?ooo]Zo`000?l000001ol0001EoookJPOo000000?ooo]Z
o`000?oonfX01?l000001?oonf[o0000oookJ_oonfX4o`000003oookJ_l0003ooo]Z00;ooo]Z00?o
0000oookJ_l000000ol000001?oonf[o0000oookJ_l00002oookJP;o000000?ooo]Zo`000?oonfX0
1OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
0_l0000?oookJP;o00002ooonfX6o`0000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l00007oookJP04
o`000?oonf[o0000o`0000?ooo]Z0_l000000ooonf[o0000oookJP02oookJP?o00000_oonfX01?l0
003ooo]Zo`000?l00002oookJP;o00000_oonfX2o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0003oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX2o`0000;ooo]Z00Go0000oookJ_oonf[o
oo]Zo`000006oookJP03o`000?oonf[ooo]Z00?o000000?ooo]Zo`000?l000000ol00002oookJP03
o`000?oonf[ooo]Z00?ooo]Z0_l000001?oonf[o0000o`000?l00004oookJP04o`000?oonf[ooo]Z
o`0000_ooo]Z00Oo0000oookJ_l0003ooo]Zo`000?oonf[o000000Oooo]Z00Co0000oookJ_l0003o
00000_oonfX00ol0003ooo]ZoookJP01o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000004o`000?oonf[ooo]ZoookJPCo000000Gooo]Zo`000?oonf[ooo]Zo`000003oookJP04
o`000?oonf[ooo]ZoookJP;o00001?oonfX01?l0003ooo]ZoookJ_l00005oookJPCo00000_oonfX2
o`0000?ooo]Z0_l00002oookJP03o`000?oonf[o000000;ooo]Z0_l00002oookJP03o`000?oonf[o
000000?o00000_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00?o00000ooonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l000001?oonf[o0000o`000?l0
0003oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l000001?oonf[o0000oookJ_l00004oookJP03o`00
0?oonf[ooo]Z00Wooo]Z0_l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000Co0000
1OoonfX2o`000004oookJ_l0003ooo]Zo`0000Cooo]Z0ol00006oookJP?o00000ooonfX2o`0000;o
oo]Z00Co0000oookJ_l0003o00000ooonfX2o`0000?ooo]Z00?o0000oookJ_l000001OoonfX00ol0
003ooo]ZoookJP02oookJP05o`000?oonf[o0000oookJ_l000000_oonfX01?l0003ooo]Zo`000?l0
0005oookJP;o000000Cooo]Zo`000?oonf[o00000_oonfX9o`0005Oooo]Z1?l000001?oonf[o0000
o`000?oonfX3o`000003oookJ_l0003o000000Gooo]Z0_l00003oookJP?o00000_oonfX00ol0003o
oo]ZoookJP05oookJP;o00000ooonfX00ol0003ooo]Zo`000004oookJP04o`000?oonf[ooo]Zoook
JP;o000000?ooo]Zo`000?oonfX02?oonfX00ol0003ooo]ZoookJP0:oookJP;o00000_oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[o000000;o000000Gooo]Zo`000?l0003o0000oookJP02
o`0000Cooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000Gooo]Z00?o0000oookJ_l000001?oo
nfX2o`0000Cooo]Z0ol00002oookJP;o00000_oonfX00ol0003ooo]ZoookJP04oookJP;o00000_oo
nfX00ol0003ooo]ZoookJP0:oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_l00000
0ol00003oookJPGo000000?ooo]Zo`000?oonfX00ol00002oookJP?o000000Cooo]Zo`000?l0003o
00000_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP03
oookJP;o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP09o`000?oonf[o
oo]ZoookJ_l0003ooo]Zo`000?oonf[o000000;ooo]Z0Ol000000003o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00?o0000oookJ_oonfX0
0_l00002oookJP;o00000_oonfX2o`0000?ooo]Z00Co0000oookJ_l0003o00000_oonfX3o`0000;o
oo]Z0ol00002oookJP05o`000?oonf[o0000o`000?oonfX00_l000001Ooonf[o0000o`000?oonf[o
000000;ooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000oookJP04oookJP03o`000?oonf[o
oo]Z00Oooo]Z00?o0000oookJ_l000000ooonfX2o`000003oookJ_l0003ooo]Z00Kooo]Z0_l00000
0ooonf[o0000o`000002oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z0_l00005oookJP03o`000?oo
nf[ooo]Z00?ooo]Z0_l00002oookJPKo00000_oonfX3o`000003oookJ_l0003o000000?o00001Ooo
nfX00ol0003ooo]ZoookJP07oookJP04o`000?oonf[ooo]ZoookJP;o000000?ooo]Zo`000?oonfX0
0_l00005oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l00006oookJP03o`000?oonf[ooo]Z00Gooo]Z
00Go0000oookJ_l0003ooo]Zo`000003oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000ooonfX0
1?l0003ooo]ZoookJ_l00002oookJPGo000000?ooo]Zo`000?l000000_l0001GoookJP_o00000_oo
nfX6o`0000;ooo]Z0_l00003oookJP?o000000?ooo]Zo`000?oonfX01_oonfX01Ol0003ooo]Zo`00
0?oonf[o000000Cooo]Z0_l00002oookJP;o00000_oonfX2o`0000gooo]Z00?o0000oookJ_l00000
2OoonfX00ol0003ooo]ZoookJP05oookJPGo000000Gooo]Zo`000?l0003o0000oookJP02o`0000;o
oo]Z0ol00004oookJP03o`000?oonf[ooo]Z00?o00000_oonfX01?l0003ooo]Zo`000?l00002oook
JP;o00002_oonfX00ol0003ooo]ZoookJP09oookJP;o000000_ooo]Zo`000?oonf[ooo]Zo`000?oo
nf[o0000oookJ_l0003ooo]Zo`000007oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000000ooonf[o
0000o`000002oookJPCo00000ooonfX2o`0000Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oook
JP?o000000?ooo]Zo`000?oonfX02_oonfX3o`0000Cooo]Z0_l000001Ooonf[o0000oookJ_oonf[o
000000Cooo]Z00?o0000oookJ_l000001?oonfX1o`00000000?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP02o`000003oookJ_l0003o000000;ooo]Z0ol00002oookJP;o00000_oonfX2o`00
00;ooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP04o`000003oookJ_l0003o0000
00?ooo]Z00?o0000oookJ_l000000ol00002oookJPCo000000Cooo]Zo`000?l0003o00000ooonfX2
o`0000;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?oonfX0
1?l0003ooo]ZoookJ_l00005oookJP05o`000?oonf[ooo]ZoookJ_l000002OoonfX00ol0003ooo]Z
oookJP04oookJP;o000000Cooo]Zo`000?l0003o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Kooo]Z0_l000000ooonf[o0000oookJP03o`000003oookJ_l0003ooo]Z00;o000000Oooo]Zo`00
0?oonf[ooo]Zo`000?oonf[o000000Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00000;oookJP;o0000
1?oonfX00ol0003ooo]ZoookJP02oookJP;o00001OoonfX3o`0000;ooo]Z0_l00002oookJP06o`00
0?oonf[ooo]Zo`000?oonf[o00000_oonfX2o`000004oookJ_l0003o0000oookJP;o00001?oonfX0
0ol0003ooo]Zo`000003o`000003oookJ_l0003o000000Ko0000FOoonfX7o`0000;ooo]Z1Ol00003
oookJPCo000000?ooo]Zo`000?oonfX00ooonfX2o`000003oookJ_l0003o000000;o000000?ooo]Z
o`000?l000000ol000000ooonf[o0000oookJP02oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z
0_l0000=oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0
003ooo]ZoookJP05oookJP04o`000?oonf[ooo]ZoookJP?o00001OoonfX2o`0000Gooo]Z0_l00004
oookJP?o00001ooonfX2o`0000;ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol00002
oookJP;o000000Cooo]Zo`000?oonf[o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z
00Go0000oookJ_l0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00?ooo]Z00Ko0000oookJ_oo
nf[o0000oookJ_l00003oookJP?o000000?ooo]Zo`000?oonfX00_oonfX00ol0003ooo]Zo`000002
o`0000;ooo]Z00Go0000oookJ_l0003o0000oookJP04o`0000;ooo]Z1?l0000;oookJP03o`000?oo
nf[o000000?ooo]Z0_l00002oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX00ol0003ooo]Z
oookJP01o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o
000000;ooo]Z00Co0000oookJ_l0003o00000_oonfX2o`000005oookJ_l0003o0000oookJ_l00000
1ooonfX2o`0000;ooo]Z0_l00003oookJP?o000000?ooo]Zo`000?l000000_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000;ooo]Z1?l000000ooonf[o0000oookJP07o`000003oookJ_l0003ooo]Z00?o
oo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP07oookJP;o00001OoonfX00ol0003o
oo]ZoookJP08oookJP?o000000?ooo]Zo`000?oonfX00_oonfX01?l0003ooo]ZoookJ_l00006oook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?l00002oookJP;o000000Cooo]Zo`00
0?oonf[o00001?oonfX01_l0003ooo]ZoookJ_oonf[o0000oookJP;o00000_oonfX01?l0003ooo]Z
oookJ_oonfX2o`0000;ooo]Z00Ko0000oookJ_oonf[ooo]Zo`000?oonfX2o`000004oookJ_l0003o
oo]Zo`0000?ooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z00Co0000oookJ_l0003o
00000_oonfX01?l0003ooo]ZoookJ_l00002oookJP;o000000?ooo]Zo`000?l000001?l000001?oo
nf[o0000oookJ_l00002oookJP?o000000?ooo]Zo`000?l000001OoonfX01?l0003ooo]Zo`000?oo
nfX6o`000003oookJ_l0003ooo]Z00?o0000F_oonfX7o`000005oookJ_l0003ooo]Zo`000?oonfX0
0_l00002oookJP08o`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l00003oookJP04o`000?oonf[o
oo]ZoookJP;o00001OoonfX2o`0000;ooo]Z0ol00003oookJP07o`000?oonf[ooo]ZoookJ_l0003o
oo]Zo`000002oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l00006oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z00Co0000oookJ_l0003o00000_oonfX8o`000004oookJ_l0003ooo]Zo`0000;ooo]Z0_l0
00001Ooonf[o0000oookJ_l0003ooo]Z00Go00001ooonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000003oookJP04o`000?oonf[o0000o`0000Ko
oo]Z0_l00004oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00000;oookJP04o`000?oonf[o
oo]ZoookJPGo000000Gooo]Zo`000?oonf[o0000oookJP02o`0000;ooo]Z0_l00005oookJPCo0000
00?ooo]Zo`000?l000000_l000001_oonf[o0000o`000?l0003ooo]Zo`0000?ooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]Zo`000002o`0000Gooo]Z0_l00003oookJP7o000000000ol0003o
oo]Zo`00000?oookJP03o`000?oonf[ooo]Z00;o00000_oonfX2o`0000;ooo]Z0_l00002oookJP;o
000000?ooo]Zo`000?l000000_l000000ooonf[o0000oookJP03oookJPGo00000_oonfX00ol0003o
oo]Zo`000003o`000003oookJ_l0003o000000;ooo]Z0_l000000ooonf[o0000oookJP04oookJP03
o`000?oonf[ooo]Z00?ooo]Z1_l00005oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX01?l0
003ooo]ZoookJ_oonfX2o`0000Wooo]Z00?o0000oookJ_l000000ooonfX01?l0003ooo]ZoookJ_oo
nfX2o`0000;ooo]Z00?o0000oookJ_l000000_l000001Ooonf[o0000o`000?l0003ooo]Z00?o0000
0_oonfX5o`000003oookJ_l0003o000000Ko00000ooonfX01?l0003ooo]ZoookJ_l00003oookJP04
o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oook
JP05o`000?oonf[ooo]ZoookJ_l000000ooonfX01?l0003ooo]ZoookJ_l00005oookJP;o00000ooo
nfX2o`0000;ooo]Z00?o0000oookJ_oonfX01Ol000001_oonf[o0000o`000?l0003ooo]Zo`0000?o
oo]Z0ol00002oookJPCo000000?ooo]Zo`000?l000000_l0001KoookJP[o00000_oonfX2o`000003
oookJ_l0003o000000;ooo]Z0_l00003oookJP?o000000?ooo]Zo`000?oonfX01_oonfX00ol0003o
oo]Zo`000003o`000005oookJ_l0003ooo]Zo`000?oonfX00_l00002oookJP05o`000?oonf[ooo]Z
oookJ_l000005ooonfX01?l0003ooo]ZoookJ_l00004oookJP;o000000?ooo]Zo`000?l000002_l0
00001Ooonf[o0000oookJ_l0003ooo]Z00?o00000ooonfX00ol0003ooo]Zo`000003oookJPCo0000
0_oonfX00ol0003ooo]Zo`00000:oookJP?o00000ooonfX01?l0003ooo]Zo`000?oonfX2o`0000Oo
oo]Z0_l0000:oookJP03o`000?oonf[ooo]Z00Sooo]Z2?l000000ooonf[o0000o`000004o`0000;o
oo]Z0ol00002oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Co
oo]Z00?o0000oookJ_l000000ol000001?oonf[o0000o`000?oonfX3o`000003oookJ_l0003o0000
00Cooo]Z0Ol000000003o`000?oonf[ooo]Z00?ooo]Z0_l00002oookJP?o00001_oonfX2o`000003
oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_l00004oookJP03o`000?oonf[o000000;o
oo]Z00Co0000oookJ_oonf[ooo]Z0_l00003oookJP07o`000?oonf[o0000o`000?oonf[o0000oook
JP06o`00017ooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000o`000006oookJP04o`000?oo
nf[ooo]Zo`0000;ooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]Zo`000005oookJP;o0000
0_oonfX2o`0000;ooo]Z0_l00004oookJP?o00001?oonfX2o`000004oookJ_l0003ooo]Zo`0000;o
oo]Z00?o0000oookJ_oonfX00ooonfX8o`000003oookJ_l0003ooo]Z00Cooo]Z00?o0000oookJ_l0
00003?oonfX01?l0003ooo]ZoookJ_oonfX2o`0000?ooo]Z0_l00003oookJP04o`000?oonf[ooo]Z
o`0000?ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00002oookJP03o`000?oonf[o
000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[o000000?o000000Co
oo]Zo`000?l0003o0000GOoonfX5o`000003oookJ_l0003o000000?o00000_oonfX4o`0000Gooo]Z
00Co0000oookJ_oonf[o00000ooonfX00ol0003ooo]Zo`000005oookJP04o`000?oonf[ooo]Zo`00
00Oooo]Z0_l00004oookJP04o`000?oonf[ooo]Zo`0000Sooo]Z0ol00004oookJP05o`000?oonf[o
oo]ZoookJ_l000002?oonfX5o`0000;ooo]Z0ol00002oookJP;o00000_oonfX00ol0003ooo]Zo`00
0002oookJP;o00001OoonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000001?oonfX2o`0000Go
oo]Z00?o0000oookJ_l000001ooonfX01?l0003ooo]Zo`000?l00008oookJP05o`000?oonf[o0000
oookJ_l000000_oonfX01?l0003ooo]ZoookJ_l00004oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z
00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000000;ooo]Z00?o0000oookJ_l000000_oonfX00ol0
003ooo]ZoookJP02o`0000;ooo]Z1Ol00002oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX0
1?l0003ooo]Zo`000?l00003oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX01?l0003ooo]Z
o`000?l00002oookJP03o`000?oonf[o000000;ooo]Z0Ol000000003o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX00_l000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z0_l000001?oonf[o
0000o`000?l00002oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]Z
oookJ_l000000ooonfX3o`0000?ooo]Z0ol00002oookJP?o000000?ooo]Zo`000?l000001?l00005
oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]Zo`000005
oookJP;o00001?oonfX2o`000003oookJ_l0003ooo]Z00Gooo]Z00Go0000oookJ_oonf[o0000oook
JP02o`000003oookJ_l0003o000000?o00000_oonfX2o`000004oookJ_l0003ooo]Zo`0000;ooo]Z
00Co0000oookJ_l0003ooo]Z1Ol00005oookJPGo000000Cooo]Zo`000?l0003ooo]Z0ol000001?oo
nf[o0000o`000?l00004oookJP03o`000?oonf[o000000Kooo]Z00Co0000oookJ_l0003o00000_oo
nfX01?l0003ooo]ZoookJ_l00003oookJP?o00001?oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`00
00Kooo]Z00?o0000oookJ_l000000ol00002oookJP;o00001_oonfX00ol0003ooo]ZoookJP03o`00
00?ooo]Z0ol00002oookJPCo000000Cooo]Zo`000?l0003o0000GOoonfX7o`000003oookJ_l0003o
000000;o00000ooonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00Ko
0000oookJ_oonf[ooo]Zo`000?oonfX2o`000003oookJ_l0003ooo]Z00Gooo]Z00Co0000oookJ_l0
003o00001?oonfX01?l0003ooo]ZoookJ_l00002oookJP;o00000_oonfX01?l0003ooo]Zo`000?oo
nfX2o`0000Gooo]Z00Co0000oookJ_oonf[o00002?oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o
000000Cooo]Zo`000?oonf[ooo]Z0_l000001_oonf[o0000oookJ_oonf[o0000oookJP;o00000_oo
nfX7o`000003oookJ_l0003ooo]Z00Oooo]Z00?o0000oookJ_l000001?l00003oookJP03o`000?oo
nf[o000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[o000000;ooo]Z
0_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[ooo]Z00;o00000ooonfX2o`000005oook
J_l0003ooo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00Go0000oookJ_l0
003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Co000000?ooo]Zo`000?l000001OoonfX01Ol0
003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oookJ_l000000_oonfX01_l0003ooo]Zo`000?l0
003ooo]Zo`0000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00Co
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zo`00
0004o`000003oookJ_l0003o000000?ooo]Z00Co0000oookJ_l0003o00000ooonfX00ol0003ooo]Z
oookJP02oookJP;o00000_oonfX2o`0000;ooo]Z00Co0000oookJ_l0003o00000ooonfX2o`000004
oookJ_l0003o0000oookJP;o00000_oonfX3o`0000;ooo]Z1Ol00003oookJP04o`000?oonf[ooo]Z
oookJPCo00000ooonfX01?l0003ooo]ZoookJ_l00007oookJP;o00000_oonfX02?l0003ooo]Zo`00
0?l0003ooo]Zo`000?oonf[o00001_oonfX4o`0000;ooo]Z00?o0000oookJ_oonfX01?oonfX2o`00
00Cooo]Z00Co0000oookJ_oonf[o00001?oonfX5o`000005oookJ_l0003ooo]ZoookJ_l000000ooo
nfX00ol0003ooo]Zo`000002o`000003oookJ_l0003o000000;ooo]Z1?l00002oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP02o`0000?ooo]Z00?o
0000oookJ_oonfX00ol00004oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX2o`0000;ooo]Z
0_l00003oookJP0;o`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Zo`000?oonfX00ol0
0004oookJP?o000000?ooo]Zo`000?l000000_oonfX5o`0005oooo]Z1Ol000000ooonf[o0000o`00
0002o`000003oookJ_l0003o000000Ko000000Cooo]Zo`000?oonf[o00001?oonfX5o`0000;ooo]Z
0ol00006oookJP;o000000?ooo]Zo`000?l000001OoonfX00ol0003ooo]ZoookJP04oookJP;o0000
0ooonfX2o`0000Kooo]Z00Co0000oookJ_oonf[ooo]Z0_l00004oookJPCo000000Gooo]Zo`000?oo
nf[ooo]Zo`000003oookJP04o`000?oonf[o0000oookJP?o00000ooonfX01_l0003ooo]Zo`000?l0
003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]Zo`000?oonfX5o`0000?o
oo]Z00Co0000oookJ_oonf[o00001ooonfX01?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zo`000003oookJP04o`000?oonf[o
oo]Zo`0000;ooo]Z0_l000000ooonf[o0000o`000002oookJP?o00000_oonfX2o`0000;ooo]Z00Ko
0000oookJ_oonf[o0000oookJ_l00006oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?oo
nf[ooo]Z0ol00004oookJP;o00000_oonfX00ol0003ooo]Zo`000002o`0000?ooo]Z0_l00002oook
JP03o`000?oonf[ooo]Z007o000000000ol0003ooo]ZoookJP03o`0000Cooo]Z0ol00003oookJP03
o`000?oonf[ooo]Z00;ooo]Z0_l00002oookJP;o00000_oonfX2o`0000?ooo]Z00?o0000oookJ_oo
nfX00_l000001_oonf[o0000oookJ_l0003ooo]Zo`0000?ooo]Z00Co0000oookJ_l0003o00000_oo
nfX01?l0003ooo]Zo`000?oonfX3o`0000Cooo]Z0ol000001Ooonf[o0000oookJ_l0003ooo]Z00;o
00000ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000001Ooonf[o
0000oookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zo`000003oook
JP03o`000?oonf[ooo]Z00cooo]Z0_l00007oookJP?o000000Gooo]Zo`000?oonf[o0000oookJP02
o`000006oookJ_l0003ooo]ZoookJ_l0003ooo]Z0ol000000ooonf[o0000oookJP06oookJP;o0000
1?oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z00;o000000?ooo]Zo`000?oonfX00_l000002ooonf[o0000o`000?oonf[o0000oook
J_l0003ooo]Zo`000?oonf[o000000Cooo]Z0ol00006oookJP03o`000?oonf[o000000co0000HOoo
nfX5o`000005oookJ_l0003o0000o`000?oonfX01?l000001?oonf[o0000o`000?l0000:oookJP03
o`000?oonf[o000000Go00000_oonfX4o`0000Gooo]Z0_l00005oookJP;o00001?oonfX00ol0003o
oo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z0_l00003oookJPGo000000Gooo]Zo`00
0?l0003o0000oookJP03o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX2o`000003oookJ_l0
003ooo]Z00;o000000?ooo]Zo`000?oonfX00ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o0000
1OoonfX00ol0003ooo]ZoookJP02o`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Gooo]Z
0_l00002oookJP;o00001?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Gooo]Z
00Ko0000oookJ_oonf[ooo]Zo`000?oonfX2o`0000Gooo]Z00?o0000oookJ_l000000_oonfX01?l0
003ooo]Zo`000?l00006oookJP03o`000?oonf[o000000?o000000Sooo]Zo`000?oonf[ooo]Zo`00
0?oonf[o0000oookJP;o00000_oonfX00ol0003ooo]Zo`000002oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP01o`00000000Go0000oookJ_oo
nf[ooo]Zo`000003oookJP;o00000ooonfX01_l0003ooo]Zo`000?oonf[o0000oookJP;o000000Co
oo]Zo`000?oonf[ooo]Z0_l00002oookJP;o00000_oonfX3o`0000?ooo]Z00?o0000oookJ_l00000
0ol00003oookJP;o000000?ooo]Zo`000?oonfX01_l000001?oonf[o0000oookJ_l00008oookJP03
o`000?oonf[o000000;ooo]Z00?o0000oookJ_l000000_oonfX01Ol0003ooo]Zo`000?oonf[o0000
00Oooo]Z00?o0000oookJ_l000000_oonfX01?l0003ooo]Zo`000?l00004oookJP03o`000?oonf[o
oo]Z00;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00005oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z
00?o0000oookJ_oonfX00ooonfX01?l0003ooo]ZoookJ_l00004oookJP03o`000?oonf[o000000;o
000000Cooo]Zo`000?oonf[ooo]Z1Ol00006oookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oook
J_oonf[ooo]Zo`000007oookJPGo000000Gooo]Zo`000?oonf[ooo]Zo`000004oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`000005oookJP;o000000?o
oo]Zo`000?oonfX00_oonfX9o`000003oookJ_l0003ooo]Z00Ko0000HOoonfX7o`0000;ooo]Z00?o
0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?o00001Ooo
nfX01?l0003ooo]ZoookJ_l00003oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l000000ooonf[o
0000oookJP09oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z0ol00002oookJP03o`000?oonf[ooo]Z
00Cooo]Z0_l00002oookJP?o000000Cooo]Zo`000?oonf[ooo]Z0_l000001?oonf[o0000oookJ_l0
0004oookJP03o`000?oonf[o000000?o00001OoonfX00ol0003ooo]Zo`000004oookJP04o`000?oo
nf[o0000o`0000?ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP06oookJP;o0000
00?ooo]Zo`000?oonfX00ooonfX01?l0003ooo]Zo`000?oonfX3o`000006oookJ_l0003o0000oook
J_l0003ooo]Z0_l00005oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]Zoook
JP02oookJPKo000000?ooo]Zo`000?oonfX00_l000000ooonf[o0000oookJP02o`000003oookJ_l0
003o000000?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP07o`000?oonf[o0000oookJ_l0
003ooo]Zo`000002oookJP04o`000?oonf[ooo]ZoookJP;o000000?ooo]Zo`000?oonfX01Ol00004
oookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoook
JP7o000000001Ol0003ooo]Zo`000?oonf[o000000?ooo]Z00Oo0000oookJ_l0003ooo]Zo`000?oo
nf[o000000?ooo]Z00Co0000oookJ_oonf[o00000ooonfX2o`0000;ooo]Z0_l00002oookJP04o`00
0?oonf[o0000oookJP?o00001OoonfX2o`0000;ooo]Z1?l00002oookJPCo00000_oonfX01?l0003o
oo]Zo`000?l00004oookJP03o`000?oonf[ooo]Z00;o000000Cooo]Zo`000?oonf[o00000ooonfX0
0ol0003ooo]ZoookJP02o`000003oookJ_l0003o000000Sooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0003oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z
0ol00002oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP02o`0000?ooo]Z00Co0000oookJ_oonf[ooo]Z1_l000000ooonf[o0000oookJP09oookJP03
o`000?oonf[o000000?o000000?ooo]Zo`000?oonfX00_l00005oookJP03o`000?oonf[o000000;o
oo]Z00Ko0000oookJ_oonf[ooo]Zo`000?oonfX3o`0000Kooo]Z00Co0000oookJ_oonf[o00000ooo
nfX00ol0003ooo]Zo`000006o`000004oookJ_l0003o0000oookJPCo000000?ooo]Zo`000?l00000
1?l0001ToookJP04o`000?oonf[o0000oookJP?o000000?ooo]Zo`000?l000000ol000000ooonf[o
0000o`000002o`0000?ooo]Z00Go0000oookJ_oonf[o0000oookJP02o`0000Gooo]Z00Co0000oook
J_oonf[o00000ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o000000Cooo]Z00?o0000
oookJ_l000000_oonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oonf[o000000cooo]Z1_l0
00001?oonf[o0000o`000?oonfX4o`000004oookJ_l0003ooo]Zo`0000?ooo]Z00Ko0000oookJ_l0
003o0000oookJ_l00002oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_oonf[o00000_oo
nfX00ol0003ooo]Zo`000002o`0000?ooo]Z0_l00004oookJP;o00001OoonfX2o`0000Cooo]Z1_l0
00000ooonf[o0000oookJP02oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00Co0000oookJ_l0003o
00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z1ol00004oookJP06o`000?oonf[ooo]Z
o`000?oonf[o00001?oonfX2o`0000?ooo]Z0_l0000:oookJP04o`000?oonf[o0000o`0000?ooo]Z
0_l00003oookJP?o00001_oonfX1o`00000000?o0000oookJ_l000000ooonfX2o`0000?ooo]Z00So
0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJP;o000000Cooo]Zo`000?oonf[ooo]Z0_l00002
oookJP;o00000ooonfX00ol0003ooo]Zo`000003oookJP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z
0_l00002oookJP;o000000?ooo]Zo`000?l000000ol00002oookJP03o`000?oonf[o000000Kooo]Z
0_l000001Ooonf[o0000oookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ol00002oookJP05
o`000?oonf[o0000oookJ_l000000_oonfX3o`000003oookJ_l0003o000000;ooo]Z00Go0000oook
J_oonf[ooo]Zo`000003oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z1?l000001?oonf[o0000oook
J_l00005oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_oonf[o00000_oonfX01_l0003o
oo]ZoookJ_oonf[o0000oookJPGo000000?ooo]Zo`000?oonfX00ol000001?oonf[o0000o`000?l0
0004oookJP03o`000?oonf[o000000Cooo]Z0_l00004oookJP04o`000?oonf[o0000oookJP?o0000
00?ooo]Zo`000?l000000_oonfX6o`0000Gooo]Z00Co0000oookJ_l0003o00000ooonfX01?l0003o
oo]Zo`000?l00007oookJP?o00000_oonfX7o`000003oookJ_l0003ooo]Z00Go0000I?oonfX7o`00
0005oookJ_l0003ooo]ZoookJ_l000000ooonfX01?l0003ooo]Zo`000?oonfX2o`0000?ooo]Z0_l0
00001Ooonf[o0000o`000?oonf[o000000Cooo]Z00Co0000oookJ_l0003ooo]Z0_l000002?oonf[o
0000o`000?l0003ooo]Zo`000?oonf[o00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Gooo]Z
00?o0000oookJ_l000000ooonfX4o`0000Oooo]Z1?l000000ooonf[o0000o`000003oookJP?o0000
00?ooo]Zo`000?oonfX00_l000000ooonf[o0000oookJP06o`000003oookJ_l0003ooo]Z00;o0000
0_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o00002?oonfX2o`000003oookJ_l0003ooo]Z00;o
oo]Z00Co0000oookJ_l0003o00000ooonfX01?l0003ooo]Zo`000?l00002oookJP?o00000_oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000001?oonfX0
0ol0003ooo]ZoookJP04oookJP05o`000?oonf[o0000o`000?oonfX00ol00002oookJPKo00001?oo
nfX2o`0000;ooo]Z0ol000001?oonf[o0000o`000?oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX0
0ooonfX01_l0003ooo]Zo`000?l0003ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX1o`00
000000?o0000oookJ_l000000ooonfX00ol0003ooo]Zo`000008oookJP05o`000?oonf[ooo]Zoook
J_l000000ooonfX2o`0000;ooo]Z0_l00002oookJP?o000000?ooo]Zo`000?l000000_oonfX4o`00
00?ooo]Z0_l000000ooonf[o0000o`000004o`0000Oooo]Z0_l00008oookJP;o00002OoonfX00ol0
003ooo]ZoookJP03o`000003oookJ_l0003o000000Cooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0
0002oookJP;o00000_oonfX00ol0003ooo]ZoookJP03o`0000Cooo]Z0_l00005oookJP03o`000?oo
nf[ooo]Z00Co000000?ooo]Zo`000?oonfX01?oonfX01?l0003ooo]Zo`000?l00003oookJP?o0000
0_oonfX8o`0000Gooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000gooo]Z0_l000001Ooonf[o0000
o`000?oonf[o000000Oooo]Z0_l000000ooonf[o0000oookJP03oookJP?o00000ooonfX01Ol0003o
oo]ZoookJ_l0003ooo]Z00co0000I_oonfX5o`0000?ooo]Z0ol000000ooonf[o0000oookJP02oook
JP;o00000_oonfX3o`000004oookJ_l0003ooo]Zo`0000Gooo]Z00Co0000oookJ_oonf[ooo]Z0_l0
0002oookJP03o`000?oonf[ooo]Z00;o00002?oonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z0ol0
0003oookJP;o00000ooonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o00000_oonfX01Ol0003ooo]Z
o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003ooo]Zo`000?l00003oook
JP;o000000?ooo]Zo`000?oonfX01?l00003oookJP07o`000?oonf[ooo]ZoookJ_l0003ooo]Zo`00
0003oookJP;o00001?oonfX00ol0003ooo]ZoookJP04o`000009oookJ_l0003ooo]ZoookJ_l0003o
oo]Zo`000?oonf[o000000Gooo]Z00Oo0000oookJ_l0003ooo]Zo`000?oonf[o000000Kooo]Z00Go
0000oookJ_oonf[o0000oookJP02o`0000Kooo]Z1_l000000ooonf[o0000o`000008o`000003oook
J_l0003o000000?ooo]Z0_l00004oookJP;o000000?ooo]Zo`000?l000000_l000000ooonf[o0000
oookJP03o`0000?ooo]Z00?o0000oookJ_l000002OoonfX1o`00000000?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]Zo`000002oookJP03o`000?oonf[o000000;ooo]Z0_l00002oookJP?o00001?oo
nfX00ol0003ooo]ZoookJP02o`0000;ooo]Z0ol00004oookJPCo00000_oonfX2o`000003oookJ_l0
003o000000;o000000Cooo]Zo`000?l0003o00000_oonfX00ol0003ooo]ZoookJP02oookJP;o0000
0ooonfX00ol0003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000000ooonf[o0000
o`000003oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00006oookJP04o`000?oonf[ooo]Zo`0000;o
oo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`000007oookJP03o`000?oonf[o000000;o
000000?ooo]Zo`000?l000001OoonfX2o`0000?ooo]Z00Co0000oookJ_l0003o00000_oonfX3o`00
0004oookJ_l0003ooo]ZoookJPCo000000Cooo]Zo`000?oonf[o00005?oonfX00ol0003ooo]Zo`00
0005oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00003oookJP?o00000_oonfX00ol0003ooo]Zo`00
0003oookJP06o`000?oonf[o0000oookJ_l0003ooo]Z1?l000000ooonf[o0000o`000002o`000004
oookJ_l0003o0000oookJP?o0000IooonfX6o`000005oookJ_l0003o0000o`000?oonfX00_l00000
0ooonf[o0000o`000002o`0000?ooo]Z0_l00002oookJP05o`000?oonf[o0000oookJ_l000001Ooo
nfX00ol0003ooo]ZoookJP09oookJP;o000000Kooo]Zo`000?oonf[ooo]Zo`000?oonfX2o`0000Go
oo]Z00?o0000oookJ_l000000_l00002oookJPGo000000?ooo]Zo`000?l000000_l000001?oonf[o
0000o`000?oonfX2o`000004oookJ_l0003o0000o`0000Gooo]Z1?l000000ooonf[o0000oookJP03
oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003ooo]ZoookJ_l0
0002oookJP08o`000?oonf[ooo]Zo`000?oonf[o0000oookJ_l00003oookJP03o`000?oonf[ooo]Z
00?ooo]Z0_l00006oookJP;o00001?oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX04?oonfX01_l0
003ooo]ZoookJ_oonf[o0000oookJPOo00000ooonfX4o`000003oookJ_l0003o000000?ooo]Z00?o
0000oookJ_l000001?oonfX01?l0003ooo]ZoookJ_l00003oookJP04o`000?oonf[ooo]Zo`0000?o
oo]Z00Co0000oookJ_l0003o00000_oonfX2o`000004oookJ_l0003ooo]Zo`0000?ooo]Z0Ol00000
0003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o000000000ol0003ooo]Zo`000008oookJP;o
000000Cooo]Zo`000?l0003ooo]Z0_l000001?oonf[o0000oookJ_l00002oookJP;o00000_oonfX2
o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX8o`000004oookJ_l0003o0000o`0000;ooo]Z1?l0
000?oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX02Ol0003ooo]ZoookJ_oonf[o0000oook
J_l0003ooo]Zo`000002oookJP03o`000?oonf[o000000Gooo]Z00Co0000oookJ_oonf[o00000ooo
nfX02ol0003ooo]ZoookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o000000Gooo]Z00Co0000
oookJ_oonf[o00000_oonfX00ol0003ooo]ZoookJP04o`0000;ooo]Z0_l00005oookJP03o`000?oo
nf[ooo]Z00Co000000?ooo]Zo`000?l000000_l00002oookJPKo000000?ooo]Zo`000?oonfX00ooo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_l0003o0000
0ooonfX3o`0000Cooo]Z00?o0000oookJ_l000001?oonfX3o`000003oookJ_l0003o000000Oooo]Z
00Oo0000oookJ_oonf[o0000oookJ_l0003ooo]Z00Co00000ooonfX7o`0006Wooo]Z0ol00003oook
JP06o`000?oonf[o0000oookJ_l0003ooo]Z0_l00002oookJPKo00000ooonfX01?l0003ooo]Zoook
J_oonfX2o`000003oookJ_l0003o000000Gooo]Z00Co0000oookJ_oonf[ooo]Z0_l00003oookJP;o
000000Gooo]Zo`000?oonf[ooo]Zo`000005oookJP?o00001OoonfX01?l0003ooo]ZoookJ_oonfX3
o`000003oookJ_l0003o000000Cooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003ooo]Zo`00
0004o`0000Cooo]Z0_l00006oookJP04o`000?oonf[o0000o`0000;ooo]Z00?o0000oookJ_l00000
0_oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000;ooo]Z0_l00003oookJP03o`000?oonf[o0000
00;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000003oookJP03o`000?oonf[o000000;ooo]Z00Ko0000
oookJ_oonf[o0000oookJ_l00005oookJP;o00000_oonfX01?l0003ooo]Zo`000?oonfX3o`000005
oookJ_l0003ooo]ZoookJ_l000000_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o000000?ooo]Z
o`000?l000001?l000001_oonf[o0000o`000?oonf[o0000oookJP;o00000_oonfX3o`000003oook
J_l0003ooo]Z00;o00000_oonfX3o`000003oookJ_l0003o000000?ooo]Z0ol00002oookJP?o0000
1OoonfX1o`00000000?o0000oookJ_l000000ol00002oookJP03o`000?oonf[o000000;ooo]Z00Wo
0000oookJ_oonf[ooo]Zo`000?oonf[o0000oookJ_l000000ooonfX2o`0000;ooo]Z0_l00002oook
JPGo00000_oonfX01?l0003ooo]Zo`000?l00002oookJPWo00001OoonfX2o`000003oookJ_l0003o
oo]Z00;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oookJP07o`000?oonf[o0000oookJ_l0003o
oo]Zo`000005oookJP;o00001_oonfX01?l0003ooo]ZoookJ_l00002oookJP06o`000?oonf[o0000
oookJ_l0003ooo]Z1?l000000ooonf[o0000o`000004oookJP;o00000_oonfX4o`0000;ooo]Z0_l0
0005oookJP03o`000?oonf[o000000Ko00000_oonfX3o`0000;ooo]Z1_l000000ooonf[o0000o`00
0003o`0000?ooo]Z00Go0000oookJ_l0003ooo]Zo`000004oookJP;o000000Cooo]Zo`000?l0003o
00001?oonfX00ol0003ooo]ZoookJP03oookJP;o00000_oonfX2o`000007oookJ_l0003o0000o`00
0?oonf[o0000oookJP02o`0000;ooo]Z0ol00003oookJPCo00000ooonfX2o`000004oookJ_l0003o
oo]ZoookJP;o000000?ooo]Zo`000?l000000ol0001ZoookJPOo000000Sooo]Zo`000?l0003ooo]Z
o`000?oonf[o0000oookJPCo00000_oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]Z
o`000?oonfX00_l000001?oonf[o0000o`000?l00002oookJPGo00002?oonfX2o`000003oookJ_l0
003ooo]Z00;ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP03oookJP04o`000?oo
nf[o0000oookJPGo00000ooonfX2o`000006oookJ_l0003o0000oookJ_l0003ooo]Z0_l00006oook
JP03o`000?oonf[ooo]Z00;ooo]Z0_l000001?oonf[o0000oookJ_l00002oookJP04o`000?oonf[o
0000oookJP?o00000_oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00;o00001_oonfX2o`000003oook
J_l0003ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00001?oonfX3o`000003oookJ_l0003o000000?o
oo]Z00Co0000oookJ_oonf[o00000_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00;o00001?oonfX2
o`0000Cooo]Z00?o0000oookJ_l000000ol00003oookJP;o000000Gooo]Zo`000?l0003ooo]Zo`00
0003oookJP;o000000Cooo]Zo`000?oonf[ooo]Z0ol00002oookJP03o`000?oonf[o000000;o0000
0_oonfX2o`000004oookJ_l0003ooo]Zo`0000Cooo]Z00Co0000oookJ_l0003o00000ooonfX1o`00
000000?o0000oookJ_oonfX00ooonfX01ol0003ooo]Zo`000?l0003ooo]Zo`000?oonfX00ol00004
oookJP?o00000_oonfX2o`0000;ooo]Z0_l00002oookJP?o000000Gooo]Zo`000?l0003o0000oook
JP04o`000006oookJ_l0003o0000oookJ_l0003ooo]Z0ol00003oookJP04o`000?oonf[o0000oook
JP;o00000_oonfX00ol0003ooo]Zo`000007oookJP;o00000ooonfX00ol0003ooo]Zo`000003oook
JP03o`000?oonf[ooo]Z00;ooo]Z0_l000000ooonf[o0000oookJP09oookJP04o`000?oonf[o0000
oookJPCo00001OoonfX2o`000003oookJ_l0003ooo]Z00Co000000Oooo]Zo`000?l0003o0000oook
J_l0003ooo]Z00So000000?ooo]Zo`000?oonfX00ol00002oookJPGo000000?ooo]Zo`000?l00000
0ol000001?oonf[o0000oookJ_l00002oookJP06o`000?oonf[ooo]Zo`000?oonf[o00002_oonfX0
0ol0003ooo]ZoookJP02o`000003oookJ_l0003ooo]Z00Kooo]Z0ol00006oookJP;o000000Kooo]Z
o`000?l0003ooo]Zo`000?oonfX3o`000005oookJ_l0003ooo]Zo`000?oonfX00ol00002oookJPOo
0000K?oonfX5o`000004oookJ_l0003ooo]ZoookJPCo00000ooonfX00ol0003ooo]ZoookJP04o`00
00Sooo]Z00Oo0000oookJ_l0003ooo]Zo`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX00_l0
0004oookJP06o`000?oonf[ooo]Zo`000?oonf[o00000ooonfX00ol0003ooo]ZoookJP06oookJPGo
000000?ooo]Zo`000?l000000ol000001Ooonf[o0000o`000?oonf[o000000;ooo]Z1_l00002oook
JP;o000000?ooo]Zo`000?l000000_oonfX00ol0003ooo]Zo`000002o`000005oookJ_l0003o0000
oookJ_l000000_oonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0002oookJP03o`000?oonf[ooo]Z00?ooo]Z00Co0000oookJ_l0003o00000_oonfX3o`0000Cooo]Z
00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP05oookJP?o00001_oonfX2o`0000;ooo]Z
00?o0000oookJ_oonfX02?l000001?oonf[o0000oookJ_l00002oookJP03o`000?oonf[ooo]Z00;o
000000Cooo]Zo`000?oonf[o00000_oonfX2o`000003oookJ_l0003o000000;o00000_oonfX00ol0
003ooo]Zo`000002oookJP;o000000?ooo]Zo`000?oonfX00_oonfX01Ol0003ooo]Zo`000?l0003o
oo]Z00;o00000_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000004
o`000?oonf[ooo]ZoookJPKo00000_oonfX02?l0003ooo]Zo`000?l0003ooo]Zo`000?oonf[o0000
0_oonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z0_l00003oookJP;o00001?oonfX00ol0003ooo]Z
oookJP02oookJP?o000000?ooo]Zo`000?l000000_l00002oookJP?o00000ooonfX2o`0000;ooo]Z
00Ko0000oookJ_oonf[o0000oookJ_l00004oookJP05o`000?oonf[o0000oookJ_l000002?oonfX0
0ol0003ooo]ZoookJP02oookJP;o00002OoonfX01Ol0003ooo]Zo`000?oonf[o000000Cooo]Z00Ko
0000oookJ_oonf[ooo]Zo`000?oonfX4o`000003oookJ_l0003o000000?o00000ooonfX2o`000005
oookJ_l0003o0000o`000?oonfX01?l00002oookJP;o00000ooonfX3o`0000;ooo]Z0_l000000ooo
nf[o0000oookJP05o`000005oookJ_l0003ooo]ZoookJ_l000002OoonfX2o`000003oookJ_l0003o
oo]Z00Oooo]Z00?o0000oookJ_oonfX02OoonfX5o`0000;ooo]Z1?l000001?oonf[o0000oookJ_oo
nfX4o`0000;ooo]Z00?o0000oookJ_oonfX01_l0001]oookJP[o000000?ooo]Zo`000?l000000_l0
00001_oonf[o0000oookJ_oonf[o0000oookJP;o000000Gooo]Zo`000?oonf[o0000oookJP02o`00
0003oookJ_l0003ooo]Z00;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;ooo]Z1_l000000ooo
nf[o0000o`000003oookJP03o`000?oonf[ooo]Z00[ooo]Z1ol00002oookJPOo00000ooonfX00ol0
003ooo]ZoookJP03o`0000;ooo]Z00?o0000oookJ_oonfX00_l00002oookJP?o00000_oonfX01Ol0
003ooo]ZoookJ_oonf[o000000?ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00;o00001OoonfX0
1?l0003ooo]Zo`000?l00004oookJP;o00000_oonfX01Ol0003ooo]Zo`000?oonf[o000000Oooo]Z
00Go0000oookJ_oonf[ooo]Zo`000004oookJP;o000000?ooo]Zo`000?oonfX01?oonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Oo000000Cooo]Zo`000?l0003ooo]Z0_l000002Ooo
nf[o0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`000003oookJP?o000000Gooo]Zo`000?l0003o
oo]Zo`000003oookJP03o`000?oonf[o000000Gooo]Z00Co0000oookJ_l0003o00001OoonfX1o`00
000000Ko0000oookJ_oonf[o0000oookJ_l00003oookJP;o000000Cooo]Zo`000?oonf[ooo]Z0_l0
00000ooonf[o0000o`000003o`0000;ooo]Z0_l00002oookJP;o00000_oonfX4o`000003oookJ_l0
003o000000Go000000?ooo]Zo`000?l000001?l00003oookJP?o00001?oonfX3o`000004oookJ_l0
003ooo]Zo`0000?ooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP;o00001OoonfX2o`000003
oookJ_l0003o000000;ooo]Z00?o0000oookJ_l000000_l00003oookJP04o`000?oonf[ooo]Zo`00
00Kooo]Z00Co0000oookJ_l0003ooo]Z0ol000000ooonf[o0000o`000002o`000003oookJ_l0003o
000000?ooo]Z00?o0000oookJ_l000001?l000001?oonf[o0000o`000?oonfX3o`000003oookJ_l0
003ooo]Z00;o000000?ooo]Zo`000?l000000ol000000ooonf[o0000oookJP02oookJPGo00001ooo
nfX00ol0003ooo]ZoookJP02oookJP?o00000_oonfX2o`0000?ooo]Z00Go0000oookJ_l0003ooo]Z
o`000002oookJP;o00001?oonfX00ol0003ooo]ZoookJP03o`0000;ooo]Z0_l000002Ooonf[o0000
o`000?oonf[o0000oookJ_l0003ooo]Zo`000002oookJPGo000000?ooo]Zo`000?l000001?l0001_
oookJPKo000000?ooo]Zo`000?l000001?l00002oookJP;o00001OoonfX4o`000005oookJ_l0003o
0000o`000?oonfX00ol00002oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00005oookJP04o`000?oo
nf[o0000o`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000003o`000004oook
J_l0003o0000o`0000;ooo]Z1?l00002oookJP04o`000?oonf[ooo]ZoookJP;o000000?ooo]Zo`00
0?l000000ooonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oonf[o000000Cooo]Z00Wo0000
oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000001?oonfX01_l0003ooo]Zo`000?l0003ooo]Z
o`0000Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0
0003oookJP03o`000?oonf[ooo]Z00;o00000_oonfX01?l0003ooo]Zo`000?l00004oookJP03o`00
0?oonf[ooo]Z00;o00001?oonfX00ol0003ooo]Zo`000003oookJPCo000000?ooo]Zo`000?oonfX0
0_l000000ooonf[o0000o`000003o`0000;ooo]Z00Co0000oookJ_oonf[ooo]Z1Ol00005oookJP03
o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP04o`000?oonf[ooo]Z
o`0000;ooo]Z0Ol000000006o`000?oonf[o0000o`000?oonf[o00000_oonfX01?l0003ooo]Zo`00
0?l00005oookJP;o000000Cooo]Zo`000?l0003o00000_oonfX2o`0000;ooo]Z0_l00003oookJP03
o`000?oonf[o000000;o000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000005o`0000;o
oo]Z00?o0000oookJ_l000000ooonfX2o`0000?ooo]Z0_l00002oookJP05o`000?oonf[o0000oook
J_l000000ooonfX00ol0003ooo]Zo`000002o`0000Gooo]Z00Co0000oookJ_oonf[o00001?oonfX2
o`000003oookJ_l0003ooo]Z00;ooo]Z0ol000000ooonf[o0000o`000003o`0000Sooo]Z00?o0000
oookJ_oonfX00_oonfX2o`000003oookJ_l0003ooo]Z00?ooo]Z0ol000000ooonf[o0000o`000003
o`0000;ooo]Z00?o0000oookJ_l000000_oonfX6o`000005oookJ_l0003o0000o`000?oonfX02?l0
00001?oonf[o0000oookJ_l00004oookJP03o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX0
1Ol000000ooonf[o0000o`000002o`000004oookJ_l0003ooo]ZoookJP;o000000?ooo]Zo`000?oo
nfX00ooonfX2o`000004oookJ_l0003ooo]Zo`0000;ooo]Z0ol000001Ooonf[o0000oookJ_l0003o
oo]Z00Oo0000LOoonfX7o`000003oookJ_l0003o000000;o00000_oonfX5o`000003oookJ_l0003o
oo]Z00?o00000_oonfX3o`0000;ooo]Z00?o0000oookJ_l000001?oonfX01Ol0003ooo]ZoookJ_oo
nf[o000001Kooo]Z4Ol00004oookJP?o000000Cooo]Zo`000?oonf[o00000_oonfX2o`000004oook
J_l0003ooo]Zo`0000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00003oookJP;o00000_oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00_oonfX01?l0
003ooo]ZoookJ_l00002oookJP03o`000?oonf[ooo]Z00Wooo]Z00Co0000oookJ_oonf[o00001?oo
nfX00ol0003ooo]ZoookJP08oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l000000ooonf[o0000
oookJP02oookJP;o000000Kooo]Zo`000?oonf[o0000oookJ_l00002oookJP04o`000?oonf[o0000
oookJP;o00000_oonfX3o`000005oookJ_l0003ooo]Zo`000?oonfX00_l000001?oonf[o0000o`00
0?oonfX6o`000003oookJ_l0003o000000?ooo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]Zoooo
nfXnoookJP7o000000001?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003ooo]Z00;ooo]Z0_l0
00001ooonf[o0000o`000?oonf[o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02o`0000;o
oo]Z0_l00002oookJP?o000000Cooo]Zo`000?oonf[ooo]Z1Ol000001?oonf[o0000o`000?oonfX2
o`0000?ooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oookJP03o`000?oonf[o000000;ooo]Z00Oo
0000oookJ_oonf[ooo]Zo`000?oonf[o000000Oooo]Z00?o0000oookJ_oonfX00_oonfX01?l0003o
oo]Zo`000?oonfX2o`000005oookJ_l0003o0000oookJ_l000000_oonfX01?l0003ooo]ZoookJ_l0
0002oookJP;o000000Cooo]Zo`000?l0003o00000_oonfX00ol0003ooo]Zo`000002o`000003oook
J_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ol000001Ooonf[o0000oookJ_oonf[o000000;o
oo]Z00?o0000oookJ_oonfX00_oonfX3o`0000;ooo]Z0_l000000ooonf[o0000o`000002oookJP;o
000000?ooo]Zo`000?l000002?l00003oookJP03o`000?oonf[o000000;ooo]Z00Go0000oookJ_l0
003ooo]Zo`000009oookJPCo00001?oonfX2o`0000Cooo]Z00Co0000oookJ_oonf[o00001?oonfX0
0ol0003ooo]Zo`000002o`000003oookJ_l0003o000000co0000L_oonfX:o`000003oookJ_l0003o
000000;o000000Cooo]Zo`000?oonf[o00000_oonfX2o`0000;ooo]Z00?o0000oookJ_l000000_oo
nfX2o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_l000002?oonfX00ol0003ooo]Zoook
JP02o`0000Sooo]Z0_l000000ooonf[o0000o`000007o`0000;ooo]Z00Ko0000oookJ_oonf[o0000
oookJ_l00006oookJPOo000000?ooo]Zo`000?l000000ooonfX00ol0003ooo]ZoookJP02o`0000?o
oo]Z00Co0000oookJ_oonf[ooo]Z0_l000001_oonf[o0000oookJ_oonf[o0000oookJP;o00000ooo
nfX5o`0000Cooo]Z00?o0000oookJ_oonfX01?l00003oookJP04o`000?oonf[o0000oookJP;o0000
1OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l00000
0ooonfX01_l0003ooo]Zo`000?oonf[o0000oookJPCo000000?ooo]Zo`000?oonfX01?l000000ooo
nf[o0000o`000002oookJP04o`000?oonf[ooo]ZoookJP;o000000Cooo]Zo`000?l0003ooo]Z0_l0
0003oookJP06o`000?oonf[o0000oookJ_l0003ooo]Z0ol000001?oonf[o0000oookJ_l00002oook
JP;o00000OoonfX1o`00000000?o0000oookJ_l000000_l000001?oonf[o0000o`000?l00002oook
JP?o000000Cooo]Zo`000?oonf[o00000_oonfX3o`0000;ooo]Z0_l00002oookJP;o00000ooonfX3
o`000005oookJ_l0003o0000o`000?oonfX00ol000001Ooonf[o0000o`000?oonf[o000000?ooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_l00004oookJP;o0000
00?ooo]Zo`000?l000000_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o000000[ooo]Z
0_l00006oookJP04o`000?oonf[ooo]ZoookJP;o00001?oonfX3o`0000?ooo]Z00?o0000oookJ_oo
nfX01ooonfX2o`0000;ooo]Z1Ol00003oookJP03o`000?oonf[ooo]Z00_o000000?ooo]Zo`000?l0
00001_l00004oookJP05o`000?oonf[ooo]ZoookJ_l000001OoonfX01?l0003ooo]ZoookJ_oonfX2
o`0000;ooo]Z0_l00003oookJP;o000000?ooo]Zo`000?l000000_oonfX00ol0003ooo]ZoookJP03
oookJP;o000000?ooo]Zo`000?oonfX00ol000000ooonf[o0000oookJP02oookJPWo0000M?oonfX9
o`0000;ooo]Z0_l000001Ooonf[o0000o`000?l0003ooo]Z00;o00000_oonfX5o`0000Gooo]Z0ol0
00001_oonf[o0000oookJ_l0003ooo]Zo`0000Oooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oook
JP03o`000?oonf[o000000?ooo]Z1Ol000000ooonf[o0000o`000002oookJP?o000000Cooo]Zo`00
0?l0003ooo]Z1?l000000ooonf[o0000o`000005oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l0
0002oookJP03o`000?oonf[o000000?ooo]Z0ol00002oookJP03o`000?oonf[o000000Sooo]Z00Co
0000oookJ_l0003ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00;o00000_oonfX2o`0000Gooo]Z
00?o0000oookJ_oonfX00_l000001?oonf[o0000oookJ_l00002oookJP04o`000?oonf[ooo]Zo`00
00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`000?oonf[ooo]Z00;ooo]Z1?l00003
oookJP;o000000?ooo]Zo`000?oonfX01Ol000001?oonf[o0000o`000?l00002oookJP;o000000Go
oo]Zo`000?oonf[o0000oookJP04o`0000?ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002oook
JP?o00000_oonfX1o`00000000?o0000oookJ_l000000ooonfX2o`0000;ooo]Z00?o0000oookJ_oo
nfX00_l000000ooonf[o0000o`000005o`0000;ooo]Z0_l00002oookJP;o00000_oonfX4o`000007
oookJ_l0003o0000o`000?oonf[o0000oookJP05o`0000Kooo]Z00Co0000oookJ_oonf[ooo]Z1?l0
0006oookJP06o`000?oonf[ooo]Zo`000?oonf[o00001?oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00Wooo]Z0_l00003oookJPCo000000?ooo]Zo`000?l000001?oonfX00ol0003o
oo]ZoookJP02o`0000Sooo]Z00Co0000oookJ_l0003o00001?oonfX2o`0000;ooo]Z0_l00004oook
JP?o000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000006o`000003oookJ_l0003o0000
00Go00002OoonfX2o`0000;ooo]Z0_l00002oookJP04o`000?oonf[ooo]Zo`0000Kooo]Z0_l00003
oookJP03o`000?oonf[ooo]Z00Ko00000_oonfX2o`000003oookJ_l0003o000000;o000000Gooo]Z
o`000?l0003o0000oookJP02o`0000;ooo]Z0_l0001foookJPco000000?ooo]Zo`000?oonfX00_l0
00000ooonf[o0000o`000002o`0000Cooo]Z1?l00002oookJP?o00001OoonfX01Ol0003ooo]Zoook
J_oonf[o000000?ooo]Z00Go0000oookJ_l0003ooo]Zo`000007oookJP?o000000Gooo]Zo`000?l0
003ooo]Zo`000002oookJPOo000000?ooo]Zo`000?oonfX00_oonfX2o`0000;ooo]Z1ol000000ooo
nf[o0000o`000003oookJP?o00000ooonfX01?l0003ooo]Zo`000?l00005oookJP;o00000ooonfX0
1_l0003ooo]Zo`000?l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_l000001?l00002oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_l0003ooo]Z00?o
00000_oonfX00ol0003ooo]ZoookJP03oookJP06o`000?oonf[o0000oookJ_l0003ooo]Z0ol00006
oookJPCo000000Gooo]Zo`000?l0003o0000oookJP03o`0000?ooo]Z00Go0000oookJ_l0003ooo]Z
o`000002oookJP07o`000?oonf[ooo]Zo`000?oonf[o0000oookJP02o`000005oookJ_l0003ooo]Z
o`000?oonfX00_l00002oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003ooo]Z0Ol0
00000003o`000?oonf[ooo]Z00Gooo]Z1?l00002oookJPSo00000ooonfX2o`0000;ooo]Z0_l00003
oookJP;o000000Kooo]Zo`000?l0003ooo]Zo`000?oonfX3o`000005oookJ_l0003o0000o`000?oo
nfX01Ol00003oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_oonf[o00000_oonfX3o`00
00;ooo]Z00Go0000oookJ_oonf[o0000oookJP05o`000004oookJ_l0003ooo]Zo`0000Cooo]Z00?o
0000oookJ_oonfX00ol000001?oonf[o0000o`000?oonfX3o`000003oookJ_l0003o000000Co0000
00?ooo]Zo`000?oonfX00ol000000ooonf[o0000o`000003oookJPCo000000?ooo]Zo`000?oonfX0
1?l000000ooonf[o0000o`000002o`0000?ooo]Z00?o0000oookJ_l000000ooonfX2o`0000?ooo]Z
0_l000000ooonf[o0000oookJP02o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l00000
1_oonfX01?l0003ooo]ZoookJ_oonfX3o`000003oookJ_l0003ooo]Z00;ooo]Z00Go0000oookJ_l0
003ooo]Zo`000002oookJP04o`000?oonf[ooo]ZoookJPGo000000Cooo]Zo`000?oonf[ooo]Z0ol0
00001?oonf[o0000o`000?oonfX;o`000003oookJ_l0003o000007Oooo]Z1Ol000000ooonf[o0000
o`000004o`000003oookJ_l0003ooo]Z00Co00000_oonfX2o`0000?ooo]Z00Co0000oookJ_l0003o
00001_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000?ooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]Zo`000002oookJP_o00000ooonfX2o`000003oookJ_l0003ooo]Z00?o
000000?ooo]Zo`000?l000000ol00003oookJP03o`000?oonf[o000000;o000000?ooo]Zo`000?oo
nfX00ol000001?oonf[o0000o`000?l00003oookJP03o`000?oonf[o000000Gooo]Z0_l00004oook
JP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_l000001_oonfX2
o`0000Sooo]Z0_l000000ooonf[o0000oookJP02o`000004oookJ_l0003o0000oookJP;o00000_oo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX00_oonfX3o`000006oookJ_l0003o0000o`000?oonf[o
00000_oonfX2o`000004oookJ_l0003ooo]ZoookJP;o000000Cooo]Zo`000?l0003ooo]Z0ol00002
oookJPWo000000Kooo]Zo`000?l0003o0000oookJ_l00002oookJP03o`000?oonf[ooo]Z007o0000
00000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1o`00000000Co0000oookJ_l0003ooo]Z0_l0
0003oookJP04o`000?oonf[ooo]Zo`0000Cooo]Z00Co0000oookJ_oonf[ooo]Z0_l00002oookJP;o
00000_oonfX2o`0000;ooo]Z1?l000000ooonf[o0000oookJP07o`0000Gooo]Z0_l0000:oookJP04
o`000?oonf[ooo]Zo`0000Sooo]Z0_l00004oookJPKo000000Gooo]Zo`000?l0003o0000oookJP02
o`0000Cooo]Z00?o0000oookJ_l000000ooonfX01Ol0003ooo]Zo`000?oonf[o000000Kooo]Z00?o
0000oookJ_oonfX01ol00002oookJP04o`000?oonf[o0000oookJPCo000000?ooo]Zo`000?oonfX0
0_oonfX01Ol0003ooo]Zo`000?oonf[o000000;ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l00002
oookJPGo000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000002oookJP;o000000Gooo]Z
o`000?l0003ooo]Zo`000003oookJP;o000000Sooo]Zo`000?l0003ooo]Zo`000?oonf[o0000oook
JP;o000000Cooo]Zo`000?oonf[ooo]Z1_l000001?oonf[o0000oookJ_l00003oookJP04o`000?oo
nf[o0000oookJP;o000000?ooo]Zo`000?l000001?l0001ioookJPOo000000Sooo]Zo`000?l0003o
0000oookJ_l0003ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00_l00003oookJP?o00000_oonfX2
o`000003oookJ_l0003ooo]Z00;o00000_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00_oonfX3
o`000004oookJ_l0003ooo]ZoookJPOo000000Gooo]Zo`000?l0003o0000oookJP02o`0000?ooo]Z
0_l00003oookJP?o000000Gooo]Zo`000?l0003o0000oookJP02o`000004oookJ_l0003o0000o`00
00;ooo]Z0_l00002oookJP;o00000ooonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z0ol00004oook
JP?o000000?ooo]Zo`000?l000000_l000000ooonf[o0000oookJP02o`0000;ooo]Z00[o0000oook
J_l0003ooo]Zo`000?oonf[o0000oookJ_l0003ooo]Z0_l0000:oookJP?o000000?ooo]Zo`000?oo
nfX00_oonfX00ol0003ooo]Zo`000003oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z0_l00002oook
JPCo000000?ooo]Zo`000?oonfX00_oonfX5o`000005oookJ_l0003o0000o`000?oonfX02?l00000
0ooonf[o0000oookJP05oookJP;o00001_oonfX2o`0000;ooo]Z0Ol000000003o`000?oonf[ooo]Z
00;ooo]Z0_l000000ooonf[o0000o`000002o`0000;ooo]Z00?o0000oookJ_oonfX01Ol00003oook
JP;o00000_oonfX2o`0000?ooo]Z0ol000000ooonf[o0000o`000005o`000005oookJ_l0003ooo]Z
oookJ_l000002OoonfX2o`0000Cooo]Z1_l00003oookJP04o`000?oonf[ooo]Zo`0000_ooo]Z0_l0
0003oookJPCo00000_oonfX00ol0003ooo]Zo`000002o`000006oookJ_l0003ooo]Zo`000?oonf[o
00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oookJ_l000000_l000001_oo
nf[o0000oookJ_oonf[o0000oookJP;o000000Cooo]Zo`000?l0003o00000_oonfX3o`000004oook
J_l0003o0000o`0000;ooo]Z0_l000000ooonf[o0000oookJP04o`000003oookJ_l0003ooo]Z00?o
oo]Z00?o0000oookJ_l000001ol00007oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l0
00000ooonfX2o`000003oookJ_l0003o000000;ooo]Z0_l00002oookJPCo000000Cooo]Zo`000?oo
nf[o00000ooonfX4o`000003oookJ_l0003o000000Go0000O?oonfX5o`000003oookJ_l0003ooo]Z
00?o000000?ooo]Zo`000?l000001?l00004oookJPOo00000ooonfX03Ol0003ooo]ZoookJ_oonf[o
0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l000002OoonfX7o`0000?ooo]Z00?o0000oook
J_l000001_l000001?oonf[o0000o`000?l00002oookJP?o00000_oonfX2o`000005oookJ_l0003o
0000oookJ_l000000ooonfX00ol0003ooo]Zo`000006oookJP06o`000?oonf[o0000o`000?oonf[o
00000ooonfX2o`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX4o`000004oookJ_l0003ooo]Zo`00
00?ooo]Z00?o0000oookJ_l000001OoonfX01?l0003ooo]Zo`000?l00002oookJP03o`000?oonf[o
000000;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX01?oonfX01Ol0003ooo]Zo`000?l0003ooo]Z00?o000000?ooo]Zo`000?l00000
0ol000001ooonf[o0000oookJ_oonf[o0000oookJ_l000000ooonfX3o`0000?ooo]Z0_l00003oook
JP;o00001OoonfX01Ol0003ooo]Zo`000?l0003ooo]Z00?o00000_oonfX1o`00000000?o0000oook
J_l000001_l000001Ooonf[o0000o`000?l0003ooo]Z00Wo00000_oonfX2o`0000;ooo]Z0_l00002
oookJP?o00000_oonfX3o`000003oookJ_l0003o000000;o00001?oonfX00ol0003ooo]ZoookJP07
oookJP05o`000?oonf[o0000oookJ_l000001OoonfX02?l0003ooo]Zo`000?oonf[o0000oookJ_l0
003ooo]Z0_l00005oookJP04o`000?oonf[ooo]ZoookJP?o00001ooonfX4o`0000;ooo]Z00?o0000
oookJ_l000001?oonfX00ol0003ooo]Zo`000002oookJP?o000000?ooo]Zo`000?oonfX01?oonfX2
o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000000ooonfX00ol0003ooo]Zo`000005
o`000005oookJ_l0003ooo]ZoookJ_l000000_oonfX6o`000003oookJ_l0003o000000Co000000Go
oo]Zo`000?l0003o0000oookJP02o`0000?ooo]Z0_l000001ooonf[o0000oookJ_l0003ooo]Zo`00
0?oonfX00ol000000ooonf[o0000o`000003oookJPCo00000_oonfX2o`000003oookJ_l0003ooo]Z
00?ooo]Z1ol000001?oonf[o0000o`000?l0001moookJPoo00000_oonfX00ol0003ooo]ZoookJP02
oookJPKo000000?ooo]Zo`000?l000000ooonfX01Ol0003ooo]Zo`000?oonf[o000000?ooo]Z00?o
0000oookJ_oonfX00ol00003oookJP03o`000?oonf[o000000go000000?ooo]Zo`000?l000000_l0
00000ooonf[o0000o`000002o`0000;ooo]Z00?o0000oookJ_oonfX00_l000000ooonf[o0000o`00
0002oookJP03o`000?oonf[o000000;o000000?ooo]Zo`000?oonfX00_l000001?oonf[o0000oook
J_oonfX3o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Z
o`000009oookJP;o00000ooonfX6o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
0_l000001ooonf[o0000oookJ_l0003ooo]Zo`000?oonfX00_l00003oookJP03o`000?oonf[ooo]Z
00;o00001?oonfX00ol0003ooo]Zo`000008o`000004oookJ_l0003ooo]ZoookJPKo000000?ooo]Z
o`000?l000000_oonfX01Ol0003ooo]Zo`000?oonf[o000000Gooo]Z0_l000001_oonf[o0000oook
J_oonf[o0000oookJPCo00000OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z
0Ol000000003o`000?oonf[ooo]Z00Gooo]Z00Co0000oookJ_oonf[ooo]Z1_l00002oookJP?o0000
0_oonfX2o`0000;ooo]Z0_l00002oookJPKo000000?ooo]Zo`000?oonfX00_l00004oookJP04o`00
0?oonf[o0000o`0000?ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP02o`0000Ko
oo]Z00?o0000oookJ_l000000_l000000ooonf[o0000oookJP02oookJPGo00000ooonfX01?l0003o
oo]ZoookJ_l00003oookJP03o`000?oonf[o000000?ooo]Z00Co0000oookJ_l0003o00000_oonfX0
0ol0003ooo]ZoookJP0@o`000005oookJ_l0003o0000o`000?oonfX00_l000001?oonf[o0000oook
J_oonfX3o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?oonf[ooo]Z1ol00003oookJP03
o`000?oonf[o000000;o000000Gooo]Zo`000?l0003o0000oookJP05o`000003oookJ_l0003o0000
00;o000000Gooo]Zo`000?l0003o0000oookJP02o`000004oookJ_l0003o0000oookJP;o000000Go
oo]Zo`000?oonf[o0000oookJP02o`000004oookJ_l0003ooo]Zo`0000;ooo]Z1Ol00003oookJP;o
000000?ooo]Zo`000?l000001Ol0001ooookJPWo000000?ooo]Zo`000?oonfX00_oonfX2o`0000?o
oo]Z0_l00003oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJPSo000000?ooo]Zo`000?l0
00001Ol000000ooonf[o0000oookJP03o`0000;ooo]Z1_l00003oookJP03o`000?oonf[ooo]Z00?o
oo]Z00Co0000oookJ_l0003o00001?oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00ol000001?oo
nf[o0000o`000?oonfX3o`000003oookJ_l0003o000000;ooo]Z0_l00004oookJP04o`000?oonf[o
oo]ZoookJP;o00000ooonfX2o`000003oookJ_l0003o000000;o00000_oonfX01?l0003ooo]Zo`00
0?oonfX2o`0000;ooo]Z00Ko0000oookJ_l0003ooo]Zo`000?oonfX5o`0000Gooo]Z0_l000000ooo
nf[o0000o`000007oookJPGo000000Cooo]Zo`000?oonf[ooo]Z1?l00002oookJP03o`000?oonf[o
oo]Z00Co000000Gooo]Zo`000?l0003o0000oookJP03o`000003oookJ_l0003ooo]Z00;ooo]Z0ol0
00001?oonf[o0000o`000?l00002oookJP7o000000000ol0003ooo]ZoookJP03o`000004oookJ_l0
003ooo]ZoookJP;o00001OoonfX00ol0003ooo]Zo`000002o`0000?ooo]Z0_l00002oookJP;o0000
0_oonfX4o`000003oookJ_l0003ooo]Z00Co000000?ooo]Zo`000?l000001ooonfX4o`000003oook
J_l0003ooo]Z00;o00000_oonfX01?l0003ooo]Zo`000?oonfX2o`0000;ooo]Z00Ko0000oookJ_oo
nf[o0000oookJ_l00002oookJPGo000000?ooo]Zo`000?oonfX01OoonfX4o`0000Gooo]Z0_l00002
oookJP05o`000?oonf[o0000o`000?oonfX00_l000001_oonf[o0000oookJ_l0003ooo]Zo`0000;o
oo]Z0_l000000ooonf[o0000oookJP03oookJP?o00000_oonfX3o`000003oookJ_l0003o000000;o
oo]Z0_l000000ooonf[o0000o`000003oookJPCo000000Gooo]Zo`000?oonf[ooo]Zo`000002oook
JP03o`000?oonf[o000000[o000000?ooo]Zo`000?oonfX00_oonfX2o`000003oookJ_l0003ooo]Z
00Co000000Cooo]Zo`000?oonf[ooo]Z0_l000000ooonf[o0000oookJP03o`000003oookJ_l0003o
oo]Z00?o000000Gooo]Zo`000?l0003o0000oookJP02o`000003oookJ_l0003o000000Ko0000POoo
nfX4o`000005oookJ_l0003ooo]Zo`000?oonfX01Ol000001?oonf[o0000o`000?l00003oookJP?o
00000_oonfX00ol0003ooo]ZoookJP03o`000004oookJ_l0003o0000o`0000?ooo]Z00?o0000oook
J_oonfX01ooonfX3o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000001?l000000ooo
nf[o0000o`000002o`000003oookJ_l0003ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ol00002oook
JP05o`000?oonf[ooo]Zo`000?oonfX00_l00002oookJP;o000000Gooo]Zo`000?oonf[ooo]Zo`00
0005oookJP;o000000?ooo]Zo`000?oonfX00ooonfX3o`000003oookJ_l0003ooo]Z00Sooo]Z00Go
0000oookJ_oonf[ooo]Zo`000004oookJP;o00000_oonfX2o`0000;ooo]Z2Ol000001Ooonf[o0000
oookJ_oonf[o000000Cooo]Z00Go0000oookJ_l0003ooo]Zo`000002oookJP04o`000?oonf[ooo]Z
oookJP;o000000?ooo]Zo`000?l000001?l000001_oonf[o0000o`000?oonf[o0000oookJP?o0000
00Gooo]Zo`000?l0003ooo]Zo`000002oookJP03o`000?oonf[ooo]Z00?o00001?oonfX01?l0003o
oo]Zo`000?oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00Ol000000003o`000?oonf[o000000;o
oo]Z2?l000001?oonf[o0000oookJ_oonfX6o`0000;ooo]Z0_l00002oookJP;o00000_oonfX8o`00
0003oookJ_l0003ooo]Z00;o000000Cooo]Zo`000?l0003o00000ooonfX2o`000003oookJ_l0003o
oo]Z00Cooo]Z00Wo0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonfX00_l00002oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00Oooo]Z00?o0000oookJ_l000001ooonfX2o`000003oookJ_l0003o000000?ooo]Z00Go0000oook
J_oonf[ooo]Zo`000004oookJP;o000000Oooo]Zo`000?oonf[ooo]Zo`000?oonf[o000000;ooo]Z
00Co0000oookJ_l0003ooo]Z0ol000000ooonf[o0000o`000003o`000005oookJ_l0003o0000o`00
0?oonfX00_l00002oookJP?o000000Kooo]Zo`000?l0003ooo]Zo`000?oonfX8o`0000?ooo]Z0ol0
00000ooonf[o0000o`000003o`0000?ooo]Z1Ol000000ooonf[o0000oookJP02o`000003oookJ_l0
003o000000Go000000Gooo]Zo`000?l0003o0000oookJP09o`0008Cooo]Z2ol000000ooonf[o0000
o`000005o`0000;ooo]Z0_l00002oookJP03o`000?oonf[o000000?o00001OoonfX01Ol0003ooo]Z
o`000?l0003ooo]Z00;o000000?ooo]Zo`000?l000002_l00002oookJPOo000000Wooo]Zo`000?oo
nf[o0000oookJ_l0003ooo]Zo`000?oonfX00_l00002oookJPCo000000Sooo]Zo`000?oonf[o0000
oookJ_l0003ooo]Zo`0000;ooo]Z0_l000000ooonf[o0000oookJP03o`0000;ooo]Z0_l000001?oo
nf[o0000oookJ_l00004oookJP03o`000?oonf[o000000?ooo]Z0_l00002oookJP03o`000?oonf[o
oo]Z00Ko000000?ooo]Zo`000?oonfX00_oonfX01_l0003ooo]Zo`000?oonf[o0000oookJP?o0000
0ooonfX01?l0003ooo]ZoookJ_l00003oookJP;o00000ooonfX4o`000004oookJ_l0003ooo]Zo`00
00?ooo]Z00Co0000oookJ_l0003o00000_oonfX4o`000003oookJ_l0003o000000?o000000?ooo]Z
o`000?l000000_oonfX9o`000003oookJ_l0003o000000?ooo]Z00Go0000oookJ_oonf[o0000oook
JP03o`0000;ooo]Z0_l00002oookJP7o000000000ol0003ooo]ZoookJP3ooookJ_oooo]Z?_oonfX1
o`00000000?o0000oookJ_l000000_l000000ooonf[o0000oookJP02o`000004oookJ_l0003ooo]Z
oookJPSo00000ooonfX2o`0000;ooo]Z0_l00002oookJP?o000000?ooo]Zo`000?l000000ol00000
1?oonf[o0000oookJ_l00007oookJP03o`000?oonf[o000000;ooo]Z1Ol000001?oonf[o0000o`00
0?l00008oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00Co0000oookJ_l0003o00000_oonfX2o`00
0003oookJ_l0003ooo]Z00Go00000ooonfX01?l0003ooo]ZoookJ_oonfX2o`000004oookJ_l0003o
oo]Zo`0000?ooo]Z00?o0000oookJ_l000000_l000000ooonf[o0000o`000002o`0000;ooo]Z00Go
0000oookJ_l0003o0000oookJP03o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l00000
0ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000Ko00000_oonfX01Ol0003ooo]Z
o`000?l0003ooo]Z00Ko000000Kooo]Zo`000?oonf[ooo]Zo`000?oonfX4o`000003oookJ_l0003o
000000Go000000Cooo]Zo`000?l0003ooo]Z0ol000000ooonf[o0000oookJP08o`000003oookJ_l0
003o000000Ko0000QOoonfX?o`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?l000000_l0
00000ooonf[o0000oookJP03o`0000;ooo]Z1?l00003oookJP03o`000?oonf[ooo]Z01Co000000?o
oo]Zo`000?l000000ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000Co00000_oo
nfX4o`0000Sooo]Z00co0000oookJ_oonf[o0000oookJ_l0003ooo]Zo`000?oonf[o0000oookJ_l0
0004oookJPCo000000?ooo]Zo`000?oonfX00_l000001?oonf[o0000oookJ_oonfX4o`0000?ooo]Z
00?o0000oookJ_oonfX00ol00002oookJPKo00000ooonfX2o`0000Cooo]Z00Ko0000oookJ_l0003o
0000oookJ_l00003oookJP04o`000?oonf[ooo]Zo`0000Gooo]Z1?l00004oookJP?o00000_oonfX6
o`000004oookJ_l0003ooo]ZoookJP;o000000Gooo]Zo`000?oonf[o0000oookJP04o`000005oook
J_l0003o0000oookJ_l000000_oonfX01?l0003ooo]Zo`000?l00004oookJP7o000000000ol0003o
oo]Zo`000002oookJP;o000000?ooo]Zo`000?l000003Ol00002oookJP;o00000_oonfX2o`0000;o
oo]Z1?l000000ooonf[o0000oookJP02oookJP05o`000?oonf[o0000oookJ_l000000ooonfX3o`00
0003oookJ_l0003o000000Cooo]Z00Ko0000oookJ_l0003o0000oookJ_l00002oookJP;o000000?o
oo]Zo`000?oonfX00_oonfX2o`000003oookJ_l0003o000000?ooo]Z1?l000001ooonf[o0000o`00
0?oonf[o0000oookJ_l000000ooonfX2o`0000;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol00004oook
JP;o000000?ooo]Zo`000?oonfX01?oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]Zo`000007o`0000;ooo]Z00?o0000oookJ_oonfX00_l00002oookJPgo000000?ooo]Zo`00
0?l000001Ol000001ooonf[o0000o`000?l0003ooo]Zo`000?oonfX00ol00005oookJPOo00000_oo
nfX3o`000003oookJ_l0003ooo]Z00;o000000Cooo]Zo`000?l0003ooo]Z1_l00028oookJPCo0000
0_oonfX3o`000005oookJ_l0003o0000o`000?oonfX01_l000000ooonf[o0000oookJP03o`000003
oookJ_l0003o000000?o000000Cooo]Zo`000?l0003ooo]Z0ol00002oookJP[o000000?ooo]Zo`00
0?l000004_l00002oookJP03o`000?oonf[ooo]Z00;o000000?ooo]Zo`000?oonfX00ol00002oook
JP?o000000Cooo]Zo`000?l0003o00000_oonfX3o`0000Cooo]Z00?o0000oookJ_l000000_l00003
oookJP?o00000ooonfX01?l0003ooo]Zo`000?l00003oookJP05o`000?oonf[ooo]ZoookJ_l00000
1?oonfX01?l0003ooo]ZoookJ_l00006oookJP04o`000?oonf[ooo]ZoookJP?o000000Kooo]Zo`00
0?oonf[o0000oookJ_l00004oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00002oookJP03o`000?oo
nf[o000000?o00000_oonfX3o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?oonfX00_l0
00001?oonf[o0000o`000?oonfX2o`0000;ooo]Z0_l000001Ooonf[o0000oookJ_oonf[o000000;o
oo]Z1?l00002oookJP7o000000001?l0003ooo]Zo`000?oonfX5o`0000Cooo]Z0_l00002oookJP;o
000000Cooo]Zo`000?l0003o00000_oonfX2o`0000;ooo]Z0_l00002oookJP;o000000?ooo]Zo`00
0?l000001_l000000ooonf[o0000oookJP02oookJP03o`000?oonf[ooo]Z00?o00001?oonfX01ol0
003ooo]Zo`000?l0003ooo]Zo`000?oonfX00_l000001_oonf[o0000oookJ_l0003ooo]Zo`0000;o
oo]Z0_l00002oookJP04o`000?oonf[o0000o`0000;ooo]Z0ol000000ooonf[o0000o`000003oook
JP06o`000?oonf[ooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]Zo`000002o`0000Kooo]Z00?o
0000oookJ_l000000_l000000ooonf[o0000o`000002o`0000;ooo]Z00Go0000oookJ_l0003o0000
oookJP03o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000_l00004oookJP;o0000
00?ooo]Zo`000?oonfX01ol00002oookJP03o`000?oonf[o000000Co000000?ooo]Zo`000?l00000
2?l000000ooonf[o0000o`000002oookJP03o`000?oonf[o000000;o000000?ooo]Zo`000?l00000
1?oonfX00ol0003ooo]Zo`000002o`000003oookJ_l0003ooo]Z00Ko00000ooonfX4o`0008_ooo]Z
1_l000001?oonf[o0000o`000?l00002oookJPGo000000Gooo]Zo`000?l0003o0000oookJP09o`00
0003oookJ_l0003o000000;o00000_oonfX@o`0000;ooo]Z0ol000001?oonf[o0000o`000?oonfX4
o`0000;ooo]Z00?o0000oookJ_oonfX01ol00002oookJP;o00001?oonfX00ol0003ooo]ZoookJP06
o`0000;ooo]Z0_l000000ooonf[o0000o`000002o`000004oookJ_l0003ooo]ZoookJP;o00000_oo
nfX2o`000003oookJ_l0003o000000;ooo]Z00Co0000oookJ_l0003o00001?oonfX01?l0003ooo]Z
o`000?oonfX3o`0000;ooo]Z00?o0000oookJ_l000000_oonfX01_l0003ooo]Zo`000?oonf[o0000
oookJP;o000000?ooo]Zo`000?l000001OoonfX01?l0003ooo]Zo`000?oonfX3o`000004oookJ_l0
003o0000o`0000?ooo]Z0ol00003oookJPoo000000?ooo]Zo`000?l000000_l000000ooonf[o0000
o`000002o`0000;ooo]Z1?l00002oookJP03o`000?oonf[o000000Cooo]Z0Ol000000003o`000?oo
nf[o000000?o000000Cooo]Zo`000?oonf[ooo]Z0ol000000ooonf[o0000o`000002o`000003oook
J_l0003o000000;o00000_oonfX2o`0000;ooo]Z0_l00002oookJP;o000000Cooo]Zo`000?oonf[o
oo]Z0_l00002oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003o00001_oonfX3o`00
00;ooo]Z0_l000001?oonf[o0000o`000?l00003oookJPCo000000?ooo]Zo`000?oonfX00ol00004
oookJP;o00000_oonfX00ol0003ooo]Zo`000002oookJP04o`000?oonf[o0000o`0000;ooo]Z00Co
0000oookJ_oonf[ooo]Z0_l000000ooonf[o0000o`000003o`0000?ooo]Z00Co0000oookJ_oonf[o
00000_oonfX4o`0000;ooo]Z0_l000001Ooonf[o0000o`000?l0003ooo]Z00;o000000?ooo]Zo`00
0?l000002_l000000ooonf[o0000oookJP08o`000006oookJ_l0003o0000o`000?oonf[o00000ooo
nfX;o`000004oookJ_l0003o0000oookJP?o00000ooonfX00ol0003ooo]Zo`000002o`000004oook
J_l0003o0000o`0000;ooo]Z2Ol000000ooonf[o0000o`000003o`0008gooo]Z2Ol000000ooonf[o
0000oookJP0:o`000003oookJ_l0003o000000?o000000Cooo]Zo`000?l0003o00000ooonfX8o`00
0003oookJ_l0003o000000Co000000?ooo]Zo`000?l000001_l000001?oonf[o0000o`000?l00002
oookJPKo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000004oookJP03o`000?oonf[o
oo]Z00;o000000Cooo]Zo`000?l0003o00000_oonfX3o`0000;ooo]Z0_l000001Ooonf[o0000o`00
0?l0003ooo]Z00?o000000Kooo]Zo`000?oonf[ooo]Zo`000?oonfX4o`000004oookJ_l0003ooo]Z
oookJP?o000000Cooo]Zo`000?oonf[ooo]Z0_l0000;oookJP;o000000Wooo]Zo`000?l0003ooo]Z
o`000?oonf[o0000oookJ_l000000ooonfX4o`0000?ooo]Z0ol000001?oonf[o0000oookJ_oonfX3
o`000006oookJ_l0003o0000oookJ_l0003ooo]Z0ol000000ooonf[o0000o`000004o`000003oook
J_l0003o000000;ooo]Z1?l000000ooonf[o0000o`000002oookJP;o000000Cooo]Zo`000?l0003o
oo]Z0ol000001?oonf[o0000oookJ_oonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSko
oo]Z0Ol000000003o`000?oonf[o000000?o000000Gooo]Zo`000?l0003o0000oookJP02o`000003
oookJ_l0003o000000?o000000Cooo]Zo`000?l0003o00000_oonfX2o`0000?ooo]Z00?o0000oook
J_oonfX00_l000000ooonf[o0000o`000003oookJP03o`000?oonf[ooo]Z00Ko00002_oonfX00ol0
003ooo]ZoookJP02o`0000Cooo]Z0ol000001?oonf[o0000oookJ_oonfX2o`000004oookJ_l0003o
0000o`0000Cooo]Z0_l00002oookJP05o`000?oonf[ooo]Zo`000?oonfX00_l000000ooonf[o0000
oookJP04oookJP03o`000?oonf[ooo]Z00?o000000Oooo]Zo`000?l0003o0000oookJ_l0003ooo]Z
00?o000000?ooo]Zo`000?l000000_oonfX2o`000004oookJ_l0003o0000o`0000Cooo]Z1_l00000
0ooonf[o0000oookJP02oookJP?o000000Cooo]Zo`000?oonf[ooo]Z2?l000001Ooonf[o0000o`00
0?l0003ooo]Z00Go000000?ooo]Zo`000?l000002_l00002oookJPSo000000Cooo]Zo`000?l0003o
oo]Z4_l0002?oookJPgo000000?ooo]Zo`000?l000002?l000000ooonf[o0000oookJP03o`000003
oookJ_l0003ooo]Z00So000000?ooo]Zo`000?l000002ol000000ooonf[o0000o`000002oookJPCo
000000Gooo]Zo`000?oonf[o0000oookJP04o`000007oookJ_l0003o0000o`000?oonf[o0000oook
JP02o`000004oookJ_l0003o0000o`0000;ooo]Z0ol00002oookJPCo00000_oonfX5o`000004oook
J_l0003o0000o`0000;ooo]Z00?o0000oookJ_oonfX00_l00007oookJP06o`000?oonf[o0000oook
J_l0003ooo]Z2Ol00005oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0
0002oookJP04o`000?oonf[ooo]ZoookJP;o00001OoonfX00ol0003ooo]ZoookJP02o`000003oook
J_l0003o000000?ooo]Z00Co0000oookJ_oonf[ooo]Z2Ol00003oookJP03o`000?oonf[o000000go
000000?ooo]Zo`000?oonfX00ol00001oookJP7o000000000ol0003ooo]Zo`000004o`000003oook
J_l0003o000000Go000000?ooo]Zo`000?l000001Ol00002oookJP;o00000ooonfX01?l0003ooo]Z
oookJ_l00002oookJP;o000000?ooo]Zo`000?l000000_l000000ooonf[o0000oookJP02o`0000Go
oo]Z1Ol00002oookJP04o`000?oonf[o0000oookJPCo000000?ooo]Zo`000?oonfX00_l000000ooo
nf[o0000oookJP03oookJP?o00001?oonfX4o`000003oookJ_l0003ooo]Z00;o00000_oonfX2o`00
0003oookJ_l0003ooo]Z00?o00000ooonfX01Ol0003ooo]Zo`000?l0003ooo]Z00go00001?oonfX3
o`0000Cooo]Z00?o0000oookJ_l000000_l000000ooonf[o0000o`000004o`000003oookJ_l0003o
000000;ooo]Z00?o0000oookJ_oonfX02?l000000ooonf[o0000o`000005o`0000;ooo]Z2Ol00002
oookJPKo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000004o`000003oookJ_l0003o
000000Oo0000TooonfXGo`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000003ol00000
0ooonf[o0000o`000003o`000003oookJ_l0003o000000go000000Cooo]Zo`000?l0003ooo]Z2?l0
00000ooonf[o0000o`000004o`000004oookJ_l0003ooo]Zo`0000?ooo]Z0ol000001_oonf[o0000
o`000?l0003ooo]Zo`0000;ooo]Z00Co0000oookJ_l0003ooo]Z1?l000001?oonf[o0000oookJ_l0
0003oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00000_oonfX00ol0003ooo]Z
oookJP03oookJPCo00000_oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o000000;o0000
0ooonfX00ol0003ooo]ZoookJP02o`0000Cooo]Z0_l000001?oonf[o0000o`000?oonfX4o`0000;o
oo]Z0_l000000ooonf[o0000o`000002oookJP06o`000?oonf[o0000oookJ_l0003ooo]Z0ol00000
0ooonf[o0000o`000008o`000003oookJ_l0003ooo]Z00?o00000OoonfX1o`00000000Go0000oook
J_l0003o0000oookJP04o`000005oookJ_l0003o0000o`000?oonfX02Ol00002oookJP;o00000ooo
nfX01?l0003ooo]ZoookJ_l00002oookJP;o00000_oonfX4o`000003oookJ_l0003ooo]Z00;ooo]Z
1Ol000000ooonf[o0000o`000003o`000003oookJ_l0003o000000;o00000_oonfX2o`000007oook
J_l0003ooo]Zo`000?oonf[o0000oookJP02o`000003oookJ_l0003o000000Go00000_oonfX00ol0
003ooo]Zo`000002oookJP03o`000?oonf[o000000;o000000?ooo]Zo`000?l000001?oonfX6o`00
0003oookJ_l0003o000000;o00000_oonfX3o`0000;ooo]Z0_l000000ooonf[o0000o`000007o`00
0003oookJ_l0003o000000;o00000ooonfX6o`000003oookJ_l0003o000000?o000000?ooo]Zo`00
0?l000003ol00002oookJPoo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`00000<o`00
09Oooo]Z5ol000000ooonf[o0000o`00000Do`000003oookJ_l0003o000000co000000Gooo]Zo`00
0?oonf[o0000oookJP03o`000003oookJ_l0003o000000?o00000_oonfX3o`0000;ooo]Z1_l00002
oookJP?o00000_oonfX5o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?oonfX02ol00000
1_oonf[o0000o`000?oonf[o0000oookJP?o000000?ooo]Zo`000?l000000ol000000ooonf[o0000
oookJP02o`000003oookJ_l0003ooo]Z00_o00001?oonfX3o`000003oookJ_l0003ooo]Z00Co0000
0ooonfX4o`000003oookJ_l0003ooo]Z00_o000000?ooo]Zo`000?oonfX01Ol00002oookJPco0000
0OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSkooo]Z0Ol000000003o`000?oonf[o
000000co000000Gooo]Zo`000?l0003o0000oookJP03o`0000;ooo]Z0_l00003oookJP04o`000?oo
nf[ooo]Zo`0000;ooo]Z0_l000000ooonf[o0000o`000002o`000003oookJ_l0003o000000?o0000
00?ooo]Zo`000?l000001?l00002oookJPGo000000?ooo]Zo`000?l000000_l000001Ooonf[o0000
o`000?l0003ooo]Z00Ko00000ooonfX00ol0003ooo]Zo`000003o`0000;ooo]Z0ol000000ooonf[o
0000o`00000=o`0000;ooo]Z0_l00002oookJP?o000000?ooo]Zo`000?l000000_oonfX6o`000003
oookJ_l0003o000000Ko000000Gooo]Zo`000?l0003o0000oookJP0>o`0000;ooo]Z9_l000000ooo
nf[o0000o`00000;o`0009[ooo]Z=Ol000000ooonf[o0000o`000005o`000003oookJ_l0003o0000
00;ooo]Z00?o0000oookJ_l000002_l000000ooonf[o0000o`000008o`0000;ooo]Z0_l00002oook
JPGo00000ooonfX8o`000004oookJ_l0003ooo]Zo`0000?ooo]Z0_l000001ooonf[o0000o`000?l0
003ooo]Zo`000?oonfX01?l000000ooonf[o0000o`000005o`0000Cooo]Z1?l000000ooonf[o0000
o`000002o`0000;ooo]Z2?l000001?oonf[o0000oookJ_l00004oookJP04o`000?oonf[o0000oook
JP;o00000_oonfX:o`000003oookJ_l0003o000000Wo000000?ooo]Zo`000?l000001Ol00001oook
JP7o000000000ol0003ooo]Zo`000008o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l0
00000_oonfX2o`0000?ooo]Z00Co0000oookJ_oonf[o00000_oonfX2o`000003oookJ_l0003o0000
00?o000000?ooo]Zo`000?l000000ol00008oookJP;o000000?ooo]Zo`000?l000000ol000001Ooo
nf[o0000o`000?l0003ooo]Z00?o000000Cooo]Zo`000?l0003ooo]Z0_l000000ooonf[o0000o`00
0003o`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?oonfX06ol00002oookJQ?o000000?o
oo]Zo`000?l000003?l00002oookJS7o0000X?oonfX?o`000003oookJ_l0003o000001ko000000?o
oo]Zo`000?l000001?l000000ooonf[o0000o`00000Fo`000003oookJ_l0003ooo]Z00co000000?o
oo]Zo`000?l000000_l000001Ooonf[o0000o`000?l0003ooo]Z00_o000000?ooo]Zo`000?l00000
3Ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000;ooo]Z00?o0000oookJ_l00000
1?l00002oookJPCo000000Cooo]Zo`000?l0003o00000_oonfX01?l0003ooo]Zo`000?l00002oook
JP03o`000?oonf[o000000Oo000000?ooo]Zo`000?l000006Ol00002oookJP7o000000000ol0003o
oo]Zo`00000Ao`000003oookJ_l0003o000000;ooo]Z0_l00003oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z0_l000000ooonf[o0000o`00001Fo`000003oookJ_l0003o000004_o0000YOoonfZJo`00
0003oookJ_l0003o000002oo00000OoonfX1o`00000000?o0000oookJ_oonfX0oooonf[ooookJSko
oo]Z0Ol000000003o`000?oonf[ooo]Z0?oooo]ZoooonfXnoookJP7o0000003oo`000?oo0000@_l0
00000001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.0256409, -0.0250052, \
0.00182832, 0.00295828}},
  ImageSoundCache->{{{0, 575}, {354.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000500200000000000000000l000Y<cm<
FVQhR9RY^LSFh^gfo?oooOO^hmG5/in;MV9??2`N4PT30003210K9cA3Df=cPi>Q
[kc8d]cTjo3enO_mooooooono_glo?_kno_knocloOgnooooooono?[fl^gWgmO=
`[JXVX]lK5a<?BlR5`d60@0010/D82loDFAhS:2ca=CRkOKlooomn?3Vflk0/J6A
PW9TETTm<RPP618=2@H30@0000000@420P<310@410@30`810@0000000@<520`@
5QdU;SU4DEi/NhZJZKS7e>3[m?[nookjm>[OdL6_WHUfHe0o;b4E30D100452a<N
:SM5E6=bPY2N[;S4c]OPingbm_WkoOkoooooooknoOclo?_knocloOgno_oooooo
o_gknOKbkNOPf<o5^ZfPTXAeIUM8>RdQ5Pd70P000`P@6bLfAUMZOI2R]<GDhNcd
nokoo_[dk>;Gb[f^Wi62LfEHC40f;2@L5Q0<20D30@00000000410P830`<30`<3
0P810@00000000831@P<41HL8b`e?dYGI75oSYb[^LODgnWbn?goooghl>OKcKj]
W8YgIE=3<bDI40P300021P`D7RTf@e5OKGb:UjBa_<K@f>3Wk?7en?_mo_oooooo
ooknoOgmo?clo?cmoOknooooooooookln_Odl>_Ug]O>aKZ_XiJ9NfeND4<f:QlE
3@H200021PdF8BhlC5e^P9:S]<CBgnWbnOgoooghl^[Pe/Zm[j:DQWQ[GU97?3<Z
8a`F4@d91P@20@00000000010@820P820P820P4100000000004210L:3A8G7B@[
=3e8Dem[N8FCXJjkb=COj?7go?ooo__ekNCHbkf]WHajJEQ8>B`P5@d60P000PD;
4Q/U<Ce9EfAaOhbHY;2ja<gEgN?Yk_;fn?_lo_ooooooooono_kmoOgmoOgmo_kn
ooooooooookno?[hmO;^jN?MeLg4^k2UVHf0LfIIC3lc:1hE3@L3000110T@6B@`
?TeLKGf>WZjmbmSSk?CjoOoooOWdkNGKd<Fi[9nBQGU/HEE;@CP_:24K5A4=2@L5
0`810000000000410@420P820P410@00000000000@831@L:3A4F6b8X<3Q1BeIQ
K7R5TIjZ]l?>fN;[l_Slooooo?Oaj=oCakVZVh]kJea=?S4U6a8;1@8000452Q0H
8B/e@DeIIG9nRYJQZkJob=3Gg^CYkO7emo[koOkoooooooooooono_kno_kno_kn
o_ooooooooooo_glnoSflno[in7Ke<g5_;:XWY>7NfmSEd]0=BXQ614:1@800044
2@lG8B`hAE=QL82?WZfkb=CNj?3fnokooogjmNoXgmK<`KJZWi>7Ng1UFU17?SH^
9b4L5a8>2`P610<20@000000000000410@410@410@400000000000010@<41PP;
3Q4E6R0U;3<k@daFH6]fPHbHXjnjaLoHhNW`m_[mooonnoOaj^7Gc<2cYIN8NV]M
Cd8f:R0G40T50@000@@83A<K8b`f@D]FHVehPhjIXjbe_/K=e=[PiN[^lOCgnO_l
oOkoooooooooooooookno_kno_koooooooooooooookmo?_imoGbkn_Wh]gGdL[2
^[:YWiF;P7I[H5E:@3H/8a/D3PP40@000@<731<K92hiAE9OK7Z8UZ>`_LWCgNK]
m?WloooooO[flN_Sfm?9`;F[X9J;PGI/HUU@B40h<B/U81/F4Pl<2PL510<20@00
00000000000000000000000000000000000000420`@620X<3a<F6alU:S4g?dI?
Ef1YLgf7TYbV/;[4cMKNi^cbmo_moooooOWeknSPelg3]j^OTXEhJeiBASX`9QdF
3`X50P00008420dC6B0X<CY3CEMQJgEoR9:KY:bd_<?:d=KKh>GYk?3bmOOin_cm
o_koooooooooooooooooooooooooooooooooooooooono_glnoWgmO?`kN[Vh]gH
dlg7`;VaZJ6HShIlLfUPETa3>S8Y8Q/D3`X60`4000431P/@5QhV;cU3CUYVLWj:
Uj:^^LC>emoWkO?hnokoooomnoOck^SQf];:`KV_YYfDRX5hKfMNETi7@3Xd;RPS
7a/G514>2`T71P@30P8100000000000000000000000000000000000000000041
0P<41@H82P`>4A@H6alT:Bhd>D16CUEMIFeeOXN?V:6Z/kc4c=CKh^S^l_OjoOoo
ookmn_Kak>KNe/k5^k6VVi24NFiSF4e3>C0X81TC3@T50P4000021@P<4AHL8RTa
>418DEURJg=lQ8bDW:B[/[VoaL_@eM[Nh^KYk>oaloGgnO[ko?gno_kooooooooo
ooooooooooooooooooooooooooooooooo_kmoOckn_SgmO?akncYi^?OfmKAc<O1
^kF_Z:6ITXZ2NW9ZHUYBBT8j<b`U7aTD3`/7108000000P@72a0E6b8Y<CU2BeEO
JG=nR9:MYk2j`l_Cfn7XkO;fnOcnooooo_cjmo?_j^GOfM?<aKff[ZJOUhn7P7Qa
JF9LEDm9@cdh<bhZ9B8N6aLE4Q0=30X81`H510<20P4100000000000000000000
0000000000000000000000000@420P<41@H720X<3Q0B5ALJ7B4U:Bda=S]0AD]A
EeiTJg9iP8N>UYfTZk>j`LO>e=[PiN[^l_Kinogoooooo_cjmo?_j^GOf=;:`k^b
ZZ6HSXElLfUPF4m6?SL_:28L5a8=2PH40P0000010P@72PdA5Q/P9B/a=ce4Be5H
GfI]M7^2R8nEVj6W[K>h_L;7bloCem_NhNCWjNc^l?;cmOKhnO[knocmoOkno_oo
ooooooooooooooooooooooooooooooooooooooooooono_kmoOclno[in?Ofm??a
kng[jNKShMkJem?@c<O3_kZe/:ZUWiZDSXR2NgE_J69LEDm9@cdg<B`V8AdH510=
2PL50`4000000@841PT<41@H7B8X;S@k@TUAF61XL7R0R92HX:N_][g4bm7Gg>;V
jnobm_SkoOkoooooo_gln_OelNkZi^;NfMC?b/Bo^K>]Z::LUY2:Q7iiLfiXHeiI
E4m:AT8m>CHb;R/X9B8O7AXH5Q@B40l=30X920L61@D40`<20P810@4000000000
00000000000000000000000000000000000000010@410P820`<41@D61`P92P/=
3PlA4aDF6A/M7b8U9bX]<C@g>cm3Ad]?DeQLHFIZKgAiOhB9SYBIWZ>Y[[>h_L;7
c=3EfMgQiNW/ko;emoWko?koooooookno?_im_Cak^[WhmkJeM3;aL2j]:jXXI^E
SXR1NWA]If1JE4i8@Sdg<RdX8alK5a@@3@/81P@30P40000000420`D72@/=41<F
6AdP92P/<3@h?D56BTmDF5eRIf]`MGUnPhN<T9BIWJ6UZJf`];Rk_/;5b<_>d=?E
f=[Mgn7SiNKXj^_]k^oal_?dmOKfmoSinO[jno_lo?gmoOgno_kno_oooooooooo
ooooooooooooooooooooooooooooooooooooooooo_kno_knoOgmoOclo?_kn_[i
nOSgmoKem??blO3_k^g[j^SWiNCRh=kLf]SFe=;?cL[8aL;0_KZg];2]ZZNSX9bI
UI6>RXJ2Og]gLfm[If=OFeQDD4a8A44m>SHc;b`Y9B8O7AXG5A8@3P`:20L510<2
0@00000000010@8310H72@/=3a4D5aTL7b8V:Bd`=3Pl@4A9CE5FFUmSJ6eaMW]o
Q8V=TYJKX:BX[K6e^Kg1aLW=d=CGf]gPhnKYjng`l_?emoSjnocmo_kooooooooo
ookmo?_jnOSgmO?bl>k/j^SVhn7Ng=WGe=7>c<W6`l2m^[Nd/:fZYjBQWY^GU96>
RhR5PWmlNGIcL6eZJ6ERH5eJF5ECD4i<BDM5@d4n?3Xi=cDc<Bl^;2XY9bHT8b8P
7ahM6aXI61LF5A@C4Q8A40l?3Pd=30/;2PX92@P81`L71PH51@D510@410<30`<3
0P820P820P410@410@410@410@40000000000000000000000000000000000000
00000000000000410@410@410@410@410P820P820P830`<30`@410@41@D51@H6
1PL71`L820T92@X:2`/<30`=3Ph?3a0@4A8B4a<D5AHF5aPI6AXK71dN7alP8B8S
92DV9bPZ:b`];Rl`<S<d=CLh>CXl?Ci0@D=4ATM8BT]=CU1ADeEFF5UKGEiPHF=U
IVQZK6e_LG9dMWQiNgeoP8:4QXN9Rhf>T9:DUINIVibNX:6SYJNXZZb][k6b];Jg
^KZl_[o1`/C5alS:blg>cm7BdmGFemWJfmcNgn3Qh^?Ti^OXjN[[k>c]k^o`lO;b
loCemOKgmoShnOWjn__ko?cloOgmo_kno_ooooooooooooooooooooooooono_kn
o_gmoOclo?_kn_[inOShmoOfm_Gem??cl_;al>o_k^g]k>_Zj^WXinKViNCSh^7P
gmoNgMcKf]WHemKEe=?Bd]7@clk=c<_:bLS7a/G4`l;1`;nn_Kbk^[Vh]kJe];>b
/K2_[Zf/ZjZYZ:NVYJBSXZ6PWijMW9^JVIRHUiJEU9>BTI2?Shj=S8^:RHV8QhJ5
QHB3PX61P7mnOWelNg]jNGQhMgIfMGAdLg9bLG1`Kfi^KFe/Jf]ZJVUYJ6MWIVIU
IFATHf=RHV5QH61OGemNGUeMG5aLFe]KFUYIFEUHF5QGEeMFEUIFEEEEE5ADE5=C
De=BDU9BDU5ADE5ADE1@D51@D51?Cdm?Cdm?Cdm?CTi>CTi>CTi>CTi>CTi>CTi>
CTi>CTi>CTi>Cdm?Cdm?Cdm?Ce1@D51@D51ADE5ADE9BDU9BDe=CDe=DE5AEEEEE
EUIFEeMGEeQHF5UIFUYJFe]KG5aMGEeNGUmOH61PHF5RHV=SI6AUIFIVIfQXJFUZ
JV]/K6e]KVm_L71aLW9cM7AeMWIgN7UiNW]kO7enOWn0PH62PhB5QHJ7R8V:RX^<
SHj?T92ATY>DUIJGV9VIVY^LWIjOX:6RXjBUYZNXZJZ[[:f^[k2a/[>d]KJg^;Vj
^kbm_[o0`L;3a<G6alS9b/_<cLk?d=7Ad]?DeMKGf=WJfmcMg]oOh>7RhnCUiNKW
j>WYj^_/kNg^kno`lO7blo?dmOGfm_Ogn?SinO[jno_ko?cmoOgmo_kno_oooooo
ooooooooooooooooooooo_kno_gmoOclo?_kn_[inOSgmoKfmOCdlo;al?3_k^g/
jn[Yj>OViNCSh^7PgmgLfm[IemKEdm;Aclk<bl[8alG4`/6o_[bk^KNf];>a[jj/
ZZVWYJBRX9nMViZHUYFCTHn>S8Z9QhF3PX1nOG]iMgIdLW5_KFaZJ6MUI69PGeeL
FUUGEUACDE1>CD]:B4M6A4=2@3ln?3/j>CLf=C@c<S0_;Rd/:bXY:2LV9B@S8R4Q
81lN7A`L6aXI6APG5aHE5A@D4a8B4A4@40l?3Ph=3@d<30/;2`X:2PT92@T820P8
1`L71`H61PH61@D51@D51@@410@410@410@410<30`<30`<30`<30`<30`<30`<3
0`<30`@410@410@410@41@D51@D51@H61PH71`L720P820T92@X:2`/;30`=3@h>
3a0@4A8B4a@E5AHG61TJ6a`M7QlP8B8S9BHW:BX/;Bl`<S<e=cTj?3i0@TA6B4Y<
Ce5CEEQJGEmRI6MYK6maM7MjOH22QHR;SY6DUiZMX:>VZJb_/[Fh^kk1a<O:cLoB
eMOJg=oQi>KXj^c^l?;cmOOhnO[ko?gno_ooooooooono_glno[imoKdl_3^k>[W
iN;Og=WEd/o;alC0_;Rd[j^WXijJUI6<Qh=nNGE`K6MRGUUEDDa8A40l>3@`;BTV
8QlL6ALD4Pl=2`T71PD30P410000000000420`@51PP92`d?4A<F61/N82<V:B``
<cHj?D54B4a?DeMJGV9VJFeaMGQlP8>7RXjAUIRLWj:UZ:^^/KBg^[bo`/C6bL_=
cm7CeMOIfmcNh>7Si>GWj>WZjnc]k^o`lO7blo?dm?Gem_KgmoOhn?SinOWinO[j
n_[jn_[jn_[jn_[jn_[jn_[inOWin?Shn?Ogm_KemOCdlo?blO3_knk]k>[Yj>OU
i>;QgmgKf]SEdm7?c<[7a<:o_;Vf/Zn/Z:FQWIVETHf9QH5lN7A_JfIRGEUDD4a7
@chj=S8^:RHR7a/H5A8?3@X81PD30P40000000410`@620X=41<F6QhR9R/`=CY0
AD]AEeeSJW1gOHB:T9NMY:Z`][c1alcAe]_OhnO[k_7dmoWko?knooooooonoO_j
n?Gcl>gZin?Og=SCcl_6`Kfh/jjYY9nJUI2;QX5mN7=_JVIQGEUEDDe9AT8o?3Tf
<c0]:bPV928P7Q`J6ALF51<B4A0?3Pd<30/:2PT920P81`L71`H61PH61PH61PH6
1`L71`P820T92PX;30d=3Pl@4A<D5ALH6Q`N828T9RT[;S4d=cXn@DE9CE5FFUiS
J6ebMgb1QhbBUifRZ:fc^;k3b<gBemcPi>S/ko?en?[loOkoooooo_gkn?Kckn_W
h]gHd/c6_kRaZZ:KTh^3Ng=[I5aDCDHo>38/9R0K5a8?2`P60`810000004310L9
30lC5a/P92T^=3ToA4Y@EUaRJ6idNGn5RY2EVj2UZJjc]k^o`lO:cM7De]WLg^3R
i>KXj^_]k^o`lO;cm?CemOKfmoOgmoShn?Shn?SgmoOgm_KemOCdlo;al>o^kN_Z
j>KTh^3NfmSEd/o<b<C0_;Rc[jZUWiZDShV3OGI`JV=MEU1:@cdg<B`V8A`G4`l<
20H30P0000010P@72PhB5a`R:2lf?TI>EemXLGZ3S9FNYk2h`<S?e]cRj>gamOSk
oOkoooonoO_im_;^j^KQfmK@b/>m][2YXYbESXN1NWA^J69LEe9=B4<o>SHc;b`X
9B<P7Q/I5aHD4Q4@3`h=30/;2PX92@T820P820P92@T:2P/;30d>3a0A4Q@E5aTK
7R0S9RT/<3<g>d15BTmDFV1VK79iP8N>UIbSZ[6i_lK=dmWOiN[^l_Kio?kooooo
oO_hmO3[i]oIdLW1^:nUW9:7OG=YGeE<@cXb:R<L5Q4<20D30@0000431@P<41DJ
7bD/<SU0AdmFGVE]M7^2RI2GWJBY[kFj_lC8c=3Dem[Mh>?UinW[k>k_l?7bloCd
mOGem_Kfm_KemOGdm??cl_7`k^g/j^SVi>7Og=SEdLg9aL2k]K2ZY9fGT8V1NW9Z
He]CBd<l=BhW81XE40`81@8100000P@8314F7B@/=Ci8DUaWLWf8TijY/kg6cmOO
i^cam_[lo_oooogkn?C`jnGOfM;:`k^cZj>KTh^3NgA/IEiHDTa6@C`g<RhZ9b<P
7Q/I5aDC4Q0?3Pd<30/;2`X:2PX;2`/<30d>3a0A4a@F61/M82<V:Rhb=ca1AdaC
FF1WKgInQXjGWjR`^<38d=ONiN_`mOSlo_oooogkmo?^in3HclJk/JFJSX9fJUmC
B3hd:b8K50h91@8000010`H93Q<I82L^=Si7CeQPJG9jPX^BVZ6X[kFk`LK;cm?G
fmkQi>KXj^c]ko3al_;cloCdm?Cdlo?bl_7`kng/j^SVi>7Nf]OCcl[5_kZc[JJO
Uhn7OgI]I5]BBD4h<2PQ6Q<>2@D200000@<72a4H82Pb?4MCGfahQI:NZkK1c=KO
ingcn?cnooono?WflN_Ug]K>aKfdZZ6HShImM6aTGEE>B48l=c8]:BDR7a`I5aDC
4Q4?3Ph=3@`<30`<3@d>3a0A4Q@F61XM82<W:c0d>Sm5C5=JHVYbNhB=Uj2Z/kc6
c]OOi^cbmo_moooooO[eknSPelg2]ZZMT89eIeY=@CH[8QTB30L30@000@@7314H
7bL_>49;EEiXLW^4SIJNYZfd^l77c=7EfMgPhnKXj^c]k^o`lO;bl_;bl_7al>o^
k>[Xi^CQg][Fd/g8`[be[ZJNUXf4Ng5WGE=9@3H]91dE3`X50P0000862a4H8B/f
@TmLJWR6U::__<SCgNK^m?WmoooooO[el>WRf]78_[BZX9J<PWQ_IUiFCTM0>SD`
:bLS7a`J5aDD4Q4@3`h>3Ph>3Pl?414C51HH6ahQ9BT]<SPnA4]CFf=/MGn9TijX
/kg7d=WRjO3fn_goookln?;[h]W=`KBVV8UkK5e?@SDZ81L?2@@1000110P>51`T
;CM1BeIPJgF0RY>LYJfd_<;8c]?GfmoRiNOYjnc^kno`l?3`l?3_k^g[j^SUh]oL
f=?>bL>l]JjUWI>:P7E[H5E:@3D/8QXB30L300000PH<4a`V<Si<FfYiRIRW]L??
fnG]m?[mooonnoOaj^?Jd<Jl/JJKT8EkLFMNEDe6?cPc;BTU8AhK61HD4a8A410?
3a0@4A8C5AHI6ahQ9BX^=3Y0AdmGH6YdOXVDWjZe`<_EgnO_mO[mooonnoG_i]c@
`kFVUhMfIeM8>RdR60l9104000862a8J8b`g@TeHI6mjQHnIXZ^c^l;8c]?Hg=oS
iNSZjnc]k^o_knk^kNc[jNOThMkJe]7<a[nh/:NNU8YoM6QMDDHj<2DL50d70`00
0@@93aPR;Sa:FVYkRib/^lWFhN_cnOgoookjmNoWg]C:_[>WVi24NFiTFe9:@S/e
;bXV8QhK6ALE518B4A4A4A8C51HH6QdP92P]<SPoATiGHF]eP8bHY;2lam;Li^ke
n_kooogiln[Pe<NhZ9N6MFACA3DX71<;1@40008631<L9S0lB5APK7R3SYVS[;Bl
`l[@eMWMhNCVj>[[k>g]kNg/k>[YinCRg][FdL_5_[J]Y9Z@QGU]HEA8?34V71<<
1P8000863ADP;3Y:FV]mSj2a`LoLio7ho?ooo_[ekNGKd<Fi[:2CQg]`IE]BBD4j
=2hY924M6aPF5A@C4a<C4a@E5aTL7b8V:c0f?DE=EV1[MX:>VZNd`<cGh^_cnOgo
oogil^WNdL:bX8ilJUQ7>2TM4`X40@0010T@628]>DEBGV]hQ8nJYJjg_lK<d]OK
gn;UinWZjnc/k>_ZjNOUhn3Lf=?=akng[jFKT8AhJeiAA3P/8AL?20<0004631DQ
;Se>H7:5V:ZkbmWUkoOlooomnO?[h]O;_k:UV8]nLVMLDTU1>S<]:2@P7AXH5aDE
51@D5AHH6Q`O8bL/<CPoAe1JI71lR9FS/;g:e^7ZloWmooolmnoTelVhYYB0KEY9
>2TL4@T300011P`D7RTe@TmMJWN4T9^V/;W1b<kDfMgPhnGWjN[Zj^[Yj>OUh]oK
em7<aKfeZj6FRWe`HeE8>bhR60l80`000PL?6BHeAUQ[Oi>V^<WHiNogoOooo?O`
imgAa;NYW8j1M6QMDdU1>C<]:2<P7AXH5aHF5QHG61XL7b8V:c4g?dM@FVEaOX^H
Y[C2cm_VkoOlooomn?3Uf<RgY91lJ5E2<B<F30D100452a<M:CE3DEm]NXNDWjZd
_<C;dMKKgn;Ti^OXjNWXinKThMkJe]3:`k^bZ9fAQGMZG4do<RDJ40T30002210K
:CU;Gg>7W;32d^7]m_coooghl>OLcl:dYIN9O6mSF4i5?3D_:RDQ7Q/J61LG5aPI
6QdO8bL/<SU0BE=NJGJ3TIn^_<[GhngenooooOS_i=K5/in:MF1<>RTK40L20004
2Q8M:CI4DV5_OHZGXjfg`<O>e=WMh>?Ui^OWinOUi>7NfmKAblBk/ZRMT8=eIeQ:
>bhQ5Pd60@011PdH9SI9GG:7WK74eN?_n?gooo_djn7DakRZVhanLFAICTDl=BlY
9B4N71XI61PI6Q`N8BDY;SDlA4iHI71nS9^Z^<OEhNcenooooOO]hM;0[IR2K5M3
<24D2P<000<94A`X=TACHW60SIZV/;[2b]3Ff]kQhnGVi^KUi>;Og=SCcLJn]JZO
ThEgJ5U:>bdP5@/40002214N;CmCJGnEZkoAhNggoOoonoCZgm;4]JJFQgU/GeA:
@CTb;2LS81dK6QXJ6Q`N82@X;C<j@TaFHVmmRiZZ^LSFhnkfo?oono?Yf/VfXHYd
GDPe91H;10000`TB7BXhB5MWMXBBWjZe_/K=dmSLgn7Si>GTi>;PgMWEclS0^:fR
UXQjJU];?2dP50/400032Q@R<dMLLhZQ]/[Kj_CloookmN_Pd/BdYIF6MfYMDTLn
=c0Z9R8O7A`K6a`M7b8U:Rlf?TI@G6QfQIBT]<?Bgn_enooonoCYf/RdWXM_F4<_
7a480P011PhH9C=3DV9bPHnMZK>maLcBem_NhN;Shn?QgmgIe<o8`;N]XIB6MfQH
B3PY71480P011PlL;3mEK8BK//OIj?Ckoookm>[Nd<6aXI61LfEICD@k=2hY924O
7AdL7AhQ92L/<SU2BeIRL7j>WZjnc]cYlo_ooocdjM[7/Yb4Je@n:a/>1@000`TC
7bdlC5e]OHbIY[6ka<_Ae][Mh>7Rh^7OgM[Ed<[2^JnSUXQiJEQ8>2TK40L10088
4R4bAeifSjJmdN;_nOkooOK]hM?3/j:BPW=UF4e3>c<]:2@R7ahN7QlQ92P/<SU2
C5MSLH2@X;72dN3/m_coo_W_h]6lYHedG4D`7Q070@022A8O;Ce=GVmoSYbX/kg6
cM;GfmkOh>7Pg]cIeLo9`KR]XI>5MFAD@c8S5P`400043AX[?eI_R:6hcN3^n?ko
oOK/h=71/J2?Og1REDY1>34/9b@Q81lO828U:Bdc>d==FFIdQ9BU]/OGiO7io_ol
m>SHa:fENf9:=24B1`400PTB7bhnCf1aPI2NZkJoalkDf=_MgmoOg]_He<o8`;J/
Wi62LV5@?RhO4PP200484b8fC6AnV;77fn_foOommnkQd/:aWhinKf5DBClg<B/W
928Q824S9BT]<cY3CEUVMHBEY[S9fNObnooon_7SdKbSRVmF?RTH2`<00@H?6bXj
C5e^OhnMZ[FoalkCem_Mg]kMg=WEd<[2^JnRUHIeI591<24C2@800PPD93Q?JH>M
]/gPkoWooo_cj=[:^JNFQ7AVF4e3>S<]:BDS8R8R92L[<3HnAe9NK7b=W[32d^;^
n?koo?CWeL2WSG9H@2XI2`<00@L@7BdmCf5cPi>Q[KS1bLoDf=_LgMcKf=G@b/:i
[Z6CQ7=QCch]7A070@0331X/@U]eT:_3f>WfoOomm^_Nc[f[VHMgIeY>@c/d;RTV
92<S92HY;S<k@diJIgN7VJ^mc]k/mogooOGXe/2WSG5F?RPG2P800PTD8S93EFQi
RYVV/[c5c=;FfM_Kfm[Ge<o9`KN/Wi61L5i;>BPI3@@000HA8CI>J8BO^M3Sl__o
o_S^hM70[Y^9NFUKCd@k=2hZ9bDT92HX;34h@4UEHW61TjFgbM[Ym?coo_KZf<:Y
SW9F?BLF2@800`XF9CI8FVenSYfZ]/37c]?FfM[JfMOCclW1]jbOT81_G4Xg9QL;
0`0121DV?EIbSZW3fN[go_ollnOHakFRSgi^Ge97?SH`;2PV9BHW:Rhc>T==FFMg
R9Z]`=7RkoWooo[_gl^bUgYNA2`I2`800PTE8cA7FVanSij[]/38c]?Ff=WIemC@
blBk/:BEQWARCc`Z6Pd400474bDkEG6>Z/CJk?Snoo_biMG3/9f;NFUKCd@k=2l[
:2LW:2X^<cY2C5QVMXNI[L3Bh_3joooikMc6[I1cEcdV50L100@>6b/mD6=fQiNU
/Kc4bm3DemSHe]??b/:i[j:CPg5NBcPV5`X2008;6Be5HGjK]loTlocooOKZflVf
Xi1nKEiAASdf<2`Y:2PY;30e?4E@GF]lSZ6damWXmOgooOCUd;RLOV55;AT:0P03
2aPX>TePLhFEY;2ka<[@dmKGe]CAcLJn]JVKRgYWE40^7@l5004752HnFGJD/L_P
lO_oo_O[g<ZgXi1nKEiAASdf<2dZ:BT[;S<i@D]GIGF6VJg0dnCanoonm^WE_J63
IDP_6P/200<;62PkCV9eQiNU/[c4bm3CeMGDd/k9`KR]X960KEY6<b4B1`401Q4S
>eIcTZo:h?7koogfj][8]:6=NfYLCd@l=C0]:bX[;S4g?TQCH721U:Rlcn3_nOoo
n>_G_j>5ITT_6P/200<<6RXmDFEhRYZX];k6c=3Ce=CBcl[4^k6TUHEbGd/g9AD9
0@04424hE7:A[l[PlOcooOGXf<FaWHYhIeU=@cXd<2d[;2da=Ca5Cea[O8jR]/[L
k?SnooW]f/:VQfQ:<1X;0P043A//?eAXNhfLZ[Joalc@d]?Bd<c6_[FYVh]iIE4m
:QT;0`033AhdCfj=[<SOl?_ooOGXelB`W8QfIUQ<@SXd<2d];C0c>D5;EVAeQiZ_
`mKWm?goo?7Ob:b=KTld7@`300<<6R/oDfQkSIfZ][o7c=3Ad]7>bL:j[j:CPVmK
AS8P4@H00@PG;4ITQ:?0fNgiookgj][7/ij:N6MICD8k=C4^;Rla=Sa4Ce]ZNhjR
]l_NkOWoo_OYe;VKNe`n9A8500495BHiCV=fRIVX];g5blk@dLo<al6h[In@OVYF
@BdK3@<00`dN=E9aTK7<hoCmoo_ah]2kYi9oKEiAAShg<c0_<38f?4E?G6]lSjBi
cN3_n_onmNG?/iAcDcLO3@<00`dK;D9FJgn@X:fh`LO<cm3?c<S2^JjQTX1]F4<_
70h4008=7SICLi>ccnGeo_ojk]o<]j:>NfUKCT@l=S8`<38e>T9;EfIfRIfbam_[
n?oomnWC^9UhF3XQ3`<00``K;D5FJgnAX:jh`LO;c/k=b/Fn]JVKRWQTCSTV5@P1
00LF:dIVQjO5g_7loocbhm6lYi9oKEe@AShh=34a<cHl@deJJGZ=X[O<gnojoogd
hl^^SFa<;aT90@064b<gC65fRIVX];g4bLc=cL[5_[FZW8aiIDlj9QD80@075Re8
J8Z[bN7coOokkn3<]j:=NVUJCD@l=c@b<cDj@DYEHg>6V[35fN_gooogim6dU79A
=1`;0@064B8fBf1eR9VW/kg4bL_<blS3^k:UUhEbGDLb7`l4008=83UHNI^kencj
oogei]BoZIB0KUiAAcli=C<d=SY1BUESM8NK/LOKk?Soo_GUcJn>Jd/^5`P00@PF
:3aBIgb>WZbg_lG9bl_9a;jeZI^;N6==>2<B1P012a`eDgBG^=CZnOonmNOD`:ZD
P6iNDDLo>CHd=CPmA4iJJG^>Y;[?h_;loo_^f[nOO5Xk8@d200@@83A:H7F8VJNc
_<?7b/[8a;feZI^;Mf===b<B1@0231hhEgVL_MW^nooll^??^ZB>NfUJCT@m>CHf
=c]1BUESM8NL//SLkO[ooO?PaZN4HD4U40@00`hN<TMNLhJHY[:k`/K9bLK2^k:V
UhIbGDLa7@d300@A9d=TQj[9h_CnooS[f/F_VHAaHEA9@C/h=cPk@DUDHG64VJo5
f^ciookdhLNXQF519A0300@?7cA:H7F9VZRc_<;6b<O4_kN]X91nJE<m9aD7004:
73EEN9^mfNkkoocah<bfWhYgIUM<@cdi>3Tl@DUDHG:4VK36fngioogbglBSP5`l
80d200HB93U?IGZ=WZ^f_/?6alG1^k:VUhIbG4D_70`200HE;4Y]TKCBj_WooO?T
d;ZSSWYXFTi5?SXi>Se2BeISM8NM/l[Nko_oo>oI_9]fDc<J2@012AP[@EM]PYBS
[kW0a<K5`[feZYb;N6=<=R4@10044BI3IXZ]cNKgookei]:lYY1kJU]?ASlk>S/n
A4eHIgR<X[S?ho?mooWYdK:?JTLY4`D00`hO=4YQMhZKZKBl`LC4`[jg[J2@OFQB
>bHC1P023B8nH8BYbNCfo_kfimBnYi5lJU]?AT0l>ca0AU1LJgfAZ;kEj?Ooo_GR
ajJ2GC/P30401aDX?UE[P9:R[[Rn`/C2_kV_XiB2KUM0:QL8004;7SUJOjC6hOCn
ooOXeKnXTGe[G517@Cdl?T99DUm_PYN]a=[]n_oll=ZmVWE@<1L7008<7C58GgF9
VZRc^l32`[nj/ZNIQg=MAS0K2`4021TcE7VN`MkboOohj]O1ZI=nK5eAB44n?Cm3
BeERLhJK//[Ol?con^_C/hmYABL@0`054R@jDFQmT:2/][g0`L2l]J^NSGYUCCHQ
3`<01A@/C72F^]S_o?ojkM[4[IJ1KUmBBD8o?T15C5MTMHVO]/gRlogon>O<ZhIP
?B0<0@085b]1FFn4UZB`^;g0`;fh[j>DPViG@2TE1`023B=1I8Z_d>WioocaglVb
VhEbHUE;A40o@DE=EfEeRIngc^?doOogiLVWPE/i7@X00@XJ;dIMM8RIYk6i_[nn
^[BZWHaiHd`d7`h200LH<U=iWl?Pm?knm^KB^j>=NFMICTM2@455C5ISM8NM]<cQ
l_gomnK:Z89L>Ad9004;6c17GgF9VZRb^Kfn_KRaYYR7LUa4;AT9004<83iRRJo@
jO[oo>oMak2HPg1PE4]5@T94BU=OKh6G[/KLko_on^[A/8YS?b4<0@096Be5G7>7
V:Ja^;bm_;N_Y9J4KeU1:QH7008?9TEZTKOGk_conN_G`:VBOF]LDDU4@T=8CeUW
N8fS^m?Wmoonl]bmVG5;:a8400DC9SeEK86CXZjf^[bk]k2UUhEaFT8[5PL00PlU
AFZB]mS_o?ohj]JnYi1kJE]@BDA3ADYBGFaoU:_3f^gjoo_[dK29HSdO2`412a/a
B61gRY^X/KRk^kRbZ9^;Mf59<A`;0@0:7ceQRK3Bjo_on^gI`ZZCOVaMDTY6A4I;
Dem^P9J]aMc_nooij<fZPe`h6`P00PdO=TiUNhjNZ[>h^[Ve[Z>DPfiF?RLC1@04
4be?MYk3hOGoo_?Rc;BLQW=SETe8ADI:DEa[O96Y`MS/n_okjm6_R60k7@T00P`N
=4aTNXjMZK:g^KRd[:2BOfYB>R<@0`0663AHP:O;ioWoo>oLaJfEP6eODda7ATQ>
Ef=cQifecN?do_kcg[jHL4TX408021L/A5acQiRU[kFh^;B]XYB2KEDm9Q8400DF
<UEmYL[Vn?olkmc5[IF0KEmDC4Q7BU1IIgN<X[_Cj?SooNoF]HeT?b0:004<7SA<
I7^>WJVa][Ne/:NJRWIPB2lJ2@023RE6KIJmgO?no_CScKBLQW=SEdm:B4Y?F6Ee
RJ2hd>Kfoog`f;N?IT0P2`0131hdCFEkSYfY/KFf]:jTUhIbFd8Z5@H011<]D7VR
anGhooc_g<F/U7m]GeA=BTY=E5m]P9F]aMg`o?oghlFPMdh[4P<01aL/A5edR9RU
[[>e]:nVVHUeGTH]60P00a4ZCGFOaN?gooc`gLF]UH1]GeE>BT]?EV5`PiVab^7c
o_odg[jGKDDT3@412a`cBfAjSIbX/;Bd/JZPTX1ZDSXR3`<021dlHXbdeo3mooKU
ckNNR7ATFE1<BdiEGfeoU:c5g?3looORa9ecBbP?0P096S19HGR;VjN^/k>`ZIn@
OVQ@=b0=0P0:845XT[[Kloknm>;;/YZ4LF9GD4a=DEQTLhNM]/kUm_oml=JdRf4j
6`P00a0T?5E]PY>QZk2b/J^RUHA_F3lW4P@01QTgGHN`e>kmooOVd;NOR7EUFE9>
CE5HI7>6W;G>i?KooO3F/hYO>AX700@B9SiGKX>DXZ^`/JnYWi5oJU4h8@h200XQ
@FVD_=gdoogbglN^UX5_H5I@CU1EGV]mTZ[3fnolooOR`i]aB2D=0@4;7SE>IWb?
WJR^/:nZXIB3KUHm9A4300PM?6B?^=[bo_kchLV`V89`HUMACe5FGfeoU:c5gO3m
ooGO_YEZ@R4:008>8SYCJh2BWjV^[jfWW8ikIDdd7@/10@lXC7FPanKioo[/e[jU
SWUYGEEAD5ALJ7R<XkcEj_Won^S:XgQ>:Q0200XL<daTNhfLYZb_[JNMT7eXCcHO
30413BI9Lik6iOSonncG_ZF>NVUMEE5AEUiZNhnW`=S]nooghl>KKdHS30023B4i
DVZ0TIjX[JfZXiR8MEi5;1H600DG=Eb7/MK`oOkdh/^bVH=aHeUCDUAKIWF8WkSA
ioSonn[=YgaA;14200XL<daUNhfKYJ^]ZZBIRWIPAbhG1`045S=JQK3Ekognm>;;
/IV3LF=IE5=FGFQhS:>leN_jooWUaYibB2D<0@8=8CUBJh2AWZN[ZjNOTh9]EC`T
3`802R54KY[3hoSonncG_ZF=NFUNEeAEFVAbQI^ccNCfooc]dJ]oE2hB0P096c=<
IG^=VjBZZjRPU8A`F3lV4@<02Am1JiO1h_OonngG_ZF>NVYNEeEFG6IeQijgd>Oh
oo_Ybj=gC2P>0@4<83QAJWn@WJFYZJFLSgeWCcDM2`0242aAOJW@k?com^C</iZ4
LVAKEUIJHVioUJg6go;no_7G/hMK<aD400PI<4URNH^IXjRYYIfAP6]C>B4=0@4=
9dagY<cZnoogi/neW8IdIUaGEeYSKh6F[/SPloknl=F_PeL`4`<02A`cCFEkSIZS
Z:NSVXajID`b6`T00a@aFHJaeo7no_;NaZbDOfiRFeMIGVUhRj:ke>_jooSS`YQ[
@1h800@C:D9KLXJEX:JWY9fAP6]C>B4=0@4>:DikYlo/o?oehl^bVH=bIEaIFEiX
MhZP^]?Zn_oii<>IK44O20044bU2Fg>6UInUYZ>KSWeWCcDM2P024RmFPk3FlOkn
l]k6[9AoKf=LFE]RKGfAZL?Ll?gol]VcQeXb50<02A`cCFIkSIZRYJBNU8EaFT0W
4@<02R95LIo8j?_on>K?]Ib6M6MNFU]PJWV=Y;gGk?_om]nkT68h60D01aP`BF9h
RYRPY:>NU8EaFT4W4P<02R96LZ39j?_omnG>]9^5M6MOFeaRKGfAZ<;Kl?gol]Rc
QUP`4`802QhfD6QmSYZQY:6JSWiYD3LN2`024RmGQK;Hl_oml=_2Z95mKF=MG61X
MXRN]m7XnOoii<>HJChL1`065Re7H7J8UYnRXYbAPViF?2<>0P4>:DmlZ];_oOkc
glJ/U81`IEiMH6QfQijgd>SiooWT`iQY?Q`600HG;TMQMhVFWZ:PVXmoJU8h7``1
0Q8_EhFcfO?ooNoJ`:N?O6eSGUiSKGb?Y/3IkogolmVcQUP_4@81320hDVYoSiZP
XIfDQWAMA2XD10098DEbX<[Zo?ofhl^aV8=cIf1OHVYgRJ2idn[jooOQ_I5R>1L4
00PK<deUNh^GWZ2MUHQfGdH/5@D021m2Kik8jO_om^C;/IV4LfQQGf=[NH^R^mG/
noofgKR;G3<D0`0;7SMAJGf=V9jOVi63L5Po9A0200dXCgf/e?3no_7L`jVAOVmU
HF5WLH6E[LOPm?omk<fSM4LR2@0452Y4GGB6Ti^NW9F9Mf58;QL600LM@FfLanSk
ooKSbk6HQ7=XHV5VKgjAZL;LlOknl=>[O4hW30034BM0FW64TIZMW9F9Mf99;aL6
00LM@FfMb>WkooKSb[2HPg=XHf9WLH6E[LKOm?omk<fSLdHQ2@055Ba6GgF7TiZM
VI63LEY09a4200dXCgj]eO7noNoJ`:N@OFmVHfE/N8ZP^M?Zn_ofg[R:Fc4B0P4<
8CYDJgn>Ui^JU8QhHTT_5`H01ai2Kio:j_com>78[YJ2LfUTIF]fQibecnOhooWS
_i9R=QH300XN=e5YOHbFViZDR7QRBBlG1P077T9`X<_[o?odh<N]UH5bJFEVKGV:
X;WCj_[om]fhRET_4@813B8lEVf0SYNJV923LE]19a4300dXDH2_eo?oo>kG_JB=
O6mWIFUbP9B[aMkco_g/c:5a@ah700HG;dURMhRCV9VCRGQSBc4I1`067D5_Wl_[
o?odglJ/U85cJVIXL7f?Y[oIkognlMBZNT/T2P0452]5GWB5TINHThUiID`b6PL0
1Qa0KIk9j_com>36[9F1LfYWJG5oTJS2g?7no^k@YGE680P01QL^BF5gQi:GUi65
MEm6;1D400XTBgZZe?7noNoI_jF?OG1YJ6afQYZbc>GgooWS_i5P=A@20@`Q>UA[
OXbDUiB;OFUB>1h:00<F>6FF`nKkooKRb[2HQ7E/JF]cP9>[a=kco_g[bim^@1`6
00PJ<deUNHRBUYB<OfeE?28=0@8C<ej?_^?iooSUcK>JQWM]JVacP9>Za=kco_g[
bim^?a/500PK=4iVNXVBUI>;OFYB>1l;00<F>FJGa>OkooGQb:jGPgE]JVigQIVa
bnCgoo[T_i5O<a<20@dR?5I]OhbCU8n5MF18;AH500TSBg^/eO;oo>gF_:>=O75/
K79nT:K0fO3mo^o@YGA57`L01aTaBfAhQi2CTHUkIdle70T01AXnKIk;k?gnl]g3
ZY>1M6e/LGb=X[_Ek?col]J/Nd/S2@055Ri8HGF5Si:@RG]XD3HM2@056Si/W/_/
oOkbgL>YTh5dKVecOXnU_]S_oOk`dZIeAAl700LI<TaTN8J?TXn5MV9:<1P600PQ
BGVZeO;oo>gF_:>=OG=^KgN4Ujk8hOGonnK2Tf8e4`813B<lEVanRY2@RWi]ESdS
3@424cAQTl;VnooehLR^UhAgL6mdOhnU_]S_oOk_d:Ac@ad600PK=4iUNHJ>T8b1
LEa3:A8300h/EhVih?Son>K=/i^7NG5_M7j>XkcFkOcolMBYMdLP1`076C9<I7N5
SHn;PG1K@RPA0P4?;EV;^n7iooOTbk6JQgUbL7F0TJO0f_3mo^k=XFho6PD02Qhg
DFQjQhf>R7a[E3/Q30035SUWV/SZoOkbgL>ZTh9gLG9iQYV`b^?gooWR_8aI;Pl1
0Q4X@U]`P8Z>Rh9dGdL]5@@02bMAPkCLm_oiilneWHUkM79gPI:X`M_ao_g/bYeZ
>aL300/P>U=ZNhN<S8EgI4dc6PL01b17N:[El_okjmBjXHenMG=fP92U_]S_oOk^
cZ5^?aX400XN>59XNXJ<RhAgI4`b6PL01b18NJ_Flookjm>iX8anMG=hPY>Y`]cb
o_g[b9YW>1D30@dR?5E[O8N;RH5bGTH/50@032UDQkSPn?ohi<bbVXQkMGEkR9Zb
c>ChooSP^8ID:@`011D/AUmbPHV:QWYYDcTP2`046Ce]X<k^o_g_f;jUT85hMGR2
TZS1fo7noN_9VVLh5@813B<mEValQXZ7OVmJ@BL@0P4A<UnC`^OkooCOaJbEQGYf
N86@Y;gGk_gnklnRKclI100;7cUBJGZ4RHMnKe]2:1420A0`GI31i__om=o6[9J5
NgMiPY6U_]S_oOk^cIm/?1L300`Q>eAZNXB8QGa/EchT3P4253MVVLS[oOkafl6X
Th=jMg^5UZc5goConnK1T5d`40434RU3FfmnQXN2MVE>=1/800LPB7Z]f?Con^W@
]Yn<OgUiP8fP^=;ZnooceJUfAAd600TM=U1VMh:7Q7]/EchU3P4253MVV/W/oOk`
f/2WThAkNGj9V[7:hoOon=ngQE8W2P055bm9H7=oQHEmKe]3:A830@l`GI72ioco
lmk4ZiJ6O7YmR9V_b>;fooWR^XUE:@`011H^AembOXF4OFmK@bTB0P4@<EnC`nSl
o_;M`jZEQWejOhZK//cUn?oggKB1CR@900HI<T]RM7n4PWYZESdS3@435S][Wlk_
o_g^e[fTTH=lO8:?Xk[Dk?colM6SKchH100<8C]DJGR1PgmcHT/a6@H02BE?PkGO
n?ogi<^aVhZ0O7n9VJo8h_KonN6iQe<X2`055bm9H79nPh5hJE@k8@`011ToL:CB
lOoljm>jXXn3OGj6U:W1fo7noNW5U60a40424RU3FfikPH5jJeLo9@l10Q@hJ9c<
k_kmk]NmYI:5OWj6TjO0fO3noN_8Uf<d4P424BQ2FVejPH1iJeLn9@h10QDiJYk=
koklkMJlY965Ogn7UZ[3gO;oo>O2T5`^3P0352a5GFmkP7mfIe4h7`X01Aa4MZ[G
m?ojj=2fWhj3Oh:<W;;;i?SommfbOd/Q1`086cA>HgAmP7]`GTL^5P@032]HSKoU
noocg/F/UhV1P8JCYkoHkognk<VHI3@B0@8A:49IK7UoOGEVDCPO2P057DEh[=Se
ooWWc[FOSXB0Q8nP]m3Yn_oceJQc@AX400`Q>U=WMWenMfUF?R@>0@<F?6fRd?7o
o>_C^Z>AQX64SYjdcNKiooKI[WU67@D02QhhD6EdO7egJUHn9@h10QHjK:7@l?ol
jmBjXi66PXF?WkK?ioWom=NZMT<K100;83YBIWElO7EWDc/Q30046T5dZMKdoo[X
d;JPShF3Qi:T^mG/o?k_cIiY>1@20Q0W@5QZMgajLF5;<QT700TUDHJih_[omN37
[YZ<Q8B;VJg6goCon^>kQe<V2P066C9;H71iNgIYEclU3`425CY/XM3aoo_[dkZS
TXN4R9>U_=G/o?k_cIeW=a<10Q0W@EQZMW]hKUe7;QH400d/Fi32j?cnlM_2ZYN:
QHN@X;K?ioWom=JYM44J100<8S]CIgAjN71PBc8I1P0:9e>8_>CkooCNaJfIS8J7
SindcNKiooKI[7M46`@02b4jDVEcNGQ_H4Xa6@H02RMDR[gUnoocg/B/VHb6R96Q
]m3Xn_oceJMb?aP30@dS?EAWLgQfK5a6;AD400h_GYC5j_gnkmW0Z9J;QhZEY[gF
kOgnkLZIHc<@0@<C:T=JJgEhLfME?B@>0@<G?W6Ve??on^S@]j6BRHR>W:o8hOGo
nN2fPTdR1`0873E>HW1fMViNBC0H1P0;:EN<`>Olo_;L`j^ISHR;UZNmenkmo^g9
V68a400352]4FV]dMW5TDCTP2`057DIk/=cgooOSbk:NT8Z:Tj:gd>Sjoo?CYFll
5P813bDnEFMbMW9VE3dT3P4363iaYmGdooWWckJQTX^;TZ2ec^KiooGGZGA06@<1
3B<lDfEaMG5VEChT3P435ciaYmGdoo[WckJRTh^;Tj:gcnOjooCEYW0m5`813RDn
EFIaM71TDSXQ30046dAh[]_gooOTbk>OTX^=UZJleNclo^o<Vf@c4@434bY3FFUb
LfeOBc<J1`099U>8_NGkoo?Ma:fKT8b@Vjg5g_?onnBkQe4T20086cA<GfecLFMG
@BPA0P4C>6ZPd?7onn[B^JBESHfEY;WAjO_ol]6QJSPC0@8A:45GIg1bK5i:<QX7
00TWE8Zni_cnl]c3[9^@SI:N/LWRm_ohg[9mB1h500/P>E1RKW5^HU0i80/01Ae7
O;;Nn?ofh/VbWi>>TIb]a=gcoo_T_8MA90P021/dC5m/LFiTDS`S3@436D5f[=Wf
ooSTc;BQU8nAVjc3g?;no>JnRU<V2@076c=;GV]`KF=B>b8=00@J@gN]f_OomnC;
]:6DSi:M[lGNlookhkV4CR8700TM=DeOJfm/H4hg7`X01R1;PKKQn_odh<N`WY>@
UJ6dbnCgooOJ[GM26P<03B<kDV=/KfUKB30H1@0<:e^BaN[moNoH`:ZJTY6IYkcD
k?cnk/^IHS4?00@E;4AIIfi/He<m9@h10aLoLj[HmOohiLfeXYJAUInab>7eooWO
/ge77@D02b0iCf5[KFQKAblG1@0<;5bCa^cnoNkG_jZKTi>KZl3Hkogmj/B@FBX;
00HH<4QKJ6eZGddf7PT01b5>Q;WSnoocg/F_WYFCVJNkdn[koo3=W6Dc400352]3
EfE/JV5@>R4<00@LAW^bg_Som^79/Z6FTiVV^M7Yn_obdJ1Y=Q810a8Y@EITJfYQ
D3XR30046dEk/MghooKRbK>QUiBIYk[Bj__olLnNIS@A0@<C:d9GI6YYGdhg7`X0
1Qm;PKORn_odglJ`X9JEW:Zne^gmo^c7U5d/30055bm6FFIZIU]9<AX700XXEho3
jOgnkmW1[9fFUj2`a]kcoo_S^H==80H02QhfCEiWJF=E@2PB0P4C>6^Sdo?on^O@
^:JJUYZV^M3Xn_ocdj9[=a810Q8Y@EERJFILBcDM2@078e27_>Glo_;La:nOUiRP
/<GMlookhkV3CB0600XN=TaMIVQQDShV3`425SibZMSfooSUcKJTVYNMZ[kFkOcn
kLREGBd<00DG;dIHI6MSET</5@@03c9TW<k`oo_ZdkbYW9RLYk[AjO[ol]6PJ3DA
0@<C:T9EHVMTF4H_60D032aMU<S]o_c]e[n[WYVLY[W?ioWom=BSK3PC0@8B:D1D
HFISF4H_60H032aLU<O/o_g]e[n[WYVLYk[@j?[olm:QJCHA0@<C:T5DHFIRET@]
5P@03S1RV/c_oo_[e;fZWYZNZ[gDjocokl^HH2h=00DF;TEGHVEPDclX4@8153Y^
Y]KeooSVc[RWWI^Q[lCKlOkli[f8DB<700TM=DYJHf=LC3LO2`057d^2^>?koo?N
a[6SW9fV]lgTn?off:Ua?AD20Q0V?U5NI61E@b`E100?<F>Kc_3onn[C_:ZOW:6^
`]W_o_gY`XeE9PT021/cB5URHU];=Ql:00HPC8>ji?_ol]g6/J>MWjVjd>Sjoo?B
XFTf4@434bY1DemRGU4m9Q020QDmLZWIm_ogi<fgYijNY[G:h_Kon=f_N48I0`4>
93]?G69OE48[50@043=VWm3boo[Yd[^ZX9jT/lONloojh[N0BAh500`P>4aJHEmE
@bdF1@0=;f6Jc?3onn[D_J^QWZBba]gcoo_S^89;7`D02b0gBeYPGUA3;AH500h`
HY_=l?okj]>mZj6OYKC8goCon^6eOTLL100<8CQ<FV1MDT0Z4`<14CIYX]?cooWW
d;^ZXJ2X]lcSmoogfZ]c?QH20A0U?4mKGe]>>b@?0@<H@GN^g?Som^;;]ZNPXZbm
dnWkoo7>W6<a3P045Ra2DeeNEdPd70T01bABR/3XoOk`f/>aYJ6U//GLlOkli[b6
CR4600XN=DUHGUaA?bTC0`4B=fZSe?ConNO@^Z^RXZ^kd>Oioo?CXVTe4@434bY0
DE]METPc7@T01bABR/3XoOk`f/BaYJ:W]<ONlookh[N0BAd500`Q=d]HGEU>>b@?
0@8G@7J^g?Som^;;]jVSYK31engmo^c5TEPX2P076S55E5aJDD0Z50<043EXXM;c
ooWWdKb/Y:B]_]?YnooacYaS<0h01AH/@U9JFe93;AL500d^H9W<l?okj]Bo[ZFT
[;cAioWolm:QJ3@@00@D:T1@FUYC@bhH1P0<;5jGb^ooo>_E`:nVYJfldNSioo?B
X6Pd400452Y0D5UJDT8]5`D03BmQV/g`oo_Ze;n_YZJ^_]CZnoo`cY]R;`d01AH]
@U5IF4lo:A<3014fJZ;Dm?oiim2l[JJW/L;Hk_gnjlB?ERL900PK<DECFEI<>R@>
0@<H@GR`g_WomN7;^:^VZ[K9go?on^6eOTLL100=8CM:EEUCAS8L2@0895><`^Wm
oNoJa;>YYjjmdNSioo?BX6Ld400452XoCeMGCShX4`<14SM/YMGeooSVd;b^YjZe
amcao_cU^hA=80D02aleB5AGDdHb70T01bABRl7YoOg_f/FcZZR`_m?Yn_oaciaS
<0h01AH/@4mFED/j90l10QLoMJkLn?ofh/bi[JR]^LcRm_ohg:ie?aL20@lT>T]E
ETho:aD400lbIYoAloojj=:n/:V[]/SMl_kli;Z3Bah500/O=DMCEU12;aT600/Z
FiC9k_klk=K2/ZZ[]<GJkogmjL6;DR<700TL<TEAEE14<1/800TVEXo4jokmk]W4
]:^[]<CIk_gnjl>=EBD800PK<DA@EE14<1/800PVEXo4jokmk]W4]:b/]LGJkogm
jL6;DR@700TL<TA@E4m2;aT700XZFiC8k_klk=O2/jb]]lSMl_kliK^4C1l500/O
=4IADddo:aD400haI9k@l_ojjM?0/Zb_^/cRmOoig[1g@1L20@lS>4UBDTXj9A02
0QDmLjcKn?ofhljk/:bb_m?Xn_ocdImV<Pl011DZ?TaBD4Dc7@X01R5?QkkWoOk`
g<Ng[Zjga]_`o_gX_hU@8PH02QdbA4mBBcdZ50@03c=WX=;cooWXdknb[[6nd>Kh
ooKGYVdh4P434RLkBU5?AC<N2`057db5_>Klo_7Mb;R_[kS8g?7no>NmQdhP1P0:
7S=4CU19>bLB0`4B>6jWeoKon>G@_[:_]<7Ej_[olLjKHRl=00DF:ci;D4a0;AP6
00/ZG9G:koolk=O3]Jnb_LoTmoogfZYa>a@10Q4U>DQ?CD<b7@X01R5?R;oXoOk`
g<Rh/;6kbn3doo[Q]7a56P<13B4fATi>ACDP300474Mo]n?koo?ObkZb/K[:g_;n
o>FjPTXN1@0;7cA4CDi5=R4=0@<JA7^dhO[om>7<_;:b^/WNl_kli[^4Bal500/N
<d=<CDDe8@d10aY5O;CQn_odh<bl/k:kb]oboo_T^H597@@031ldA4a<@c<O3004
7DV2^NClo_;Ob[^c/kg=h_GonMnbND8H0`4>8SI5C4]1<1/900LSDhc2j_gmkm_7
^K>e`=7Vn?ofejI]>1810a8V>DM<BCd[5PD032iPV/kaoo_Ze/>g/kS5enckono:
UU`[2`0662`nBDa5=b@@0P8E?G>/foSom^C@_kFd_<_Olooki;V1BAd400`O<d9:
BT0`70T01b=BRl7YoOg`g<Rj];O2e>SiooCCXFLc3`0452PjAd]6>BHB0`4B=ffV
eoKon>KB`KNe_<_Nl_kliKZ3BQh500/N<T59BCl_6`P01bADSL?[o_g_flRk]KW4
e^[koo7>VV4^30055RXlAdU3=B8>0@8G@7R`g_WomN??_kNg`=3Tm_ohg:ec?AD2
0Q0S=TA9ASXX50@03c=WX=?cooWYe<>i]kg<go;no>FjPTXM1@0;7S91B4Lm;1P7
00XYFYC9k_olkMW7^kNlbM__oOk[`heD90L021X^?TM7?RlK2@078e:;`^[moO3L
bKbg^lOIkOcnk/RCFRT:00LH;3a6Acl`70X01R1>QkkXoOkagL^m^;_7fNclono:
UU`Z2P065b/lADHo<1`:00HPCXNnj?gnlMk;_[Rlb=W]o?k^bIAJ:@X01aP/?4E6
?RhK2@078e:;`^[moO3Lb[fi_LWKkognjlB>E2D800PJ;Ce5AC`/60L02BQITlS^
o_c]f/Rm^Ko<go;no>JkPd/N1@0;7C0nAD<h9a@400haIIoBloojjMK5_;[2dNCf
ooSM[WDn5P823b8d@4E0=28?0@8F?gF_gOWom^CA`[^la]OZn_obd9eS<0d01ADX
>494?BhK2@068U6:`NWmo_3Mbknk_lcNlOkmj;j7CR0600XL;ce4@CLV4`@03c=X
X]CdooWYeLJm_<GDioSom]NVKCLB0@<A93I1@cd_7@/01Ai;Q;cVo?kbglg1_<3<
g_7noNW0RE0Q1P096bhl@d0f9A83010eJZCEmOoij=G6_Kk6e^WjooCCX6Lb3`04
4bHg@48k;1T800PUE8k4jokmkmc;`;g3d>?eoo[Q/g]36@<13Ala?T8m<Al=0@<I
A7^dhO[omN?@`kg1c=g`oOgZ`X]B8`L021X/>T4o=B@A0`4B=ffWeoKon>OEa[o0
bMW/noo`c9QN;0/01QHX>410=bLD1@0=;f:Ld?;on^_HbL2ob=OYn_oddj5W<Pl0
11<U=Cm0>2TF1P0::UbEb^ooo>gKb/6oamGXn?ofejI/=a410a4T=3ho>2XG1`09
:5RBangno>kLbl70amGXn?off:M]>1810a4S<cdo>2XG1`09:5VBb>gno>kLc<;0
b=KXnOoeeZE[=Q400a4T=3dn=bPF1P0;:efFbnooo>gKbl;1bMSZn_ocdYmU<@h0
11<U=Cdm=BHC100><6BNdO?on^_Hb/;2bm_]o?o_biIL:PX01QHX=Sdl<R8@0P4C
>FnYfOOon>OEb<;4cmoao_gY`8U@8@H02AX[>3dj;Qd<00@KAWjgho_om>?Ba/;7
dnGfooWO/GQ15`813Al`>Sdg:AL700TWEi76kOkmkmg=a<?:fN_joo?AWV@`3P04
4bDd?3/b8a430A4gK:KGm_oij=O9`lG@h?;noNNnQThP1P096R/h?3P/6`T01Am=
Q[gWo?kbhM36`l[GjOWomMJUJcHA0@<A8S8j>c8S4P<043AXX]CdooWZf<[4a]3P
l_kmj;j7CR0600TJ:cLk=bXI2@068E29`>Wmo_;Pd<K5bmW[n_ocdYmU<@h0118T
<SXi<20?0P4D?7:/foSomnOFbLG8e>Gfoo[P/WY260<131h^>3Xc9Q@500`]GiW=
lOokkM_=a/O@h?7noN[2Re8S1`0862Te>SHZ6@P01b9@R/3YoOkah=77a/gLkO_o
l<fIGbd<00DD9C<i=b`L2`036TEm]^;kooGTe<W6c=WZnOoeeJAZ=A000a4R<3Pg
;Ql>0@8E?GB]g?SomnOFblK;enShooOJZg4k50423b0_=cL_8@l20A8iKZSHm_oh
jMS<al_FioOon=f_MClF0P4=7Rdf=blQ40<14CM/YMKeooWZfLc7bmKVmooigZmf
?aL20@dN;CHg;b4@0P4B=fbVeoKonN[IcLS<enOgooSL[G@m5@813Qh]=SH^7`l2
0A<jL:[JmoohjMS<b<gIjOWom]VXKcTC0@8?82hf=B`M3@425d1g/=kiooOWelc9
c]_/n_ocdZ1V<Pl00a4R;cHd:QX:00@MBH6ii?_om>CEbl[Ag^olo^k9U5/Y2P06
5BDa=S8V5PL022EESlG[o_gah=;:bmCSloklikf6CAl600TI:3<e;b8A0`0><FFO
d_?onncLcl[=f>ShooSL[G@m5@813Ah/=3<[70`10aQ1N;7OnOogimO=bm7Nk_co
l<fIGbd<00DC8bld<BHF1`089UJ?aNcnoO7Qdlc=e^Geoo_T^H587@@02QXY<S</
7`l20A<iKZSHm_oij][?bm3Lk?_olm:PIS8?00<A8Bhc<BHG1`078e:;`^[mo_;R
e<g=e^Gdoo_T^X997@D02ATX<C8[7Ph20A@jL:[Jmooij][?c=;Nk_colLjKHBh=
00@B8Rhc;b@D1P0::5VCb>gnoO3Pdlg?fNSgooWN/7M05`8131`Z<C4X6PX011]6
O[KRnooei]O?c]GSlokmjL6:DB8700LF9Bla:ah?0P4B=ffVeoGonN_LdLkCgnkl
oo7>VV0^30044R4]<BdR4P@032aNV<c`ooc_gm?>dMc[nOofejM]>1810PhN:c4^
9AH700PTDhc2j_gnl^?Fcm3Ij?OonMjaN44H0`4;6bP`;bHH2@057TZ3^^GlooGU
f=3@f>Keoo_S^81870@02ATW;blW6@X011Y5OKGQn_ofimWAd=OUm?oli[b5C1l5
00PG9Bh_:1X;0@<H@WVbgoWomnSJdM3GiOCno>NnQdhP1P085bD^;bPJ2`43645h
/MoiooOYf];Af>GdoocW_HI=80H021LU;BhW6PX00aU3Nk?PnOogj=[BdMWVmOok
iKZ2BQh500TG9Bd]9QP900@LB7ngho_om^OId];Jj?Oon^6dO4DJ100:6BH];B@F
1`068Dj7_^Olo_CUf=;Cg>[iooOK[7<m5@8131/W;B/R4`D02BQHTLO/o_gbhmOB
eMo^noocdj5X=1000`lN:BdY7Q0300haIIkAl_okk^3Ed]OSlOgnkLRCFRT:00DB
8BX]9aX<0@8F?WB]g?SonN_Me=?JioGonnBjPTXN1@085b@[:b<F1`0684j6_NOl
ooGVf]?Eg^cjooKHZ6hi4`413A/W;2TN40<03BmRVlkaooc`hMOCf>?boOk]ai9I
:0X01A8P:B/U6@X00aU2NK7OnOohj]cEeMcZn?oigk9i@QT300XH9B/Y818500XY
FY?8kOkml^?He=SRlOgoklbHGR`<00@A7bP[9AT;0@<G?gJ_gOSon>_Ne]GMj_So
nMnbNT<I0`0:62@Z:1lA100;:UbEbNknoO;SfMGIi?;mo^g8TeXY2P054AlX:R<G
2@046dIm]N7jooOYgMKGgncjooKIZG0k508131XU:RHL3P8143AWXM?coo__hMSF
g>SfoocU_8E<80H01aDQ:BPP4PD02BIES/C[oOkci][FfNCboOk^bYIM;0`0110N
9bTR5PT011]6O[GQn_ogj]gGf>7^nooeeZE/=a810PdJ9BPT6@`10Q@jKjSHm_oj
kN3Hemk[n?oig[5i@QT300XG8bPU70h300laI9g@lOoll>?IemgYm_okiKZ3Bal6
00LE8BLV7Q0400/ZFiC9kOkml^GKf=cWm?kmjL6;Db@800HB7bHV7a8500TUEHg3
j_gnm>OLf=cVloknk<JAF2P:00DA7RHV7a<600LSDHVoj?comNSMf=_UlognkLRD
FbX;00@@7BDV7a<600LQChNni_com^SMfMcUlognk/VEG2/;00@@7BDV7a<600LR
ChNniocom^WNfMcVloknkLRDFbX;00@@7B@U7Q8600PSDH[0j?comNSNfMgWm?km
jlF@EbL:00@A7B@U7A4500TWEXo4j_gnm>OMf]kXmOolj<2:DB<800HB7R@T70l3
00`/GIK:k_kmlnKMf]oZmoojhkR1BQh500LD7bDR6Pd20A0cIYoAl_ollNCLfn7]
nOohgJmg@1P300TF82@Q5`X10QDlLZ[Im_ojk^;Lg>C`o?oce:=Z=Q410@`H8R@O
50L01Ae8P;ORn_ohjn3Kg^Odo_k]b9AK:P/010lK8b<L40@02RQGT<G[oOkdj=kL
h>_goo_T^X=;7`H01a<N8b4H30414CEYX]?coocaiMgMhnokooGGZ6lj50812QLP
8ahD1`0574Mn]N7jooS/hMcOj?Cno^c7TeXZ2`043a/R8QX?0`0<:ebEbNgno_CX
gmgRkOWonMnbNd@J100851hR7aD900<G?gB]foOon^kSgMoWlognklfJHBl>008=
6B4Q6`l400XXEi34jognmNWPgN;]nOoihKEnAa`500LC7B8N5@T00aLnM:cJm_oj
knCNgnOcoOk_biQP;Pd00`dI820J3P<02bYJTlO/o_kejN3NhnkjooSM/7Q26@@0
21@M8AdC1`046dEk/moiooW^hmkQj_KnoN[4SeHW2P043aXP7aL<0P4@<fJOd?7o
oO;Wh=oVlOcolm>SJSHB0@4;5QhP6Q0400TUDh_1j?com^_RgnC^nOoih;AmAQ`5
00LB720L4`L011Y4N[;Nn?ojk^COh^_foocY`XeE9PT010lJ7ahF2P414SM[XmCc
oocbin3Qj??mo_3=Vf8`3`0231LN7QP=0`0=;EjFb^gno_CYh^3VlOcom=JWKcXD
0P495AdO6@l400TUDh_0j?comn_Sh>G_n_ohgK1i@aX400LC71lJ4@H01Qm;P[SS
n_oikNCQi>kioo[R^85:7`H01Q4J7Q/B1`046dAk/]khoo[_iN7TkOSonnJmQe0S
20053aTN6a<800<H@7F]foKono3VhNC/moolj<6<E2H900@>61dK4`P00aHmLZ[H
mOoklNORi>cgoocY`hiF9`X00`hH7A/C20035SaaZMSeoocain;Tk?Ooo>W3SUHW
2P033QPM6a<800<F?G6Yf?Goo?7Wh^C/moolj<:=EBH:00<>61`J4PP00aLoM:_J
m_oklNOSiNghoo_W_hUB90T010hH71XA1`046T9h/=cgoo_`in?Vk_Won^>jQ4dQ
1`053aPL6A0600HNB7jeh?Won^oVhnO`n_ohgkAmAQ`500H@6A`H3P@022=?QkcU
noohk^KTj?;looKIZg@o5`<01a8I6aH<0`0;:EVAaN[mooO/iNCZm?gol]6QJCHB
0@494aXJ50X10A0bI9c>l?knmN_UiNcfo_g/b9AL;0d00P/E6QTB1`035cebZMSe
oocbjNGWkoWon^BkQTlR20043QLJ5`l500LPBh6hh_Won_3WiNWbo?offZee@1T4
00LA61XE2`8032]KTlK[oOogkNKVk?Gno^o=Vf<b40412Q@I6A88008E>VfUeO?o
oO?Zi^O_nOokiKf7D2<800@=5QXG3P@01b1<P[SRn_ojl>SVj_?looGGZG8m5`<0
1a4H6A<:0@4?<66Ibnkno_K/inO]moomjlJBFb/<008;51TG3`H01A]4NK3Lmook
l^WVjO;kooOL/7U46`D01PlG61@;0P0=;5bCan_mooO^inO]mokmk<VFGRh>008:
4aPG3`H011Y2MjkKm_oll^[Wj_;kooOL/7U46`D01@lF61<:0P0=;EfEb>cmooO^
j>S^moomjlJCFb`=008:4aPF3PD01Qe6O;;Nn?okl^[WjoClooGHZW<n60@01Q0F
5a890@4A<fFMc^ono_K]j>W`nOokiKj9DRD900<<51LD30<02BAAR;gUn_ojl>[X
kOKno^o>WFHd4@41214F5Pl600@H?gB[f?Goo?C/j>_co?offjmh@a/500D>5AHA
2@41435RV/_^o_kgk^WZl?WonnJnRE<V2P032a<F4`/300XVDhZni__on_7ZjNkg
o_g]biUQ<A010@TA5Q@>1@067DIk/Mggoocck>W]mOgolmFVKc`F0`063aDE3`H0
0aHkKZGDl_ommNgYk??looOM/G]67@H010dD5A480@4@<V>Jc>kno_O_j^_bn_oj
hk^6Cb<900<;4aDB2P8032]ITLCYo?oil>_[l?Woo>S2SePY30022Q8E4P/300XU
DXRmiO[on_;[jo3hoog/b9IO;`l10@TA5A<<0`088Db2]n7ioo_ck>__moknk/bK
I3<A0@4841@C30@01Qi8OK?Nmoolm>g[koOno_3?WfPf4`801`lD4`d400HLAGZ`
g?Koo?C]jnogo_kadJ9[>1@300H?4a<=10056d=h[][foogek^__m_knlM:SK3TE
0`063Q<C3@@01A]3N:kJmOommNk/koOno_7BXV/i5@<01PhC4P`400HLA7V_foKo
oOG^k>ogo_k`d:1Y=a@200H>4a8<10067TMl/Mggoocdk^c`n?onk/fMISDB0P07
3Q<A2`<0221;P;GOn?olm>k/lOWooNc9V64a40411`lC4@X200TTD8JjhoWono?^
kO;joocYa95K;0d10@P?4Q090@0<:EN=`NOkoo[ckNkcnooji;f9DbH;0089418?
1`413c1OU/S[oOoil^g^m?commneP4XP20032Q0B3@H00a@gJJ3?l?knn?7]l?Km
ooCHZgE16PD010`A4@`400DJ@GF[f?CooOK`k_7hook_cimX=a@200H=4A0:0P08
8Tf2]n3hooceknkcn_olj<BAFb`>0@483Q4>20413RaJTL?Xnoojlnk_mOcon>2g
PTdR2@022PlA3@D00aDhJZ3@l?knn?7^lOOnoo;EYg4n60@010`@40X300LNAg^a
g?KooOK`ko?jooc[aiIO<10100L=40h80@0=:UR>`NOkoo_dko3eo?ohh;N2CB<9
00893a0<1@035SY/X]7`o_khl^obn?knlM:TKC/G1005310?2@802B9<PKKOmool
m_3`m?_onnK1SUPZ3@411`h@3@H00Q4bHYS9jogon_?`lOOnooCH[7I36`H00`X?
3`X300LNAWZ_f_GooOOal?CjoocYaIAN;`l100H=3`d6004?;ejDaNWloo_dl?7g
oOoefZiiAAd700<:3Ph:0`067DEh[MWdookgl_3dnooljLFDGRl@0@0630l<1P01
431OU<KYo?okm?3bmokom=R/Md@L1P032@h>2@801am8O;7KmOommo;amO_onnO1
SeT/3P411P`>2`D00Q<eII_;k?gon_CaloWno_7CYFlm60@010X>3@P100XUD8Fi
hOSooOKbl_KmooSQ^8E@9@X00@L=3PX300DI?W2Vdo7no_WclOCjooc[bIUS<a82
00D;3P/6004@;efCa>Skoo_el_?ho_ocejYe@Q`600<93@d80P098df1]Mkgoogg
l_;foOohh[Z7DRH;004730d90`056Ci`Y]?ao_oim?;enoolj/NFHC8A0P052`d;
1@024S9QUlOZo?okmO;dnOonl=:UKchI1@032@d<1P4032QDRKcSnOommo?cn?ko
mM^aODTP200220`<20802218O;3KmOonn??cmogonN>lRE@X30411P/<2@<01ATn
L:GClOkon_Ccm_connS5U5l`4@801@X<2P@00a@fIY_;k?conoGcmO_ooNg<WFPh
5@<010T<2PD00Q0_GI?4j?_oo?KcmO[oo_3CYG0o6PD00`P<2PH00@dZEX^mhoWo
oOOdm?Wnoo?G[7Q57PL00PL;2`H100/UD8BggoOooOSdm?WnooGK/Gi:8@T00@L;
2`L100TRBgncg?Goo_Wdm?SnooKN]X9>90X00@H:2`L200PPB7^_fOCoo_Wem?Sm
ooOP^HIB9``00@H:2`L200LNAGR/eo?no_[em?SmooSR^hQD:0d100D:2`L200LM
A7JZe_;noo[emOSmooSR_8UE:@d100D:2PL200LM@gJZe_;noo[fmOSmooSR_8UE
:@d100D92PL200LMA7JZe_;noo[fmOSmooSQ^XQD:@d100D92PL100PNAGR/eo?n
oo[fmOWnooOP^8IB9``100D92PH100PPB7^_fOCoo_[fmOWnooKN]H9?9@/00@D9
2@H100XSC7nbfoGoo_Wfm_[nooCK/Gi;8PT00@H92@D00@`VDHBggoKoo_Wfm_[o
o_;G[7Q57`P00@H92@@00@h[Eh^lh_SooOWfmo_ooO3BYG506`H00PL920@00Q4`
GY;3i_[ooOSfmocoo>c<WFTi5`@00PL91`<011DgIY[9jocoo?Sfn?gon^O4U60b
4P<00`P91P801QXoL:CAkogonoOfnOkon>:lRUH[3P4010P91@402B58NZkHloko
noOgn_oom=^bOd`S2P011@P810013BQCQ[SOmoonn_Ognooml=:VLT4L1`011PP7
0`034S9OTl?Wn_omnOOhoOokj/RIICHE10021`P60P056Ce]XLk]o?oln?Ojo_oh
h[b;Eb`?0P041`P50@0:8TYl[mWco_okmoOkookcf:ikBB49004520L3008?;EV<
_N?hookjmoSlooc/c9iZ>aP5008620H200DG>VVMbn_loogimo[nooSS_XeI;A02
00<71`D100XRBG^^f??noo_hn?_oo_;G[GY88@T00@D71`<00Q4_Fhnoi?Soo_[h
nOgonn[9VVHh5P@00PH71@401Q/oKj;?k_coo?Whnokom]jgQU<Y3@400`L71001
3BQAQ;KMmOoonoSio?omk]2SL3lK1`011@L60P055SQWV/WZnoomnOSjo_ohh[f=
FRh@0P031PL4004;94an/=Wco_oknOWloog`djQeA1h800441`D200@E=F>FaNOj
ookjn?[nooST`91M<18300861P@000XSBWb^f?;noocinOcooO3DZGI57`T00@@6
1@8011DeHiK5io[oo_[inokon>>oSe``4P<00PD60`012bA<O[3Ilokoo?WioOom
km:VLd<N200110H50@055cQWV/SYn_onn_Wkooogh;^:Eb`@0P021@H3004=:564
]Mceo_olnO[mooc/c:1]?AX600441P@100LK?fjQc^cloogjnOcoo_CK/h5?9`d1
00<51@800a4_Fhfmh_Ooo__inokonNK4UF8e5@@00@D50`002R99NZcFlOgooO[j
oOomkm:WMD@O2@000`D40@0563YXVlSYn_onno[loooeg[N6E2X?0P021@D2008@
;EN:^]ofoooln__noo[WaIMT=aH500441@<00@XRB7V[eO3moogjn_goo>kAYWA4
7`T000<510401QTkJYg:j__oo__jo?onm=^dPe4X3P800PD40P034S1LS[kRmooo
o?[looohhl2AGS8D100110D2004=9dn1/][co_omn__noo_ZbYi[?AX700431@<0
00TOA7BVdNkloogknogooNoCZGM78@X100<40`401QTkJI_8jO[oo__koOonlmZc
PU4X3P800P@40@0453=OTL3Sn?ooo?_looofhKb<FRlB0`0110@2008@;5F7]mge
o_omnocoooWVa9IS=QH5004310800@dVCGj_f?;moogko?kon^[:WV`m6`L000<4
0P012R57MZSBk_coo__lo_olkM2ULd@O2@000P@300087D5`XLg[noono?_noog_
e:]iBB<;0@0210<000LJ?6ZLb>SjooklnogooO;H/7m>9`d200840`401QLhI9K4
i_WooockoOonlm^dQ5<Z3`800@<30@055CAPT/3SmooooOcmookdgKN8ERdA0`01
0`<100@D<Uf?_^7fooomo?goo_GO^X]I;a8300430`4011<`Fhbkh?KnoogloOon
m^2lSE/a4`@00@<30@034RmIRk[OmOkooOcmooofh;f>G38D10010`<100<B;eV:
^Mkeo_omo?goooKQ_HiM<Q@400430`400a8_FHZig_GnoogloOonm^2lSU`b50@0
0@<30@044bmJRk[NmOkooOcmookegk^<Fc4C10010P8100@C<E^=^moeo_omo?go
o_CN^HYI;a8400420P001ADcGXnmhOKnooglo_onlmbfQeH]4@<00@8200055SIQ
T/3SmooooOgnoogbfK>3Db/@0`010P8000HI>FFGa>GhooomoOkooO3F[gm?:0h2
00420P0021/mJYc7ioWooogmo_olk]:ZNDXT30800@81004:7d9`XLcZn_oooOgo
oo_[cZAcA20:0@010P400@`SB7NXdNgkooomoOoonNS8WF`n70P000420@023RQ?
OjkFl?coo_gnoooghl:EI3PH1P000P8000@B;UN7]]_coOonoOkoo_CN^XaL<Q@5
00020P001AHdGi2nhOGnookmo_omlMRbPe<[40<0008100086caYV/KVn?ooo_go
oo_]dJUhBR@=0P010P400@/QAGBTc^_jooomo_oonNS9WVe07PT100420@033bU@
OjoFkocooognookfh[nBHSLH1P000@4000DD<E^;^Mgdo_onoOkooO;J]HIF;A84
00010@0021/kJ9S4iOOoooknoookkM6XN4XU3@800@41008<8dMeYLk[n_ooo_ko
ooSVaY]Z?Q`90@010@00114/E8Bcf?7mooono_onm=fjS5`b5@D00041000763QS
Tl3Qm_koo_kooo_^djalCRP?0`000@400@/QAG:Rc>[jooono_oon>K7W6`o7PT1
004100044RaDPk;Hl?coookooogcgKV;Fc8E1@000@4000LJ>FFE`N;fo_ono_oo
nncAZGU;9Ph2000100023BA9MjK?jo[oooknookfhl>GIc/K20400@4000DE<EZ:
]m_boOooo_ooo?3H/XAE;A84000100012Qm1KIg7i_Soooknooohj<VOL4<P2`40
004000@A;5>1/=K_o?ooo_oooO?L^8]L<aH60001000121/kIiK2hoKnooonoooj
j/jUMTPT3@80004000<@:4ilZm;]noooo_oooOCO_8mP=QP70000000121XiHi>o
h?Gnooonooojjm2XND/V3P<0004000<?9dajZM7/n_oooooooOCO_I5Q=aT70000
000121ThHi:nh?CnooooooojjlnWND/V3`<0000000<?:4ekZ]7/n_oooooooO?N
_8mP=QP70000000121/jIIC0hOGnoooooooijLfUMTTU3P<0000000@A:U5o[M?]
nooooooooO;K^8]L<aH6000000012QhoJYW4hoKnooooookhilROL4@Q30800000
00DD;eN5/]O`o?oooooonnoF/HAE;Q<5000000023B=5LZ3:ioSnooooookeh/:G
J3dM2P4000000@LH=Un>^]gcoOoooooon^_?Z7Y=:104000000044BU?O:[Ak?[o
oooooocbfkR;GC@G1`4000000P/O@6^Ja>?fo_ooooonm^C6W6e280`200000007
5c=KR[KJlOcooooooo[/dZ]mD2/A10000000110XCGZXcn[ioooooooll]biSEhf
60P10000008;7d1[VL?SmOkoooooo_KTaI]]@R0<0P0000011aPeGH^gf_7loooo
oooij/nYNdhY4@@0000000DB:e1mZm7[n_oooooono3H]HQJ<aH70@0000033B=5
L9o8iOOnoooooogdh;nEIS`M2P8000000@XL>fBC_]ocoOooooonmnK9X79690h3
000000475S9IQkCGko_oooooooW[dJ]mD2/B1@0000001A8[CgbZd>[ioooooook
kmRdR5Xc5`L1000000<>94IbX<SVmokoooooo??N_I9T>a`:0P0000022alnJIO1
h?CmoooooogehlBKKD8Q3@<000000@TJ>62>^M_ao?ooooonmnO;XgE:9a040000
00475S5HQK;Fk_[oooooo_W[d:YmDB`C1@0000001A</DGj[dN_io_ooooojkMFa
QEPa5PL1000000@@:4]gY<_Wmokooooono3I]h]N=QT80@0000033RA6LIk7i?Km
oooooocbgKbAI3/L2P8000000``Q@F^I`^7doOooooolln30UVTo7``30000008;
7SeVU;kNl_cooooooOGRa9]]@b8=0`0000022Q`jHY2jg?7loooooogei<NOLDLU
3`@000000PTJ=en<]mW`noooooonm^K9XWE:9a04000000486CELRKCGk_[ooooo
o_OWbjAgC2TA1@00000121PcFXJbeNgjooooookgj<bVNThZ4PD000000@PG<UR5
/=C/nOkoooonmnS=Yg]?:a<60@0000485c5GQ:oCk?Wnooooo_SXcZQlD2`C1P40
00011aLaEh>_dn_io_ooookgj<jXO50/50H100000@PG<EN3[m?[nOkoooonmnS>
Z7a@;1@60@0000485c9HQ:oCk?Wnooooo_OXcJMkCb`C1P40000221PcFHF`e>ci
o_oooogfil^UNDh[4`H100000PTI=5^7/]G]nOkoooomm^G:XgM<:A860@00008:
6SIMRKCFkO[noooooOGTaj1dBRPA1@4000022Q`iH8fgf>ojo_oooocdh/FMLDLV
40D000000``N?6B@^]_`noooooolln31VFe38`l4000000<=8D1XU;gMlO_ooooo
no7M_IEX@24=100000043bA4KIW1h??looooo_[_f[V?Hc`N30<000011A4WB7:N
aN;do?ooookikMJdRUhg6`X200000@HC:dihY<[UmOgoooonn>[B[X=H<aP90P00
00885S1DOj[?j?OmoooooOKWcJQlDRhE1`4000022QXeFhJae>_ho_oooocdhlNQ
MD/Y4PH100000``N>f:>^=S^n_kooookl]o0VFe490l50@000@@?8d9[U[kMlO_o
ooonn^oJ^I1T?Al=100000464RQ:Lio5h_Clooooo_S[e;67G3HK2P<0000221H_
DWfXcNOfoOoooogfilfXOE<_5PP200000`XK=Ub7/M?[n?koooolln75WW=9:186
0@000@@>8CmVT[[Jko[nooonn_3K_9AX@28>104000464RM8LIc3h?;koooooOS[
e;:8GCLL2`<0000221H_DgfWc>Keo?oooocei/^WO58_5PP200000`/L>5j9/mC[
n?goookkl]o2Vg179a460@000@D@94=[U[gLl?[nooonnNgG]hiS?1l=10400088
5Ba>N:?8hoCloooooOKWcZZ0ES8H2@<000032a/fFhJ_d^[goOooo__bh<>MLTTY
4`L200011@lS@VVD_=__n_koookikMNgSf@m80h40@000PPE;DmhXlSSm?cnoool
mNK=ZGmE<QP:0`000@@<73QMR;7Cj_Omooonn_7N`IY`AbLB1P8000464BI5KINn
g?3jo_oooOS[e;>:H3XN3@@100032APaE7fWbnGeo?koo__chlRTNE0^5PT20001
1@hP?VB>]]O/n?gooogik]VjTfQ18a050@000PPE:daeWlGQl__nooklmNK=ZX5G
<aX;0`400@@<7CQMQk3BjOOmo_onn_3M_iU_AbLB1`8000874bQ8Ki[0gO3jo_on
o?KYdJn6G3PM30@100442a/eFH>/c^Oeo?koo_[agl:MLd/Z50P20@021Q4VAFbF
_M__nOgoo_cgj]>bRElj7`d50@0110/J<eN0ZLcUm?cnookjlN34WgE=;1D80`41
0PHA9DAZUK_Jk_Wmo_klmn[C/XYP>al>1@410@@;6S=FP:W<iOCko_knn_7O`iie
CB`E2@<10@874RI4JiFlf^khoOkno?KYd[69GcXO3PD10@4431/eF86ZcNKdnokn
oOW`g/6LLT/[5@P30@421a<XAfjH_]_^nOgno_ceiln^QE`h7@d50@411@dM>5b5
[/oWmOcno_gik]^nV6i7:1<80`410`TE:dacWL;Nl?Wmo_kklnC;ZH1G=1/<1041
0PH?8CeRRk?CjOKlo_klmncG^95X@R@A1`810@@;6C1BNZ?7hO;joOkmn_7PaJ5h
D2lH2P@10@<74RI4JY>jf>cgo?knnoGXdK28Gc/P3`H20@853AdgFh>/cNKdnogn
oOS^fkfHKdPY50P30@432AH]CGBM`]k_nOgnoO[bhlVVOUDc6``40P421a4T@6J?
]MGZm_cno_cfjM>cS6<n8Q060P421@dL=ER0ZL_Tlo[mo_chk]^oVW5::aD90`82
10XF;4acW<3LkoSlo_gjl^;9YgiF=1/<1@810`LA945VSkGDj_KkoOgkmNSB/X]R
?R8@1`<10PD>7CMJPZ[<i??joOglmngJ_IM_B2XE2@@20P@;62m?MYo3g^oho?gm
nO3PaZ=jDc8J30D20P<84bM5Ji>ien_fo?gmn_?UcZf6GCXP3`H30P<7424lH8R_
d>OdnogmnoKZeKJ@J4<V4`P30P853A`eEWjVb>7anOgmo?O]fknJLT//5`X40P84
2aP^CWBL`=c^n?cmo?W`h<JSNe@c6``50P842A@XAV^C^MK[m__moO[ci<f/Q5dj
80l60`831a4S?V::/M7Wm?[moO_ej=:cSFE191880`831PlO>5^2ZL_Sl_WloO_f
jmNjUFe7:AD:10831@dK<e=jX/GOkoSloOcgkM_0W7A>;QP;1@<31@/H;TecVkoK
kOOkoOchkmo5Xg]D<a`=1P<210XE:TM]UKWGj_KkoOcilN;:ZH9J>1l?1`<210TC
9T9WS[CCj?Cjo?cjlnG>[XQP?B8A20@310PA8ciQRJo?iO?jo?cjm>OA/heU@BDC
2@@30`L@83YLQ:[;ho7io?cjmNWE]i9ZABPE2P@30`L?7SMHOjK7h?3ho?ckmN[G
^YI^BB/G2`D30`H>73ADNj;4g^ognockm^cI_IYbCBhH30D30`H=6c5AMik1g>gg
nockm^gK`9efD30J3@H30`H<6Bm>M9^of^cfnockmnkL`Z1iDS<L3@H40`H<62i<
LIVlf>_en_ckmnkNa:9kEC@M3PL40`D;62e;KiNken[en_ckmnoNaJ=mESHN3`L4
0`D;5ba9KYFie^Wen_ckmnoOaZEnF3LO3`L410D;5b]8KIBheNWdn__kmnoOajEo
FCPO40P410H;5b]8K9>heNSdnO_kmnoOajIoFCPP40P410H;5b]8K9>ge>SdnO_k
mnoOaZEoFCPP40P410H<5b]9KIBhe>SdnO_jmnkOaZEnF3PO40P410H<62a9KYBh
eNSdnO_jmnkNaJ=mEcLO40P510H<6Be;KiJie^WdnO_jm^gM`j9lESHN40P510L=
6Rm<LIRkenWdnO_jm^cK`Z1iE3@M3`P510L>6c1?LiZmf>[dnO_jmN_J_iegDS<L
3`L51@L>739AMYfofN_enO_im>[H_IYdCc4K3PL51@P?7SEDNZ31fncen__im>WF
^YM`C2hJ3@L51@TA83QHOZ?4gNgfn_[hlnOC]Y9/BB`H30L51@TB8S]LPZO7gnkf
n_[hlNG@/XiXABTG30H51PXD9CmQQjc;hNogn_[gl>;<[HUS@BHE2`H51P/F:4=V
S;3>i?7gn_[fk]o8Z8=N?B@C2PH51`dH;4Q/T[GBi_;hn_Wek=c3XgeH>24A2@H5
20hK<4ibV;[Fj??hn_Wdj]RnW7MB=1h@20H62A0N=EAiW/3Ij_Cin_SbimBhUW1<
;a/>20D62Q8R>U^0YLGMkOGinOOai<nbSVU6:aP=1`H72aDW@F:8[<[QkoKinOK^
h<Z[QV509QD;1`H73AP/AfZ@/m3TlOOinOG/g<>SOUTi8Q8:1PH83a`aCg>H^]GX
l_Sin??YekbJME4c7A091PH:4R4hEgbQ`M[[m?Simo7UdKBAK4T]6Ph81PL;5BHo
H8FZb=o^mOWim^kPbZb8HT4W5P`71PP>6Ba8JXnbcnC`m_Whm>_K`Z9mFCTR4`X7
1`T@7S=AM9Vke^SbmoWgl^OD^YQcCc8M40T71`/D8c]KOjC4g>_dn?Sfkn;=/8eX
AR/H3@P720dH:TAVRjk<hNken?Sdk=c5YH5L?B@D2`L72A0M<TibU[SCi_7gn?Ob
imFkVWEA=1hA2PL72a@S>UYnX/;Jj_?gn?G_h/f`SFQ7;1T>2@L83QPZAFJ;[/_Q
k_GhmoC[flBTP5`l91D<20L:4AhcD7>H^MCVlOKhm_7Ve;VGLe0c7Q4:1`P<5BDm
GH6Ua=_[loOgmNgPbZf:ID@Z60h91`T?6Re9JXnac^;_mOOgl^WH_imkF3TR50/8
20/C8CMFNIfmenSbm_Oekn??/i5/BblL40X82@hH:D=TR:_9gncdmoOcjm_4YH9N
?RHF3@T82a8O=51cUkSCiO3fmoG`iM:gUW9?<ahA2`P93ALW?en3Y/GLjo?fmo?/
gLNYQV92:AP>2@P:4AdaCFnC]M3SkoGgmO3Ve;ZIME<f81<;20T=5RHmG82S`][Y
l_KflncNbJ^9ID@[6@l:20/A7C1;KI6cc^;^m?Kel>KE^i]gE3LQ4``92@dF9CeL
Oj;1fNWbm_Kck=k9[8UUAB/J3`X92a4M<4a]TK?>h^kdm_G`i]BkVWMD=b4D30T:
3QHV?Ub0Xl;IjO7em_?[gLRZR6A4:aT?2PT;4QhbCFnC]<oRk_Cfm>oTd[VHME8f
8A<<2@X>62Q0Gh:U`m[Yl_Gel^[KaJN5HD8Y6@l:2@`C83EALiJgdN?^m?Kdk^;?
]IA`Cc<O4``:2a0J:dATQjW7g>[bmOGaj=S1XWmM?RLG3PX:3ADS>EIhVk_DiNod
mO?/gl^_SVY:;adA30X<4Ad_BVZ>[l_Ok??em>oUe;^KN5Hi8aD=2P/?62LoGH2R
`MSWl?CelNWKaJR6Hd@[6Q0;2PdD8CEALiJfd>;^loGckN7>/i=`CS<O4`d:314L
;DIVRJ_7g>[am?C_i]FmWgaJ?2HG3`/;3aLV?E]mX;kFi^odm?7Yg<JZR6E6;A/A
30/=524eD76D]LoQkO?dl^cQc[BCL4ld81@=2``A72i7IhV[amcZlOCcknGD_9ik
FC`V5`l;30lH:3mLOj6oe^K_loC`j=[4YhISA2`K4@`;3QDS=e=dUkO@h^gbm?7[
gl^`Sfe=<QlC3@/=4ahaBf^>[/[Nj_7dl^gRdKRIMUDi91H?30`A6b]4HXBV`mWW
l??cknKF_j5oGClY6A0<310H9ceJO9jle>C^l_?`j=[5ZHMUARhL4Pd<3aHS=e=d
U[G?hNcblo7Zg/Z`Sfe=<b0D3P`>520bC6b>[l[Mj_7clNcQckJFM5@h8aH?30dB
7Bi6IHNXaM[Xko;bkN?C^iekFSdW6A0=3A4J:T5OPJ:oe^G^l_;^i]O0Xh9P@R/K
4Pd=41PW?EUjW;[Bhngal^oWfLBXR6I7;adC3Pd@5b@iE7FG]/oPjo7bl>WLb:f=
Jd`b81@?3@lF8SE@L9:abmkZl?;`j]k;/I9`D3DR5Pl=3aDP<Ta[SJg8g>S_l_3[
h<jeUWAD>B@G40d?51h`B6N9ZLGIinoalNcQd;RJN5Pl9aTA3PhC7Bi6I8FV`]OV
k_7ak>;B^ielFchY6Q8>3Q<L;4=QPZ>oeNC]lO7/hmBmX7mN@BXK4Ph>4Q/[@Eio
X;gDhnc`lNgTeKnRPF13;1`C3`hB6bXoG7fN^m;Rk?3akNGF`:B3HTD]7A@?3a8J
:CiKNibjdN7[l?3]iMO1YHETARhN50l?4QXX?UUjVkW@hN_`l>gUel:VQVE7;alD
40lB6RPmFGVJ^=3Pj^o`kNGG`ZJ6IDL`7aD@3a8J:3eINIZgcn3Zko3]iMO2YXIU
B30O5A0?4QXX?EUiV[O?h>[_l>cTe/6VQVE7<1lE40lC6bTnFWZJ^<oPj^o_k>CF
`JF5I4L_7aD@41<K:SmKNi^id>3Zkno/hmFoY8ASARlO5A0@51`[@5alWK[AhN[_
kn_Se;jRPV55;QhE410D7Ba2GWjO^m;Qj^o_jn;B_:1oGd<]7A@@4ADN;TAQPJ6m
dn;[knkZh=2jWGeM@B/M514A5Ql`AfB4Y;oEhn_^k^WOc[NJNEXn:Q`D4A4G8C9:
IhRW`]KTjnk]j=g<]9IfES`X6a<A4QPS=De[Rj[5f>G/k^gWflV`TW5C>BHJ4a4C
6BDhDG2@[/OJi^c^k>GIaJb=KDlf91TC4A@K:3]FM9FbbmcWkNk[hmK2YhQXBc<R
5a8A5Ad[?e]jV[O>g^S]kN[QdkfRPV=6<20F4Q8F7bi4H82O^m7PjNg]j=o?^9al
GD4/7QDB4aLR<TUVQZG0e>;ZkNcWg<^cUWIG?BTL5A8C6BDgCff=ZlGHi>_]jnGI
aZf?Ke4h9QXD4Q@L:3aFM9BabM_Vk>gZh]G0YXMWBc<S61<B5Qh]@UelVkS>g^S/
k>SOd;ZNOf14;b0G4a<H8S98IHBS_]?QjNc[i]c;/iIgF3hZ7ADC51XU=e1]SJ_4
en?Zk>[TelF[SFi@>2HK51<F7BXnF7JF//[Ki^_/jN3B_Z>4IDTb8QPD4aLP<4EQ
P9njd=oXjn_Vg<bfVWYL@BdO5a<D6RDfCVZ:Z<;Eh^W/j^CHaZf?L5<j:1`E51HM
:SeGMIBabM[Uj^_Xh=:nXhEVBS<S6A@D624`AV60W[[?g^O[j^KLbkFINU]1;AlG
51DK9SM?K8^Y`]GRjN_Yh]K4Zhe^DCTW71HD5al/@5YhUk?:f^GZj^ONd;ZPPF97
<B8I5ADJ8c=:IHBR_M7Oin[Yi=W8/9=eEch[7QLE5adY?5EbTJk6en?Yj^OPd[jU
QfQ<=BDK5QDI8S56HGnM^<kMi^[Yi=[:]9QiFd4]81PE5Q`X>E5^SJ[3eN7Xj^OP
e<6XRV]?>2LL5QDI8Bm4GWbJ]/cKiNWYiM_;]YYlGT@_8ATF5a`W>51/RjS1e>3W
jNOQe<:YS6eA>BPM5aHI8Bm3GG^I]L_Ji>WYi=_<]Y]lGd@`8QTF5adX>E1/RZO0
dn3WjNOPe<6XRfeA>BPM5aHJ8S14GWbJ]L_Ji>SXi=[:]9UkGT@`8QXG61hY>U9^
S:W1e>3Wj>KOd[nVRF]?>2LM61LK8c97HGnL]lcKi>SWh]S8/IIhFd8^8AXG6Al[
?EEbT:c4eN7Wj>GMckbRQFM<=RHL61PL9CE;IH>Q^/kLi>SVhMG4[I5cESh/81TG
6R4^@EYgUK77en;Win?Jc;JLOf57<R@K61TN:CU@K8ZV_m;NiNOUg]:oYXY/D3XY
7QTH72@cAf9oW;K;f^?Wi^7Ga[2DMeY1;R8J61XQ;D1HM9:^aMGPi^OSflbhWX5S
BC@U71TI7RTiCf^8YKg@gNCWiMkA_jN:KE4k:QlJ6A`U<dQROibfbmWRi^GPe/F_
TgII@BhR6aTK8Rm1FWJC[lGFh>GVh]W:]YaoHTPc9AdI6R0[>e9^RjNodMgTi^?L
ckbSQfU?>BTO6QXN9cM<IX>P^LgKhnKTg]?1ZXiaECh/8A/J7BDbAUmlVK?8en7U
iN3Fa[2EN5a3<2<L6Q`R;d5IMI:]a=COi>GQf<ZeVgmRB3@V7QXK8B`mE6n<Z;oA
gN?Uh][=^Z65J4hh:AlK6alY>DmYQZ:kc]_RiN?Ld;jVRVeB?2/Q6a/N9cI:I86M
]/[IhNCSgM;1ZXmbEd0^8Q`K7RHcAf1lV;;7e^3ThmkDa:jDMe]3<B@M6adT<DAL
MiB_a=CNhnCOe/NbV7]OAS<V7Q/M8bm1F7B@Zl;BgN?Th=O9]9]oHdTe9alL7B8^
?eE`SJRod=cRhn3Hb[NNPVI<=bTP71dR;3eCKXZU_LoKhN?PfLbiX8AXCSTZ8A`M
8B`kDF^8Xk_=f^7ShMW=^Z:7JU0k:b4M7B4[>U1ZQZ6ic=WPhn7JcK^SR6aB?2`R
7AdQ:cY?J8BP^<_Hh>?Qf/jlY8U]Dcd]8adM8BXiCVR4WkO;f=oRh=[>_:F:KU<n
;B<N7B4Z>DiWPingb]OOh^3Jc[bURViD?RhS7QdR:cY>Ih>O]l[Ggn;PfLflY8Y^
E3h^8ahN8R/jCfR4WkO:emoRh=W=^jB9KE<m;R<N7R8/>e1YQJ2hbmOOhMoHc;ZR
QfaB?BdS7QhS;CaAJhJQ^L_Hgn7Oel^hXHIZDC`]8alO92hnDff8Xk[<f=oQg]K9
]Yj3J4lj;2<O7bD_@5E_RjFlcMWOh=gEakBLP6E=>B/R7b0V<D9HLXjX_/oIgn3L
e<FaVGeRBSLZ8QlQ9c=5FgJAZl3@f]oPfm;3[YEjGdLe:B4O8BTeB5mjUJk3d]_O
gm[@`:ZAME]4<bLQ7b<[>4]SOYVbaM?LgmkHcKbVS75G@C4V8B0T;C]?J8>N]LSE
gMoMe/ZhXHM/Dch_9B0Q9BloE6f8XkW;emgOg=C7]9b1IThj;2@P8BLb@eUcSZRm
c]SNg][A`jnFNf59=bXS82<Z=TQONIB]`]3Jg]kHc[jYT7EKAC@X8R4T;3Y>IX2K
/lKCfmkMe/ZiXhU^ED0`9R8Q9S0oE6f8X[S:e]cNfm?6/ib1Idlk;BDQ8bTdAE]d
SjRmcMSMgMW@`JbDNEm8=bXS8B@/>D]ROIN_`m7JgMcFbk^US75H@S8X8b8V;ciB
JhFO]/SDfmgKdlJdWH=XD3d_9R8S:CA5FWB>Ykc<emcMf<o0[9AiGdTg:b@R9Bdj
C6=mV:o3dMWLfmG:^J>:L5M2<RPS8bLa@5E]Qj6gb=CKg=WAa;6JP6I>>bhV8b@[
=dQNMi:Z_/gGg=_Fc;fXSgELASDZ92<W;ceAJ8:L/lGBfMcJdlJdWXAZDSl`9b@T
:SE5FgB>Y[_;e]_KeljoZi=hGdTh;2DT9bllCVIoVK33d=SKf]?7]Z27KEE1<RPT
9BXdA5UbS:Bjb]CJfmO>_jbDNV5:>BdV92L_?4iUOYR_`/oHfmWCakJPQfeE@C8Y
9BDZ=DAILXbT^LWDf][FcKn[TgYPBST]9RDX;ce?IWnI/<;?em[Hd/JeWhI/E44b
:BDV:cI6FgB=Y[[:e=WJeLbmZI5gGTTh;BLU:C4oDVV2Vk;4d=OJem33/Y^2JE8o
<BTV9bdiBEmhTJVmbmGIfM?9^JF=Le]6=R`W9RXd@UI^Qj2ea]7HfMK=`:fFOFA>
?30X9RP`?4iTOIN]`<gFfMOAaKBOQVeF@S@[9bL]=dMLM8jV^/WCf=SCb[^WSgIM
B3P]:2L[<d9EK8FN/lC@emSEcL2^UgiUCcda:BLY<3e>I7fF[Ko=eMSFd<BdWXI]
ET8d:bLX;SU9GGF?Y[[9dmOGd/RiYHedG4Ph;RPX;3E4Efn7X;G5d=KGe<^mZiAk
HTdl<2TX:c=0DVR1VJo1c]GGeLk1/9Z1JE90<b/X:S0lCF=kU:Zmbm?Ge]34]9n7
KUM4=RdX:BliBEieSZFib=;Fe]77^:B<Lea8>2hY:BdgAUU`RJ6eaM3Ee];9^jRA
N61<>c0Z:B`e@eE/QIfb`/kDe]?;_Z^EOFA??S8[:B`c@59XP9V^`<cCe]?<`:jI
P6QB@3@/:B/b?TmUOIF[_L_Be]C=`K6LQ6]E@cD]:R/a?DeRNY:Y^lWBeMC>`k>N
QViHACL^:R/a?4]PMi2V^LSAeMC?a;BPRG1JAcP_:b/`>dYNMHjT^<K@e=C?aKFR
Rg9KB3T`:b/`>TUMM8bS]/G?e=C?aKJSS7AMBCX`:b/`>TQLLh^R]LG?dmC?aKNS
SGENBS/a;2/`>TQKLXZQ]LC>dm??aKNTSGENBS/a;2``>TQLLXZQ]LC>dm??aKNS
SGENBS/a;2`a>TULLhZQ]LC>dm?>aKJSS7ANBS/a;2`a>dUMLh^R]LC>d];>a;FR
Rg=MBS/a;Bdb?4]NMHbS]/C>d];=`kBPRG9KBCXa;Bdc?DaPMhjT]lG>d]7<`K:N
Qg1JAcXa;Bhd?TiRNI2V^<K>d]7;`;2LQFeHAST`;Ble@51UO9>X^/O?d]3:_ZfI
PV]EA3P`;Blf@U=XOiJ[_<S?d/o8_:^FOVMC@SH`;S0hAEI[PYV^_/W@dLk6^JNB
NfA@@3D_;S8jB5Y_Qifa`<_@dLg4]Z>=MV1=?S@_;c<mBeidRj6d`/c@d<_1/Yn9
LEa9?3<_;cE0Cf=iT:FgaLg@clVn[YZ3K5M6>C8_<CM3E6QoUJZkalk@c/JjZIAm
Ie=3=c4_<SY7FFj5VjnnbLo@c<>fY8igHDho=C0`=3i<GWB;XK?1blo?b/2aWXQa
FdTl<c0a=d9AIG^BYkS5c<o=ak^[Uh1ZEDDi<S0b>TIGK8:I[;c7c/o<`kJTSgUS
D44f<C0e?TaNM8ZP//3:c/k9_k2MQg5LBSdd<C8h@e9VO9:W^<C<c/c6^ZVEOfUE
ACTc<C@lB5U^Q9Z^_LO=c/[1]::<MV5>@3Hb<SM0Cf9gSJ:d`/[>cLNl[9V3KEU8
>c@a<cY6Ef^1UjZja/c=b/:fY91iI552>38b=Sm=GgB;X;;0bLg<akf^VhE_FdXm
=C8d>TEEJGnEZKW4blg:`[JUTG]UDT<i<c8f?deOM8ZO/Ko8c<c7_JjKQW1KBSdf
<c@kAUIYOiFX^<C;c<W2]JB@NVEB@cTd<cM0CV1eRj2a_lS<blJk[9Z4KUY:?CHc
=Ca7F6^1UZZia<[<b<2cXXihHe12>C@d>D9@HgR=X[?0b<_:a;VYUX5[F4Pl=S@f
?TYKKhFJ[;_5b/_7_[2NRGAOCT0h=3DkAEAWO9:V]/;9blS1]JFAO6MDAC/e=3Q1
Cf1eRYn`_/K:b/BjZiR3KUY:?SLe=ci:FVj3V:^ja<W:a[f`WhYeH4m2>CDf>dIE
IgbBYKG1b<[8`;BTT7]VE4Dk=SDj@U1RMX^O/Kk6b/S3^:VFPFaIBChg=CQ0C5e`
QYZ/^/C9bLBk[I^7LUi=@CTf=ci9F6^0UJRg`/S9a[faX8agHU53>cHg?4IEIg^@
Y;BoalW6_kBTT7]WEDHl=cLkA55SMhbP/Kg5b<O1]ZNDOf]HBChh=cY2Cf1cR9b^
^lC8al:hZYN3KU];@3Tg>D5=GG25VJ^i`/O7`kZ/VXIaGTi2>SLi@4]JKH:FZ;O1
alO4^jjMRGAQD4<k>3ToBEQ[OiBV]L36alBl[in;MV=BA3`h>Ci8EfUmTZBd_lG7
a;b`X8ehI5=6?CPi?TQFJ7b@Xk>naLO4_K6QSWUVE4Lm>CTnAeEWNhnR/[g4a/Bm
/J:?NVIEAchi>Ci7EFIjSj6a_LC6a;faXXmkIeE8?SXj?TMEIWZ>XK6l`lK4_K6R
Sg]WETPo>SXnB5EWNXnQ/Kc3a/>l/J6>NVMEB3lj>Sm8EVQkSj:a_<?5`k^`X8ei
IUE7?cXk@4UGJGb@Xk:m`lG2^jnOS7QUE4Ln>S]1BeUZOY:T/kg3aL6i[If:MV=C
AShk?49<Ffb0U:Fd_/?4`;R[VhQdHE55?S/m@diMKh>FYkFo`lBo]ZVHQG5OCd@m
>ci5D61bQYVZ]ko3`kjdYYF2KUa=@cdk?dICHgF9W:bh`<?2_;:STGi[FD]2?Ca0
BEIVNHfO[[[1`l6j[j2=NVMFBD4l?D9;FFYnTJ>a^l73_kR[VhUeHe=7?c`nA4mM
Kh:EY[Bm`/:n]JRGQ75OD4Do?Cm7DV9dQiZZ][o2`K^aXi9oK5Y=@chm@DYFIgZ=
Wjji`<;0^JfNS7UVETY1?Ci4CE]]Oi:T/[_1`KjeZIR6Lf5BAd0n@4MBHG>6V:Re
_L70^k6STWm]G4i4?ci2BUMWNXfN[KRo`Knh[9f;N6IFBT8n?dE?GFj1TjBb^l30
_;BWUXAaH556@3i1BEATMHRJZ[Jm`;ni[j2?O6YIC4@o?dA=FV]mT:6_^Ko0_KFY
VHMdHU=8@Cm1B5=RLhJHZ;Bl`;ni[j:AOVaKCTE0@4A=FVYlSj2^^;jo_;FYVXQe
I5E9@T12B5=QLhFGYk>k_kji[j6AOVaLCdE1@4E=FVYlSj2^^;fo_;BXVHMeHeA9
@d12BEASM8JHYk>k_[fh[Z2?OF]KCTE1@DI?G6anT:6^^;fn^[:VUXEbHE=9@d54
BeIUMhVJZKBk_[bfZif<NVQICDE1@TQBGg22U:B`^Kfm^:nSTX5_GU58@T96CUYZ
NhfN[;Jl_KZcYiR7MFAEBdA2A4]FI7F7V:Nc^[fl]Z^NSG]YFTi6@T=8DUm_PI>S
[kRl_;R_XY:0KemAB4=3AdmKJgb>WZbf^kbi/JJGQWASED]4@dE<F6IgRIZX/kZl
^[BYVhYhIeU=AT=5BUERLhFFYK6h_;^e[9j>OF]LD4Q4A4UBGfn1TZ6^]k^k]jjQ
TX1_Ge99A4A8D5a/OHjN[;Fj^kN`Y9F4LV9EBdE4AdmJJGZ;W:Vc^K^h/JJGQWEU
Eda6A4M>F6MgRIVW/[Rk^;:WVHUhIeU>AdE6CEMUMHJGYK2h^[VcZI^;NVUJCdQ5
ATaFHg>5UJB_]kZi/jZLS7][G519ADI<EF9bPiBS[[Ji^K>ZWHilK5eABDI6BeEQ
LH:CXZfe^KRdZYj>OFeNDTY6Ad]DHG61TZ6]]KVh/j^NSgi]GU9:ATM<EF5`PI:Q
[KFh^;>ZWXinKEiBBdM7C5EQLH:BXJbd^;RcZYf>OFeNDT]7B4eFHW62Tj6]];Rg
/ZVLSGa/GU9;AdQ=EV=cPi>R[KBh]k6XVhakJeeBBTM9CUQUM8FEXjje]kJ`YiZ:
NVYLDDY8BDmIIWJ6UZB^]KNe[jFHR7QXFU1:B4Y@FfQhR9RU[kFg]:jSUHIeIUU?
BTQ;DUe[Nh^JYk2e][>/XI>3LfAGCTU9C5AOKWj>WJVa][JbZYj@P71QEDe9BDiF
HW61TIn[/[Je/:NKS7a/GUA<BDY@FFIeQIBR[;>f]:jUV8QhJEaBBdU<DUaYNHVH
YJjd]K>/XIB4M6EID4]:CEEPKWf=W:R`];FaZIf?Og1QETi:BdmHI7:2TYnZ/KFd
[ZFIRWY[GU==BTaBG6QgQiJS[K>d/ZbQU8EeIUYAC4]>EF1^OHfKYjnc];2XWHmo
L69GCd]<D5UULh>BX:Za];:]Y9N9NFYMDde;CEANJgZ9V:B]/[>`ZInAPW=UFE5<
C51HHg60SifX/;>b[ZFIRg]/GeE>C4iCGFUhQiJR[;6c/:ZPThAdIUYBCDa@Ef9`
OhjLYjnb/ZfUVX]lKF1FCde>DeeYMhNEXZ^a/[2YWi:4MFIKDTi=DEQSL7n>W:N^
/[6]Y9V;O6ePEU1=CeANJWV8UZ:[/;:_Z9jAPW=UFU9>CU9JIG:1T9fW[[6`Zj:F
R7U[GeE@CU1FH6ekRYRS[;2a[JJKSWmaHeUBCTmDG6QfQ9>OZJna[jVOThEfJ5aD
CdmBFF=aOhjKYZf`/:^SUhYkKF1GDDmAEV1/NXVGXZ^_/:fVVhj0LFAJDdm@EEeX
MXFCWjR^/:jXWY:4MFQME51@DeYULX2?VjJ/[jjZXIF8NF]OEe5@DUQRKgf;V:>[
[jn[XiR;OFmRFE9@DEMPK7V8UJ6Y[Zn/YI^>P79UFeA@DEINJGN5TijW[Jn/YYfA
PgAWGEEADEELIgB2T9bV[:j]YijCQGMZGUIBDEAKIG:0SYZTZjj]Z:2DQgU[H5MB
DEAJI71nS9VSZZf]ZJ6FRG]]HEUCDEAJHfmmRiNRZJf]ZJ6GRWa^HeUDDUAIHVil
RIJQZJf]ZJ:GRge_HeYDDUAIHVikRIFPZ:b/ZJ:HRge`I5]EDUAIHVejR9FPYjb/
ZJ:HRgi`I5]EDeAIHVejR9FOYj^/ZJ:HRgi`IE]EDeEJHVikR9FOYj^/Z:6GRge`
I5]EDeEJHfikRIFPYj^[Z:2FRWe_I5]FE5EKI6mlRYJPYj^[YinERG]_He]FE5IL
IG5nRiNQYj^ZYYjDQgY]HUYEE5MMIW9oS9RQZ:^ZYIfBQWQ/HEYEEEQNJ7B1SYVR
Z:ZYY9^@PgIZH5UEEEUPJWJ3T9^SZ:ZXXYV>PGAXGeQEEUYRK7V6TYfTZJZWX9N;
OW9VGEQEEeaTKgb8U9jUZJVUWYB8NfmTG5MFF5iWLWn;Uj2VZJRSW965N6aRFeMF
FV1ZMX:?VJ:WZJNQVHj1MFUPFUMGFf=]NHJBW:>XZ:FOUHYmLFINFEMHGVIaOHZE
WjFXYj>LTXIiKF=LF5MJHFYePXjIXJJXYZ6HSX5eJV5JEeQLI6ijQY:LXjNWY9jD
RGeaIUiIF5YOJ7=oRiJOYJNVXYZ@Q7Q/HeaHF5aSK7R4T9ZQYZNTWYJ;Og=XH5YH
FUmWLGf9U9fTYZJRVi65NFiTGEUIG69/Mh>>VJ2UYZBNUX]oLfUPFeUJGfMaOHVD
WJ>VYJ6JTHEiKVANFUUMHfagPhjHX:FVXijERgmcJF5KFE]PJ79nRIBMXjFUX9V?
Q7Q]I5iJFUiTKGV4SiVPY:FRW9>9OG9XH5]JG65ZM82;UIfSYJ>OUhf2MVaSGEYK
GfI`NhNAVZ6TY:6JTHIjKfIOFe]NI6egPhjGWj>TXYbDRWicJF5MFeeRJWAoRYBL
XZBSWYN=PWM/I5iKG61WLG^7TIZPXj>OVI25NVmVH5aLGfE^N8B>V9nRXj2KTXQm
LVUQGEaNI6afPHbEWJ:SXIbDRh1eJf=NG5iRJW=nRI>KX:>RWIJ=PWM]IEmMGF5X
LGb7TIZOXZ:NUhj4NFmVH5eMHFM`NXF?V9jRXYnHT8IkL6QQGUePIVmiPhjGWJ6R
WiVAQgabJF9NGF1UKGN2S9JLX:6OVY:8OW=ZHemNH6E]MX6;UIbPXInJThUoM6]T
GeiPIFafP8^DVinQWiZCRWmeK6APGV1UK7F0RY>JWj6OVY>:P7E/IF1OH6E/MGn:
TiZOX9nJThZ0MFaUH5mPIFaeOhZCVYjPWYZCRWmeK6EQGf5UKGJ0RY>JWZ2NVI:9
OgE/IF5PHFI]MX2:TiZNWijITXQnMFaUHF1RIfigPH^CVYjOWIRAQgidJfEQH69W
KgR2S9BJWYnLUhn6O7=[I65QHfQ`NH>=UI^NWY^FSXEkLVYTHF5TJW9kQHjFVijN
VYF=PgU`JFAQHVE[Lgf6SiNLWYfITh^1N6mXHf5RIVeeOhRAV9bNW9RARGmfKFMS
HV=XKgN1RY:IW9fKUXn6OGA/IV=RIFYaNX><U9ZMWIZDSHAjLVYUHV=VK7AmQXnF
VYfLV9::PGQ_JFASI6Q^MWn9TINKW9^FT8MnMFeWI6=UJW5iPX^CVIbLVIB=Q7]b
JfISI6M/M7f6SYFJW9^GTHZ1N71YIF=UJFmgP8VAUiZKVYF>QWedKFMTI6I[LW^4
S9>HVi^HTX^2NG5[IVAUJ6ifOhN?UYZKVIF?QgifKVQUI6I[LWZ3Ri:GVYZHTX^3
NW9[IfEUJFifOXN?UIVJVIF?QgmfKfUVIFM[LWZ3Ri:GVYZGTX^3NW9/IfEVJFmf
OhN?UIRJV9B>QWifKfUVIVQ/Lg^3Ri:GVIVFTHZ2NG9[IfIWJW1hP8R?UIRIUi>=
QGeeKVUVIVU^MGf5S9>GVIREShR0N71[IfIXK79jPXZ@UIRHUY6:Pg]cKFUWIf]`
Mgn7SYBGV9NCSHEmMFmZIfMZKWEmQHbBUYRGU8j7P7QaJfQWJFecNX::T9FGUiF@
RH9jLfeYJ6U/LGR0R8nDUiNETH^4O7E^JVQXJg1gOXJ=TYJGUY:<QGifL6]YJ6]_
MGf4Ri6EUiJCSHMoN75/JFUZKWAkPhZ@U9JFThj8PGUbKFYYJVicNX:9Si>FUY>?
RH9jLfiZJFY]LgV1R8jCUIJDShV2NgA_JfUZKG9iP8N=TYFEU92:PgaeKf]ZJVeb
N7n6SI:DUIB@RXAlMW1/JVY]LWQoQXbAU9FCT8Z4OGI`K6Y[KG9hOhF<TIBETi2:
Q7efLFe[JfebN7j5S92CU9>?RXAmMW5]Jf]^LWQoQH^@TiBCShZ4OGIaKF]/KW9h
OhJ<T9>DTXn:PgefLFe[K6mcNGn6S92CTi:>RH=lMW5]K6a_M7V0QXb@Ti>ASHR2
NgE`KFa]L7AjPHN<T9>CTHf7PG]eL6e/KG5eNh:8SI6BTY2<QX1jM71]KFiaMWb3
RHfATY:?RhEoNG=_KFe_LWQnQ8V>TI:ASXZ4OWQcKfe^L7AiOhF:Si6BT8f8PWag
LVm]KW5eNX26RhnATHn<Qh5kMG5_KVmbMWb2R8b@TI6>RXEoNGA`KVi`LgQnQ8V=
T96@SHV3OGQcL6i_LGEjP8F:SY2@Sh^7PGafLVm_L79gO8:7S8n@T8j:QGmjMG5_
Kg5dNGj4RHf?T8n<R8=mN7=`Kg1bMW^0QXZ>Shn>RXJ0NgIbL6maM7QmPXR<SXn?
S8R3OWUdLG1`LWIjOhF9SHn?SHZ6PGagLg5`LGAhOH:7Rhj?SXb8Q7iiMG9`LG9f
NWn4RHb>SXf:QX5lMgAaLG9dN7f2Qh^=SXj;R8=nNGEbLG5cMW^0Q8V<SXj<RHF0
O7MdLW5bMGUnPXN;SHj=RhN2OWUeLg5bM7MlP8F9S8f=RhR4P7]gM79bLgIjOh>7
Rhf=S8V6PGehMG=bLgEiOH:6RHb=S8Z7PgijMWAbLgEhO824R8^<S8^8Q81kMgAc
LgAgNWn3QhZ<S8^9QH5mNGEcLgAfNGf2QXV;S8^9QX9nNWIdLgAfNGb1QHR;S8^:
Qh=oNgMeM7AeN7b0Q8N:Rh^:QhB0O7QeM7AeN7]oPhJ9Rh^:R8B1OGUfM7AeMgYn
PXJ9RX^:R8F1OGYgMGAeMgYnPHF8RX^:R8F2OWYgMGEeMgYmPHB7RHZ:R8F2OW]h
MWEeMgUmP8B7RHZ:R8J2Og]hMWEeMgUmP8B7RHZ9R8J2OgaiMgEfMgUlP8>6R8V9
R8J3OgaiMgIfMgUlP8>6R8V9R8F3OgaiMgIfMgYmP8>6R8V9QhF2OgaiMgIfN7Ym
P8>6R8V8QhF2OgaiN7MgN7YmP8>6QhR8QhF2OgajN7MgN7YmP8>5QhR8QhB2Ogaj
N7MgNG]mP8>5QhR7QXB1OgajN7MhNG]nPH>6QhN7QXB1OWaiN7QhNWanPHB6QhN7
QH>1OW]iN7QiNWaoPHB6QhN6QH>0OG]iN7QiNgeoPXB6QhN6Q89oOG]iNGUjNgf0
PXB6QXJ5Ph5oOG]iNGUjO7j0PhB6QXJ5Ph5nO7]iNGYkO7n1PhF6QXF4PX1nO7Yi
NGYkOGn1PhF5QHF3PGmmO7YjNW]lOX22Q8F5QHB3PGmmNgYjNW]mOh62Q8F5QH>2
P7ilNgYjNgamOh63Q8F5Q8>1OgilNgYkNgenP8:3Q8B4Ph:0OgelNg]kO7eoPH:3
Q8B4Ph60OWelNg]lOGj0PH>3Q8B3PX1oOGalNgalOGn0PX>3Q8>2PH1nOGalO7am
OX21PX>3Ph>2P7mnOGalO7enOh21PX>3Ph:1P7imOGalOGenP862PX>3PX60Ogim
OGamOGioP862PX:2PX60OgimOGemOWn0PH:2PX:2PH1oOWemOGenOWn0PH:2PX:1
P7moOWemOGinOh21PH:2PX60P7mnOWemOWioP821PH61PH20OgmnOWinOWmoP861
PH61PH1oOginOWinOgn0P861PH60P81oOginOWioOh20P861PH20P7moOgmoOgmo
Oh20P820P820OgmoOgmoOgmoP820P820P81oOgmoOgmoOgn0P820P820P81oOgmo
OgmoOh20P820P820Oh20P820P820OgmoOgmoOgmoP820P820P81oOgmoOgmoOgn0
P820P820P81oOgmoOgmoOh20P820P820P7moOginOgmoP820PH61P820OgmnOWin
Ogn0P861PH61P81oOginOWioOh20PH61PH60P7mnOWinOWioP821PH61PH20Ogin
OGenOWn0PH62PX:1P81oOWemOGinOh21PH:2PX61P7mnOGemOGioP862PX:2PH60
OWimOGemOWn0PH:2PX:1PGmnOGelOGenOh21PX>3PX:0OgimO7alOGioPH:3Ph>2
PX1oOWelO7amOWn1PX>3Ph>1P7mmO7alO7enP862PhB3Ph60OWelNg]lOGj0PX>4
Q8>3PH1nOGakNgamOh22PhB4Ph:1OgelNg]kO7ioPH>4Q8B3PX1oOGakNg]lOX22
PhB5Q8>2P7ilNgYjNgenP8:4QHF4Ph5oOGajNWYkOGn1PhB5QHB3PGmmNgYjNWan
P8:4QHF5Q8:0OWajNWYkO7j1PhB5QXF3PGmmNgYiNW]mOh:4QHJ6QH>0OWajNGUj
O7j0PhF6QXJ4PWmmNgUiNGYlOh64QHJ6QH>1OWajNGUiNgf0PhF6QhJ5PX1mNgUh
NGYlOh:4QXN7QXB1OW]iN7QiNgf0PhF7QhN5PWmmNWQhN7YlOh:4QXN7QXB1OW]i
N7QiNgf1Q8J7R8N5PWmlNGQgN7YlOh:5QhR8QX>0OGYhMgMiNgj1Q8N8R8N5PWik
NGMgN7YmP8>6R8R8QX=oO7UgMWMiO7n2QHR9R8N4PGejN7IfN7YnPHF7RHV8QH9n
NgQfMWMiOH24QhV9R8J3OgahMWIfN7aoPhJ9RHV7Q81lNGMeMWQkOX:6R8Z9R8F1
OGYgMGEgNWf1QHR:RXV6PWijMgEeMWUlPHB8RXZ9Qh=oNgMeMGIhO824QhZ;RXN4
P7]hMGAeMg]oPhN:RhZ8QH1lN7EdMGMjOX>7RX^;RHF1O7QeM7AfNWj2QXZ;RhV6
PGeiMGAdMWUmPXJ:Rh^9QX9mNGEdM7EiOH:6RX^<RXN2OGUeLg=eN7f2QXZ<S8Z7
PWeiMG=cMGQmPHJ:S8b:Qh=nNGEcLgAhO8:6RXb<RhN3OGUeLg=dN7b2QXZ<SH^7
PWehMG9bM7QmPXN;SHf;Qh9mN7AbLWAhOH:7Rhf=RhN2O7MdLW9dN7f3R8^=SH^7
PGagLg5bM7UnPhR<SXf;QX5kMW=aLWEiOhB9SHj=RXJ0NWEbLG9eNX25RXf>SHZ5
OgUeLW5bMW^1QX^>SXf9Q7ihM75aLWIlPXN<SXn<R8=mMg=`L7=gOH>9SHn>S8N1
NgIbL75dN7j5RXj?SX^6P7YdLG1aMGZ0QX^?Shj:Q7ihLg1`LWIlPXR=Shn=R89l
MW9_L79gOXB:SY2?S8N0NWA`Kg1dNH26S8n@Sh^5OWQcKfmaMG^2R8f@T8j9PWae
LFm_LWMnQH^?TI2<Qh1iLfm^L7AjPHN=T96?RXAmMW5^KW5fO8B:Si6ASHR1NWA_
KVmcNH27SI2AT8^5OWMaKVi`MGb3RXnATHj9PWYdKfe^LWQoQXfATY2<QGigLFi]
L7ElPhZ?TY:>RH9jLfm]KW9hOhN=TI:@S8EmMW1]KG1eO8B;T9:BSXR1NG9^K6ib
NH28SY:CT8^4O7E_K6e`MWf5S96CTXj7OgQaKFa^LgZ2RY2CTi2:PWYcKVa]LGMo
QhjBU96<QGeeKfa/KgElQHbAU9>?R81hLFa[KG9jPXZ@U9B@RX9jLfe[K71gP8R?
TiBBS8ElM6i[JfmeOHJ=TYBCSXMoMVm[JfecNhB<TYFDT8V1N75/JVaaNH::TIBE
TH^3NW9/JV]`Mh28T9BETXf5O7=]JVY^MGj7SiBEThj6OGE^JVY]M7b6SY>FU8n8
OgI_JVU/Lg^4SI>FUI29P7M_JVU/LGZ3S9:FUI6:PGQ`JVU[LGV2Ri:FUY:;PWU`
JfUZL7R1Ri:FUY><PgUaJfQZKgN1RY:FUi><PgYaJfQZKgN0RY:FUiB=Q7YaJfQY
KWJ0RY:FUiB=Q7YaJVQYKWJ0RY:GUiB=Q7YaJVMYKWJ0RY:GUiB=PgU`JVMYKWN1
Ri>GV9B=PgU`JFMYKgN2Ri>HV9B<PWQ_JFMYKgR2S9BHV9>;PGM^J6IYL7V4SIFH
V9>:P7I]J6IYLGZ5SiJIUi:9OgA/IfIZLWb7T9NIUi68OG=[IVI[Lgj8TYRIUi26
Ng5YIVM/MH2:TiRIUXj4NFmXIFM]Mh:=UIVIUHb1MVeWIFQ_NHF?UYZIThYoM6]V
IFUaO8NAV9ZHTHMlLFUUIV]dOhZDVIZGShAiKVMTIfegPXfFVYZES85eK6ITJ71j
QY6HViVBR7ebJFAUJW=nRYBJViN?QGU^IfAVK7N3SYJKVYF<P7A[IFAXL7^7TYVL
VI:8O71XI6AZM82<UI^KUhj3MfaUHfI^NHF@V9bJU8YnLVUTI6UbOXZDVibHT8Eh
KFISIFagQ8nHW9^ERgmcJF=SJ75mRIBKWIVAQGU]IF9TK7N3SiRMW9J;Og=YHf9W
LGf:U9^MVI65N6eUHVA/MhB@VIfLUH]nLFQRHVQbOX^FW9fIT8AgJfAQI6eiQY:J
WYbDRGa_IV5RJG>0SINMWIR>PGAYHV5UKg^9U9bNVi:6NFeTHF=[MXB@VYjMUX]n
LFIQHFMbOhbGWYjISh9eJF9PIFikR9BLWibCQgU/Hf1RJWJ4TI^OWIJ;OFmUH65W
Lh2>VInOVHj1LfQQH6E_OH^FWYnKTHAfJV9OHfaiQiBMX9fDR7U/HemQJGJ4TI^P
WYN;O6mTGf1WLh6?VZ2OVHeoLFIPGfE`OXfHWj2KT89cIf1OI6ilRiNOX9bBQ7EY
HEiRK7Z9UYjQWIB6MfYQGV5ZN8NDWZ6NUHQiJf9NH6UfQI>MXInGRWY/HUiPJ7F4
TYfQX9R;O6eSGUmWM8>AW:6PV8alKV=NGfIcPY6LXJ2IS7e^HeeNIW:2TIbRXIV=
OFiSGEiVLX:AW::QVXemKV=MGVEbPY6LXZ6JSGe^HUeNIW>2TIfRXIV<O6eRG5iV
Lh>BWJ>QVH]kK65LGVIdQ9>NXj6HRWY[H5aNIgF6U9nSXIN9NFYOG5mXMhNFX:BP
UXMgJ5iKGfYiRIRQY9nDQGEVGE]PK7^<VZ:TWY:3LVALFf9^OXjLXj>MT81_HUaL
Hg21TIjTXi^=O6aPFeaULhBDX:BRVHYiJEiJGVQgR9NRYJ6FQWEVGEYOJg^<VZ>U
Wi:2LF=KFf9_Oi2NY:BLSWe]H5YLI7>4UJ2UXiV:N6QMFEeXN8VIXjJQUHAcI5]J
H6emSifUYIj@OfePFU]SLX>DX:JTVXYiJ5eIGFQhRYVSYZ6EQ79SFUUPKGj@WZJU
WHmmK5mIFfAcQIJRYj>HR7IVFeQMJW^=W:FVX9:1Kf1IFF9`PYBQYjFKRgQXG5QL
IgR;VjFWXIB3L65IF61^PI>PYjJLS7YXG5MKIWN:VZFXXYF3LF5IF61^P9>QYjJL
SGYXG5MKIWN:VjFXXYF3L65HF61_PIBRZ:JLRgQWFeMKIgV<W:JXXI>1KUmGF65a
Q9JSZJFJRGETFEILJWb?WjRXX91mJUeFFF=dR9ZUZJBGQG5QEeMNKH6DXZVWWHah
IUYFFVMjSIjXZJ6BOfaMEUQRLhNIYJZUV8EaHEMFGVf1U:>YYif<MfEIEEYXNXnO
ZJVQTGeZG5EHHgF9VjNZY9J3KemFEUm_Q9NUZZNKR7AREeELJgnCXZZYWXehIEUD
FFMjSj2YZZ6AOFUKE5MSMXZMZ:^TUH5]GEEFH7:6VZN[YYV5L5mEEEe^PiNUZjRK
RG=QEUAKJh2DY:^YWXafHeMCFVQmTZ:[ZZ2>NFEHDeQVNXnQZj^RTG]WFE=GI7R=
WjZ[Xi=mJEYCEV9fRijZ[:BDOfYJDeEQM8ZMZZbUUX1[Fe=EH7>9WJV]YYJ1K5]C
E61bR9bY[JJGPVaKDeAOLXRLZJfWUh9/Fe9DGg:8W:Z]YiN2K5]BE5mbRIfZ[JNG
PF]JDUAPLhZNZZfVUX1ZFE9DH7B;Wj^]YYEoJEQAE65fSJ2/[JFCOFMGDEESN8nR
[JfTTGYUEU5FIGZAY:f]XXmhHeEAEfMmU:F^[:2<MF1CDEUZP9NW[j^NRG5MDU5K
KHBJZJnZVhE]Fe5BGG68WZ^_Z9N0JEQ@Df1eSJ6][jFCNfEED5ETNY:U[jjRSWIQ
De1GJ82GZ;2/WXUaG55@FVj6W:^`ZYV3JeQ@DUidS:6^[jJDO6EECeATNY:V[jjR
SGEODTmGJX:IZ[2/WHI^FU1@G769Wjf`Z9InIUE>Df9iTJF`[j>>MUmACUMYPIVZ
/JbMQVeICe1LLHZP[[6XUGaUE4iCHg^DYk6_XXacGE1>F6b5W:bbZiZ2JEI>DEmf
SjB`/:F@Mf1ACEEXPIV[/ZfMQFaHCTmLLhbR/;6WTgYRDTeDIWjGZ[:^WhM^FDi?
Fg6;X[2bZ9AkHU9<DfEnUjZb[in8KUU=CU]aRj:`/ZRDNV9AC5=VOiR[/jjOQVaG
CDiLLhfT/K:WTWMOD4aDJ8:K[K>]W8=YEDa?GWJAYk:bYHicG4i<Efb6WjndZiQn
I59;DF9lUZZd/:68KEM<CE]bSJBb/jRBMei?BeAYPif_]:fKP6ICBe1QNYFZ];6R
RViHC4aJLHfT/[BXTWMNCT]DJHBN[kF]VWmTDDY@HWbG[;FaX8M[ED]=G7B@YkBc
YXibFTa;Eff9X[:eZiEiGdi:DVN2WJne[Y^0IE5:Cf5lV:be/J26JUA:CEafTZVe
/jF<L5Q;BeQ`SJFd]JVAME]<BUE[R::b]ZbFNUm>BE9WPija]ZjJOV=?BE1SOi^_
][2NPVIABDiPNiR]][:QQVUCBDaMMiF[][>SRFaEBD]KMI:Z][BUS6iFBDYILY2X
][FWSW1GBTUGL8jW]KJYT79IBTUFKXbV]KJZTG=IBTUEKH^U]KNZTWAJBTQDKH^U
]KN[TgEJBTQDK8ZU]KN[TgEJBTQDK8^U]KN[TWAIBDQDKHbV][NZTG=HBDQEKXfW
][NZT75GB4QFL8nY]kNXSVmFB4QGLY6Z^;JWS6eDAdUIM9>/^;JURFYBATYKN9J^
^KFRQVM@AT]NNiZ`^K>OPV=>ATeQP9jc^K:LOEm;ATmUQ::e^JnGN5]9AU5ZRJJg
^JbBLeM7AeE_SjZh^:R=KE=6B5UeUJjj]ZB6Idm5BUilVk:j/iioHD]5CFB3X[Fj
/9QhFTQ5DF^;Z;RiZi1`E4I7Eg>C[KZgYHQXCdA9GGbK/[^dWWmPBTA=IHFS]k^_
UWEHAdECKXn[^[VYS6]AA4MJN9Va^kJQPF5;@daSPj:f^k2GMUQ7A59]Sj^j^JV<
Je14AeYiV[:l]J20GdY3CFF6YKRk[iAcEDE5E76C[[^iYXMVCD=9GgnO][bcVWUJ
Ad=@JhfZ^kZZSF]@@dMJNY^d_KFOOUe8@TeWRJRj_:f@KU93AEQfVK:m]j60GdU2
C6F7YkZl[Y9_DT=5EWFH/[fhXX5OBD9;IHNW^[f^TVmB@dAGMYVc_[NQOei8@DaV
RJVk_:f@K512AEUiW;Fn]YilFdI1CVZ=[;blZX]XCD57GGjP]kjdVGIFA49BL9>`
_[ZVQF99@4URQZJk_[2BKU52A5MhVkFo]imlFTE1CV^?[KflZHUUBT17Gh:T^[nb
UG5B@D=EMYZe_kRPOEY5@4eZSjjn_:V8I4Y0Af24Y[^o/I=^D453EgVM]l2gWGUG
@d1@KY>a_k^VPem7?dYURZ^m_Zf=J4/oAEf0Y;_0/iE`DD12EWRL]l2gWGUG@T1@
KiFb`;^TPEe5?d]XSJjo_ZZ9HdPnAf66Z;fo[i1ZC3m4FgnS^l6dUW1@?d5FNIjh
`KNLMUA1@59cVKG1^Z5lF48oCVfD/l6lYH5LA3i;JHn``;jYQF16?DQURjfo_jb:
HdLmAV67Z[o0[heVBCe5GXBX_/6aT6U;?D=LPJJm`K:CJd`m@UYoY;c2]9A]CCi2
F7fS_<:eUVi>?T5GO::l`[FGKdhn@EMlX[c2]YM_CSe0EgbR_<>fUfm>?D1GO:>l
`kFFKTdm@EQmY;g3]IE]C3e1FGnU_/>dTf];?49JPJNn`k>AJDTl@Uf4ZL32/HiV
Ac]4GhN/`L:_Rf=5>dERRjo2`Jb7Gd<kAfJ?//?0Z89K@C]:JiBea;jTOEHo?4e`
VKS4_9mgDSdmDGJO_<BiVW1=?3mFOJFna;FCJTTk@Eb4Zl73/8aSACY5Hhba`l6Z
Q5]1>TU[UKK5_ZAkE3hlCg>M^lFjVg9=>ciFOJFoaKFBJ4Lj@Uj7[L?3[XQN@SY7
Ii:eaL2VOEDm>dibWK_6^i]aCC/nEWjW`LFdT6E5>D=QRk74`Z^3FSljBVfH^LJm
X7E?>caCNjC0a[JCJ4Hi@En9/<C3[8AJ?cU9K9Ria[jPMDhj?5AlY/76]I5UA3Q2
HHbbaL:ZP5Lm>D]aWKc7^i]_BSTnF8:[`lFaRUi0>4IXUKS7`:=gCcXkDW^V`LNf
TFE4>49RS[C6`ZQmE3/iCWFQ_lNiUVU6>41NR[;6a:^1ES`hBg:O_/RkV6]7=cmL
R;36a:b3Ec`hBW6N_/RkVFa7=ciLR;76aJb2ES`hBg:O_lRkUfY5=cmNRk?7a:Yo
E3XhCGJS`LRhTfE3=T5RT;O8`ZIiCcTiDGbXa<ReSElo=TAYUk_9_imaBSLlF8F_
a/J^Q5Lk=dYbX<39^iIW@cI0HHngbL>VN4hh>E9nZlG8/hUK?CI7KIbob[fJJTDe
?Uj=]LW4Z7Y?>3QAOJ[5b;B:Fc`eAfjM_lZmV6U3=CmPSkO:`jEgC3LiE86^alR`
QELj=TYcXl;:^I9R?cA2IiNlbl2NKTHe?5^;]LW5ZGY>=cQAOjc7bK:6EcXeBG>S
`l^iTF4n=4=YVKk;_i][A3@mGi2hblBTM4Xe>EN6//W7[7i@=cI?OJ_7b[>7EcTe
BGBTa<^iSehl=4A/WL7<_IMU@3=0IINmc<6MK4@c?5n@^/c4Xg97=3YIR[K;aZQh
BcDhE8Bbb/R]ODlf=U1o[/W:/H9C=cE=NZ_8bkB7ESPdBWJXa/bfRUTi<dMcYLG<
^HeK>S=6L:?4c;Z@GC/bA6jQa<flTUll<T=]Wl?=_9=P?392K9o3cKfDH3`b@V^N
`lfmU60l<T9[Wl?=_I=P?392K:34cKbBGc/b@fjQaLflTEdj<TA`XlK=^XiK>C96
LZG7cKR;F3PbB7FXb<ffR5Df<dYi[<[</h=A=C==OZo;bk1oCS<dDH>cc<Z/NDXb
=UJ9^<k8Yg=5<CQKSkc>aJ5/@C0kHIK0cl:JICd`?fRNa<nnTehi<4=`YLS>^HYF
=S59NJg;cK>1CS<cD8>dcLZ[MdLa=UR=^lo7XVa0<3]RV<;@`IQR>Rm1KJ?7ck^<
EcHaB7V]blfbP4db<e:6]lo:Z794;cQMTl3@a9aU?2loJZ77d;b>F3D`B7V^c<jb
OT/a<e>8^Lo9YFm1;cUQV<?A`YIO>2m2LJS:ckN5D38aCX>ecl^ZLd<_=efE`M74
VF4i;T5_Y/[@^8IA<S5>P[K?bjUb@RhhGYO2dL>GGcP^@W:ZblnfPTd`<U68^]79
Y6`n;CYUW/KA_XmG=2m8O;7?cZihABheFi?1d/FIH3P]@G6Zc=2fPD``<U>;_=;9
XFPk;CeZXl[A^hQA<C1>Q;SAbjI]?RdjIIo8d[j=E38_Bh6fdLbYL40]>6:Mam:o
SeDb;TUo]M7=ZW50;3QRWLOC_hiE<Ri:PKKAcJU_?R`iI9o9dkj;DS4_CHBid/^U
JS`/>fVTbm:jQDd_<56;_]?9Wf@h;3maZlkA]Ge7;C=IU<?DaIIK=2a5Nk?Acjab
?b/gHio9dkj:D2l_CXRldlZQICP[?W2[cm6dNdD/<e^Ga]C3TUHa;DV1^=?=YVXj
:c]/Z<kC]gm7;39HULGEa9AG<Ba8P;SCcJIZ>RXkKJW>dkImAB/bFiS7eL:@Dc0]
BhFle<^QI3HZ?g>_dM6`MD0Z=V:PbmBmQT/];eB@`mG6UUTa:dN0^MC=YFLh:Sea
[M7B/WI0:SERXLcE_8E:;2mETlGFaI=E;ba:QKgEc:1Q=2Y1N;CCd:]]>RTiK:[@
e;Ei@BXdH9o<eKf5BB/_EYG7e/B@DRh/CH[1e/VJFS4ZAX2jeLjSHcDY?gNde=6[
K3TX>Vj]d]>bM3hX=VJVcmFhO48Y<UnOc=JmQ4LZ<5VIbMO1RT`[;E>Ca]O5T54/
;4j=a=O8UED^:TZ8`MO:VUT_:TN4_]O<WUda:DB0_=K>XF0b:49m^]K?Y68c:41k
^=K@YF@d:3mi]mKAYfDd9cih]]KAZ6Hd9cig]]KAZ6Hd9cig]]KAZ6Dd9cih]mKA
Yf@c9cmj^=K@YF<b9d1l^]O@Xf0a9d9o_=O>X5d`:4B2_]S=WEX^:4N7`MS;V5H]
:D^;a=W9Te4[:TnAamW6ST`Y;5BGbmW2QdLX;UZNc]RnP48W<F6UdMNhN3dV=6R/
e=JbL3PV>G6ce]>ZIS<V?WZjf=2RGBlWAHG1fLbHE2/YCI38f/J=BRP/EY_>fKn1
@RH`HZOBf;Id>RDfK[;Fe:aW<bDnO;cId9mJ;BM8R/GJbI5=:2YDVLgJ`8929S1R
Z=?H]G4h9CQb]MSCYf4_9T:3`][<Ue4Y:E2Ec=[3QD<U;f2WdmRfLSLT>7>gfM>U
GbhVA8O4fl^BCBPZEI_?f[im?R@bJ:oGeZiW<B@nO[oKciYC:BQ?ULgK`X=1931T
ZmKH/F/c93al_]_@Ve@Y9djEcM_2PT0T<6F]emN_J34T?Wo1fljGD2LXDY[@fkil
>b<cK;?IeJQP;BA4RLOLbHe79BaLYMCJ]Vld8cYj_]_@Ve8X9e2IcmboO3/S<ffe
f]FVGB/UAhk:gLJ7@R<^HjgGf:iU;b=1QLKMbhm792]LYmKJ]6`b8Sao`]g>U4/U
:ERSe=^gKc<R>Wc0gLnGCBDXEZ7DfkQa=28jNl3Md9M=9BQGX]CK^6lc8S]m`]g?
U4XT:EZUe]^eJc0R?H;5g/b?AR<[Gj_HfJmT;B92R/[Nb8M08RiX/][GYe/Y94ZD
cmk1NcTQ=7>lgM>LD2DWE:7Eg;Q^<B4lPLGNc8e48RaR[m[IZehZ8dRCcmk2NcPQ
=7FmgM:ICB@XF:KGfk=W;B51R/_Oah<l8C1^^MgEWe4U9UBRe]bfJRhQ?hS:glR5
?B0`KKWMeIiA92IEXmOL]FP]8D6;c=o6P3XP<W:mg]>HBb<XFj[JfjiO:B98UM7O
`7Dc83QnaMo=S44P;FRfgMNQDR@UEJCHgK=U:b54T=3O`WTe7cIlaN3>SD4P;6Vg
g]JOD2<VEjOIg;1P:B58Um?O_W4`7c^5b^39PSXO<GC0h=:CAB0ZI;CMf:9A8bEF
Ym[L/5lX8DVIeMnkKBdO?h_>h<Ek=1hfO/OQcHPl7bma_^3CUDDP:FBeg]RPCb8U
FZcLfjYH9B9@X]WN/f8X84RHeN2kK2`O@8oAhL9e<1hjQ/cQb7de7SEmb>7<QCXN
<GK3hM2=?Qh]KkkQdi=37bYY^^3FVDLO:6>fgmRNBb0VGk;NfZ=?8BEK[]gKYU8R
8eN[gMbYEB<SEJWLgJ]G8b9CYmcM[ETT8E6Vfmj^FR@QDJGKgZmJ925@YM_N[eXT
8E6Vfmj^FB<QDZOLgZeG8b9CZMgMZeDR8UJ[gMfXDR4SF:kNg:E?82AL/]oJXD/O
9F2fh=VLAahWI[[QeiM37BY/_n;DT3hL;G;3hm69>A``N/SScH4d73F2cN?8N2lL
>X_Bhl9_:ae1UMKR^VDV7TVOf^2bFb<PDZWNgZQA82=L/n7JWDLM9fRmhmF@?A`]
MLOTcX<d6cB3cnC6M2`L?Y;FhkaU9Qe9XMcP[eLQ8EN`h=bPBAdVIkgSeI0l6bih
bNC<OS4K>8_Ci<5[:1a5WM_Q/UTQ85J_hMbPAadWJL3Te8`h6S1ncNG8MR`K?YCH
hkUP8ai@Z]oNYD/M9FFmi=J>>AX_OLgUbGD[6cnFfN>gGB4ODjkQgJ1672M/`nGB
QS@J=HOCiL9Z9Qa8XmkPZe0M8f6ki=N@>AX_O/oUag8Y6d:Lg>:`E1hQGKSTfI<l
6RelcNK8LbTJ@YcLh[1D7R5N^NCHTCXI;go@i/I^9a]6X]kQZdhL8fFoiMB8=1Td
RMGU_V<R7Dn]h]jO@aXXLlWVcGT[6CnJg>>aDadQH;cUeh`e6C>8eNJoHb8LD:oS
gIa06BYhcNO9LRLJAJ;OhJQ:6bE[aNO@ORdI?9SLi;9C7B5R_nKEQc4H=XoIiKQJ
7QmK^NGHSCDH<hWGi[aN7aeG]^GJTCLH<HKFi[iP81eE]NGKTSPH<8KFi[iP81eF
]^GJT3HH<XWGi[aL7QiI^NKHS3<G=HkJi[MG7AmP_nOEQ2hG>YOMi;1?6R9Ya^S@
NRTH@J7QhZI562Mec^S8K2<JC:kTgYPj5bj5e^NmGAhMFkcWehL_5cVGg^F^C1TS
K/[XcG8U6DR[i=nJ>aL]Q=OW_E/M7Efoj=F2;1LmW^3SYdDH9gS@j<IV81]D]nOJ
Rc4F=iKNiJi:6BAacNW9Jb4ID;CVg8lb5SFDg^J_BaPTLLkYbFXQ6U6fim^;<1Hh
V=oUZdHG9WOAjLAS7Q]I_NSGPRXF?j;ShZ0m5Rb4f>RkEQXOI/SYcg8S64bbimf?
<ADfUn3UZT@G9gcDjL1L71eQa>WBMR@GBJoWgY4b5CJGh>FY@aHXO]KY_UPJ7VK8
j/i_8AQ@]nSJQb`E?J;Thihi5Bj<gNRbBQLTM]?Z`edK7676j]1b8QQ>]^WJQR/E
?ZGUhYXf5C:CgnN[@aHWP=SY^e<H86k?jlQS71]Ma>[BLb8GC[OYfX@Y5D6Zin2C
<A@fW>?UXS/D;XgNj:m55BIofNZjD1LQL];[a5`J76K;jlaW7AUJ`n_CLb4GD;_Z
f7hU5DRbjMf8:QA0Z^OPTBlD>J7UhiXd53BIhnFQ>A@_T^7WZ3hD:h_Nj:i352R5
g>VcB1DUOm[Z^4`F8g[Gjka@5R5fe^^oDaLPL]C[`EHG7W3Bk<=H61i^dNc4FQPM
K=7/aEXH7F_@k<EK61e[dNc5FQPMK=7/a5TH7FkBk<=G5ai`dnc2EAHOLmG/_e8F
87KGk;a?5B9kfN^iBQ@TP=_[]4HD9XGNjZm14bV<hNVY?1<]Tn?WXSLB<Y_UiIXa
4SNSj>>B;18m[>[OR2LCAKG[fgdR54jmk=Ib7QIHa^g@IQXII<k]b5XG7G3EkKi>
529ng>^c@a<XSN;YYSPB<IcViIL^4S^[j^279A=8^NcIMQhFElK]cf@H6VSBkL=C
5B1kfnbd@Q8YSn?XXS@A=:?YhhhX4TBek=]h7QEFa^k?HQPJJmC]_ddC8X?Ojj`k
4BnKinFE:a4o/^cMNalDELK^cf8G6VkFkKe:4RF9h^ZU=A4dY>[RRRDBBKg^eVdJ
5fCAk/=A4b62h>^[>14aX>WTSBHBB;c^eV`I5fGBk/9>4R:6h^^V=10eYn_QQ24C
D<C_d64F6W7Ik[M24BZFinNF:Q52]nkIL1XFHm;_`T`B8h[TjZ0`43Z_kMei71AL
c^o7DQ<QQ>;[YC8@=jc/gg`M55[=klMB4R65h^^T<A0i[ngMN1/EG]3_`ddA8hcU
jY`/442gk]U]61MYennj@Q0ZVNWVSR@AC<?`d5dD77_PkJXd3cJ/kMmi6aAPd_31
B10VTnSXTRD@BL;`dEdD77cPkJPb3cR`k]ab6AIXenni@0l/Wn_TQAlBElg`aThA
8hoWjI@V44W3l=1J4af2hnbQ;0lo^_3GIADIMmo^ZS8?>;;_ffhG5foLkk4g3SB/
k]ic61EYf^ne>PhaZNkPMQTEImW`]S/><:W^h7HI5FSIl;Dj3S6Zk]md61E[fnnb
=`hd[noMKQHGLMk_[38>>KK`fFHD6G[RkJ</3T6nlM=K4Qf6i^^G9@m<b?7:CPlT
UN_WR1hAF]?a_T0>;JK^hGDG5FgMkjdb3SZhlMMP4Qb3i^bH90m=b_;8BPlVW>gU
OQXCIM[`/cD==kGaf68B6h?Vk9LS3e3=l/E53RZSk^9f5aE_gnnX;@e1`O;@D`lR
U>_WQ1/BHm[a/c@=>KWaeU`@7XcZjH/M45cFlKPg3CFelMQO4Ab:jNZ=7Q1Leo6g
=`df]o7FG10NS^[YR1/AH][a/C4=?;kbdE<?8YS]iG`G4fkPl:DY3DS9llM53B^X
l=mZ4QV1j>bB7`mJeo:f=0`j_O;BDPhSVnkTMaDEMNC^W2<>D];b_3T<=KSbeEH>
8IS^iGPE57GTkY/R3UCDl[Xf33Vmlm5@3BBPkn9_4aN0j>b?711Qg?6];0a5b_?6
@@`_/_;IFPlOUnkVMa@EN^O^U1h?G]_b[R`<AL[ca3h<<KKceUD=8Yk`hVdB68GZ
jhLH4FcRl9lR3EGFlkD`3478m<M02c2flmEC3BBRlN1W41Z=kNQl5AAhinjA70mT
go6T90eBeO>e;`]2b_C4?0/d_?C@BP`Y[O?JF@dQW_7RJA0JS^kXN1<EOn[/R1LA
L>G_UQd>H]obXb<=E]Wc[bX;Bm;d^S4;@L[d`cT;><;dbd4;<K[ddDT;:k;dee4<
9Z[cg5T=8J;bh64>7Y[ahfP?6iC`iVl@68g^j7DA5XS]jWXB5H?/jglD4gk[k8<E
4W_ZkHHE4WSYkXPF4GKYkXXG4GCXkX/G4GCXkh/G47CXkh/G4GCXkXXF4GKYkXPF
4GSZkXHE4W_[kH<D4gk/k7lC58?]jgXA5HS^jGD@5hg_ifl?6ICaiFP>79_bhV4<
7j;cgUT;8j[dfU4;:;?ee4P:;[_ecT0:=LCfaSL9?Lce_Bl:AmCe/bL:D]_dYb4<
G^;bVQX>K>O`RaDANnc/O14ERo3WK0hKW??QF`/R[?GHB`X/^oK=?0Tib_Jo;`U8
e_F^8`]JhO>K6Pi^jNn64a:4knY`3QVJln5J2bB`mME52C;4m/Dc2DCDmK0T2e[R
liPH3WC[kWh@5HobiF<;7jWef4T9;l;faS<9A=Gf[R8;GnCbTAD@ONk[LPhIW?CO
E0XX^OK=>@Pnd_Jc90YKho>C5@mmkn]`3AZPmMe?2Bc0mlLb24OHmJPM36WYl8<@
58obiEd:8kCfd3/8?M;f/R8:H>KbRa8BRO;WH@XQ/OKB?0Pld_Ja8@YRio674A>>
lnEK2BFhml`e24CHmZHK36o/kWP=69kegD/8<<Og_BP9F>CcT1<AR?;VGPTT^?O;
=0Q7foJQ60ehkna]2af/mm@m23gEmj/L2fk/kWD<6JGff488>M7g[ah;Jnc_N0dI
XoKI@PLid_N^7@]]kNid31ZXmmHm1ckGmjHI37K_k6X:7k;gcS@7BMkeVA@?Q_?V
FPPX`OS1:0QKio:43QFLm]a51cSBmj/K2gC_k6T:8;KhbRl7DN?dSA0BUOGOB@Le
dOR]6`]dl>aW2B6in<L[25OVlhD>5IogfCl7?mWgWaD>QO?VE@L]b_Re7`Y^kniZ
2B2in<HZ25[XlWh<6:ShdcH7B^7eSa0BV?KL@PLmfONN50j;mN==1cCBn:TH383c
ieH7;Lch/A/;Mo;ZG@LYaoVf7PYbl>aQ22K4nKTO2Fo`kF<89/Ci^Ql9Ko3/HPPV
aOVh7PUblN]N1bW8nK@K2WSbjEP7;Lki[AP;POCVC`Hde?RS50j<m^551SgLmiH@
4I_gfCT6B^CeQ@`GZoW>;0MJjo9b2AnlnKlQ26oak5`7:lkiZaH<R?KRAPHmgONB
3Q>Rn=<a1UKZlg@97[gi_Al9M??ZE@HaeORP4PnFn=Xh1TgWm7/:7;Wi`B08L_;Z
E@Hbe_RM412Kn=Lc1UGZlW488L?j]QT:P_GTAPE0hOJ82aNan/LS1fkbjeH6<]Oh
V@lAX_WA;0IPknmR1R_@nJ<A3iWhec46FNgaJ0LWcOVW4`jFn=Pb1US]lFP79lki
YQ8>VOWF;`ILk_1R1RcCnIh?4:;id2P6Io;]EPDdfoR@31Fan/@O27WeiTD5@nGf
N`PN`oZa5@bAn=Xb1E[_l606;]OiUP`D[_[57`Qjm^E21DSXm7879<cjYA0?XO[?
9PI_m>U:1D7UmWT78<SjZA4>W_[@9PI^m>U914;VmGH78/cjY0l@Y_[:8@Mim^@o
14k[lfL5;=OiT`/F]o^k5`Z?nMT^1FCck4h4?nGfMPLScoZN3A:^nl8J2HShg305
HO;]C`@oi_Id1RGAnYT<5;Gk^aH:To[E:0I_mNM114k]lV05<]khPPPNbO^S3Q6^
nl0H2HoiebT5KoKW?`AAk_5J13SSmgP69=;jUPXF_O^a4@fSnlPL28SifR/5K?KW
?`ACl?1E13gWmVh5:m[iQ`PMb_^O31>gnkDB3:;kb1/8S?[G9`Ifmn8e167djdD4
C^oaE`@mj?IZ1BoOn7d68mCjS`PJb?^Q2a>jnk0@3Z_k_QD:W?_:6`R=n]DS1Woi
gB/5LOOT=@ASmNTn15ObkTT3C>oaD`=3k?AM13[XmVL4<n?gL0@]goUi1BOJnX46
8mKjR@LOdO^@21_=niH86LWkV`TGaObP2QG1o:@;4kklY``B_?bZ316jo:`=4KWl
[@d@^?b^3A2go:h=4;Sl[Pd@^Ob/316jo:/<4[clZ0/C_obU2QC2o:4:5LGlW0TG
bObG21[>ni477M;kRPHPeoZ31BGKnWX4:^3iL@@`iOMX0cOYmUh3?ngdD`=9lO59
0e?dkCh3GoKX=0=/n>8[17_jfR85R__A6PNIo<DD2ZWl^0h>^?bX2QC6o9L77=?k
Q0DVgoUa0c?XmUd3@^obBP=EmN/h0f[ihRT4P?_E70NHo<@B2jom/0/Ba?bH1acF
ngh4:nChI0<nko=;0UKfjS@3LO[M8PF?o<XD2Z_m/@/BaObD1QoJnWD3<n[fE@9=
m>di0fcjgb<5S_c94`Z`oJ`95LclR@@Vh_UT0T3alD82H_SS9`B9o<`D2Zkm[0TE
c_b512[Vn5`2BOC^>0=an]/M1Y_m_0d?`_fD1B;OnVL2@?7a?`9Zn]hP1ISm_Pd?
`_fC1B?QnF82AO?^>0=dnmLJ1jGm/@TDcob00bo[mTh2F_SU9PB?oL@?3L3mT`@T
hoUL0Tgfjbh3Poc<4P^ioI/58>3jH@99mN``0h7lc18;^_fH1B;SnE`2CoOY:P>;
oL@>3/CmR`<[j_I=0Uojh1l5Wofb2AKEo782?O;`=P9ko<lB2kcmU0@VioM@0Ugj
h1h6Xof^1aSJnfP2AoK[:`>=oL0;4<glN`8hlO4g0Wgmc10<`of80bo^m402L_cB
4PZmoHl3:nceA09^o=DC2K_mT0<[k?E30W3lda8:_of<0bo^m3d2N?g=3`g7oH02
=o;`<`:7oL4;4M;lK`56mnXV19_n/0HJh?YH0E_jgQP7/ojF0b[]mCh2NOg:3@k>
oG@1@oKZ9@BNoZ/57^GiCP5Xo=DA2/CmP08km>hZ0iOn/0HLhoU?0FSle14;aoek
0D3fjbD4XOjU12?Zmd81NOg72a7Eo6D1E?[P5`NjoXT2=_C_:P>KoZX48NWg@P5k
oL@:4m[kG05Oo=PA2/OmMP57n>HL1[?nS`8dm>lY0iknY0@VkODg0X_n]@HLi_Q5
0G[n``PEg_]B0Fcmc@`@eoaN0F3le@l<d?eW0EOkfQ4:boe^0E;kgQ<9aoeb0Dkj
ga@8aOid0Dgjh1@8aOic0Dkkga<9b?e_0E;kg14:c?eY0ESlf0l<d_eP0F;md@`?
fOaE0Fkmb0TDhOY80Ggn^`HKjOLj0HonZ`<Vl?</0Z?nU`8dm^`N1KSnO`58n^0C
2LcmI@1QoLl:4MokBP5no[L57nge<0:OoiT2=OOZ6`JnoWD1DocG3@kJo4l1N_jj
1Ao]mBh2Y?nB0CciiQH8b_eT06Gnb@LFioPi0IKoWP8cmnXI1/GnJP1QoL/85^Oh
>06IoiX1=oSW5PS<oEl0KOk11Ag]mB`2Zon60DWlf`d>gO]60H[oYP8`mnXH1lWn
H01^o[h48?3c9@>foWL0FOg>21KYn382YOn80D[lf@/@h_Xl0I[oU051nmh>3Mkk
@@6DoiT1?O[P3PcLnd81TonH0Ckkg`h=go/o0IWoTP54o=X;4>Ci=P6TohH0D?gA
21K[mbX2]?mc06;n`P@Plo4M1LOnF`1koj`2<_WV4@_Lo401Von<04gmdPLGkODV
0kgnIP1bok82;_SW4@[Lnch1Won505GnbPDMl_4L1LcnDP29oiX1@ocG21G/mRD3
`OiN07goY@4knm`:4^[g:0>noV40O?nU0Cclf`TCjoHU0l?nF@25oi/0AOgC1QWa
lQ`5d?e909SoQ`1Io/839_OY40_QnS81]OmW07WoY050oMH66O7b6PKDoD41Y?mh
06[o/@4fnm`85>kd7@GAoD@0X_mi06_o[`4io=T76?7b60OHo3T1[omY07coW@1:
o/X39?SX3PgWn2D3bOi:09koN@1]ojT0@?gA11ofj`l<i_TU0l[nB02Rog<0MOnP
04_na`8Yn^<:4^od6@KJo3<1_?mF09KoOP1/ojH0Aok90RWjhPTDlO8E2>3k:P;7
oTL0YomY08?oSP1Pok00@?k=0bKjhPPEl_4C2NGi8`?AoCX1^?mE09_oM01loi<0
G_n_04?nb08/o=`66oOZ30o^m1H8h_XT0m;m=P6ood/0Z?mS093oN`1hoi<0H?nZ
04_o_P4hoLl2:O_M1Achj0XClo0?3>cf5`OSnR44f?`/0/cn>@6oodL0/?mF0:7o
I@2Bog@0Q?n307GoT@1Xoih0FonZ053o]@15okh1??k70CCnc`8]oMD39ocK12;k
h0DMnN@66_SW21KgjPTDmN`;4_C^313bl0d>lO4>3O3b3`c_la0<k_@A2nkd4@_^
m14;k_@A2nkd4@_^m10<ko<@3?3b3`gal@d>l_0<4??^2a7ek0TDm^X85_SW1aWi
i0DMn^048_cK0bOme@8]o/h1=?k703go_P16ok@0DOnX05goW01Zohl0Mon008Ko
L@2Fof80YOmB0;Co@`33oSD1d?dX0mck7@GWn1@9ko<<4?G[1aWjh@<ToM<1=?k3
04Ko[`1LoiP0M?mo08goIP2Vodd0__lg0M;m90CSnAD9l?8;4_SW123me@4dokl0
C_nS06coP`2<of80[?m40<Wn:P;PnQL8l?8:5?WS0bOnc012oj`0I?n808_oH@2`
och0d?dR1>Sg3`kfj@@QoM40?_n_06GoQ@2@oeT0^_lc0M_k60Sal@PHo=X1=Ong
05koR@2>oeT0_?l`0]oj4`[dk0DOoLl0A?nS07GoK`2Zoch0eO`J1o7a1a[me@0o
ojL0M?m_0:co>P7Io1H9m>d58Ok:04koU@29oeP0`_lW0nWf2a?kg04iojX0M?m[
0;?o<P7Rn@h?nN41<on`06ooKP2aoc81hoT=4?[N0CWoZ01jof80__lW0n_d21Wm
d@1<oi00U?m80=Cl5@[gj08^ok80LOmW0;co9P?]l`HMo/T0FOmo0:So=@7Tn0/D
o=D0Bon=09co?P3OnPdAnmT0A_nA09Wo?P3OnPdAo=L0B_n;0:3o=`7Tn0TFoLh0
F?mj0;7o:P?^lPDRok/0L?mP0<Sn6@SgiP4hoi`0Tom00>7i2QKnc01Mog40_OlO
1_GZ0CCoX02Bocl0hoP86Ok506WoH`3:oQD:n]h0Aon50:ko9`Cbk@8_oj80Tolk
0NOf1R3o]`1lodd0g?X:5_k606_oG03Co0l@oM00H?mV0<cm4Pgle@1Jof/0bOhC
3?cF05[oJP3:oQ8=o=<0GomT0=3m3a3mc01YoeP0f?/:5_o007[oB@3Sm`HQojh0
T?lf0Nk`0S;oU02[ob85n><0Bomd0<On4@omc01^odl0hOP58_nY09Wo;0?dj@13
ogX0aOhA3ok:07CoA`3Wm@<[oiL0[OlM1o[J05ooFP3Nn@HQojD0XOlS1OWO05Wo
GP3LnPHQoj@0Y?lP1_[K067oE03Sm`<Zoi@0]OlF3?g;07[o?@7`kP11og<0dO`9
6_n[0:7o80OkeP1/odH0kO41?Omf0=7l21coYP2YoaX9oLd0OOlf0_CW05?oF`3S
mP8aoh80b_d:6_nW0:_o5`_naP29ob/4nMd0JOm30?7/04goG@3TmP8fogL0eO/5
9On@0<?n2aSoY@2aoa8?okL0WolJ2_k508oo8`Kld021ob`4n]T0M_ld0_SO06co
>P7fh`1Vocl1mNH0H_m20OCW063o@`3di`1Pod81m>H0Holo0OGT06So>P7gh01`
oc@2nMX0N_l/1?_B08Oo8`Kmb02FoaX;okX0YolB4OnX0;Wo2Q_oT`3;o@DYog/0
gOP1??mP0>_`05GoA@3fhP1cob`4o<d0U?lH3?n`0;Ko2QcoR`3En`8fof<0jnl0
Folm0OWI08Oo7@Wo]@2do`XMohH0f_T1@?mD0??V07;o:0Gn`@2Yo``Ioh`0f?T1
@OmA0?GS07_o8@So]@2ioPLUog@0io80G?le0_c;0:;o3QOoRP3Lm`1<oT81n]D0
UolA5?n@0=[h04[n@P7jd`2Ko`lFohP0h?H0EOlf0_g70Jgo22;oL@3/k@1`ob88
oj/1b_`2??i<0?WG09_o3A[oO03Xl01[ob<8ojT1c_/1A?i10Oc;0Jgo1ROoHP3d
hP2=oa0Eoh40j?00LOlM2onJ0=_g05[n:`Go[P7>n`1:oSL3o[/1`od2?oi00Og4
0Kcn0SWnA@7la`6ioP<hoTH1o<H1^oh2>_i20Og20L7m0D;n>P;n^07;o01>oRh5
ojP1f?P0HOlP2_nC0>Ga07Wo4aCoM`3bh`2Ho`PUoUH0nld1^Oh2@Ohe0on[0MWg
06Wo6@ooOP3ai@2Io`LZoTd0oL41bO/0EohR2_n;0>gY09Co1bSnC07m_@7?nP1Q
oaX?ogX0m=h1Z_l2??hd1?nO0NG`08Wo2BGnC@7n^@7En01`oa4HoV40nlT1b?/0
H?hH4_m]0?WA0L7m05[n6Q3oK`3id@72o01MoQPBofT0nl/1bo/0J_lA6OiI0?fl
0MWf083o2BOn@P;oXP7Yj`6Oo`90oRL9ogd0mmD1a?`0J?l@6oi@0On]0NG^09co
0T7n90_oL`3jbP;Bn01oo`L]oCD5ohT0m]P2a?/0L?l;9?dm0onA0?CK0/;l06oo
2RKm>PCoRP3fe@;;nP1no`HaoB`8ogD0o<<2gO80V_l1BohH5?iB0OnP0O7O0/;l
07So1S;m:@[oJP3n]@7Xj@6coP1Zo`TZoBh8ofl0oKH1jNT1]od0LOl7<OdV3?iP
0?nU0O;L0/_i08go0T_n4a[m?PCoO@3l_0;Xj@:lo01no`=1oALFoD<3ogh0o;X2
j^H2`o/0R_l1Coh?8Od`2?mT0?nN0OO@0]k`0K;m07_o0dGm4Qgm<`OoH`3oV@3i
b@;UjP;1n`2@o`1MoPPaoAdCoD04ofl0oj01n</2i^T2a_T0W?l0KOl4@OdA8?dZ
2oi>0_mi0?nT0OS:0^SV0/kf0J_n08;o0E[n1cOm5Acm:`_nB`;oK`3oU@3l^0;c
e@?SjP;;m`6^oP2<o`1Yo`=:oPX_o1LJo2X<oD<4oel0ogh0oi`0o;L2mLl3j^83
fnl2aoP1/?d0Uol0OOl0Hol3C?h7=od?9_`J6O`W3odg1oi:0oiM0Omb0?n60?nJ
0?f/0OZl0_K;0_3G0nWR0n3Z0mKa0/_f0[oj0K;l0JKn09Wo08co083o07Go06[o
0F3o0UKn0dkn14Km1Som23Wm2S?l32kl3R[l4BKl4b?l5B7l5akl61gl6Q_l6a[l
71Wl71Wl7AWl7AWl71Wl71[l6a_l6Acl61kl5R3l52?l4RKl42Wl3Rgl33;l2COm
1cgm1DCm14cn0UGn0Eko06So07?o07oo08_o09So0:Gm0K;k0[kh0l[d0mK^1>3V
1>WM0o7A0oO30_^c0OjQ0?n=0?mi0?mT0Oi?1?dl2O`[4O/L7?/A:o`8?_d3E?h0
K_l0R?l0Xod2_?P3d^l4i>44l/d3n[@1oYL0ogL0oeP2oC/:nb<Gna4[o0I7oP5X
o`2;o`6_n`?>l@CUgPCe``;mX03oN03nD@Cl;a3k5RKk1dKn06ko09Wn0/;e1>7R
1?G20_jH0?mZ0Odo2_/M7o/9@_d0L?l0XOd3cO04k=@3njT0ogD0oD<8nadPn`M8
oP1mo`6cn@CNh`Cg^P7oP`3nB`Ok7aok1T_n08Ko0[oe1>WF0obR0?mT0_`]5?X;
?Od0N_l1^OL4imL3oIl0oe`3nb@Kn`I>oP2BoP?@k0Ge_@7oN03m=A3j33gm08?o
0/S`1O?10_mi0?`c4OX:A?h0Soh3e>P5nJl0of03nalQn`9To`6dm`G]c0?oO`3l
<Q?j1dkn0:;k1NGG0oj;0?dh4?X8Boh0X_/5im@3oh<0o2lEnPEJo`6dmPGa`P;o
I`;k6bSl07go0mCV1ObI0?dl3oX7Dol1/oH5lk/1oeX5nQ4io@2Jo0GYcP?oK@;j
6Bcl08gn1NCE0omd0OXK:_`0SOh5iM83ofd2nQHbo@2Ko0G^a@;oF@Ki34Kn0;Ce
1_RY0?dj4_X3J_l3eN84ogd1nQX^o02Nn`Kb^@7nA0ki16Go0mKQ1?me0OXC>Od0
/OD6nZ00o2/Mn`2<o@K^`07nA0ki0Voo1>7D0omJ1oT7Fol3e]l4ofP4n@Y@o`;?
i0GoK`?i34go0/kT1Om]0oT:DOl3e>04of85n@INo`CNe@?oD0_i0WGo1Nc10Odg
5oX0U?/6n:80nah^o@2jk`KoM`;i2UGo1=kC0om54?T0S?`7n:80nQXeo@77i`Go
G`Oh0WKo1_:a0?/Q;Od1`NX5of07n09joPKeZ03j6CSn0]7O1?m94?T0V?T7oHD1
n0UMo`G/_03l8Rkm0L_R1?m94OT0X?L7oWD3n0=eoPOgWP3i3Too1NS00?/P<_d2
eMP3oSDNn`2oj0GoBQ7i0:_b1_mN2_P0VOP7ofd5n06;n`OnN@?h0X;l1of00_P2
O_d8o842m`9no@SmO`;g0XCl2?ig1?L1S_X7ofX7n02MmPOoF@ci0:o^1_m55_X1
aN84oRlVo0?JcP7k6cko1Nfa0?P;H?l8nX/1m`6:nPSoG`_h0;OY1Ohc9?`3g/P1
nQ9@o`OgT`7g0X[j2?mF4?T0a]h3o24io`K`YP3g17gl2?mL3_T0a]h3o1doo`Oe
V@3g0I;g1om36o/3g/D0n0]Vo`SnJ@[h0<CN0o/HB?l8nX@3m`2`jPGm8cWo1oJB
0OH0Ynh5oBLeo`OeT`7f0:W]1OdS>ol8nHL3m`2hi0?k5dgo2Oe^2OP1d=41n0U^
o@WoBA[l1>Z/0?H1W_06oB8oo`SlM0Sh0M;=0?L6O_X8oc@[oPOgR0Cg0<SF0OP8
Mo/8ocD[oPOiPPGg0M7=0?L4ROH7oB@oo`WnHa3j1>R/0?H0]><3n@]_o0So<C;o
2Oa/3?T3ij`0mP2jgP;h1h3h1odQA_l:oddLo0OgP`Kg0]ng0?D0^=h2m`F8m@Kl
5eSo2Ole<Ol9oU`En`KfQPKg0nB]0?D0b/h0m@2ZiP?h1XSe1_/AIo`9oR59o`[o
=S;o2_m=7od9o6DBn`OgO0[i1O2B1?L3ij@1mP7M]03e0=;10?D0b<`0m@2oe03e
0;OJ0OD0/=l1m@6[hP;f0JSS0_H1Yn@2mP6Xh`;f0J_Q0_D0[mh1m@2ff@7e0;gC
0?@0alX0m03A_`3e0M^a0?D2iZ43mPC_S@Oh1_Mg3_/8o5lIo@[oAb[o2ol`@?l:
oQaLo@Sj3Gcd1OL3WnD2m@30c03d0Mf[0_H4lX8;nPWmEb7n2ol`@ol:o1=am`Kg
0j?Q0O@0d;X0m@C`Q@_j2Oi=:Ol;oR1Ko0Sh1YSV0_@0d;P0m@GdMa7l2olh?_l:
n`f2l0?d0<K20?D4lgTAo0_o<TGn2_T8U>L1l`3KY`?g2?aC:?l<oAAel`Cd0<Zk
0OH6nF4Oo`cn5foe1O@0bkT1mPOkEbOo3?`?P^d2l`3MW`Ki2_li@oh9n0>]d`3d
1OI[7?h<oA9mk`;c0>:F2O/<obQInPKd0<fb0_L:oc]3oPWf0Kk20?H8oTDjo`[g
0[S60?D8oDDjo`Wf0Kk00OH9oc]6o@Se0<f_1?P;obQNn0Gc0>:@3O`=oA:4j07b
1?IS9Ol;n0>fa@3f2_l`EOT5l`3UR17m3O`:W=T0m0Sn?TKl1o<0hHh?o@gk2J3E
0?D9oc=En@Gb0Ned7Ol<m`;1]`?i3OhEQ>D0l`Om?T[k1_81kG8Oo`_f0<jV2?/>
o0VTc`3f3?lMN>X0lPSn>E;h1?43mUPdoPSb0>Yg7ol;m@3JTQ7n3OL1bJP9o0kj
1;Vh1?X>o0R]a0;i3_d;Xl/1n0gm3Ik?0?L=oPjMc`3g3Od=XL`1n0km2ZS50_T>
o0Nd^`Gk3_X3`Z/:o@kg0=>F4_l<m03SNb7o2_81lU`go@Ka1O`lEo@1lP[o87oP
0?D>o@Z[_`Gk3_P0eHlGo`_b0O9I?O/4l0So:7GT0?D>o@Rd]0Sm3_D0ig0/oPK`
1_h]KnL0m@kl1[bZ3Oh=l`7bET;i0o4;oaBJb@?k3oH0iFl`o@G`2OlLSM42nPof
0>A`<?d5l0[o5iS81?`?m03_FDCg0_8=oPViZ13o2o04o35ah@3h4?L0i6`en`?a
3?h:^:LAo`[`1_hTQ]82n`oc0OE7F^`0mA3h0>=Z>OT2lPkl0ln99?h5l0cn2[bO
5ol8k`[o4:j]4?l:k`So5:Nc3_l:k`So5:Nc3_l:k`Wo4Jj[4_l8k`_o2k^K6ol6
k`gm1Lj3:o`3l@oj0>=TAO80mA7e0?DoJmh1n`o`1OhMVkP>o`W^3?h6cH4_nP7c
4OH0lT=Yg@;l3^l7oa:bX1cn1?0@n@3/CekS0O/>k`Oo4;NH8_d3lQ7f0?DiNM06
o`_^3?d3fVU7kP3i4>l6oa2iTbOk0O@Al`;m8If_5_l4lA7f0?P_R[l?o`K_4?L0
mCF4a0go1nlAm`3f<HVo4?l5l17e0?XVVZlIoP?b4_83oaJeTRch0?LAkPSo1]IW
D>D2o@c]3oX0lcJ7_A;o0o8Bl@Co3/Ik@Nd0o0g]3oX0m36@/aWm0ODBkPWo1=mF
I]<9o`K`4_44o`c<KdoS0ol9kQ;c0_lAaGM8iP;n2NhBl`?o3/Y_DN05o`O`4o46
o`OKEV_=3_l3m1;]2od0lC:FYBOf0?/=kA7e0_l?cFQLeP[o0o<Bk@ck0?LT[8dl
jP;o1o0CkPWn0O0`WI/ak`7n2>lCk`Wn0?8/Xi<ijP?o1_4Ck@ck0?XJ_g=Ge@go
0OL@k1;d1?l5iCn>YBk`0Ol6lA?/3_P0oPkEE7Vg8OH0oPS`4n`>n@3n3MQ>PJhY
l@7o1O8Bja7d1?l3k32WQd_J3Oh0nPc]5>d=n@3n2mi3TI/ki0So0OP=kAC]3OT1
o`SU>:2:BmH@o03m2O0Cja;b1_h0nAK?Dh>T=^D9oP3k2nlDja;b1oh0na7HAYFA
BMDCnP3n1O@AjaG/3_L3o`7f6Li@RiQ5ea?i0?l4mPo/5N/AlPOm0?h8jB^hIgJZ
=n0>n`3o1?H>kAGZ4nl;n@7o0OLEf42SNfFh;^D<o03o0oL=kQCZ5N`?m0Km0?l4
lQ[BA:5jJK4fgA?g0_l0o0Od4>`EjAG/4?<8n`7o0OX=ibS4DIJ1IK4if1Sb1Oh0
o`?i2_8Ak1GY5^/Bl0cg1Od0o`7j3>XQd42]IXB@FkHgeac^2_/1o`3n0oT9l`o]
5>XFjAKZ4nh>m0Sj0oh0o`3l1_@BiBC@?;IHV7IjUEba@</YgaO_2oT3oP3o0?h2
n`Kg2_<>ka;[5NTGj1OX5^XDk1;_3o8;mPSi1?`2oP3o0?l0o@?j1oD=kQGV7]`Y
d3G4@KM>ZUbLJXmgPHAdTFRMG:UA/dNm?/HecRkE9m/Qh1cU6>TDkA3`3_<;m@Wg
2?P6n@Gj1?/3o0?l0_d2o@;m0_d1oP7n0Oh1o@;m0_d2o@;l0o`4n`Cj1OT7n0Sf
2_@<lPk_4N`Ej1WT7MlSfBWC<</h`d6jB[1EYF2IK8eiP8IbU6BRE[19_C_:;mHT
hA[Z4O8:n0Gl0Ol0o`3o0Od3nPOg2_<>ka;[5NTGiaWV6NLHj1G[4^l>m0Wh1?d1
o`3o0O`7m1;V8]<g^e:NL7n@H:m2bRSQ5O87o07o0?h3n@Wc3ndEj1SV6NHGjQ?`
3?L5o@3o0?`8ka[H=[MKShET[cgC7Nd9o03o0O`7m0o/5^HJiASY4o4:n@;o0?d8
kQo?AJ=fKjToeA[b1Ol0oPGe3n`GiQ[V5n`>mPCn0?d9jbG4EHf@D/LRk@On0?d6
la7Y6NDIjA;c1_d0oPWY:[]SNjDmfa7j0?l4mA3Y6N@JjA3e1?l0n1CEAYN<ClhI
mP7o0oDAjA[T6N/=n@7o1^/[]71X_2G`0ol2mQ3X6^@Hk@[l0?d=g4>ETdCK3Od0
n`_/6N@Jj`gj0?d=fdN>WC[U1ol1ma7W6nDElPGo0^l[[WmBe13m0?X>jA_T5_45
o`?/<J><A>08o`;e5>DLia3i0?dBcEm]`QWj0?X>j1cT5?D2o`cFEGFm6oX0nPoW
7>DBm`3l5LA^F]@<o`;c5^<Kj`Wo0^XkSZXVmP3k3nHMiPoj0?HWYY@ek`3m3NPM
iA7j0?HXXiT`lP3k3nDMi`gm0N/nQKLIo@7d5n8Jk`Co3lMdC>@3oPcW7NH>o@7Y
AWW54?l4kQ_R5?P0mBnC/1_m0_4JhQOe0?PZV:dLo@;`6^8Em`3d=HNm4_l5k1gT
4?`2heERf`Cn3^@MjPKo4[Z=;_P0la[Q5_P0kTE_e0Kn3^@Mj`Gn6ZVS7Oh4k1gT
3_h7cW/im@3c6^4Dn`7PHDk[0?LHhAOh0>MGEnL0n1OP5oP0iE]Aj`3f6N4Dn`;J
Kcge0?0MhPoo2knC8_h6j1oX1_hST<<8oQ7Q6o@0jeM@kP3b7>8>o`nbYQGo3><M
l03`CUK]0?8MhPgo5J>g2ohAh1[g0M]g<?`5iao[0_M2GnX0lAkS2_lPRll3nAWP
4_l>[;@;oQCO5o/6`9lCoa3P6_T3bY@Io`oP6oP2c9@Ho`oP6_T4aIhCoa;O5o`9
];4:o1OO4_lDV<`2macQ2_h]KnL0kB3X0_=H?o/7hakd0M6D5?lDgQCo5I;C0?8O
i@CgCd?k1n8NmP;3Z0[k6]l<oc5Sl@;W8?40dYP@oASO3_l_Ho83iB3c0LJY2?XL
h@SjBT?l2^0Ko0fJe03^8N/0gh/DoAWO2oe2B?`:ga[m4h_P0>TQl@74/@Ce8>D2
jG`IoQWO2_]>>Ol@gACo;5ch2>0KoAInj`;T7oT:V=`0j27d1:c>0>/Rl@:ha03^
8^l1_[l0kR;^0;no0>hRk`6iaP3/8_83[M40j27e1i_O0N@OnQ60kPGP6ohSGoX<
gACo@3_o5Md:mfXJo1kR0MnO1O8Sk@6bdP3U8?XEL_H:gACoAc7o6]l4jI87lb?^
0Z[K0N8MoRMAoQ?L2_Al3_LSj`6_f07Q7Ol]A_lGg@GXV0C_9?<9QO8:g1;lHAWj
8^T0/=/2ga[o@Bkn7^<0a/X0hQgo=CSo7N40b/P0hQgo>C?o7n<0_MD2gaWoCb3k
8^X2W>/8fa3hO0Wa9?HBI?dFg@?I_03R7Om59?/Sj`>?l`gJ2N^R0>HPoSP]oB;Y
0Y7c3]X8iJh0hagoCA_h9O4=JOhHgP31fPGK4OJ>0^PQoShTnRG`36Sn6^00/^H9
fP[X/03P6_i]2NdTo3<[nbG`3Uko7^<0U_DBf`;7f`OI2nRd0=dFnXT2iAooG`c^
9?dm7oHVmb<go2G`4U7o8^X7J_lNi0:1oA[P09Ch5]h0Xo@Cg02^ka7K0KK/3mX1
^^X>fP:kj@oJ0[W[4=X1/nhAf`2ZlaCL09gh6=l0S?`LhP9gob3W1eoo9>dBAOdV
m2<[mbOk?QG^9?mQ1^DNoH/0gAG`]`;H2MGM3=T1Z?LIh09aobC]5CWi9o]14>XR
oh40gAC/``KG1;Wb5ml1KolUl20XlbKoIP?P6?:k1ML4]_@Ih@EJoROg>A;Y8OfI
0=P9c>/EgP9VobOf>17X8?^U0]L5^OHLi0Y4nBSnHP;M4nCH3mX0LolWmS`=i1cd
_`SG08co9_8_4nLNmkT7e`2:obKd=PkT6o792mT0L?hYnU<3g1;KiaOP2Coe9on?
0MH3X_hUlC<=hQWZfA;M1DOg:?nB0]H2T_lXmd/3fa3?lQkX71cX7_7A4M`5@_@V
oZT6e`1Yo2[oQ@7E0HWo:_aY0=H5WolXnEP0e`R/oROgD@7H2Jkn:?MC0ML7Z?lY
nEh0ePBGob[mM03E0Ggn:_nD1=H0F?LWoK/=f`P`jao]hA[V8PkN4LKk9oIG0=D2
Q?h[oj48f0@ikB3/iAgY;`KI2ZOo:oj;1=H1@^lQk^DNjcH3e`JBoR_oZ`cK323S
5/ck:OYc0M@0A^lQjNdRlDh0e01SmRKdh1k[?P7D0Foh9oOL7N/n0M@1J?HVl^DQ
kdl0d`1>kb3SmBOhM0?E12WS5;ko;?n]4=lO2=H5NoTWlnLSlf81e0<[hQ>eobco
a1SW>P3C04O[6lkn;?nb4n<_0M<0Bn/Kc?l]ok`Gich0dP0dha>_obckgB;cK0CF
3Q3G1Foc8]cl;Onj6>Q90=<47M/9P?HUh_/]ok`IjU41e0XBePATkag8obglh2Gg
R@cN;@3A0BCK2GWc8M7o;_gQ9_VD4>8m0=884MD1C^LDX_/XiO`^omLTmi0@hd<0
e0l8dP0bg@Yfl1fmoR_]nBkof2GiWAGXF`GI9@3A1PoC03KM2Fk]6JSj9]So;_Ge
;_oI9o^_6o1m3^9<0mPV0=4<1]016M@0=m`7G>HAQ?0KZ_TTb_l[hol_m?T_oNd]
om/Yo/HTnJdMli@GkG/@iV@:h4l6fcd2ebh0e280dQP0dA42d0`4c`P7c`D9c`<<
c`8?d04Ad04Cd00Cd00Dd00Cd04Bd04@c`8=c`<:c`D8c`P5c`/2ca40d1P0dR40
e2d1f3`5g4h9hF<?ig/EkY@LmJdSnlHYom`^onh`noXakol^g?hX`?PPW>lEM>@:
C=T2:M804<h80/lM0=I12>9a5O2T8ocB;Oob<O?o;]?l8j3^4fCM12gA00[=4P3D
?PWTOa_f`B_okc;aobc3mQ]khPLdd@08cAX1fETBkZXWonTblol[^o<FIM/27<d9
0==23>VN9OkX<_7o:J_]3d[D00W=8@?ONakjfS;gob^ckQ18d`06cRh8iYPVonlc
ho`POMh26<`D0Mag7ocS<ngn8hOP0aW<5P;NQ2?nkS?NnA]TeP07cSL=kK/_o?l[
XnH68L`D0^2@9ooh<L;_3SG=2P3KP2ComS;6k`hbc0d1gXlXoo`_[nL67</Q2>Zi
<OSo97SH00?AEa_kkCC=l0d[baP6j;Lam_hQI]<20=Mm9oom;IWN00O?EAcmlc:g
iP@Ac3lFnN/da>X65L/k5OW[=<7X1A7<AAWllc:^hP47cf8Rood/R=L00=VB;_[n
7To<40K[cSGJk`TGbdHLo_X^SMH10=bU<_7i4b_9<AGkmC6Gf000gJXck?D>7LY7
7_on:Fg>2`K/fCK0h`02eY@al_P@7LY>8_oo8e3:7Q7imC26dPH4jm/f]=d00=nl
=]?W0P;FWcCVk`H8dHTal?@:3/il;oCf317=MboemP`@cW``l_@:2m2:<n[`1@GD
X3KLj040g;hg`]d00NSM=IWB2@WemReUbBDIoolN;/QJ:oSf2PSCXcO?h001jNDd
PL`I5Oko7R_9J33`k`<0gL`gW]0>4?co8Bo8J37/j`40hmheOlXR7?om4PoAYSRm
e`H;n_hQ;<Uh=MgR00?bmbU1af4aj>H00^ke:dG6HC;Vi@03l_TW=LQh=]GL0`[j
oa`IcZDiZllF6ooj2P;NgCASaU0`jN<01oSo71O?/CVEbR/Vn>h00O7k8b;<YSZL
bRXWmn`00oGn71CA`CQgaTdbhM`54Ool2P3UlBX_bJ0jU<Pj;^WO0a3on`P0jOPT
7Lno>6c5ICO3ca`TmnP02okm2@3ZnR4Ddm<dBlJ@>i?6BSCAdQPTm^D14?og0P;f
oa01i_PR4]KO<3?:]cQNa8XkS<AN>KG9>C;EdAdYk=/<7oWU0aKokP0=ooD11ogj
10?ioPP0mOl<0?7o403^oa<0johE0N[n5P7YoQH1jOhE0N[n503/oa40l?l>0??o
2P7ho@D3o?X22?od00ook04Go><78O;I5BcOcbdd`/M?>ic3NCe^`jPi@L[C;a_G
lR04j?l?0?Sk0@_ojP<Ol]HN</S6ESb5`Ylj?LcN:PcQoQ40nOT04_gP3bgFb4lm
Pl:Z>2cBl1l1l?h32ooT2b_GaeDmLl?0<QOLoA41o?818>c>?3b9`[<e6m_l40;n
kP@VglQG?VC6ebT6k?h24O_G9CVK`Jhe6=ko2@Soh1He[/2P>1gLo`X8omhJ=j70
/S@@iOl34_WB>CiaaMdT0?Od0RSC`h8l:=Wn2@cmeC4nLLGS803kk0Xb//2b<PW]
nP0Tf/:6>agPo`8HkLMX?RkHo`DCm<YL?cGFo`HBm<YP?boIo`<GkLId?AkQoP0R
fL6J=P[_mP<`/;o;9`3mha`mKLSe40[jc5ho9>3n02O7_[`[0?cR83mNc?`85N_3
ScL7m>h>>gW7mPd@lLB8>0Odk18mJl[k1aSS`:T_0?gM<44if_h0;Zboi1H9n<J4
>0GhiB=1@MSn02nS`Nh@4Nc0ZBd0om=B?a?^kQE0C]Go036I`oH96mJmdAd7n<>I
<@3od60m2?OQ<D8QjO4C@D?Kn`@kJ<oo03>;a_h1:jO1n0HS_Kk`2ag<_NP?6=Fl
hA8EfkcN4aCL_=hC5MZlhA4Ge;cX3Qc9_O098[Von0@ZX/?n03:5b_l0>V7En`Q1
?>;`7D<Kl^12@0GmcgHe0?g1/R8;ik_T3B6c`Oh0=f[DnPi39NkQACl1olNL:0SZ
^nL:9ik6o`90>nKX>443olJS9@gN^oD2<g;DmaM44?[?Q2h7j[[_135ee?HKA0[m
bIdU3mBmo@0n@nKSBc`0n[_P2Rf1d_HOA0Co`KlG8:K8o@m53?k6[Q`K/<Gm3DD<
o/Bf622Qb_XIA@?o_]<<;GKHkC`m0?BimP0o=_3DQBPC_/?m4DD3okcO1SICi]a_
;Po8`_hBA@;n^^/2?CSaciTO7iO@l3dk1>>lo`Q61?njk050:OO7^A8^IN;KNRLI
X/o_A3P9d<7k7d80k;[o2dH0n[Sl0TL6okWe04H=ok[^04@Dok_Y04@Fok_Y04@E
ok_/04D?okWc04L8okSk0TP2nKSo2dH0jk_m8406c/GcAS<EWmGPOR0YHN[;_@Xm
9_fkk`180oVhoaM21/[8k60Y8foXbl08@AWo]o`6A`7M`_9C;29_jLW;14D<o[Ko
6D0;/=?LUa<k9ojgo0U61<S;hhDH=bgn]o`:A@Jnd=fJ43hIokKo7S`CSN;:c`59
0NjnlV4R<CSm]od@@@nIh<[B04T0hl?XQ1@n5_jfo3d^:DSj]odC?aF0j/3]0TP7
[M_;d`1:0<_?e[`3BP3Lb=f[1TT0hlGOY@M80N?6gZT6B@3Lb]Vh0T/0c=7@d01:
1:kNa>T3AQ21k[Wl5cXSBOfdoTDT>QKk^^^?2TT0dm7=f`183gcb]_l[;S<PoKW[
T`Q;0;oK`_8<?R=2okCeMA190<cFa>l;?RDjokK`S0Q<0Z_U^_hW;CTAll?FdP56
6U7n]?>724`4VnfeodLMA@7?f;oj7blj3>_:b^/<>S0Kml;BgPDo:RCk_mKJ140Z
9?[0dml7?BlJm<K<kA4d>@_TdL3k:BI40<7S]_mJ4Dd5Q?Rbl:40BQdho[kBi`lc
?@CAg[KoGPi>2fOn]N3@1C`f2]_J]omP34h?E?nje>LD;T@0[O2alJT0A2hBi=Ng
of`7CAXdn/O1oT@CCPi@oko9n38JCPYMokc;mc4JCP]Foko7nclBCa<mn/Rmof<7
C2<KimZcnId0@CX2/_>ah=hE9Td7F_o2`?mU1D//3<gZ/>OE4BM=2E3mb;WnQ`12
?02Jo;K<nd/:CBX;ann`fn`/550P6=WX[n7U91Q@7QWIjJoNjbhBCbH=aO:ad_U>
1TXf0IKn_;ooS00hB@I;mmJ`jmXP5e0W2KCi]l?oQ`0gC0/ik>6^foA91DLo06Kl
dJoYhRd>CCP0NOo</>cO;0e<>P1]oM:^i>e31DE414G^i:k@oW/0<U0J4[Wl_KKe
cb8?C3h1DO7S[/coTPDVDR/1POkC[MWkL`0_DR@5S_oA[MWlN@4[DR/1MO_L[L_o
X`dHCch3?=kd^;Kai4D1>E4Q1HGmfjg8o[TM34M;4Q:Uom6/c_n^5`i8Ba@>VooG
[LKmbBh4?E8V0FC_k[JcjOEe11i?A@dFXooI[KoghE00:U8n1an_omN]__GWG04R
D4H@3HWij;Fah_fM5`ToDbl1=<;oe:fkl?9l2Q55DRX0>LCoeZfgj_ZF5`LjEC/8
58kgk[b[cOcNGP<FAe<_0RBTo>ZiZlgkhfT83d1E>`X=M^Wjbj^hi_jg>00OBe<`
11R8koS:ZkKRolM=0Q=2ED0B0dg6onFiZ/;`njli01Q4ET4D0Cndo?33Z[GMomid
50<YCU@g30E<_?c`aJ^aeO_`VBh05SmFC2L34FO?onc3Z[3An?NaB0H9;dmE?QH0
8h7NonS1ZZk<l_g;JQL06d5FDC<>0Bb8goo/ajfZ`>CokJA62@@RAEIA=Q8076W3
nO[L^ZV]aNSokZeD4P0E=e5GBR`<01mY_OCni/F^YkC@koo[[5XI00`ZAeME@bH9
01aMZnSom=RlZZRec^com/V2>``042a6EUQ<=1P30b=OY^3mo>O<]JRX]<[Tn_kX
]gHh3P0983U=F5Q=>B0:00X]Hj7Fmooeh<ReZJJ/^m3WnOocdJ1W=1010a8W?4eG
FEA8=b8>0P4@<5f@`>CjooSXeL>dZZFW[k_<g^olooSS`YU]@b8;0@4:62TiAe5H
FUQBB3//70h400<?8d1RQZW9h_Cmoo_bi]W<`;F]Z:FTYjbc_<KBg^Wcnooono;T
dK^SRFmF?b/K3PH1004631<K92de?DA;D5AHFU]KFeUGE51<Ad4k=BlY8adG4Pd9
1P<100000@<62PhB61dT:S4g?TE<DeYQIfidNGn4RHjBUYZMX:>UZ:Z[[Jj_[jn_
[jn^[J^ZZ:JSXIfJUY:>RXEoNWA^J65KE4e6?cPa:R@N61<>2PH30@0000431PX>
4aPN92X`=ce3B4eBEUUKGEeMG5UFDTa6?SH^9A`C2`D100463ad^@e]dSjW1enSe
oOonn>oTf<c0]ZfWXZ6RYZff`/oMj_Kmoo[]ekZGLTh^5PH00P/I:CU7De]NGEQ>
@30N3P<01a`lIY>nhOOonnkLbKNZXZ2U/<3Dj?SonN6iQe<W2P055Ra1DUaOFT`i
8@`01Ai;Q;cWoOg]eKf[XJ6Z_MG^o__P[6db300:8SeBGUiC?B89010nP<;`ooCI
_JROY;GAk_oebXDm3@0@;DYLH5@k6`<5;7>ol_o/bjnPX[CClooUXe4C014cDF1L
AR@60bmod?cifKNQX;?FmogAO2X12bi@H5]06@0BF[Oeo=bfX::kh_k]XT861R]@
HEPh3`4]S>?oiKbQXKcVomn28`0H@emM@1@0;I?[oMZ`WJ[An_>R=P4C@EmM>`d4
B;SllL:QXL?bn[0n0AA5HET`119dh?kGZYffj?k0B08EAf9E9P0WWOOb_ijWe?kL
I@P>@V9F9@0b/?gW/YbdjObW:04^G5hd0b2Nn^ZcW;K^mi0F1ciRE1d1EM[lbInW
gOn`:08gHEHO0E_QnL2L/>_fP``BCV<o1B>`omJRY=_nXAL;BFA21RFgoljNZ^Sf
N0DMFEhW0FC^kJfMcOn^6Pe>HcD0CNCb/9c=ojLC4UAQ:@5bn>6RYNKbHP0bI4/7
;M3h]9_>oi878UmE3ak1o;RKcOn<12QRCPLcg?6ZXN?`D@54IC41P_k;V[ooWPLW
HdX3CO7OW[3j_18MHE05ANkPWK;l[`XVI4D0J?c=VLKnM013IBH=^ORZX^oA6QaS
B@1/o/BIeOA52EQI2DKedYS9neH5EE/:AOK@V<ofA0]LDP9XokfKiMTH8fHh1KCe
XZonQ@1=G`a9nlBIh]TD:VP/4MKSVLKh?A=T@@:dlIfioU@;HDL0Zo>N^Oi=3f=1
1;oZVLKe;1mX;AWWdIORc0HoH`aLojfWof`8HD<5c>2GfMP9?V<9JojU/_i06VPW
:ORlWo]j1f8n3N?>V?2M0Ea81MKEUnfT05a81]_@V?:A168l4no0W_eS4VTU>OnY
/O/U<VH7R_:Gf<H0FDT9il:OoU0MJQ9/nIWBc01JAPob]jOo:c=T0ZkOU_=i46XI
HoVGfKL1I34coj35fP1K@1cmYk_W15M65_^X^NP3F4<LoZ?1fP1P=c;oVm:h0fPP
H_FDk7XGJPJ]eY[o;3iJ1O6]^>80HRi<nIC/LQiX0Lk1YoH7FSXio9GYM1mX0=^h
/>L0IBEZjiCm<49C5?nJg8`IJ@3O/[SE0F/AY<nQn0=R:6gVU_lEES]8li?m9Te5
=OVBnRm9B37jT_//C4DkmY?n7U@jE>^Fo`]P9h3GX?<0J`nl^kK72f`0lIoJMBiJ
6_fBo1eI;gOGX^X1K@;UXmEh<ELUn9;o1fHF^;NnYaiR4OjAo`eT6KJf`I`UGAoh
Toh1K0OQXMiGAT1UejKC3VP:oi7o16/8i9kU@E8`T<2kVb]D?NFNg`aY3ObBo01_
0?jAoPM/1O2FmAQV3mfMjbYO6<jRi3IL7LNThSQL7<ZRiC1O5]JMkB1V3>VFn0e/
0_Z@o`1`0OnAm`EZ5_2Ld1iGD/jhPT@cZjSR:VH9li7o06l8n9SG7UEPa<IKEa[O
UO`2L0GiV=0UCGbeec=V1_^>nPMU>]:lIeLGjY3o0F/Vg;AeDa[XT?l2JC;B_UUN
3?V>mQ1JJKKM7Vl0niVk>S7;U?l0JSO;bCUZ0?nF`ST`dY;o1F=H^=lDL@O/[79M
2Oj@e38ddY3n2eYnY_@1KS77daea2>NdE6P0nij>E`_oT[i47OF=gS8^i8g`9C_B
S_PKA<B@o1I8_I7m5DVmT?`HALJ?nAhne8g`:C;WS=li8_N?`4/@oiNAG`;iZEI^
0n747g<T`>H1JVZPoP]?`Xg^<R?jTImN0OBc=7<L`NP0IHZDoB4alhnXG@3`^b5d
>:gj1do?Rm==2?Z^<g@]/?T8C=R;`EP1k/0CLF6JoR@XoIQULABmlPA>fX^_HP3K
fP1R/H_DE07Yb`EYWHcNC`;[b`AWYX_CE`3Pf01LbHZ[I`G6l@Q2m9AOMC>RobhF
nkL?K9n:aV42b?8;>ObN=gEZT>ED0=GY1T3jW3MeM8gHG@;5maDYok4>JKb:SW<]
WOU60]_Y2CKoZa9Z`8YlMDJCiUX2_OdW4^oF0D;mYa=XbhaOMg6:^FhSW?=E0K_o
<PONk18Rn<d1@?na15WaWAaZdi0oLjb9IWN6R8YgIXVWMDb<_G8jSl]^;i;DK2VC
f6`WTmM/:Y;BKS:?ag4oS;MeE8VNMfn7OgRCR5Ue^XdbKMjI4Ugh[056olP5:?7W
7@_BoCl0[_MQ6i;4MFB6K7K1TAYOnkD0<O?W8PG2oeLAU<EgMHM:KnNT0CkihR04
_OaQ98^JNK:@4eGoca8<aomM8H^CNL>G1TGjiBX0ZNQcJ8HhIOg33@k4oFHlQEY_
m;L65<[nICb5DVcj`@l:^_AaJ8LTF?kQ;`2I^g[4W@0Wf?mS?h@jHOoN;P6EZ7WN
[@D?^^mfTHl4<mooIDb5853fmU4SQD=Po^U24HMKJ?oR>`b8HFWohcd?QeATo^a9
7X@gEoKiFd6553oPog21T00K^nAldK0A09F?L_oRA1n38dKSog>HV@<8XJagoMi4
8X<G>mCfN/R`602:Eegcofn?VPH3UGmZo?YXNi@31IJ0JO[mKHjL2P2<F5WZoWW6
]RH;PQTc`MMko>MHGHl20hmKEnCiONG?A3N700VEJU_VnGg/edi?SP@0RCQ1amIi
ooQ_[K8]7H<02I5DCM3MN_ojLl6o?S^;1@246RNWS67Sl7gon7?5aDQEUA<8P@48
S3De/9QSh>Uko_mlk^IXZk]4EYPL5X@2084638//:j5ZBkn[IMgMM_GiO_ooO_[f
N>GUKLKAGj6nCgf]?ebP<46F92b?6Aj:4A>630f420V31PN21@J21@J21PN320Z4
2`n641N:5b>?8CFG;TbQ?6Z^C8foG;;CJmGWMo3hOokoP?cgN^[HJljSDZmQ<Y@U
4X<307l53hXSB:I<WLm_i_J0oo]ki/EN]F8]SA03OP@ASS5]_6KJlh3omWGCV4BH
80Un0aBB?8c?MOOoOnRlDZ4/37d46iQ9[N=nooEa`fXVP`06RcVBf7comW6oG1eo
0AJIDLKcP_?6D9LA088YO==moneVZbd6OQ]SbG[ol6NY:0=o9GgHP?cFDi@80Xe9
b?V1fW`RO@U2_WSoj5bH2@>@DmgoN/111gh^Wnj3gg/LO1M`fh?^W2Ym3UgCP_6Q
:g`@I]V3jXXNNaj;jh?DF0Uo?<OnN:lI0IATnniFR@0haX;_RQUk<;_mN:T>2JAe
o[l`NajMmgf`4`NTMof_9GX_`_m_U`0]b8CNE0::HokF>7/T]Om`U010ehG79@>T
NoB02hAMoM8aNSKJnUJ059omKhl2I>inXP4ifXBe2Qk9Q/@G4;f5cB4:]hGA9@Vg
QLlQ3;b6aaLEaXJj2RSGPjT0B^YlU@=mo6^35[_mCWTikm/WOF3oS@BEO^8`2lB6
[01MmVj27M;`=GYMoh41XHG82cOZMhHHcnl_O6ShF0:lQjD1Rom?N5;oP@2/Qjh0
POm?N5OnJ`6lQY/8]_@^OgGU82[/L7`jo9L0[hNN1kg]8XN0c@EUodahJNlX:O1W
N57mD@kNMG]1of/6e7Yn??m`1MAiO47oGPcPLGQBncXTleigJ^H@G?lkP86n0;?T
3j68T2;iPPGLL7IQk15SoRb;R:4BkYP2f71fIn86RO<DXHR6>Olk=_hkQHRM6_U^
5?A@O8B[4?9o3_1BO8FW5?Q[6_U2QHVD:olfBOhOWhIlEnP3Zll0eVMgPZTHoDTn
oabUPgMZc`;SQAKl<iB8NeoJ0=b;5_d^VXIgK<L7mEPmoA2kLgF4Vc7j2jZj1_Hg
V8EeM[<Joab?c0;c>IR4M7bV:oX7`9PKoaBoJW^<Of;73olMVkL>oaVmJGf<NVnd
8oX4eG14l03]=JAhMhamK;@VmP3YBW7=2_l@d56APWB;Ofb_<>d1nan_Rcc/0O/G
cDnFO7N=MH2?F[lUl07m4/eNLK`Nm`3j5=M0ZFV6Q7B=M8F3KZ5;b2C/1_l1m1g9
E8ZFBM4Im@;o0o@Fg370CJEVSgUoQGJ<LHibRgR3PGV=Ji]LZdbk?<//fQoV4o0;
n0Cm0Ol0o`3n0_`4n@Of2_@=l@o`4>l@k`o`3_8<m@Wg1_X3o@7o0?l0oP;k1oD>
kASQ9=@caD:dDjASU7:6OW^8M8i`Sg6<Mh:4LiIM[T?;9^L=n`3n2>T[^FEhZCOQ
2oh0nA?K>;=PSgigSVn=NG^DEklXk0Co2Mi8R:P/l@3l4m=8WGMhSfn9Q6Je;>h1
najbRCc]0?PO_f25RVj<PFBl8?T1i5=Ve`Gl6kmUOhm_PiI4h`;h=8791odO]Vmg
TGIa]Qkn3;VK6olB`FYhTGMZ`Q3o9XGB0O4lU8U^PZ8Zo0fX^PKg=iF:KWj]7?lU
N><0fUejTWiDi03@VPki>8n?LVc>0^Mn6_dbTHmbImH0eIl8l4enTX94ma64jPJm
OFao^`OYRPcaDGRAT2[o@CSo<HZCOd7l9U;o9i2BOD;l;4Oo<XJCR2goEAkfDgB=
ZP[Q[P3:OVaZiPa`oBV7Ti0MmI01dGe/I^hIC_m5MHbd0KOU4YJDRQkaY@2iS7Hm
ofl5dX5_D?iC3]elKEKmD0kKOVi?of@5c8Qd>_fC0:nBQQWOe1:;Tj`0S_i5KgcU
92;TOW0onjH4VIFU08WoDf][nEX2^9>=2ZolAFaameT1/YBG0X_oGVYEoj88RY79
4RKJRh0A/oiCJESo[Q1oRN8g1K>FY`57j8Mn3jCoIV/giNdoJUcn_ambM_b=2Wj5
l6H1RhgTC@2CT=a109NAfd40U93PC@2<S>]W1823n8hAM7;o`2aZE_?^D6T^`Omf
N0QZii6M1QJ`U]M@0gajolTiJ3W7ogf103S5Ula60gYco^ABJaR0iiB_8025O_oK
Cf/EL]fG`D04LfC_oGJ001ZSS_Vo@VTFJ=>Hf7@LJ3JUkYJnB@a[AkkfTkM12V]5
]o6F`UPEIc6>gIWNTcEX3dBbT?gRJ7h30giXh?bC_EdOIQQ?/hoolGV@6`=[>HW?
UoWNKHLB0F/iPLRDo_1lVC4AIQLlWWoaoIKBWTif101/=VnfRo_oU<fMDGX;0VLO
?YQdf>bJn>j3[V`lL@@1Ia``S6FcdY?noiSSdWNRH3ac2`MT1`Yb>5>HK;G<S_Gf
VoclU=gDO[:=G8e5=G@D56L00V@50fTI5g<a=h99GY=NPjA^XkAj_<:3clj9g=J=
i=b?j=n@j]n@j=f?i=R<g=68clJ1_KUgXjUZPiQHGHM2=gLY5V/A0V@10V@45FdQ
=h9MGZBXP<oXU_GoW?gYSljgK726=QUX1P5U3Bb0If^jfIGfoY[]bWMkQBl<H`0C
LTYR]MZGo?NCb:IB:fP32Fe2H[WVVooVQHj59P9R4D6L`iGmlH^IQR@0Hb1C/NJM
o<m]AVX15Wj>RoGgS95m50=]GWcVoY>TPQP2KVJ2k_R;Og@64h2WU_oEJBYR2Tfi
nIc7S1`4M8bBomAS6f0OImWnSG9[03NZmIfjP0XGSMNOgY4J2X73W^VH7PR0aIoS
TAH@RmbOagl5::KiVHQZ0U?CnWl_H3V4o/M507BgWmEo0cJkohLiGd6;ok4Y2ho`
VWIR6W_l`cP5RNfJLF4UQ?n_8ANTohT]H7>LhG`0EnOLB@:8liA5GfNLgWL1IoK1
:QN]oWD6LMFLHUiOW=E_2WcoV`M8i=8d5K;iI@27nhLBKMRJ@V6QXGYNJZ2/HD2K
cfPTU>A_58g_M0b9mGL:QoEg2XWcM0n=jfhJU=aW;i_0HE:PUUf3XV1P_9/YJnb9
18GoI`F_jSH/hkL8I?n22I7FHEfRHf7ET0J8oU@He<09JOie8IjFGKbF2XSlBBOX
Y027gV1kX2IfoeTMhZH0Rm5MW9X;SO@`B?ij9j9PI_UW5^6P0YJTGMio1/bc092f
G=V01]2[0INIGo1/6^b;6:9<LOhiD?iUNi/2[LH0TYmPnEXdoViRWP>]`02IOFSo
>E[eGKj24>ao?Z88Zk`1WeAglQ:3/eon?ec^Fn5W=OmQ/X4InV^6T0[^MFRG0nEl
FYX2hWeKV@?WN6^E2O5^RXXHoF>gMS?mFnIDFN1LobR1Ufg/0YheVK<EY03KN7n7
9OmJlSmeYfcX0:@E^XaHTQ_oF_DdPX1mbP^U0>eUbEYW]6gO0ZH0j6K;EFjOM/`?
X`KmF_LWTT6VSf^2A=YTi0>U0_aJo1ZL7<Mb^EEiM96LH85>`G749YL/jF;O3:0H
n5g[1:<Bo5c]1:<DnEgU2ilRjfG@8i<oaGN]FgQXNib1/dNA8MMOnPbW0OmJj12H
?kR3TiU@T1cQF_l0YQcSL:UiGH/QhUWn0:4b_XN7`2nS0?mLcTEcP2cPF?X7UeAh
]6Cm0:@d[9U`l0NW9L2@MN`9YbRgUfkf0Z@mT;1Qo`:FHdWKE^/_LHl7of2/XRbY
5<^EJOh1U6h/lES2Q3NX5<BNH_l@P8/5of^9iP:OHCCcFZjd5ZQ6Fn9F_ihOZD5N
heNg[aBVE3_eGIWN0IQk2OihKolFK:4<][]EciHIYV4Nog5aoamNYb5mhEVKj@23
VPNdaEF`e02;UPFhaUFYh@1oX1>9i5b6oQaDZdH[oh1Mi94<V904ZMUJPola?:U/
0n6fE9ch64f[H`KS^5FCoB`hYg`0/]iPKoB428bR:cOnUe>SnRXbY8`;LOb0E[K`
7CVUSPmOohmCVom=5I6U?A?QcUmUf]<;A:JB6cWh]UU]h/`;@:>J:acQeVMJ]_]=
37j]LPEPo[5IILg`>Q60[GT;@o?<IeNRoi41Aj6TD@1jokIOFZOoVPDgUZ]`2cCP
jH=BK/gjK@16Vj]c4B75nJ1JFI_fdC08HJBXK10M]_nfIe9hd?fA31]dZJI[516G
oMF0E5^Fj_9f1aa_YJ^1<P16cok0MU=KSmgnZbT1?8F[ZH0g0BRSn^ZRJ55MS=?o
e5l83Tj<Zj^<DA44C;cmjjedEE9YV]WohX@T01iJSJV^WGDm2`@kV^Woh:UiFU1G
LIcAnO[8M2H133EVSJJ`ZiQfBQh21cAk`o?oj/BJMemBCeMXQ:S>kooge9eO:PT0
32M9JHFJZ:n`Zj2@NUm29Q020@hXCGRSbNOiooc`g/VcWX]kKF9IDe1>Ce5EFf9Z
M7n;V:Fb_l_GhN[bn?cnooomn_Kbk>KPf]C>b<>n^KFb[jf[ZZZZZjf`/kJj_lC:
d=KLh^S^loSko_ooo_[fknOMdlNj[J2CQWY`IUiGDTm=CE1DFfAaP96V^m7UmOkn
l]^iT6<j6@D021/eDfn8VjVa/ZjSTGQI=QL30QY9Q/;^ooKI/Xa]F4i=Eff=]n7l
n]6;@0`06DEcUjbcZiA]?0l08W36n_S?VFeCC5QgZ^;ohhl`0A9:PZNcZXM?504i
Xo?h`X=IBeV3aO[/Rb01<GJU]:=a:@0bZocWWV=;F8[Fol0o02ajZk:AB@DQXogL
RUE=L/7oaCP1@Y6dYF@?5YoncgQ=EiS`iE<0?iFeVdP0C^G]SU5BTo;J>@EOZK1d
4B;8n9QBDicj^aHNQ[FH=@JLojMEDZ3nX@DjW[=c24KbcVA;RoR`1cfS/600O?nQ
Cek9l3HFSKEg1FGoXdiRemdG<Z>]B@O6i6U=Y?i<4i:cGP6gj6Q>[_L^:ZBY<b?d
/De]lIH1P;IR0lkAEEoT[01m]Ud8hKe=LOYY59nX8U3nN4bmf@9a]UPBmIa8WO<?
GkMR3OBIB:SV0gNe@3KoLE;OTA6VV@>k`dZ?m0Mf]35LlUQZobUF^4/jnemToR]H
]d5?lUEeo@]l/1JR`dN]`@Z[Q@OmL5_m8f^c6ZNhAlR;:kMAC^M;W<T>/FdZmU2>
e`V`KRkbCIc06;IBG]E7aWA7]a_1UE7l3hnI1_mDSl<N^3FOXdkk2iN<6O99_6iH
/@;jGXC69KTLeWQYk0jh<K^6H?@:^3:nPFGZ4kTNgVak`SBf0oiA[FM`WaCVAO48
ZEZCSV?Q9[P2od_;;9IeKYeMiBRg0?a6i`V]A<MYSg]eT4J]FN@a/PGWAol8^PCn
AO40^1OmBN05]2?hBm/7]27jBN@2^1;oAOH1^`7eA_hL]0k7E]1JU6J2RUFLBnE=
hP2k0>a:k4RKHgbG=J`VodCo8:hdTh=<Yb_oA?l^YEUiY1Rg1^e>bgA/f4[f4K4k
PilF^@3HG8fJ=Om4kF1geTSm::27F^46/dEc_`2j7hVV1[`?UiX<_0^IV@^l496T
1;/ROk/0]dYVg@fXSTol=hOM@o=cBom;VjL:d7HO_AUjcP^U[4KlK4_nDFbf0IVb
0ZbPA_Yg>?9R<KdTInheM_a9OkH4Q=8KRo55T[@3PmPSOoa;I;`KI?QDC?A[3kV9
A>BN0i_87W_oEBjmK4KYX06>fcQLmG43[M53NkdhC_JJ0HOXD3cGW0^5of49[mY6
C[j3@JNk=D[T[@YLoIT0LOj31XKdLA6EjF@IW^AO7:3THAVIjV/@S?El1GWnT@1S
o:L>Cmjh?D:L_i11@[SSD`BIoX8BFL_=G@mkoj<CB;>oWD@LYomn5T^cjX@0Dm:n
TD@EWobI=b21ojlm?dNaoh4T;HWo/4Lo;ZKlXT`:HMjo]540IKKfXRdo;j;e_6l0
B8BioXm51eJf_oAm=@iK_kodP3`8Dj>koi]M04EMZ_?@T2Ho37R`okZXFQLKG:Zi
ok^68Cl5I9;e`Nf:G@<o6G^Uo<7ZRf<9?PURQn:ookjECDT=5dmQVl?o`>jJORi4
21U=ChnZm/7ocJNAIDX5?P0]DeR=WnNmmO6li9n@IUY31cl44T<FEF=dTY[F]MSo
`_g^__G0[L>BTX1^L4=FC1Y8;PE05`0m2@<l0PXm010n01Dn01Hn01<n00hm0@Ll
1`4m4`10:0]8ABUHJ5]`RijFZ=g5_?ka`o7n^kc=WGiWIE0>7S`90DE?C7BJdLS0
o?nk/:b3FaLO>aL@Eh6`^Koko[BCKEI20@1:L9fd`?OgZGHb9c/X=GZ]oOjiTULk
>b4bO;;oojme8a@nEi6na=JeK44<7GFcooRLE`41F9okoj]T1P1DWO_oYU/00fB_
o^f8A@heUl?ASCdkGL3_^Fl60FNfll=J>TnfkkMU00n2`/]/7DBEonig>dFem:mC
24Fj`h062HC4[c01I;gBH0eC]>J06Db_k8TKC;3YOAAB]mUK1V;0^RX0PLJ<0b6e
`5d=OO6R?U3Yle/lWo9f1f[5T04ieK53B>_ZAdBdbR@;[ke<=]o_ATJj]0/[ejTk
Lon@1Gc6GB?Dkc]?`h/2ROmW@;VZ0F?kMSff[P5XoFa1_IL1VOe5D/I[8NK83H?1
@W3h@1OQS3^iU@K2hAF0`3j5ha9EodeGadiPnC4bnUaBb4iUm21>oceX`cfBaP2e
ePBaWc_2J4Gm:e3n9hBe=kYi=_l^E_`IVJHjaEM[gP35[@G^E6Vm=keWF^L0bY`@
nc>;YSg8@YfF;?`=[Zh>oBJQTD_5=kiJOKDJo`niU2Kl1]QEOZA5aSK3BYb4Dm@<
o`_?IUkD2ol9gd2NP6J]A<@fbCW0BZQYPIEBaBC]1_l1mAWAAienI[8gfQKd1?h0
oPCf3nXLg2[?=l=2^4^`DZ]FZ5RWF:QE[52bBK/oaCCB9^0Hk@ci0_l0o@S^7]53
Y7E^[CSN4?/0o0gR<KIRQHmM/T;5=LXh`4^SM6jb:nl1najbQco[0?PR]G=Y/Cg:
=L1CS9hbm03SGE?Z0>Y4QZ=1bSJiIfGC1?A<E?43dV]O`3C4EgC=0n]/;?lPVZ8l
bd>@]P[bJRCn=7jg=<=UD?HCO?0=YZ<hb5YIm1I/nQj8^3>iQQggO@[SNT?<D5kh
:SgmDUC<A77`8D7mFTg<CeCoEA3MScO2Q@kBf1=maS]klcTHgYHd^:T0O_mIA<Yf
4<C`=5G=HaoHiReGcFHHaoA2BLV30XOoMSJf`a@PcK8eM_nL36S=J`Z@oHHbWnmU
0GW=IPV2miTbPOng9D_5/AP:W<YJ3Gg_ZCIEioU`<Y;o_cLm/nQk4dg2c4h5F/Rl
>`5PbKXm0e[6b5D<CKkRR2HlZOc>F39nl_jE=SJFh/9J01R7cK9?53nVoo27=39m
b/ao6P9;/Oo^RcLOD:C?]6Xa<W36jLMg7@TnU^ok_V@=0d6IkOW2LB0@=g[0f<jV
MD``;TB3a_SeZE<81cQdY[_?f]BEA`83>6nCZ<ccmk=X<S<`81UFXMWAcn;]/6Y1
Ac8703a[Kh2jmNC@hOBkQ81lAPlW<0/0=TdaEI2HR[WXalcom=3YolZoi[bG^JQg
R99PGWeA?fY8;5e28EE07E=07eM29f57=g1ADX=ON9YfZ:nFf<6nn/gXo=7ofLWY
WZnHI7`a?C@0;P4Y>RanJ[6ma?oAol:kXemY3c059Sa7VY;bd?k9^Xm?A`0^2g1^
e<chckUnAB`:=T:T/?o?gFaR02hISY[od=mYF00a>jW5m<B:@18bE<S?oX]d0311
/mkG[C8^28f^ml5T<`1jWOc4JC80Pjcc^cl]4jGJbYP6<F_9ogQ57ESad9Pe0IC?
bHh0>[GBd441QLC=R`10eM:I<PjbnH4j>h?g[@Hg`]:B;bC2oUH8Q=JVE2n3ki`0
C?_263?7dEd/O]>Q;DC?cc<RbNLi4/C`?0g3lC/@a^Xg7L_E<C_A[Ba`e6`/^<lU
>?Bk05ShRb6I]c]djf<0^^lbC=AM<>Zk06cKEFKYG@77`B^`bP=KiUYZlTl@dGT`
mZPJ[XD3`<L[d[/8V9@6_l@[h[0J^G02cfdfogEYo3QWc`1nW`C7Sc;oKWWo;jfm
5/MG9]@7MY/0cdi7fAnmWSChAZO?;OmPUn<[ofRDi2_oGigC;_a4/JHgiQc7F52a
0=D<R6X]c`oO=[VQKOD[oCC3EUZB3]<8gc?EQYFm>/L0eP3:=lb6W:I4Y`[B6?TZ
oc?<6iM8Yi>IVTn8</9Gk3?21=4Zob_Q0=DHob[W0=DLob_I0M4fmc>`7<9]_Dm`
Ni>_@9Lhlc;D0_TZdP_5Lj=UCm1?d@3h:/8P]IYAWC3o1]=>`ei;i2kG8Nm6HLI4
eQOdAEo?>=LZgEQ7mA3DHXVA;O<9]Jl>kbf=VdkG</1g<OH<[;h0ocmDm@G:W1Sb
<F_P4<jE6o<cH?44a:l2od/mo1:FdB:aWBNQ[R7@X0GoDc?VBUcHMbCj@c_a?ekH
PQCoEBo=RBK<]PG=XRQ[o@^2f7TAoV/WTnL0UMQb4Oah9WOm5VOFZ@F`cCLgcK@2
WmR30MRf<C[<`02<f:@9RniC9gGoD22feh<0[NA@9f_jO@JEf;@W=?VV=2f<of4;
U=No@`kAgUHVBLO];AjRf<5A0Z?jPc0/Lno54bbVf<Q^0eKfbePW<h?ccB@CQ<gH
[TH0JoOEJBhXDK?o/1/@Ll7Jbh`X16o`jXa29ReK/_cGDP4YP/7Ie:mV5@MSf_k6
MChW:41f`__ZRR<0:G6/c][E_Y1?4`4_RmooiZebB2lU9cA@N[3Ro_>oM2l60am;
NJ2mcmSKf<noYhQT?Qd600`YDh>bf?;noO;OajjEOVYIBd0g<2/X9R@T92DV:2/]
<3<f>C`o@TA6B4Y:Bd];BTQ7AD90?CXg=30^:bPV9B@S92DW:Rhe?DQEIGR?Yl7I
k_com]nkSEd`400463QNPj>lc]SLf];1YX1B90D3:6fil?oU/Wa@<bDS;4E_Z^Go
ghX]01IDUL;Hg<n[KB@0;9Wbm[EY>2@W@h7DolA602Qo`=_H]VXC3H7dj8]192YG
]?k2;`EL]M[FXc`0J??LL2hSB:_oY@dVVMKHXBd;Z_fF>297]oeZ06O9g:ha4LO/
JbH^ROf<06W>fI8<E_jO<RIdnXd0O]O?GPC6fd/QF^nM08OK`cH/niDY<kWP26SG
bCXboghSAnR?2jgMR03H/R/fdjP7[]eg2_F58UWn=DoG_@jUb2dkjFDddl8@[;/W
B_dYJ]jD1_aR8jRg4l[73LRF8GgQ1<7=4LV>89?06=:d0?eA:nHhN]i>N[PQQL4S
fIHNkb]JkPWBZA3e;5cW4]NC<MLRRYe>gdJ/O2G]3[K30oPXMJa@gbgLDcWk3M]_
S80Xo03DQff>9_/0eW^;MRkn4]i5fdEB`UkJ0OTR]R30WfEm<ODcg`Wl8/4>cgVe
BeVCT/4bTRk^C=T2bb;o9=l1hb3m6]l1hB3o:Md1`bKeEm4UQCjWWjFN?hLMeSgo
7oLPg0bD?IFbQ>8Vf0WO19/nQKiWnaol?<mDC8/6h06d>876B_dPkhfGib3lD<2T
:n4Vd74fbQGFGC[55MEY==@TcI@YlDbfeQonRH?o8L74;<ln<n04Hi/:diPSoh]b
nB]Rg@5RZ1[5eakKaARNL@7E[1o/_aZJN`O<eajfeP1IbTn?nCHHh7`Pj<X3H/UJ
O>E=0=7Q86ORB2?^cP18lYP/RZiALli_6JKfB@71ocD3coP/3=G`:A3Fl2X;d_P`
0/Wo?P:dmE/KSLZ@ETb5eih:A?oA5b6/hj@Q5/koDb=bVM>W02kLhY4P3<?`OV8V
BogLIAhDa>Z?O@/ce>??<PaeOoWCBad;/lC;^A<L;<KL]k0=72S1c/g1;1d5WY?j
fiT^6T91cN7oPIL770jOQ_oRhEA^01dMYhOohoA^U@lL0653/MSLh]_2CWX5701B
=GS5X?oTojk=W4Ek3AhD720AO465`HO^g]Oii?o3fnJ5aJ5FYEPjObDZG0XR?`0N
;00L8P4L7`8L8P0M;@0O@0DTG1T^P4E1YXQSa]>Ig?kIi>[ogj7C`E=ENRD06Q/e
3c>RXXSMooSQVK>V<@HM6e0hDlgjjN:HXI4T0`0YXlJliKRnVb@60CBmlnkOK44m
6VV5WNFcXGPK?Dj0i<>/NAY:K9_UV6=0793HjmU40014f^C5NAYa_nCH?04@InBO
C1`YboGALaZFmOn]75o2llLS>iOQdBP_Rmo@9SVQkLHOFm;oZAVAoNQ[7/ORMa@o
i7`36jCL:DOCohLLb==806kT=c35ogdOeZP?6[W>6i_hNPA]hRQUoKXIE>D_FO^j
55kS9W[nM`2DdaVia@a2lX`Ti4dfm:l4Rm0HcI44]N`QJ=/IaiH5a]P<RlTIgUI2
oe@LlV`nha_6QQ[fMa7`ITSN6=UDF_<>Rn<4_Y<ehaSJBWGF0=f37_lVU:P_haSQ
<ZR><oP5bXH]o0OBHFbi;>4HiakE?ZEoE]4?o`KOBX>]:O80oA3J?ZIcMIm?_SKB
9mdNi1WW5nPGiaSV6^DKhagR7N4NhQgS7>@JiQWW5nPGj1SV6n4Sebo6AJ]VPiAA
bAge0?`EbF=YaQCn1>DmV91=bb?U5nHRbe>0]1[o4;>P6OlI[Xm1fQSX8/1bAo<6
/kH4keEPd1[X9ZjK5OUN:OhmJM4HiCJ3fP>Mi0^K^acX<H?S3Fkm=5oL5]9m5>:k
0iW75miT8^^j1XWC5/nD0I[lBSgY:7OmJP2QcaK4^`/hiJTHfXh0HOBL6M^A0DST
]1K9aRD9WmXKQ_ng9S_YE@Qbk;TE[_NE73_YJ00c^=XOFM_oUaJfnK@o9=boCPXn
ih/I05OZL@X2H>Y`301FjHDR0cgT]F@W8]3cd7PEU>[lbR4SBiCZKb4=:=7klJPH
?5nEjXI>=ARRhN[PB0/98koin=a12P`O/NGPiVU5AQEUJggXfnVm:@077Ib_XN[?
il8a2R8EH4ECf?gWjJ35]bl@>1@/1bNSTg;Oo]c[d?_MLj>d=S5_700Z51<35T85
7W0T:Y=<>:U^A;J4C;b<C[b8B[Ie@:QF<Y4_9Fh<6Sl0510L5@5M8cNTBJcFUogZ
l=CViFRjC2=<0a@1LcFFf:kkjoMa]BlI6C@QHLnUnNWQCHL04`VPIo_/n5jB01@E
]XckikD/>30Z/nSnMY/05D7Ff;304A<Pc<^h`@`C=mSYS9d179cZnSljDU3oi5`D
4m7YNGXQ=o[XIA<Qg?e>>fUeh<807mc[MQ<fiOPZ0[cSI4AeU;2=;eSX^PTho]00
:OoI0RClg0<To]P0:oo=13ga/b5R`h1OY7TbZ_0f0=kY5ES]CaOdePIB`FR=i3H2
ij`Bdml2E;19/OlKCNdI:nIlTODQ?^dC<m1H]OhDY^4;Of<0jFLMlGB/oA??d3g<
:TCZ0GII0ndCAhX4jSTdY@kXAc6U2nTc?8/0k@eMFQ7/1J@ZMMY@nA;fT;fn7<<<
k@Il=6gFK_hBlS3X574dO/^Ai1Zf0>hBha;oBNL<SB7FSmE4Gc:XZLUMESBZX]51
K2GKN><9[QCo8nhIoABZ4MbLUDd]gF7[1ODCXbC>`CbA5?H2j8JIFako5>ab[5HM
o`[YTG:04n<7dLh:hQAcUVg^@/YF5nd8b=`1obP]o`;KcP7m9Bco0=7M1oI55mLi
S>mYI;hDBoL1d><P`8D@InH6d^@/X:PC?ol<W>nB4_m24X_E1LK/KbWl@15jk`6S
kk00f9/F9<fO3/C_W`3FZQ`IV^T5On[OD2?lOaHMW?4DF=k/W0>FkThA9Z[a8C_<
l<i25N79>Q0UV?mL2I?VkKP^6MCSFQLBA<?fDPAgeo3PTQHRb_F5:a0HC[koT`/S
T][_jKiP1RNeolAP910B;Fo=ol9302Qoa>K`k=FSEQ05BkKjl[E^>QdA3aHYC8:o
lOoMUdTA01@oLYo1f>K^l?3/i=S6[Y5aD34H1`0342DoGG^H//SJj?;ioOoooogk
n_Sgm_KfmoWjo?koooolmnoTeL6ZSg5C=Qd;0@4<83aLOIfhc]kXk_7`k>?B]XmO
;@P296RhlOkNY6Li7A4>52M>S]KohH4O0C61`nGak]VTCPHISOC/TT0G3QQ3WOKN
DP0oZ>?biZm206Sdf68M3Am[iN8i2X;Ll^292d7`bdLA4e?NeaTa_O3WSPE/ohDL
3dCLaPESg_6i6e3oNADDMom3:lcb`AQ/mdh>;]JX1K7bbQQoiS<>G?lTH^[S@Tod
=`i[n0FIl[d1gXH?=OT[MO360^Ib3E;k0;[aLD;R7AoY<HKbV23`7aoa6ZCbHW>]
3UKS5^O>0?lU8?`1cn@8nc8Kn@7EgP3n7C;e6NjVAZL<XTNZj`[o73kFCO=<fSPR
nBSbHl/k9?<jlcgc8DBZR^`0iPfc3N6[QDdRi6S_0M`<g@7`E?PFP2;PVklWE5GB
/Z<^Ce?FY/4QKQoXKoX@_`?c4=L>oG3T@4M4@nEUo`cgAnXaATdTkRoQ3nN]]]l?
i3cYE2^90O<9Ee0<l`1i>R7b0h8h7_<0K4/6m0Y2O@S_FQ_GEm3U2oG6IMXM?o<2
?iT/g=`;i=X[Sdd1kIl=mm@_RE/<i=d;/>d0=<f1SmP`0>_=2iWb5AWocB1JZW>8
_DlKboXS0>Kg4aO_ePhhl[d<Ao>j33gbc`hOk_4F0^7n:`nnd6=MKFo8_@XRnnhl
2egam20</:FT/@TKh_BW4037^Yfg0A:Zm?D[>F=1oo6C4PFQKOC/JPl1XVOkl9TF
76XekOGiA8T53CoKZmk/TQXn;aE`i;OOk[LYL`@;3:e;j_?_/>NQ:H@02P=P6EW@
IO;bf]kcnGOMUS2X9A=N00/N6PX1B0h5LA@JSA/_WAliXR0gW1`XSAHAL101AP/8
60Xc00ml:BG1WEkYnl;ee?o[GHb_5P4X2U/R;MW/_?F_g/hO12<;QVeSl^OlgBH6
6`jX]jCfS96:2Ti4G_C1b:H;@d=VmJ:BMPV<]L?b?@L48NSXfih9QL7JjQl=7fOf
GQ@4;?:UGBTHjLb<@Q?VdX`l5^^iGQXUlghE05Gf=@aB`>@=PoGfPPkXYbH0Jo8H
G>GiNA;aK`11d]09e/4V29_S2LSA;`RVg0WKX`A5jZP?m3ldj]4KF>d:e9l0QOmD
=_<<cJ00YO8WH>D9kT1EoTDUmVTik`S]?F[a4gKd4iBm5oH:iT5dg@3:XP_gA737
6?@8laW:I5gM0O=3L=D4nb>]Pe?;8>`<mPSf3>dJfCJfGhR@Ekl]ha3h0_l0o0Kd
3n`GiAcS7>DGk0od1_`0o`;h4><]_UN?R5ng=MTJkPcf2?H<k1o;Dh:^8_/5dW@o
m@;IHeo>5o@8m1W4Mccj4ICE0=:1>>/8mA^cY@WWTPKQPRkb2>Y9C_m88O5i:_D:
f8@:bm/DK^@8k5XPhM8GGn`8fiP0K_b55oLVEoW27DOe3i_jP0IOlPfLoIXE@OLJ
F^WeKa?dI@0d^N<9Yoo<D1KdM`T8LoDL<iGTfPVDmOjZ1lGnhXD9e?OEOPWAo>RI
1kKkolP9LJoAkQ`<6EOhNDDb3]Ooom@>:RiKn9V:M`N;XZ?hIU1H1i>MU?R9Ti<8
@B@jl?OojRlJ@@MeCDS`o?ScEW:J2`X439i]B^godORbmNQ2L:dB1Td75`L8H0XB
X4@UahHmg;MDi]=Tj]eZjm]Tj<]Ch:PlcflT[b/AMP48:aX7078CA<U5f?:fkoSm
KMeS56@81`BS<M3ef[c_WA]X40TXdgKkn>8^QPL8=^2PfO1h3AUg;o;ilB]Y;AG0
n?hiMbXGd_W_8Ce/>_oeL0P3f<27]0`CgOV_2`3IdVJ9@C?kk148X_Vg2@g]ob8D
aLQFFh^5T99IG;J^?T_5]Ca=_:Y@Hib8OI=UB[SJ;@OVoP`Un8`6cO@07n>_Kj@o
2^cV1Ygf02O1O;Ce3cWi61WEQ;Sl2W?f04Ad6^n[1oneW?L9VO0UU2HLn@1<DP3i
4c5_1?TM;f`1n@Y3BPOi0glNF_1>iPO]]lSE2/0Kn0IS877VSo`7eR7i08/?dkGK
OBM3@>VKi@im2_Adn@Z;2?>1kA1U;^JkVBhU]ZG`2:<6l0kiJ>XH=ZBPm03P1Y8V
f^4D[@Fd4]oQ3/05RdFnl`Sn42oS@OVCNGL5Ycnan3KN?PSB7L3g>/iB1YmYOoZN
>//:9_l0eoI7WHh6>?d0doQ[FLd?4]MBIoOQ4LR91akXBEodkCi/fa`7KO@2X_WS
;FoW:@DimE/`go[53XkT<@DN_Ll1Qo;h/P]kn5H92E7aV`26kO[KD`S3iE0;1BVX
oEl4P>CjlkHa3JglT2P71Qmfjn=:0EG0l?_feH8K2GW_kY@m4PD543Akd_oDJA05
?X_7jOOkn_?P_XU;5`0BBI;Bn?kW`9AZB2lM4P/71@@41@H82`hB5adS:Bhd>Ce0
@T=3@T0m>C@^:B<M5a8>2PP610@41@L;4Qd^B6ZD`>Snn=6@Aa406Dj<`>;dn__g
j<F7>@<ELmcnbG4]3@@55DFQm^AS0R^Fh?Wkk;0n0Fgfe5TC10Xj]?ig05gDnOW@
C`BYmfdA0aR9ofL8W_?kd3HWm:8J0andhPYZk?_966ke@`@CY=d1V?SbJagoF`DE
`:LAeObn0>9o1aC=O3S^mV5>hAL7UjlUkOE5RJX86oDG[?bT8nL@4>HN/Ob3GJd5
=_<BlNH0oaP?mP7QlP[o6Q7n0o3O2=/6BK5eo5gC<0cn3ORdJFD5i`3e_VIM1oTA
nXK<8QgFQ?X6h`>Z0oFV_1lZV<7[:f4;lH;g1H/7o7Ch1g/:jIo^?SdRNN:gf`Z@
0?`G`0Ga[N2N4801o0>64H_ZPo`3ojOHe0GNFo263;DfmVX?/C[dQPWDJ>KD0onh
[o`4/?8/Q2X3o3@?e8S7oPEnnP0^U5GKo`Ean`PFf:RD`B80mlh3Xo/;3_WH=e6;
NJNj=AgOn1@0l_d92OS_1Q;ik`L;m_/<0>gk7AS?`U1_OeZmdPdAnoY90T?ioa/^
YFO7h`44SOck6d22>o[hH@<0eXjmjQ`23^6K_>db0`32F?Wk_15C?`bDn=JLkE86
:5`>S?B_e?[:8J800P:958g`P_cmoHGb[2:j60ID2`87E`D<Wa18bb>9hCRejdS9
kdg<kTNlj3JGfb5J_@lIQPD1=@8j00JSBRKZiXomfoogAWVa1PL;1K:9F__Poo0P
54@2UWIOo;WPd0HH0acdmOoW30/17oOOjlP3F5YaoE@/:PW[m_C30Xk0do@<:49m
o2<34EKm<00<E_dW1bMonQ0jRmKX0jWmlXd5mIPV053l3V3MoiT6nFL0<kgS0^Fa
7PZGk0;UYPdTb=83nDXI_oQC9O`5bL8=@o>B4od6b[40Poe1A?@2nBQglb5=od=A
jP?m2MAi9_i8?OlUQL@CnP7l2]i>K]D2lD]Ph`3`>hjR=n4?n0?m0Od3n@_/7MHh
]eVENgBJF;55`CW9=</faCniCjEWRHIWZDG:9n@Am@Kl0_h2o0O_8L=UIld9oBJ?
``Oh>86m6_P2oPKVBFGZ1ZCC0L2Q7OX1nR2Bf`N1n2UPj@;m5iKW7SWeQaSm1=BZ
0VClQQ?n2JO_D@6Cj07bM@1Lj[d3ndh7M>k30_Mg0anSk`7:lY`]7?h/3eW1k@:`
oo2B0o70LB`Ao7@R1R?nFA439?iW9Q<CnjEnFPCWn_S:0H>Q[?`S0@@BmnC`c`9:
>4WnWKB_0E/j@?g7kMd72089h>VdoW>[a0D920BnTUCll_ClFZ[C30QM0Bh10i`b
5]fU@_G`O?co[okcd?kUg_kQg_kYcokh[ogoNoWM@NQn5KLB0e8D0@2=36[[G?on
m8SdRPj02`4:bSSio_iGg1D10jPXm_kn=;440Ccb/Z7]7`44ghC0lR@13nbePmH0
0honoAM6TD7Um0l1M?ke2a7BXFfZAbG`l@05i_i70HOoX053o/d1:ogD0CCn^@5T
og41`?dC1Oo_5BZ/X9n_9@Wgj`6=oPD@djjWc`l<oT`4mLFKd`X[o`THV5;_h03l
g93O17ok9h0F8Oh3DbP;o`5A91On3g`?G_UIf@7XdLkX0/Pgo@m06eGfT?l1eS;n
07`5gk__FRHOM^KEXAD]G^SHRB4JYLSc86H3odko:OT2KRO/i3QW0O0>oJFX;`Ko
9?jRVch3k@7hgab/06AfY_mGdc82c1?Io2k[;0:h<kSoPGV:0CC`5OGg8]]@04OY
3nolGGV]10[ADVollbjOY@D5X;0Jionk0>m^0PNEe06no_=H<Om>0PEao1iKkooT
@RgmP@/05jO`83kHo_c59bc^_Bd20AZ>ohX0FMGlooB_;@ZLok4n2@014U?1okD]
0T^]j?coo_GETSd44fW<o^b_JC@E1P4000864BA1Ii6kg_KonnW?/91aECh/7Q@=
20D30`8310H93QHQ<4ALN9Rienomo_3E[hEK>1h=104000896d5l`oSf/4T545V]
i?[oooSJSRT2G>7eU347004FI^3/D@5XfOgoljLK:N3IAPD03FgkSP25l_oeS02U
jCd20T3`Q0c1o_bN0=:]3`0Vig@WiOoM5Z6n3@1;oPRVoo4^UZl60iVX;OGmK5g4
1PG1Egkoi03n9@20U6;nh07h30GS3=SnC<dn09e0__mEeBh1e@G]m`3[0RjnQ?mI
k1<<nD_oMN<B4>Ekob[l0E=3inhaF@;oDolNi`2a0_mao`5n0_ino`6H0_lniP3a
EOh5E`VQj<SX0J`Oo`5>4UKkK^L0mLoDlP3aSo2m0MIem;H1hXkZiP3ocK[g0:kj
<g8N0Oli1MBTc?H2Fol34K>Eb^T66OmH0Okb:SUjNL_D4@7kl`0lohT0Z?le0=kn
5`7ZoQT0f_ll09goU`0_o_X61nS3@Xm_:^Sh2P20ooT;<[19eoPJ02SieUK;2061
o_A0`PP0Eo_4Q>lO0071;_oooBg70000`2;[onJ7nHT9S`H009`9NO=Co_o>aooo
H_[29nMY3/X^1JlD0j0=0Z8C1;D[2M9T6^flAOcmW?oEnOmJ`nL;4G40A`87i<mj
ojkck`X1;P2oX6_oS<;;040F8_k=k]`0A2Tioh>:R@39imkj1QdJ@Om561@<oYUb
C`?j_I=N0_^ZJcD:of0A03Oo4RYgcNh0e_:[?a3o72VIllT0o680?<SQ0?]N0VS_
^0;o5V?k^QI=nP3iD1_DhB=?mP3n77gg=B[cNb?l0?l@/KP0b[P0e8/ZmP3o0?TM
/9LQoaVM^0gn7Jn7B]LCm`;o0?l0o`3o0_/7m@k]5^DMh23O7n8Jj1?`2oP4o@7o
0?l0o`3m1^lS_FiKf@?g>W7L0>ILF=d8o`3o1]aX=oli@_llEn`1o`;RNA7N`0F9
h@7o1kGH6bgT/0Ko1K3[B`:Bk@3lD0V2mk<1obTRX_Zi0?i@03>[m03Ljihk3_l/
1Bj:o@63e_KQ0<oon[l0h_ge_`3Fo_oQ09Zna?d7614bofUPJ@3Lm=om30071_Sm
n_X:01L1i>JZoe>9^P0b00K]iXooWOCf4RR@02<80:/g4>o5BokoW?oWfOnlm_nN
o_nEo_nRn?o3h?o^YoomEoZ`5mLQ06PG002/2YSlO^_onBkL3@0?V`c:on1`lbX0
2KPRo_o^3hA21<3ooanK>`GJonh7@JD`jOdX03?nnAQRWSc5l@41i?m]047ok`40
no/94?7T4R3/hA0Em?H60?gi02[oSP38o`46hmYhLbdPn_<0WOl0595liol0Sol9
;TXPoYh0m/O<n`3:nF^b0V_o>8X5F?m1W`:BnXKX0?SAi=`0/3?o1Sd=JOV`o@2c
7ol;VP3nVOhBB`;Q^o`JC@7fU?l0X`3L5_mln0<WP]Cm0:l0U@_hkb200:8=loP1
b010TjGoJm8V0<T;jOlYmaP0`AoBogj>K`0]kQckoC7AD00Wo@;XojHVj0`0HM`=
joo70?]700RoSR[_omlAZ[X<01WISa?EoofI0=6h5@03GoiP5L3nonm_0Jk_E@D0
0C?3ldX8Qn_ooo_7C@1Pk^Ec7@8000DXN]_n]d417FfjjO_ooooon^[;WFHb3@0=
<66C`>7fookgjmkAa;VaZjNVYj^a^/CAg^cgo_oeh;jAGRh<00heJZ7>k?_ooooo
nnNfIaP3Bl;odVhQ0`000RB2kn5:0F;EoOoohVh0KOjS800037KnN@BLn_ojU`2W
hc0003G_O1GDoojI0nb00P0goBYboOn`1Oe400O8KUCmogi7ePH0N[8joOi<YW@0
5?l0kOm/W6H0<]a0onh1j049oa7nl`;F01oEL?nNZBh0h@;niCaR0<H0o]]/=@3n
A?mOo`0l@_?_FbP3gkOo2U`0nJ?o3TT2dmKfMP`W9On:nP3XKolX6R4Eocn/0<Wb
^_h0oloRn03ma^;l0?kS^nl0[Oi0KA03obH3^YoRn`1bo`0=WI[JiP4DofP0nOdE
5iniZ8DY@>kW1PCmo`41ood00Ooo0P?jk0hhg8m=[fhMgo/10:gog00=iGZ5j`80
Tooo4XIQ1o3ok`QfG`C@oo`]e0404Nm@kooU4;/3003@5^CoaZGoe1GK501J9`00
W04ch@nGn2cIoTWboeSgoe?_oS_@nQb5iPDQZP07=`1g20?[^doog?Wo8eF/04T4
1o_oeOlR<W@0^YY[oTmWR`38bZWo4@091_nlb;80f?Sfm02</<7m06fJ__`0T]C`
j`7On]^70?mK20AGo`2_on5]1Oh@A<OoX@7o3e_/jU<Eo`3M_AHTd/T1oP7:a0]@
ng/Io`7o5hoV4VOm;V?V0Ol0o`c8QRGo:GOP0>=JHlhCnP3o0?h0o`3n1?DBi2O<
?[ICYEnMHYmLZTbm=]DOj`cj0Ol0o`7n0?l2lRJ]TBcm4:Bo0n]QB>`1o`7o3[Bg
0;_F2H_L0Oh0lFLBcn4SB?`1obE6km@/;ol0lYD98[K[0?m@0DG3k@7lS1/0C_l0
YOWk/03oR3P@5?hO0Pm:o`TK:eco2Ph@=_hX20h6ojJcZ`7@g/7o2@0<0_gho?`2
0``0mOVooc1Q[P5F1`Gim9GnRO?k32nZ01DQ0H/90MYP3oNg:OkR@?o_AooY>ok<
8ON52MdS09050AUd02S[7nkoa9go^PJ`2@46iB[oo_`Hb0P1:ob7XOhd0@3XDlCo
;`47nZEMhQ00c?kG00[_U537D@cdo`@0c_i^0Egna04Yom`0:?k60E[nLP7:o`H0
m_E;<eEbk?408Odl0??VVi`61?hh0<^diOh1`oiGO`@ToPHb6@7m02PJ1Oh:CPI8
ofS80??Mkl`0O13m3X00kM3kHPhBFO_MaP8W>?cPZPP>Un;n5eL0mS[mN?X15:k0
oa[a02RE`?hlo`84oSWog3Z00T6KUofmEWh19>DkooX7oa41MHm_ooXFjcX25ol3
e?g[1^]A00:`ScKhoMh7c9010B?aESkboOag4OF11083MOhk;]Woo_=h0:;eGPH1
00mhnK@@:k;hoogoiXdK38?djHP`1`020P057eJOh_oXYeXM0@LVDGbS`MSWlOSl
o_ooooooooooooooo_chlNOG`J9kCbD70AmMZn_ogi]A7@@00P8023B@k^mf1bBI
k?omooBT7Ag9kf880@4;Moil0iWkoOo14FgjBP023kK:0;3oo]L;/;D70Q7OHTgl
oM<0mTL10/9QKoooGXJC007:<k7mj07g1@2U@;kl_dR>0A_VCOkY6ZD1:KBHo9;5
6@3Z2ooUD4H1d`OodiLG0?]ooBkX0W@2olCL0B91o>>j0R@Zokoi07l<o2:H0O?I
mk<0KaKl02l::OhnQ`1mofNQ07Ko@fd46o`054<Zoj81o>^YZP8:o440lnf:KALM
ooL2Ho`c0Ogo2@CFlD/JVma`9XoMHQVflRL4n?l30LKlYP84om/KWGl=nOmA0`Cl
V6Kb0093okmFl`832OIAf?jd08A104WmFnOln1_[5058E@4@h@ZeodoooK7Ao>jD
oOm`o_mZo_mooO:ao;gaoEg]oPmGd007<`:^>@oool_m<GO30e`>2_oWo_h02@@1
onSom@5I=SWk<bDi0?o5c;<3lo[je@C^n_:n0_g3TUD1oC404FCo0LGofg02n`Y=
bOn[0?`8JO;UCaCn0_2D0U3`Z0Cl0OMP5=CD47?[0?/1oBUekQ20k@ZX/AKn0?`4
oP3i6/1aF=L9o`cGCXZJAm0Nk@_i1?`3nPOc5Mde/FmZ_1oi0?0dV9hbk@?o0_/3
o`GMIS_o;5Km:fGZ0?`3oRYNof@6_l`0n`3/U05IlK81n`2llgT9@?l3l[Hh04Oo
0]Se^EH3na8HC9[o0/GlomL4mnSJ[0;lh=nn1>oooo@3UHelo@h15`3ok?ok02D0
1?o^n_l30dP3ch@boLgloaADb08E9@>V5P7bV`\>"]},
  ImageCacheContents->"Sound"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0.`\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0.`\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Fourier Series", "Title"],

Cell["\<\
Define a function that is periodic  with wavelength \[Lambda] using \
the modulus function:\
\>", "Subtitle"],

Cell["\<\
Boomerang uses Mod to force a function, f, with a single argument, \
x, to be periodic with wavelength \[Lambda]\
\>", "Text",
  CellTags->{
  "mmtag:17:periodicity__constraining_a_function_to_be_periodic", 
    "mmtag:17:Mod[]"}],

Cell[BoxData[
    \(Boomerang[f_\ , \ x_\ , \ \[Lambda]_\ ]\  := \ 
      f[Mod[x, \[Lambda]]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AFunction[x_\ ]\  := \ \((\((3 - x)\)^3)\)/27\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(AFunction\\)\\\" is similar to existing \
symbol \\\"\\!\\(Function\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[TextData[{
  "The following step uses ",
  StyleBox["Boomerang",
    FontWeight->"Bold"],
  " to produce a periodic repetition of ",
  StyleBox["AFunction",
    FontWeight->"Bold"],
  " over the range 0 < ",
  StyleBox["x",
    FontSlant->"Italic"],
  " < 6:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(AFunction\\)\\\" is similar to existing \
symbol \\\"\\!\\(Function\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Boomerang[AFunction, x, 6], {x, \(-12\), 12}, 
      PlotRange \[Rule] All]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0396825 0.309017 0.294302 [
[.10317 .29652 -18.4688 -20 ]
[.10317 .29652 18.4688 0 ]
[.30159 .29652 -13.4688 -20 ]
[.30159 .29652 13.4688 0 ]
[.69841 .29652 -7 -20 ]
[.69841 .29652 7 0 ]
[.89683 .29652 -12 -20 ]
[.89683 .29652 12 0 ]
[.4875 .01471 -26.9375 -10 ]
[.4875 .01471 0 10 ]
[.4875 .16187 -41.9375 -10 ]
[.4875 .16187 0 10 ]
[.4875 .45617 -29 -10 ]
[.4875 .45617 0 10 ]
[.4875 .60332 -14 -10 ]
[.4875 .60332 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .30902 m
.10317 .31527 L
s
gsave
.10317 .29652 -79.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.30159 .30902 m
.30159 .31527 L
s
gsave
.30159 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.69841 .30902 m
.69841 .31527 L
s
gsave
.69841 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.89683 .30902 m
.89683 .31527 L
s
gsave
.89683 .29652 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .30902 m
.14286 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.57937 .30902 m
.57937 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.77778 .30902 m
.77778 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 .01471 m
.50625 .01471 L
s
gsave
.4875 .01471 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .16187 m
.50625 .16187 L
s
gsave
.4875 .16187 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .45617 m
.50625 .45617 L
s
gsave
.4875 .45617 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .60332 m
.50625 .60332 L
s
gsave
.4875 .60332 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.01 w
.5 0 m
.5 .61803 L
s
.0075 w
.02381 .60332 m
.03279 .54164 L
.04262 .48471 L
.053 .43558 L
.06244 .39972 L
.07298 .36852 L
.07839 .35575 L
.08426 .34412 L
.08969 .33523 L
.0947 .32849 L
.09946 .32327 L
.10458 .3188 L
.10963 .31542 L
.11425 .3131 L
.11647 .31222 L
.11889 .31142 L
.12116 .3108 L
.12331 .31032 L
.12602 .30985 L
.12848 .30954 L
.12986 .3094 L
.13113 .3093 L
.13253 .30921 L
.134 .30914 L
.13518 .3091 L
.13645 .30906 L
.13764 .30904 L
.13873 .30903 L
.14001 .30902 L
.14073 .30902 L
.1414 .30902 L
.14263 .30902 L
.14393 .30902 L
.14507 .30902 L
.14631 .30901 L
.14761 .309 L
.14882 .30898 L
.14995 .30895 L
.15099 .30892 L
.15218 .30888 L
.1533 .30882 L
.15453 .30874 L
.15582 .30864 L
.15815 .30839 L
.16065 .30803 L
.1634 .3075 L
.16795 .30626 L
.17051 .30533 L
.17285 .30431 L
.17738 .30184 L
Mistroke
.18168 .29881 L
.19129 .2892 L
.19666 .28184 L
.20153 .27379 L
.21101 .25381 L
.21993 .22917 L
.22972 .19471 L
.24004 .14889 L
.24972 .09615 L
.25394 .06991 L
.25853 .03905 L
.25976 .03033 L
.26107 .02088 L
.26218 .60126 L
.26341 .59228 L
.26803 .56017 L
.27821 .49822 L
.29655 .41389 L
.30667 .38051 L
.31594 .35695 L
.32611 .33779 L
.33122 .33047 L
.33681 .32402 L
.34211 .31924 L
.34711 .31578 L
.3516 .31343 L
.35646 .31158 L
.35899 .31087 L
.36176 .31025 L
.36466 .30977 L
.36605 .30959 L
.36737 .30945 L
.36859 .30935 L
.36991 .30925 L
.37101 .30919 L
.37222 .30913 L
.37353 .30909 L
.37425 .30907 L
.37492 .30906 L
.37612 .30904 L
.37742 .30902 L
.37867 .30902 L
.37981 .30902 L
.38113 .30902 L
.38237 .30902 L
.38352 .30901 L
.38458 .30901 L
.38574 .309 L
.38698 .30898 L
.38822 .30895 L
Mistroke
.38891 .30893 L
.38955 .30891 L
.39196 .30878 L
.3933 .30869 L
.39477 .30856 L
.39744 .30824 L
.40022 .30777 L
.40273 .30721 L
.40564 .30639 L
.40838 .30542 L
.41326 .30314 L
.41853 .29976 L
.42345 .29563 L
.42804 .2908 L
.43351 .2837 L
.43848 .2758 L
.44865 .25489 L
.45955 .22431 L
.46948 .18801 L
.47865 .14635 L
.48937 .08675 L
.49461 .0529 L
.49691 .03706 L
.49812 .02843 L
.49942 .01901 L
.50061 .59884 L
.50169 .59098 L
.5038 .57603 L
.50841 .54526 L
.5181 .48847 L
.52882 .43714 L
.5387 .39948 L
.54803 .37149 L
.5579 .34889 L
.56781 .33248 L
.57344 .32556 L
.57871 .32047 L
.58369 .31673 L
.58632 .31513 L
.58912 .31369 L
.59182 .31254 L
.59425 .31168 L
.59673 .31096 L
.59901 .31042 L
.6012 .31001 L
.6036 .30966 L
.60602 .3094 L
.60734 .3093 L
.60856 .30922 L
.60973 .30916 L
Mistroke
.61084 .30911 L
.61183 .30908 L
.61291 .30906 L
.61408 .30904 L
.61532 .30903 L
.61638 .30902 L
.61755 .30902 L
.61875 .30902 L
.62003 .30902 L
.62077 .30902 L
.62144 .30901 L
.62274 .30901 L
.62396 .309 L
.62528 .30897 L
.62653 .30894 L
.62768 .3089 L
.62879 .30886 L
.62983 .3088 L
.63106 .30871 L
.63219 .30862 L
.63449 .30838 L
.63695 .30802 L
.63962 .3075 L
.64208 .30688 L
.64474 .30606 L
.64767 .30493 L
.65259 .30243 L
.65783 .29885 L
.66274 .29447 L
.66791 .28866 L
.67716 .27478 L
.68712 .25399 L
.69802 .22312 L
.70828 .18506 L
.71762 .14196 L
.72279 .11428 L
.72839 .08098 L
.73096 .06452 L
.73368 .04624 L
.73601 .02993 L
.73733 .02036 L
.73856 .59985 L
.73981 .59075 L
.74115 .58127 L
.74354 .56476 L
.74897 .52984 L
.75884 .47471 L
.7685 .43051 L
.77738 .39755 L
.78768 .36748 L
Mistroke
.79299 .35506 L
.79882 .34362 L
.80864 .32892 L
.814 .32303 L
.819 .3187 L
.82402 .31536 L
.82666 .31396 L
.82947 .31271 L
.83192 .31182 L
.83462 .31101 L
.83711 .31042 L
.83938 .30999 L
.84163 .30967 L
.84399 .30941 L
.84522 .30931 L
.84637 .30924 L
.84762 .30917 L
.84896 .30911 L
.85013 .30908 L
.85139 .30905 L
.85258 .30903 L
.85367 .30902 L
.85466 .30902 L
.85575 .30902 L
.85689 .30902 L
.85795 .30902 L
.8592 .30902 L
.85984 .30901 L
.86054 .30901 L
.86178 .309 L
.86294 .30898 L
.8636 .30897 L
.8643 .30895 L
.86555 .30891 L
.8669 .30885 L
.86838 .30877 L
.87085 .30857 L
.87224 .30842 L
.8735 .30825 L
.87595 .30786 L
.87826 .30737 L
.88289 .30604 L
.88716 .3043 L
.89184 .30173 L
.89681 .29813 L
.90173 .29356 L
.90623 .28839 L
.91635 .27281 L
.92574 .25272 L
.93465 .22779 L
Mistroke
.94424 .19375 L
.95447 .14822 L
.97285 .03877 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJPWooo]Z1?l0000BoookJP00oooonfX1oook
JP[o001o1_oonfX3o`00O`[ooo]Z1ol0003ooookJPOooo]Z1?l0000BoookJP00oooonfXAoookJP?o
001o2_oonfX5o`000?oooo]Z2OoonfX4o`0001;ooo]Z002FoookJPCo0000M_oonfX3o`00O`[ooo]Z
1Ol00021oookJPCo0000PooonfX4o`0001;ooo]Z002FoookJPCo0000M_oonfX3o`00O`[ooo]Z1Ol0
0021oookJPCo0000P_oonfX5o`0001;ooo]Z002FoookJPCo0000M_oonfX3o`00O`Wooo]Z1_l00021
oookJPCo0000P_oonfX5o`0001;ooo]Z002FoookJPCo0000LooonfX6o`00O`Wooo]Z1_l00020oook
JPGo0000P_oonfX5o`0001;ooo]Z002EoookJPGo0000LooonfX6o`00O`Wooo]Z1_l00020oookJPGo
0000P_oonfX4o`0001?ooo]Z002EoookJPGo0000MOoonfX4o`00O`Wooo]Z1_l00020oookJPGo0000
P_oonfX4o`0001?ooo]Z002EoookJPGo0000M_oonfX3o`00O`Wooo]Z1_l00020oookJPGo0000P_oo
nfX4o`0001?ooo]Z002EoookJPGo0000POoonfX7o`00083ooo]Z1Ol00022oookJPCo00004ooonfX0
09Gooo]Z1Ol00021oookJPOo0000P?oonfX5o`00087ooo]Z1Ol0000CoookJP00UOoonfX5o`00087o
oo]Z1ol00020oookJPGo0000POoonfX5o`0001?ooo]Z002EoookJPGo0000POoonfX7o`00083ooo]Z
1Ol00021oookJPGo00004ooonfX009Gooo]Z1Ol00021oookJPOo0000OooonfX6o`00087ooo]Z1?l0
000DoookJP00UOoonfX5o`00087ooo]Z1ol0001ooookJPKo0000POoonfX4o`0001Cooo]Z002Eoook
JPGo0000POoonfX7o`0007oooo]Z1_l00021oookJPCo00005?oonfX009Cooo]Z1_l00020oookJPSo
0000OooonfX6o`00083ooo]Z1Ol0000DoookJP00U?oonfX6o`00083ooo]Z2?l0001ooookJPKo0000
P?oonfX5o`0001Cooo]Z002DoookJPKo0000P?oonfX8o`0007oooo]Z1_l00020oookJPGo00005?oo
nfX009Cooo]Z1_l00020oookJPSo0000OooonfX6o`00083ooo]Z1?l0000EoookJP00U?oonfX6o`00
083ooo]Z2?l0001ooookJPKo0000P?oonfX4o`0001Gooo]Z002DoookJPKo0000P?oonfX8o`0007oo
oo]Z1_l00020oookJPCo00005OoonfX009?ooo]Z1ol00020oookJPSo0000OooonfX6o`0007oooo]Z
1Ol0000EoookJP00TooonfX7o`00083ooo]Z2?l0001noookJPOo0000OooonfX5o`0001Gooo]Z002C
oookJPOo0000OooonfX9o`0007kooo]Z1ol0001ooookJPGo00005OoonfX009?ooo]Z1ol0001ooook
JPWo0000O_oonfX7o`0007oooo]Z1?l0000FoookJP00TooonfX7o`0007oooo]Z2Ol0001noookJPOo
0000OooonfX4o`0001Kooo]Z002CoookJPOo0000OooonfX9o`0007kooo]Z1ol0001ooookJPCo0000
5_oonfX009;ooo]Z2?l0001ooookJPWo0000O_oonfX7o`0007kooo]Z1Ol0000FoookJP00T_oonfX8
o`0007oooo]Z2Ol0001noookJPOo0000O_oonfX5o`0001Kooo]Z002BoookJPSo0000O_oonfX:o`00
07gooo]Z2?l0001noookJPGo00005_oonfX009;ooo]Z2?l0001noookJP[o0000OOoonfX8o`0007ko
oo]Z1?l0000GoookJP00T_oonfX8o`0007kooo]Z2_l0001moookJPSo0000O_oonfX4o`0001Oooo]Z
002BoookJPSo0000O_oonfX4o`000003oookJ_l0003o000000?o0000OOoonfX8o`0007kooo]Z1?l0
000GoookJP00T_oonfX8o`0007kooo]Z1?l000000ooonf[o0000o`000003o`0007gooo]Z2?l0001n
oookJPCo00005ooonfX0097ooo]Z2Ol0001noookJPCo000000?ooo]Zo`000?l000000ol0001loook
JPWo0000OOoonfX5o`0001Oooo]Z002AoookJPWo0000O_oonfX4o`000003oookJ_l0003o000000?o
0000O?oonfX9o`0007gooo]Z1Ol0000GoookJP00TOoonfX9o`0007gooo]Z1Ol000000ooonf[o0000
o`000003o`0007cooo]Z2Ol0001moookJPGo00005ooonfX0097ooo]Z1?l000000ooonf[o0000o`00
0002o`0007gooo]Z1Ol000000ooonf[o0000o`000003o`0007cooo]Z1?l000000ooonf[o0000o`00
0002o`0007gooo]Z1?l0000HoookJP00TOoonfX4o`000003oookJ_l0003o000000;o0000OOoonfX5
o`000003oookJ_l0003o000000?o0000O?oonfX4o`000003oookJ_l0003o000000;o0000OOoonfX4
o`0001Sooo]Z002AoookJPCo000000?ooo]Zo`000?l000000_l0001moookJPCo00000_oonfX5o`00
07_ooo]Z1Ol000000ooonf[o0000o`000002o`0007gooo]Z1?l0000HoookJP00TOoonfX4o`000003
oookJ_l0003o000000;o0000OOoonfX4o`0000;ooo]Z1Ol0001koookJPGo000000?ooo]Zo`000?l0
00000_l0001loookJPGo00006?oonfX0093ooo]Z1Ol000000ooonf[o0000o`000002o`0007gooo]Z
1?l00002oookJPGo0000NooonfX5o`000003oookJ_l0003o000000;o0000O?oonfX5o`0001Sooo]Z
002@oookJPGo000000?ooo]Zo`000?l000000_l0001loookJPGo00000_oonfX5o`0007_ooo]Z1?l0
0002oookJPCo0000O?oonfX5o`0001Sooo]Z002@oookJPGo000000?ooo]Zo`000?l000000_l0001l
oookJPGo00000_oonfX5o`0007_ooo]Z1?l00002oookJPCo0000O?oonfX4o`0001Wooo]Z002@oook
JPCo00000_oonfX4o`0007cooo]Z1Ol00002oookJPGo0000NooonfX4o`0000;ooo]Z1?l0001loook
JPCo00006OoonfX0093ooo]Z1?l00002oookJPCo0000O?oonfX4o`0000?ooo]Z1Ol0001joookJPGo
00000_oonfX4o`0007cooo]Z1?l0000IoookJP00T?oonfX4o`0000;ooo]Z1?l0001loookJPCo0000
0ooonfX5o`0007[ooo]Z1Ol00002oookJPCo0000NooonfX5o`0001Wooo]Z002?oookJPGo00000_oo
nfX4o`0007_ooo]Z1Ol00003oookJPGo0000N_oonfX5o`0000;ooo]Z1?l0001koookJPGo00006Ooo
nfX008oooo]Z1Ol00002oookJPCo0000NooonfX5o`0000?ooo]Z1Ol0001joookJPCo00000ooonfX4
o`0007_ooo]Z1Ol0000IoookJP00SooonfX5o`0000;ooo]Z1?l0001koookJPGo00000ooonfX5o`00
07[ooo]Z1?l00003oookJPCo0000NooonfX4o`0001[ooo]Z002?oookJPCo00000ooonfX4o`0007_o
oo]Z1?l00004oookJPGo0000N_oonfX4o`0000?ooo]Z1?l0001koookJPCo00006_oonfX008oooo]Z
1?l00003oookJPCo0000NooonfX4o`0000Cooo]Z1Ol0001joookJPCo00000ooonfX4o`0007_ooo]Z
1?l0000JoookJP00S_oonfX5o`0000?ooo]Z1?l0001koookJPCo00001?oonfX5o`0007Wooo]Z1Ol0
0003oookJPCo0000N_oonfX5o`0001[ooo]Z002>oookJPGo00000ooonfX4o`0007[ooo]Z1Ol00004
oookJPGo0000NOoonfX5o`0000?ooo]Z1?l0001joookJPGo00006_oonfX008kooo]Z1Ol00003oook
JPCo0000N_oonfX5o`0000Cooo]Z1Ol0001ioookJPGo00000ooonfX4o`0007[ooo]Z1Ol0000Joook
JP00S_oonfX4o`0000Cooo]Z1?l0001joookJPGo00001?oonfX5o`0007Wooo]Z1?l00004oookJPCo
0000N_oonfX4o`0001_ooo]Z002>oookJPCo00001?oonfX4o`0007[ooo]Z1?l00005oookJPGo0000
NOoonfX4o`0000Cooo]Z1?l0001joookJPCo00006ooonfX008gooo]Z1Ol00004oookJPCo0000N_oo
nfX4o`0000Gooo]Z1Ol0001ioookJPCo00001?oonfX4o`0007[ooo]Z1?l0000KoookJP00SOoonfX5
o`0000Cooo]Z1?l0001joookJPCo00001OoonfX5o`0007Sooo]Z1Ol00004oookJPCo0000NOoonfX5
o`0001_ooo]Z002=oookJPGo00001?oonfX4o`0007Wooo]Z1Ol00005oookJPGo0000N?oonfX5o`00
00Cooo]Z1?l0001ioookJPGo00006ooonfX008gooo]Z1?l00005oookJPCo0000NOoonfX5o`0000Go
oo]Z1Ol0001hoookJPGo00001?oonfX4o`0007Wooo]Z1Ol0000KoookJP00SOoonfX4o`0000Gooo]Z
1?l0001ioookJPGo00001OoonfX5o`0007Sooo]Z1?l00005oookJPCo0000NOoonfX4o`0001cooo]Z
002<oookJPGo00001OoonfX4o`0007Wooo]Z1?l00006oookJPGo0000N?oonfX4o`0000Gooo]Z1?l0
001ioookJPCo00007?oonfX008cooo]Z1Ol00005oookJPCo0000NOoonfX4o`0000Kooo]Z1Ol0001g
oookJPGo00001OoonfX4o`0007Wooo]Z1?l0000LoookJP00S?oonfX5o`0000Gooo]Z1?l0001hoook
JPGo00001_oonfX5o`0007Oooo]Z1Ol00005oookJPCo0000NOoonfX4o`0001cooo]Z002<oookJPCo
00001_oonfX4o`0007Sooo]Z1Ol00006oookJPGo0000MooonfX5o`0000Gooo]Z1?l0001hoookJPGo
00007?oonfX008cooo]Z1?l00006oookJPCo0000N?oonfX5o`0000Kooo]Z1Ol0001goookJPCo0000
1_oonfX4o`0007Sooo]Z1Ol0000LoookJP00RooonfX5o`0000Kooo]Z1?l0001hoookJPCo00001ooo
nfX5o`0007Oooo]Z1?l00006oookJPCo0000N?oonfX5o`0001cooo]Z002;oookJPGo00001_oonfX4
o`0007Sooo]Z1?l00007oookJPGo0000M_oonfX5o`0000Kooo]Z1?l0001hoookJPCo00007OoonfX0
08_ooo]Z1Ol00006oookJPCo0000N?oonfX4o`0000Oooo]Z1Ol0001foookJPGo00001_oonfX4o`00
07Sooo]Z1?l0000MoookJP00RooonfX4o`0000Oooo]Z1?l0001goookJPGo00001ooonfX5o`0007Ko
oo]Z1Ol00006oookJPCo0000N?oonfX4o`0001gooo]Z002;oookJPCo00001ooonfX4o`0007Oooo]Z
1Ol00007oookJPGo0000M_oonfX4o`0000Oooo]Z1?l0001goookJPGo00007OoonfX008[ooo]Z1Ol0
0007oookJPCo0000MooonfX5o`0000Oooo]Z1Ol0001foookJPCo00001ooonfX4o`0007Oooo]Z1Ol0
000MoookJP00R_oonfX5o`0000Oooo]Z1?l0001goookJPCo00002?oonfX5o`0007Gooo]Z1Ol00007
oookJPCo0000MooonfX5o`0001gooo]Z002:oookJPGo00001ooonfX4o`0007Oooo]Z1?l00008oook
JPGo0000MOoonfX5o`0000Oooo]Z1?l0001goookJPCo00007_oonfX008[ooo]Z1?l00008oookJPCo
0000M_oonfX5o`0000Sooo]Z1Ol0001eoookJPGo00001ooonfX4o`0007Oooo]Z1?l0000NoookJP00
R_oonfX4o`0000Sooo]Z1?l0001foookJPGo00002?oonfX5o`0007Gooo]Z1?l00008oookJPCo0000
M_oonfX5o`0001kooo]Z0029oookJPGo00002?oonfX4o`0007Kooo]Z1Ol00008oookJPGo0000MOoo
nfX4o`0000Sooo]Z1?l0001foookJPGo00007_oonfX008Wooo]Z1Ol00008oookJPCo0000IOoonfX5
o`00O`Cooo]Z0ol007l3oookJP;o001o1?l00009oookJPGo0000M?oonfX5o`0000Sooo]Z1?l0001f
oookJPGo00007_oonfX008Wooo]Z1Ol00008oookJPCo0000I?oonfX7o`00O`?ooo]Z0ol007l2oook
JP?o001o1?l00009oookJPGo0000M?oonfX5o`0000Sooo]Z1?l0001foookJPCo00007ooonfX008Wo
oo]Z1?l00009oookJPCo0000I?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l5o`0000Wooo]Z1Ol0001doookJPGo00002?oonfX4o`0007Gooo]Z1Ol0000O
oookJP00R?oonfX5o`0000Wooo]Z1?l0001GoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o1Ol000000ol007oooo]ZoookJP06oookJPGo0000M?oonfX4o`0000Wooo]Z1?l0001eoook
JPGo00007ooonfX008Sooo]Z1Ol00009oookJPCo0000EooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o2OoonfX5o`000003o`00Oooonf[ooo]Z00Kooo]Z1ol0001boookJPCo00002OoonfX4o`0007Go
oo]Z1Ol0000OoookJP00R?oonfX5o`0000Wooo]Z1?l0001SoookJP?o001o0ooonfX3o`00O`Wooo]Z
1?l00002o`00O`Sooo]Z1Ol0001coookJPGo00002OoonfX4o`0007Gooo]Z1?l0000PoookJP00R?oo
nfX4o`0000[ooo]Z1?l0001SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l4o`0000;o001o2?oo
nfX5o`0007?ooo]Z1Ol00009oookJPCo0000MOoonfX4o`00023ooo]Z0027oookJPGo00002_oonfX4
o`0006?ooo]Z0ol007l3oookJP?o001o1ooonfX00ol007oo0000o`000003o`000003o`00Oooonf[o
oo]Z00Oooo]Z1Ol0001coookJPGo00002OoonfX4o`0007Cooo]Z1Ol0000PoookJP00QooonfX5o`00
00[ooo]Z1?l0001SoookJP?o001o0ooonfX3o`00O`Oooo]Z00?o001oo`000?l000000ol0000:oook
JPGo0000LooonfX4o`0000[ooo]Z1?l0001doookJPGo00008?oonfX008Oooo]Z1Ol0000:oookJPCo
0000HooonfX3o`00O`?ooo]Z0ol007l7oookJP03o`00Ool0003o000000?o00002_oonfX5o`0007?o
oo]Z1?l0000:oookJPCo0000M?oonfX5o`00023ooo]Z0027oookJPCo00002ooonfX4o`0006Cooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP03o`00Ool0003o000000;o00002ooonfX5o`0007;o
oo]Z1Ol0000:oookJPCo0000M?oonfX4o`00027ooo]Z0027oookJPCo00002ooonfX4o`0006Cooo]Z
1ol007l9oookJPCo00000ol007l8oookJPGo0000L_oonfX5o`0000[ooo]Z1?l0001coookJPGo0000
8OoonfX008Kooo]Z1Ol0000;oookJPCo0000IOoonfX5o`00O`Wooo]Z1Ol00003o`00O`Sooo]Z1Ol0
001boookJPGo00002_oonfX4o`0007?ooo]Z1Ol0000QoookJP00Q_oonfX5o`0000_ooo]Z1?l0001c
oookJPGo00002ooonfX5o`0007;ooo]Z1?l0000;oookJPCo0000LooonfX5o`00027ooo]Z0026oook
JPGo00002ooonfX4o`0007?ooo]Z1Ol0000;oookJPGo0000L_oonfX4o`0000_ooo]Z1?l0001coook
JPCo00008_oonfX008Kooo]Z1?l0000<oookJPCo0000LooonfX4o`0000cooo]Z1Ol0001aoookJPGo
00002ooonfX4o`0007;ooo]Z1Ol0000RoookJP00QOoonfX5o`0000cooo]Z1?l0001coookJPCo0000
3?oonfX5o`00077ooo]Z1Ol0000;oookJPCo0000L_oonfX5o`0002;ooo]Z0025oookJPGo00003?oo
nfX4o`0007;ooo]Z1Ol0000<oookJPGo0000LOoonfX5o`0000_ooo]Z1?l0001boookJPGo00008_oo
nfX008Gooo]Z1Ol0000<oookJPCo0000L_oonfX5o`0000cooo]Z1Ol0001aoookJPCo00003?oonfX4
o`0007;ooo]Z1?l0000SoookJP00QOoonfX4o`0000gooo]Z1?l0001boookJPGo00003?oonfX5o`00
073ooo]Z1Ol0000<oookJPCo0000L_oonfX4o`0002?ooo]Z0024oookJPGo00003OoonfX4o`0007;o
oo]Z1?l0000=oookJPGo0000L?oonfX5o`0000cooo]Z1?l0001aoookJPGo00008ooonfX008Cooo]Z
1Ol0000=oookJPCo0000LOoonfX5o`0000gooo]Z1Ol0001`oookJPGo00003?oonfX4o`00077ooo]Z
1Ol0000SoookJP00Q?oonfX5o`0000gooo]Z1?l0001aoookJPGo00003OoonfX5o`0006oooo]Z1Ol0
000=oookJPCo0000LOoonfX5o`0002?ooo]Z0024oookJPCo00003_oonfX4o`00077ooo]Z1Ol0000=
oookJPGo0000KooonfX5o`0000gooo]Z1?l0001aoookJPCo00009?oonfX008?ooo]Z1Ol0000>oook
JPCo0000L?oonfX5o`0000kooo]Z1Ol0001_oookJPGo00003OoonfX4o`00073ooo]Z1Ol0000Toook
JP00PooonfX5o`0000kooo]Z1?l0001`oookJPGo00003_oonfX5o`0006oooo]Z1?l0000>oookJPCo
0000L?oonfX5o`0002Cooo]Z0023oookJPGo00003_oonfX4o`00073ooo]Z1Ol0000>oookJPGo0000
K_oonfX5o`0000kooo]Z1?l0001`oookJPGo00009?oonfX008?ooo]Z1?l0000?oookJPCo0000Kooo
nfX5o`0000oooo]Z1Ol0001^oookJPGo00003_oonfX4o`00073ooo]Z1?l0000UoookJP00P_oonfX5
o`0000oooo]Z1?l0001_oookJPGo00003ooonfX5o`0006kooo]Z1Ol0000>oookJPCo0000KooonfX5
o`0002Gooo]Z0022oookJPGo00003ooonfX4o`0006oooo]Z1Ol0000?oookJPGo0000KOoonfX5o`00
00oooo]Z1?l0001_oookJPGo00009OoonfX008;ooo]Z1Ol0000?oookJPCo0000KooonfX4o`00013o
oo]Z1Ol0001]oookJPGo00003ooonfX4o`0006oooo]Z1Ol0000UoookJP00P_oonfX4o`00013ooo]Z
1?l0001^oookJPGo00004?oonfX5o`0006gooo]Z1Ol0000?oookJPCo0000K_oonfX5o`0002Kooo]Z
0021oookJPGo00004?oonfX4o`0006kooo]Z1Ol0000@oookJPGo0000KOoonfX4o`00013ooo]Z1?l0
001^oookJPGo00009_oonfX0087ooo]Z1Ol0000@oookJPCo0000K_oonfX5o`00013ooo]Z1Ol0001/
oookJPGo00004?oonfX4o`0006kooo]Z1Ol0000VoookJP00POoonfX5o`00013ooo]Z1?l0001]oook
JPGo00004OoonfX5o`0006cooo]Z1Ol0000@oookJPCo0000K_oonfX4o`0002Oooo]Z0021oookJPCo
00004OoonfX4o`0006gooo]Z1Ol0000AoookJPGo0000K?oonfX5o`00013ooo]Z1?l0001]oookJPGo
00009ooonfX0083ooo]Z1Ol0000AoookJPCo0000KOoonfX5o`00017ooo]Z1Ol0001[oookJPGo0000
4OoonfX4o`0006gooo]Z1Ol0000WoookJP00P?oonfX5o`00017ooo]Z1?l0001/oookJPGo00004_oo
nfX5o`0006_ooo]Z1Ol0000AoookJPCo0000KOoonfX5o`0002Oooo]Z0020oookJPGo00004OoonfX4
o`0006cooo]Z1Ol0000BoookJPGo0000JooonfX5o`00017ooo]Z1?l0001]oookJPCo0000:?oonfX0
083ooo]Z1?l0000BoookJPCo0000K?oonfX5o`0001;ooo]Z1Ol0001ZoookJPGo00004_oonfX4o`00
06cooo]Z1Ol0000XoookJP00OooonfX5o`0001;ooo]Z1?l0001[oookJPGo00004ooonfX5o`0006[o
oo]Z1Ol0000BoookJPCo0000K?oonfX5o`0002Sooo]Z001ooookJPGo00004_oonfX4o`0006_ooo]Z
1Ol0000CoookJPGo0000J_oonfX5o`0001;ooo]Z1?l0001/oookJPGo0000:?oonfX007oooo]Z1Ol0
000BoookJPCo0000JooonfX5o`0001?ooo]Z1Ol0001YoookJPGo00004ooonfX4o`0006_ooo]Z1Ol0
000YoookJP00O_oonfX5o`0001?ooo]Z1?l0001ZoookJPGo00005?oonfX5o`0006Wooo]Z1Ol0000C
oookJPCo0000JooonfX5o`0002Wooo]Z001noookJPGo00004ooonfX4o`0006[ooo]Z1Ol0000Doook
JPGo0000JOoonfX5o`0001?ooo]Z1?l0001[oookJPGo0000:OoonfX007kooo]Z1Ol0000CoookJPCo
0000J_oonfX5o`0001Cooo]Z1Ol0001XoookJPGo00005?oonfX4o`0006[ooo]Z1Ol0000ZoookJP00
OOoonfX5o`0001Cooo]Z1?l0001YoookJPGo00005OoonfX5o`0006Sooo]Z1Ol0000DoookJPCo0000
J_oonfX5o`0002[ooo]Z001moookJPGo00005?oonfX4o`0006Wooo]Z1Ol0000EoookJPGo0000J?oo
nfX5o`0001Cooo]Z1?l0001ZoookJPGo0000:_oonfX007gooo]Z1Ol0000DoookJPCo0000JOoonfX5
o`0001Gooo]Z1Ol0001WoookJPGo00005OoonfX4o`0006Wooo]Z1Ol0000[oookJP00O?oonfX5o`00
01Gooo]Z1?l0001XoookJPGo00005_oonfX5o`0006Oooo]Z1Ol0000EoookJPCo0000JOoonfX5o`00
02_ooo]Z001loookJPGo00005OoonfX4o`0006Sooo]Z1Ol0000FoookJPGo0000IooonfX5o`0001Go
oo]Z1?l0001YoookJPGo0000:ooonfX007cooo]Z1Ol0000EoookJPCo0000J?oonfX5o`0001Kooo]Z
1Ol0001VoookJPGo00005_oonfX4o`0006Sooo]Z1Ol0000/oookJP00NooonfX5o`0001Kooo]Z1?l0
001WoookJPGo00005ooonfX5o`0006Kooo]Z1Ol0000FoookJPCo0000J?oonfX5o`0002cooo]Z001k
oookJPGo00005_oonfX4o`0006Oooo]Z1Ol0000GoookJPGo0000I_oonfX5o`0001Kooo]Z1?l0001X
oookJPGo0000;?oonfX007_ooo]Z1Ol0000FoookJPCo0000IooonfX5o`0001Oooo]Z1Ol0001Uoook
JPGo00005ooonfX4o`0006Oooo]Z1Ol0000]oookJP00N_oonfX5o`0001Oooo]Z1?l0001VoookJPGo
00006?oonfX5o`0006Gooo]Z1Ol0000GoookJPCo0000IooonfX5o`0002gooo]Z001joookJPGo0000
5ooonfX4o`0006Kooo]Z1Ol0000HoookJPGo0000IOoonfX5o`0001Oooo]Z1?l0001VoookJPKo0000
;OoonfX007Wooo]Z1_l0000GoookJPCo0000IOoonfX6o`0001Sooo]Z1Ol0001ToookJPGo00006?oo
nfX4o`0006Kooo]Z1Ol0000^oookJP00NOoonfX5o`0001Sooo]Z1?l0001UoookJPGo00006OoonfX5
o`0006Cooo]Z1Ol0000HoookJPCo0000IOoonfX6o`0002kooo]Z001hoookJPKo00006?oonfX4o`00
06Cooo]Z1_l0000IoookJPGo0000HooonfX6o`0001Sooo]Z1?l0001UoookJPGo0000;ooonfX007So
oo]Z1Ol0000IoookJPCo0000I?oonfX5o`0001[ooo]Z1Ol0001SoookJPGo00006OoonfX4o`0006Co
oo]Z1_l0000_oookJP00MooonfX6o`0001Wooo]Z1?l0001SoookJPKo00006_oonfX5o`0006;ooo]Z
1_l0000IoookJPCo0000I?oonfX5o`00033ooo]Z001foookJPKo00006_oonfX4o`0006?ooo]Z1Ol0
000KoookJPGo0000H_oonfX5o`0001[ooo]Z1?l0001SoookJPKo0000<?oonfX007Kooo]Z1_l0000J
oookJPCo0000H_oonfX6o`0001_ooo]Z1Ol0001QoookJPKo00006_oonfX4o`0006?ooo]Z1Ol0000a
oookJP00MOoonfX6o`0001_ooo]Z1?l0001RoookJPGo00007?oonfX5o`00067ooo]Z1Ol0000Koook
JPCo0000H_oonfX6o`00037ooo]Z001eoookJPGo00007?oonfX4o`00067ooo]Z1_l0000LoookJPGo
0000H?oonfX6o`0001_ooo]Z1?l0001RoookJPGo0000<_oonfX003oooo]Z0ol007l5oookJPGo001o
:?oonfX6o`0001cooo]Z1?l0000HoookJPGo001oA?oonfX5o`0001gooo]Z1Ol0001PoookJPGo0000
1OoonfX5o`00Oa;ooo]Z1?l0001BoookJP?o001o1OoonfX5o`00O`;ooo]Z1_l0000boookJP00?ooo
nfX3o`00O`Cooo]Z1ol007lWoookJPGo00007OoonfX4o`0001Oooo]Z1ol007m2oookJPKo00007Ooo
nfX5o`0005oooo]Z1_l00004oookJPOo001o4OoonfX4o`0005;ooo]Z0ol007l4oookJPOo001o00?o
oo]Zo`000?l000000ol0000coookJP00?ooonfX3o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool0
07lVoookJPKo00007OoonfX4o`0001Kooo]Z1?l007l01?oonf[o001oo`00Ool007m2oookJPGo0000
7_oonfX5o`0005oooo]Z1Ol00004oookJPCo001o00Cooo]Zo`00Ool007oo001o4OoonfX4o`0005;o
oo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o1_l0000coookJP00;ooonfX:o`00O`Ko
oo]Z0ol007l3oookJP?o001o0ooonfX3o`00ObGooo]Z1Ol0000NoookJPCo00002_oonfX:o`00O`;o
oo]Z0ol007l3oookJP?o001o@?oonfX6o`0001kooo]Z1Ol0001NoookJPKo00001?oonfX3o`00O`?o
oo]Z0ol007l@oookJPCo0000D_oonfX3o`00O`?ooo]Z0ol007l3oookJP03o`00Ool0003o000000Co
0000=?oonfX002oooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lUoookJPGo0000
7_oonfX4o`0000[ooo]Z2_l007l8oookJP?o001o?ooonfX6o`0001oooo]Z1Ol0001MoookJPKo0000
2ooonfX3o`00Oa3ooo]Z1?l0001BoookJP?o001o0ooonfX3o`00O`?ooo]Z00?o001oo`000?l00000
1?l0000doookJP00?ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o9?oonfX5o`0001oooo]Z1?l0
000LoookJP?o001o?ooonfX6o`0001oooo]Z1Ol0001MoookJPKo00002ooonfX3o`00Oa3ooo]Z1?l0
001BoookJP?o001o0ooonfX3o`00O`?ooo]Z1_l0000eoookJP00?ooonfX3o`00O`?ooo]Z0ol007l3
oookJP?o001o9?oonfX5o`0001oooo]Z1?l0000GoookJP;o001o0_oonfX4o`00Ockooo]Z1_l0000P
oookJPGo0000G?oonfX6o`0000Oooo]Z0_l007l2oookJPCo001o4?oonfX4o`0005;ooo]Z0ol007l3
oookJP?o001o0ooonfX5o`0003Kooo]Z000ooookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lSoook
JPKo00007ooonfX4o`0001Oooo]Z1ol007looookJPGo00008OoonfX5o`0005cooo]Z1Ol00008oook
JPOo001o4OoonfX4o`0005;ooo]Z0ol007l3oookJP?o001o0_oonfX6o`0003Kooo]Z000ooookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007lRoookJPKo00008?oonfX4o`0001Oooo]Z1_l007looookJPKo
00008OoonfX5o`0005_ooo]Z1_l00008oookJPKo001o4_oonfX4o`0005;ooo]Z0ol007l3oookJP?o
001o00?ooo]Zo`000?l000001?l0000goookJP00??oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o
8?oonfX8o`00023ooo]Z1?l0000GoookJP;o001o@_oonfX6o`0002;ooo]Z1Ol0001JoookJPKo0000
2OoonfX2o`00OaKooo]Z1?l0001?oookJPKo001o0ooonfX3o`00O`Oo0000=ooonfX003cooo]Z1_l0
07l4oookJP?o001o00Cooo]Zo`00Ool007oo001o8?oonfX8o`00027ooo]Z1?l0000GoookJP;o001o
@OoonfX7o`0002;ooo]Z1Ol0001IoookJPOo00002OoonfX2o`00OaKooo]Z1?l0001?oookJPKo001o
1?oonfX00ol007oo0000o`000005o`0003Sooo]Z000noookJPCo001o1?oonfX7o`00Oaoooo]Z2?l0
000RoookJPCo00006?oonfX7o`00Oc[ooo]Z1ol0000SoookJPGo0000F?oonfX7o`0000_ooo]Z1ol0
07l@oookJPCo0000DOoonfX4o`00O`Cooo]Z1ol0000ioookJP00?ooonfX3o`00O`Gooo]Z1Ol007lO
oookJPSo00008ooonfX4o`0001Sooo]Z1ol007lioookJPOo00009?oonfX5o`0005Kooo]Z2?l0000<
oookJPOo001o4?oonfX4o`0005;ooo]Z0ol007l3oookJPOo0000>_oonfX006[ooo]Z1ol0000Uoook
JPCo0000EooonfX7o`0002Gooo]Z1Ol0001EoookJPSo00009?oonfX4o`0005Oooo]Z1ol0000koook
JP00JOoonfX7o`0002Kooo]Z1?l0001FoookJPOo00009_oonfX5o`0005?ooo]Z2Ol0000UoookJPCo
0000EOoonfX8o`0003cooo]Z001XoookJPOo00009ooonfX4o`0005Cooo]Z2?l0000WoookJPGo0000
D_oonfX9o`0002Kooo]Z1?l0001DoookJPSo0000?OoonfX006Kooo]Z2?l0000XoookJPCo0000Dooo
nfX8o`0002Sooo]Z1Ol0001@oookJPWo0000:?oonfX4o`0005;ooo]Z2Ol0000noookJP00I?oonfX9
o`0002Wooo]Z1?l0001AoookJPWo0000:OoonfX5o`0004oooo]Z2Ol0000YoookJPCo0000D?oonfX:
o`0003oooo]Z001PoookJPco0000:_oonfX4o`0004oooo]Z2_l0000ZoookJPGo0000C?oonfX:o`00
02_ooo]Z1?l0001=oookJP_o0000@OoonfX000;ooo]Zool0003oo`0003go00000ooonfX000;ooo]Z
ool0003oo`0003go00000ooonfX000;ooo]Zool0003oo`0003go00000ooonfX000;ooo]Zool0003o
o`0003go00000ooonfX000;ooo]Zool0003oo`0003go00000ooonfX003oooo]Z3ol00019oookJPCo
00005?oonfX00ol0003ooo]ZoookJP0DoookJPgo0000B_oonfX5o`0002[ooo]Z3_l0000eoookJP03
o`000?oonf[ooo]Z01;ooo]Z1?l0000[oookJPko00007_oonfX00ol0003ooo]ZoookJP0noookJP00
?ooonfX9o`0004oooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z01?ooo]Z2Ol0001?oookJPGo0000
:OoonfX;o`0003Wooo]Z00?o0000oookJ_oonfX04_oonfX4o`0002[ooo]Z2ol0000RoookJP03o`00
0?oonf[ooo]Z03kooo]Z000moookJPSo0000D_oonfX4o`0002Wooo]Z2Ol0001@oookJPGo0000:?oo
nfX9o`00057ooo]Z1?l0000XoookJP[o0000I_oonfX003cooo]Z2?l0001CoookJPCo0000:?oonfX8
o`0005;ooo]Z1Ol0000WoookJPOo0000E?oonfX4o`0002Oooo]Z2Ol0001XoookJP00>ooonfX8o`00
05Cooo]Z1?l0000WoookJPOo0000E?oonfX5o`0002Kooo]Z1ol0001EoookJPCo00009_oonfX8o`00
06[ooo]Z000joookJPSo0000EOoonfX4o`0002Kooo]Z1ol0001EoookJPGo00009OoonfX7o`0005Ko
oo]Z1?l0000UoookJPSo0000JooonfX003Wooo]Z1ol0001GoookJPCo00009OoonfX7o`0005Kooo]Z
1Ol0000ToookJPOo0000EooonfX4o`0002Cooo]Z1ol0001]oookJP00>?oonfX7o`0005Sooo]Z1?l0
000ToookJPOo0000EooonfX5o`0002?ooo]Z1ol0001HoookJPCo00008ooonfX7o`0006kooo]Z000h
oookJPKo0000FOoonfX4o`0002?ooo]Z1ol0001HoookJPGo00008_oonfX7o`0005Wooo]Z1?l0000S
oookJPKo0000KooonfX003Oooo]Z1_l0001JoookJPCo00008ooonfX6o`0005Wooo]Z1Ol0000Qoook
JPOo0000F_oonfX4o`0002;ooo]Z1_l0001`oookJP00=_oonfX6o`0005_ooo]Z1?l0000RoookJPKo
0000F_oonfX5o`00027ooo]Z1_l0001KoookJPCo00008_oonfX5o`00077ooo]Z000eoookJPOo0000
FooonfX4o`00027ooo]Z1_l0001KoookJPGo00008?oonfX6o`0005cooo]Z1?l0000QoookJPKo0000
LOoonfX003Gooo]Z1_l0001LoookJPCo00008?oonfX7o`0005_ooo]Z1Ol0000PoookJPGo0000GOoo
nfX4o`00023ooo]Z1_l0001boookJP00=?oonfX6o`0005gooo]Z1?l0000PoookJPKo0000G?oonfX5
o`0001oooo]Z1_l0001MoookJPCo00008?oonfX6o`0007;ooo]Z000coookJPKo0000G_oonfX4o`00
01oooo]Z1_l0001MoookJPGo00007ooonfX5o`0005kooo]Z1?l0000OoookJPKo0000LooonfX003?o
oo]Z1_l0001NoookJPCo00007ooonfX5o`0005kooo]Z1Ol0000NoookJPKo0000G_oonfX4o`0001oo
oo]Z1Ol0001doookJP00<_oonfX6o`0005oooo]Z1?l0000NoookJPKo0000G_oonfX5o`0001kooo]Z
1Ol0001OoookJPCo00007_oonfX6o`0007Cooo]Z000boookJPGo0000H?oonfX4o`0001kooo]Z1Ol0
001OoookJPGo00007OoonfX6o`0005oooo]Z1?l0000NoookJPGo0000MOoonfX0037ooo]Z1_l0001P
oookJPCo00007OoonfX6o`0005oooo]Z1Ol0000MoookJPGo0000H?oonfX4o`0001gooo]Z1_l0001e
oookJP00<OoonfX5o`00067ooo]Z1?l0000LoookJPKo0000H?oonfX5o`0001cooo]Z1_l0001Poook
JPCo00007OoonfX5o`0007Kooo]Z000`oookJPKo0000HOoonfX4o`0001cooo]Z1_l0001PoookJPGo
00007?oonfX5o`00067ooo]Z1?l0000LoookJPKo0000M_oonfX0033ooo]Z1Ol0001RoookJPCo0000
6ooonfX6o`00067ooo]Z1Ol0000KoookJPKo0000HOoonfX4o`0001cooo]Z1Ol0001goookJP00;ooo
nfX6o`0006;ooo]Z1?l0000KoookJPGo0000H_oonfX5o`0001_ooo]Z1Ol0001RoookJPCo00006ooo
nfX6o`0007Oooo]Z000_oookJPGo0000HooonfX4o`0001[ooo]Z1_l0001RoookJPGo00006_oonfX6
o`0006;ooo]Z1?l0000KoookJPGo0000N?oonfX002kooo]Z1_l0001SoookJPCo00006_oonfX5o`00
06?ooo]Z1Ol0000JoookJPGo0000HooonfX4o`0001[ooo]Z1_l0001hoookJP00;_oonfX5o`0006Co
oo]Z1?l0000IoookJPKo0000HooonfX5o`0001Wooo]Z1_l0001SoookJPCo00006_oonfX5o`0007Wo
oo]Z000^oookJPGo0000I?oonfX4o`0001Wooo]Z1Ol0001ToookJPGo00006OoonfX5o`0006Cooo]Z
1?l0000IoookJPKo0000NOoonfX002gooo]Z1Ol0001UoookJPCo00006OoonfX5o`0006Cooo]Z1Ol0
000HoookJPKo0000I?oonfX4o`0001Wooo]Z1Ol0001joookJP00;OoonfX5o`0006Gooo]Z1?l0000H
oookJPGo0000IOoonfX5o`0001Sooo]Z1Ol0001UoookJPCo00006OoonfX5o`0007[ooo]Z000]oook
JPGo0000IOoonfX4o`0001Sooo]Z1Ol0001UoookJPGo00005ooonfX6o`0006Gooo]Z1?l0000Hoook
JPGo0000NooonfX002cooo]Z1Ol0001VoookJPCo00005ooonfX6o`0006Gooo]Z1Ol0000GoookJPGo
0000I_oonfX4o`0001Sooo]Z1Ol0001koookJP00;?oonfX5o`0006Kooo]Z1?l0000GoookJPGo0000
I_oonfX5o`0001Kooo]Z1_l0001VoookJPCo00005ooonfX6o`0007_ooo]Z000[oookJPKo0000I_oo
nfX4o`0001Oooo]Z1Ol0001VoookJPGo00005_oonfX5o`0006Oooo]Z1?l0000GoookJPGo0000O?oo
nfX002_ooo]Z1Ol0001WoookJPCo00005_oonfX5o`0006Oooo]Z1Ol0000FoookJPGo0000IooonfX4
o`0001Oooo]Z1Ol0001loookJP00:ooonfX5o`0006Oooo]Z1?l0000FoookJPGo0000IooonfX5o`00
01Gooo]Z1Ol0001XoookJPCo00005_oonfX5o`0007gooo]Z000ZoookJPGo0000J?oonfX4o`0001Ko
oo]Z1Ol0001WoookJPGo00005OoonfX5o`0006Sooo]Z1?l0000FoookJPGo0000OOoonfX002[ooo]Z
1Ol0001XoookJPCo00005OoonfX5o`0006Sooo]Z1Ol0000EoookJPGo0000J?oonfX4o`0001Kooo]Z
1Ol0001moookJP00:_oonfX5o`0006Sooo]Z1?l0000EoookJPGo0000J?oonfX5o`0001Cooo]Z1Ol0
001YoookJPCo00005OoonfX5o`0007kooo]Z000YoookJPGo0000JOoonfX4o`0001Gooo]Z1Ol0001X
oookJPGo00005?oonfX5o`0006Wooo]Z1?l0000EoookJPGo0000O_oonfX002Wooo]Z1Ol0001Yoook
JPCo00005?oonfX5o`0006Wooo]Z1Ol0000DoookJPGo0000JOoonfX4o`0001Gooo]Z1Ol0001noook
JP00:OoonfX5o`0006Wooo]Z1?l0000DoookJPGo0000JOoonfX5o`0001?ooo]Z1Ol0001ZoookJPCo
00005?oonfX5o`0007oooo]Z000XoookJPGo0000J_oonfX4o`0001Cooo]Z1Ol0001YoookJPGo0000
4ooonfX5o`0006[ooo]Z1?l0000DoookJPGo0000OooonfX002Sooo]Z1Ol0001ZoookJPCo00004ooo
nfX5o`0006[ooo]Z1Ol0000CoookJPGo0000J_oonfX4o`0001Cooo]Z1Ol0001ooookJP00:?oonfX5
o`0006[ooo]Z1?l0000CoookJPGo0000J_oonfX5o`0001;ooo]Z1Ol0001[oookJPCo00004ooonfX5
o`00083ooo]Z000WoookJPGo0000JooonfX4o`0001?ooo]Z1Ol0001ZoookJPGo00004_oonfX5o`00
06_ooo]Z1?l0000CoookJPGo0000P?oonfX002Oooo]Z1Ol0001[oookJPCo00004_oonfX5o`0006_o
oo]Z1Ol0000BoookJPGo0000JooonfX4o`0001?ooo]Z1Ol00020oookJP009ooonfX5o`0006_ooo]Z
1?l0000BoookJPGo0000JooonfX5o`00017ooo]Z1Ol0001/oookJPCo00004_oonfX5o`00087ooo]Z
000VoookJPGo0000K?oonfX4o`0001;ooo]Z1Ol0001[oookJPGo00004OoonfX5o`0006cooo]Z1?l0
000BoookJPGo0000POoonfX002Kooo]Z1Ol0001/oookJPCo00004OoonfX5o`0006cooo]Z1Ol0000A
oookJPGo0000K?oonfX4o`0001;ooo]Z1Ol00021oookJP009_oonfX5o`0006cooo]Z1?l0000Aoook
JPGo0000K?oonfX5o`00017ooo]Z1?l0001]oookJPCo00004OoonfX5o`0008;ooo]Z000UoookJPGo
0000KOoonfX4o`00017ooo]Z1Ol0001/oookJPGo00004?oonfX5o`0006gooo]Z1?l0000AoookJPGo
0000P_oonfX002Gooo]Z1Ol0001]oookJPCo00004?oonfX5o`0006gooo]Z1Ol0000@oookJPGo0000
KOoonfX4o`00017ooo]Z1Ol00022oookJP009OoonfX5o`0006gooo]Z1?l0000@oookJPGo0000KOoo
nfX5o`00013ooo]Z1Ol0001]oookJPCo00004OoonfX4o`0008?ooo]Z000ToookJPGo0000K_oonfX4
o`00013ooo]Z1Ol0001]oookJPGo00003ooonfX5o`0006kooo]Z1?l0000@oookJPGo0000PooonfX0
02Cooo]Z1Ol0001^oookJPCo00003ooonfX5o`0006kooo]Z1Ol0000?oookJPGo0000K_oonfX4o`00
013ooo]Z1Ol00023oookJP009?oonfX5o`0006kooo]Z1?l0000?oookJPGo0000K_oonfX5o`0000oo
oo]Z1Ol0001^oookJPCo00004?oonfX5o`0008?ooo]Z000ToookJPCo0000KooonfX4o`0000oooo]Z
1Ol0001^oookJPGo00003ooonfX4o`0006oooo]Z1?l0000?oookJPGo0000Q?oonfX002?ooo]Z1Ol0
001_oookJPCo00003ooonfX4o`0006oooo]Z1Ol0000>oookJPGo0000KooonfX4o`0000oooo]Z1Ol0
0024oookJP008ooonfX5o`0006oooo]Z1?l0000>oookJPGo0000KooonfX5o`0000kooo]Z1Ol0001_
oookJPCo00003ooonfX5o`0008Cooo]Z000SoookJPGo0000KooonfX4o`0000kooo]Z1Ol0001_oook
JPGo00003_oonfX5o`0006oooo]Z1?l0000?oookJPCo0000QOoonfX002;ooo]Z1Ol0001`oookJPCo
00003_oonfX5o`0006oooo]Z1Ol0000=oookJPGo0000L?oonfX4o`0000kooo]Z1Ol00025oookJP00
8_oonfX5o`00073ooo]Z1?l0000>oookJPCo0000L?oonfX5o`0000gooo]Z1Ol0001`oookJPCo0000
3_oonfX5o`0008Gooo]Z000RoookJPGo0000L?oonfX4o`0000kooo]Z1?l0001`oookJPGo00003Ooo
nfX5o`00073ooo]Z1?l0000>oookJPGo0000QOoonfX002;ooo]Z1?l0001aoookJPCo00003OoonfX5
o`00073ooo]Z1Ol0000=oookJPCo0000LOoonfX4o`0000kooo]Z1?l00026oookJP008OoonfX5o`00
077ooo]Z1?l0000=oookJPGo0000L?oonfX5o`0000cooo]Z1Ol0001aoookJPCo00003OoonfX5o`00
08Kooo]Z000QoookJPGo0000LOoonfX4o`0000gooo]Z1Ol0001`oookJPGo00003?oonfX5o`00077o
oo]Z1?l0000=oookJPGo0000Q_oonfX0027ooo]Z1Ol0001aoookJPCo00003OoonfX4o`00077ooo]Z
1Ol0000<oookJPGo0000LOoonfX4o`0000gooo]Z1Ol00026oookJP008?oonfX5o`0007;ooo]Z1?l0
000=oookJPCo0000LOoonfX5o`0000_ooo]Z1Ol0001boookJPCo00003OoonfX4o`0008Oooo]Z000P
oookJPGo0000L_oonfX4o`0000cooo]Z1Ol0001aoookJPGo00002ooonfX5o`0007;ooo]Z1?l0000<
oookJPGo0000QooonfX0023ooo]Z1Ol0001boookJPCo00003?oonfX5o`00077ooo]Z1Ol0000;oook
JPGo0000L_oonfX4o`0000cooo]Z1Ol00027oookJP008?oonfX4o`0007?ooo]Z1?l0000<oookJPGo
0000LOoonfX5o`0000_ooo]Z1?l0001coookJPCo00003?oonfX5o`0008Oooo]Z000PoookJPCo0000
LooonfX4o`0000cooo]Z1?l0001boookJPGo00002_oonfX5o`0007?ooo]Z1?l0000<oookJPCo0000
R?oonfX001oooo]Z1Ol0001coookJPCo00003?oonfX4o`0007;ooo]Z1Ol0000:oookJPGo0000Looo
nfX4o`0000_ooo]Z1Ol00028oookJP007ooonfX5o`0007?ooo]Z1?l0000;oookJPGo0000L_oonfX5
o`0000[ooo]Z1Ol0001coookJPCo00002ooonfX5o`0008Sooo]Z000OoookJPGo0000LooonfX4o`00
00_ooo]Z1Ol0001boookJPGo00002_oonfX4o`0007Cooo]Z1?l0000;oookJPGo0000R?oonfX001oo
oo]Z1?l0001doookJPCo00002ooonfX5o`0007;ooo]Z1Ol0000:oookJPCo0000M?oonfX4o`0000_o
oo]Z1?l00029oookJP007ooonfX4o`0007Cooo]Z1?l0000;oookJPCo0000EOoonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o2_oonfX5o`0000Wooo]Z1Ol0001doookJPCo00002_oonfX5o`0008Wooo]Z
000NoookJPGo0000M?oonfX4o`0000_ooo]Z1?l0001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l9oookJPGo00002OoonfX5o`0007Cooo]Z1?l0000:oookJPGo0000ROoonfX001kooo]Z1Ol0001d
oookJPCo00002_oonfX5o`0005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo00002OoonfX5o`0007Cooo]Z
1?l0000:oookJPGo0000ROoonfX001kooo]Z1Ol0001doookJPCo00002_oonfX5o`0005?ooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo00002OoonfX4o`0007Gooo]Z1?l0
000:oookJPCo0000R_oonfX001kooo]Z1?l0001eoookJPCo00002_oonfX5o`0005?ooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Sooo]Z1ol00007oookJPCo0000MOoonfX4o`0000[ooo]Z1?l0002:
oookJP007_oonfX4o`0007Gooo]Z1?l0000:oookJPCo0000E?oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o2?oonfX5o`0000Sooo]Z1Ol0001eoookJPCo00002OoonfX5o`0008[ooo]Z000MoookJPGo
0000MOoonfX4o`0000Wooo]Z1Ol0001DoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o2?oonfX5o`0000Sooo]Z1Ol0001eoookJPCo00002OoonfX5o`0008[ooo]Z000MoookJPGo0000
MOoonfX4o`0000Wooo]Z1Ol0001DoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000
2?oonfX5o`0007Gooo]Z1?l00009oookJPGo0000R_oonfX001gooo]Z1Ol0001eoookJPCo00002Ooo
nfX5o`0005Cooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol00008oookJPCo0000M_oo
nfX4o`0000Wooo]Z1?l0002;oookJP007OoonfX4o`0007Kooo]Z1?l00009oookJPCo0000EOoonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0000Sooo]Z1?l0001foookJPCo00002?oonfX5
o`0008_ooo]Z000MoookJPCo0000M_oonfX4o`0000Wooo]Z1?l0001FoookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol00007oookJPGo0000M_oonfX4o`0000Sooo]Z1Ol0002;
oookJP007OoonfX4o`0007Kooo]Z1?l00008oookJPGo0000E_oonfX7o`00O`Wooo]Z1ol007l8oook
JPGo00001ooonfX5o`0007Kooo]Z1?l00008oookJPGo0000RooonfX001cooo]Z1Ol0001foookJPCo
00002?oonfX5o`0005Oooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0000Oooo]Z1Ol0001foookJPCo
00002?oonfX4o`0008cooo]Z000LoookJPGo0000M_oonfX4o`0000Sooo]Z1Ol0001eoookJPGo0000
1ooonfX4o`0007Oooo]Z1?l00007oookJPGo0000S?oonfX001cooo]Z1Ol0001foookJPCo00002?oo
nfX4o`0007Kooo]Z1Ol00007oookJPCo0000MooonfX4o`0000Oooo]Z1Ol0002<oookJP007?oonfX4
o`0007Oooo]Z1?l00008oookJPCo0000M_oonfX5o`0000Kooo]Z1Ol0001goookJPCo00001ooonfX5
o`0008cooo]Z000LoookJPCo0000MooonfX4o`0000Oooo]Z1Ol0001foookJPGo00001_oonfX5o`00
07Oooo]Z1?l00007oookJPCo0000SOoonfX001_ooo]Z1Ol0001goookJPCo00001ooonfX5o`0007Ko
oo]Z1Ol00006oookJPGo0000MooonfX4o`0000Oooo]Z1?l0002=oookJP006ooonfX5o`0007Oooo]Z
1?l00007oookJPGo0000M_oonfX5o`0000Kooo]Z1?l0001hoookJPCo00001_oonfX5o`0008gooo]Z
000KoookJPGo0000MooonfX4o`0000Oooo]Z1?l0001goookJPGo00001_oonfX4o`0007Sooo]Z1?l0
0006oookJPGo0000SOoonfX001_ooo]Z1?l0001hoookJPCo00001ooonfX4o`0007Oooo]Z1Ol00005
oookJPGo0000N?oonfX4o`0000Kooo]Z1Ol0002=oookJP006ooonfX4o`0007Sooo]Z1?l00006oook
JPGo0000MooonfX5o`0000Gooo]Z1Ol0001hoookJPCo00001_oonfX4o`0008kooo]Z000KoookJPCo
0000N?oonfX4o`0000Kooo]Z1Ol0001goookJPGo00001OoonfX5o`0007Sooo]Z1?l00006oookJPCo
0000S_oonfX001[ooo]Z1Ol0001hoookJPCo00001_oonfX5o`0007Oooo]Z1Ol00005oookJPCo0000
NOoonfX4o`0000Kooo]Z1?l0002>oookJP006_oonfX5o`0007Sooo]Z1?l00006oookJPCo0000N?oo
nfX5o`0000Gooo]Z1?l0001ioookJPCo00001OoonfX5o`0008kooo]Z000JoookJPGo0000N?oonfX4
o`0000Kooo]Z1?l0001hoookJPGo00001?oonfX5o`0007Wooo]Z1?l00005oookJPGo0000S_oonfX0
01[ooo]Z1?l0001ioookJPCo00001OoonfX5o`0007Sooo]Z1Ol00004oookJPGo0000NOoonfX4o`00
00Gooo]Z1Ol0002>oookJP006_oonfX4o`0007Wooo]Z1?l00005oookJPGo0000N?oonfX5o`0000Co
oo]Z1Ol0001ioookJPCo00001OoonfX4o`0008oooo]Z000IoookJPGo0000NOoonfX4o`0000Gooo]Z
1Ol0001hoookJPGo00001?oonfX4o`0007[ooo]Z1?l00005oookJPCo0000SooonfX001Wooo]Z1Ol0
001ioookJPCo00001OoonfX4o`0007Wooo]Z1Ol00004oookJPCo0000N_oonfX4o`0000Gooo]Z1?l0
002?oookJP006OoonfX5o`0007Wooo]Z1?l00005oookJPCo0000NOoonfX5o`0000Cooo]Z1?l0001j
oookJPCo00001?oonfX5o`0008oooo]Z000IoookJPCo0000N_oonfX4o`0000Cooo]Z1Ol0001ioook
JPGo00001?oonfX4o`0007[ooo]Z1?l00004oookJPGo0000SooonfX001Wooo]Z1?l0001joookJPCo
00001?oonfX5o`0007Wooo]Z1Ol00003oookJPGo0000N_oonfX4o`0000Cooo]Z1Ol0002?oookJP00
6?oonfX5o`0007[ooo]Z1?l00004oookJPGo0000NOoonfX5o`0000?ooo]Z1Ol0001joookJPCo0000
1?oonfX4o`00093ooo]Z000HoookJPGo0000N_oonfX4o`0000Cooo]Z1?l0001joookJPGo00000ooo
nfX5o`0007[ooo]Z1?l00004oookJPCo0000T?oonfX001Sooo]Z1Ol0001joookJPCo00001?oonfX4
o`0007[ooo]Z1Ol00003oookJPCo0000NooonfX4o`0000Cooo]Z1?l0002@oookJP006?oonfX4o`00
07_ooo]Z1?l00004oookJPCo0000N_oonfX5o`0000?ooo]Z1?l0001koookJPCo00001?oonfX4o`00
093ooo]Z000HoookJPCo0000NooonfX4o`0000?ooo]Z1Ol0001joookJPGo00000ooonfX4o`0007_o
oo]Z1?l00003oookJPGo0000T?oonfX001Sooo]Z1?l0001koookJPCo00000ooonfX5o`0007[ooo]Z
1Ol00002oookJPGo0000NooonfX4o`0000?ooo]Z1Ol0002@oookJP005ooonfX5o`0007_ooo]Z1?l0
0003oookJPGo0000N_oonfX5o`0000;ooo]Z1Ol0001koookJPCo00000ooonfX5o`00093ooo]Z000G
oookJPGo0000NooonfX4o`0000?ooo]Z1?l0001koookJPGo00000_oonfX5o`0007_ooo]Z1?l00003
oookJPCo0000TOoonfX001Oooo]Z1Ol0001koookJPCo00000ooonfX4o`0007_ooo]Z1Ol00002oook
JPCo0000O?oonfX4o`0000?ooo]Z1?l0002AoookJP005ooonfX4o`0007cooo]Z1?l00003oookJPCo
0000NooonfX5o`0000;ooo]Z1?l0001loookJPCo00000ooonfX4o`00097ooo]Z000GoookJPCo0000
O?oonfX4o`0000;ooo]Z1Ol0001koookJPGo00000_oonfX4o`0007cooo]Z1?l00002oookJPGo0000
TOoonfX001Kooo]Z1Ol0001loookJPCo00000_oonfX5o`0007_ooo]Z1Ol00002oookJPCo0000O?oo
nfX4o`0000;ooo]Z1Ol0002AoookJP005_oonfX5o`0007cooo]Z1?l00002oookJPGo0000NooonfX5
o`000003oookJ_l0003o000000?o0000O?oonfX4o`0000;ooo]Z1Ol0002AoookJP005_oonfX5o`00
07cooo]Z1?l00002oookJPCo0000O?oonfX5o`000003oookJ_l0003o000000?o0000O?oonfX4o`00
00;ooo]Z1?l0002BoookJP005_oonfX4o`0007gooo]Z1?l00002oookJPCo0000O?oonfX5o`000003
oookJ_l0003o000000?o0000O?oonfX4o`0000;ooo]Z1?l0002BoookJP005_oonfX4o`0007gooo]Z
1?l000000ooonf[o0000o`000003o`0007cooo]Z1Ol000000ooonf[o0000o`000002o`0007gooo]Z
1?l00002oookJPCo0000T_oonfX001Gooo]Z1Ol0001moookJPCo000000?ooo]Zo`000?l000000ol0
001loookJPGo000000?ooo]Zo`000?l000000_l0001moookJPCo000000?ooo]Zo`000?l000000ol0
002BoookJP005OoonfX5o`0007gooo]Z1?l000000ooonf[o0000o`000003o`0007cooo]Z1Ol00000
0ooonf[o0000o`000002o`0007gooo]Z1?l000000ooonf[o0000o`000003o`0009;ooo]Z000Eoook
JPGo0000OOoonfX4o`000003oookJ_l0003o000000;o0000OOoonfX5o`000003oookJ_l0003o0000
00;o0000OOoonfX4o`000003oookJ_l0003o000000?o0000T_oonfX001Gooo]Z1?l0001noookJPCo
000000?ooo]Zo`000?l000000_l0001moookJP[o0000OOoonfX4o`000003oookJ_l0003o000000;o
0000TooonfX001Gooo]Z1?l0001noookJPCo000000?ooo]Zo`000?l000000_l0001moookJP[o0000
OOoonfX4o`000003oookJ_l0003o000000;o0000TooonfX001Gooo]Z1?l0001noookJPWo0000OOoo
nfX:o`0007gooo]Z1?l000000ooonf[o0000o`000002o`0009?ooo]Z000DoookJPGo0000O_oonfX9
o`0007gooo]Z2Ol0001noookJPCo000000?ooo]Zo`000?l000000_l0002CoookJP005?oonfX5o`00
07kooo]Z2Ol0001moookJPWo0000O_oonfX9o`0009?ooo]Z000DoookJPGo0000O_oonfX8o`0007ko
oo]Z2Ol0001noookJPWo0000TooonfX001Cooo]Z1?l0001ooookJPSo0000O_oonfX9o`0007kooo]Z
2Ol0002CoookJP005?oonfX4o`0007oooo]Z2?l0001noookJPWo0000O_oonfX8o`0009Cooo]Z000D
oookJPCo0000OooonfX8o`0007kooo]Z2Ol0001noookJPSo0000U?oonfX001Cooo]Z1?l0001ooook
JPSo0000O_oonfX8o`0007oooo]Z2?l0002DoookJP004ooonfX5o`0007oooo]Z2?l0001noookJPSo
0000OooonfX8o`0009Cooo]Z000CoookJPGo0000OooonfX7o`0007oooo]Z2?l0001ooookJPSo0000
U?oonfX001?ooo]Z1Ol0001ooookJPOo0000OooonfX8o`0007oooo]Z2?l0002DoookJP004ooonfX4
o`00083ooo]Z1ol0001ooookJPSo0000OooonfX8o`0009Cooo]Z000CoookJPCo0000P?oonfX7o`00
07oooo]Z1ol00020oookJPOo0000UOoonfX001?ooo]Z1?l00020oookJPOo0000OooonfX7o`00083o
oo]Z1ol0002EoookJP004ooonfX4o`00083ooo]Z1ol0001ooookJPOo0000P?oonfX7o`0009Gooo]Z
000BoookJPGo0000P?oonfX6o`00083ooo]Z1ol00020oookJPOo0000UOoonfX001;ooo]Z1Ol00020
oookJPKo0000P?oonfX7o`00083ooo]Z1ol0002EoookJP004_oonfX5o`00083ooo]Z1_l00020oook
JPOo0000P?oonfX6o`0009Kooo]Z000BoookJPCo0000POoonfX6o`00083ooo]Z1_l00021oookJPKo
0000U_oonfX001;ooo]Z1?l00021oookJPKo0000P?oonfX6o`00087ooo]Z1_l0002FoookJP004_oo
nfX4o`00087ooo]Z1_l00020oookJPKo0000POoonfX6o`0009Kooo]Z000BoookJPCo0000POoonfX5
o`00087ooo]Z1_l00021oookJPKo0000U_oonfX0017ooo]Z1Ol00021oookJPGo0000POoonfX6o`00
087ooo]Z1Ol0002GoookJP004OoonfX5o`00087ooo]Z1Ol00021oookJPKo0000POoonfX5o`0009Oo
oo]Z000AoookJPGo0000POoonfX5o`00087ooo]Z1_l00021oookJPGo0000UooonfX0017ooo]Z1?l0
0022oookJPGo0000POoonfX5o`0008;ooo]Z1Ol0002GoookJP004OoonfX4o`0008;ooo]Z1Ol00021
oookJPGo0000P_oonfX5o`0009Oooo]Z000AoookJPCo0000P_oonfX4o`0008;ooo]Z1Ol00022oook
JPGo0000UooonfX0017ooo]Z1?l00022oookJPCo0000P_oonfX5o`0008;ooo]Z1Ol0002GoookJP00
4?oonfX5o`0008;ooo]Z1?l0001eoookJP?o001o2_oonfX5o`0008;ooo]Z1Ol0002GoookJP004?oo
nfX5o`0008;ooo]Z1?l0001eoookJP?o001o2_oonfX5o`0008;ooo]Z1Ol0002GoookJP004?oonfX5
o`0008;ooo]Z1?l0001eoookJP?o001o2_oonfX5o`0008;ooo]Z1?l0002HoookJP004?oonfX4o`00
08?ooo]Z1?l0001eoookJP?o001o2_oonfX5o`0008;ooo]Z1?l0002HoookJP004?oonfX4o`0008?o
oo]Z1?l0001eoookJP?o001o2_oonfX7o`00083ooo]Z1?l0002HoookJP004?oonfX4o`0008?ooo]Z
1?l0001eoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1?l0003loookJP?o001o2_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooook
JQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o2_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ3ooo]Z1?l0
07l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-12.8195, -1.067, 0.0445896, \
0.00601229}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Fourier Series", "Subtitle",
  CellTags->"mmtag:17:Fourier_series"],

Cell[CellGroupData[{

Cell["\<\
Demonstration of the orthogonality of the trigonometric functions\
\
\>", "Section",
  CellTags->"mmtag:17:orthogonality_of_trignometric_functions"],

Cell[CellGroupData[{

Cell[BoxData[
    \(coscos\  = \ 
      Integrate[
        Cos[\(2\ \[Pi]\ Minteger\ x\)\/\[Lambda]]\ Cos[\(2\ \[Pi]\ Ninteger\ \
x\)\/\[Lambda]]\ , {x, xo, xo\  + \ \[Lambda]}, \ 
        Assumptions \[Rule] {Minteger\ \[Epsilon]\ Integers, \ 
            Ninteger\  \[Element] \ Integers, 
            xo\  \[Element] \ Reals, \ \[Lambda]\  > \ 0}]\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\(4\ \((Minteger\^2 - 
              Ninteger\^2)\)\ \[Pi]\)\)\((\[Lambda]\ \((\(-\((Minteger + 
                    Ninteger)\)\)\ Sin[\(2\ \((Minteger - Ninteger)\)\ \[Pi]\ \
xo\)\/\[Lambda]] + \((\(-Minteger\) + 
                  Ninteger)\)\ Sin[\(2\ \((Minteger + Ninteger)\)\ \[Pi]\ \
xo\)\/\[Lambda]] + 
            Minteger\ Sin[\(2\ \((Minteger - Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]] + 
            Ninteger\ Sin[\(2\ \((Minteger - Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]] + 
            Minteger\ Sin[\(2\ \((Minteger + Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]] - 
            Ninteger\ Sin[\(2\ \((Minteger + Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]])\))\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      coscos /. {Minteger \[Rule] 4\ , \ Ninteger \[Rule] 34}]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Assuming[
      Minteger\ \[Epsilon]\ Integers\  && \ 
        Ninteger\  \[Element] \ Integers\  && 
        xo\  \[Element] \ Reals\  && \ \[Lambda]\  \[Element] \ Reals, \ 
      Limit[coscos, Minteger \[Rule] Ninteger]]\)], "Input",
  CellTags->{"mmtag:17:Assuming[]", "mmtag:17:Limit[]__and_Assuming[]"}],

Cell[BoxData[
    \(\[Lambda]\/2\)], "Output",
  CellTags->{"mmtag:17:Assuming[]", "mmtag:17:Limit[]__and_Assuming[]"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cossin\  = \ 
      Integrate[
        Cos[\(2\ \[Pi]\ Minteger\ x\)\/\[Lambda]]\ Sin[\(2\ \[Pi]\ Ninteger\ \
x\)\/\[Lambda]]\ , {x, xo, xo\  + \ \[Lambda]}, \ 
        Assumptions \[Rule] {Minteger\ \[Epsilon]\ Integers, \ 
            Ninteger\  \[Element] \ Integers, 
            xo\  \[Element] \ Reals, \ \[Lambda]\  > \ \ 0}]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(1\/\(4\ \((Minteger\^2 - 
                Ninteger\^2)\)\ \[Pi]\)\)\((\[Lambda]\ \((\((Minteger + 
                    Ninteger)\)\ Cos[\(2\ \((Minteger - Ninteger)\)\ \[Pi]\ \
xo\)\/\[Lambda]] + \((\(-Minteger\) + 
                    Ninteger)\)\ Cos[\(2\ \((Minteger + Ninteger)\)\ \[Pi]\ \
xo\)\/\[Lambda]] - 
              Minteger\ Cos[\(2\ \((Minteger - Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]] - 
              Ninteger\ Cos[\(2\ \((Minteger - Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]] + 
              Minteger\ Cos[\(2\ \((Minteger + Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]] - 
              Ninteger\ Cos[\(2\ \((Minteger + Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]])\))\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      cossin /. {Minteger \[Rule] \(-7\)\ , \ 
          Ninteger \[Rule] 35}]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Assuming[
      Minteger\ \[Epsilon]\ Integers\  && \ 
        Ninteger\  \[Element] \ Integers\  && 
        xo\  \[Element] \ Reals\  && \ \[Lambda]\  \[Element] \ Reals, \ 
      Limit[cossin, Minteger \[Rule] Ninteger]]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sinsin\  = \ 
      Integrate[
        Sin[\(2\ \[Pi]\ Minteger\ x\)\/\[Lambda]]\ Sin[\(2\ \[Pi]\ Ninteger\ \
x\)\/\[Lambda]]\ , {x, xo, xo\  + \ \[Lambda]}, \ 
        Assumptions \[Rule] {Minteger\ \[Epsilon]\ Integers, \ 
            Ninteger\  \[Element] \ Integers, 
            xo\  \[Element] \ Reals, \ \[Lambda]\  > \ 0}]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(1\/\(4\ \((Minteger\^2 - 
                Ninteger\^2)\)\ \[Pi]\)\)\((\[Lambda]\ \((\((Minteger + 
                    Ninteger)\)\ Sin[\(2\ \((Minteger - Ninteger)\)\ \[Pi]\ \
xo\)\/\[Lambda]] + \((\(-Minteger\) + 
                    Ninteger)\)\ Sin[\(2\ \((Minteger + Ninteger)\)\ \[Pi]\ \
xo\)\/\[Lambda]] - 
              Minteger\ Sin[\(2\ \((Minteger - Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]] - 
              Ninteger\ Sin[\(2\ \((Minteger - Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]] + 
              Minteger\ Sin[\(2\ \((Minteger + Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]] - 
              Ninteger\ Sin[\(2\ \((Minteger + Ninteger)\)\ \[Pi]\ \((xo + \
\[Lambda])\)\)\/\[Lambda]])\))\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      sinsin /. {Minteger \[Rule] 10\ , \ Ninteger \[Rule] 9}]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Assuming[
      Minteger\ \[Epsilon]\ Integers\  && \ 
        Ninteger\  \[Element] \ Integers\  && 
        xo\  \[Element] \ Reals\  && \ \[Lambda]\  \[Element] \ Reals, \ 
      Limit[sinsin, Minteger \[Rule] Ninteger]]\)], "Input"],

Cell[BoxData[
    \(\[Lambda]\/2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example of determination of fourier coefficients", "Section"],

Cell[TextData[{
  "First we will \"do it the hard way\" and write short programs that \
evaluate Fourier coefficients; then we will demonstrate how to make use of \
built-in functions in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["FourierTransform",
    FontWeight->"Bold"],
  " package\[Ellipsis]"
}], "Text"],

Cell["\<\
Define functions based on the formulas derived for the fourier \
amplitudes\
\>", "Text"],

Cell["The constant term:", "Text"],

Cell[BoxData[
    \(EvenTerms[0, function_\ , \ 
        wavelength_]\  := \ \(1\/wavelength\) \(\[Integral]\_0\%wavelength 
              function[dummy] \[DifferentialD]dummy\)\)], "Input"],

Cell["\<\
A function that defines each even amplitude individually (this is \
not very efficient, it would be better to evaluate the integral once and use \
that result)\
\>", "Text"],

Cell[BoxData[
    \(EvenTerms[SP_Integer, function_\ , \ 
        wavelength_]\  := \ \(EvenTerms[SP, function\ , \ 
          wavelength] = \(2\/wavelength\) \(\[Integral]\_0\%wavelength 
                function[
                dummy]\ Cos[\(2\ SP\ \[Pi]\ dummy\)\/wavelength] \
\[DifferentialD]dummy\)\)\)], "Input",
  CellTags->
  "mmtag:17:Fourier_series__example_function_for_calculating_cosine_terms"],

Cell["\<\
Define the zeroth odd term as zero for symmetry with the even \
terms:\
\>", "Text"],

Cell[BoxData[
    \(OddTerms[0, function_\ , \ wavelength_]\  := \ 0\)], "Input"],

Cell[BoxData[
    \(OddTerms[SP_Integer, function_\ , \ 
        wavelength_]\  := \ \(OddTerms[SP, function\ , \ 
          wavelength] = \(2\/wavelength\) \(\[Integral]\_0\%wavelength 
                function[
                dummy]\ Sin[\(2\ SP\ \[Pi]\ dummy\)\/wavelength] \
\[DifferentialD]dummy\)\)\)], "Input",
  CellTags->
  "mmtag:17:Fourier_series__example_function_for_calculating_sine_terms"],

Cell["\<\
A function to create a vector of amplitudes for the odd terms and \
one for the even terms\
\>", "Text"],

Cell[BoxData[
    \(OddAmplitudeVector[NTerms_Integer, \ function_, \ 
        wavelength_]\  := \[IndentingNewLine]Table[
        OddTerms[i, \ function, \ wavelength], \ {i, 0, NTerms}]\)], "Input"],

Cell[BoxData[
    \(EvenAmplitudeVector[NTerms_Integer, \ function_, \ 
        wavelength_]\  := \[IndentingNewLine]Table[
        EvenTerms[i, \ function, \ wavelength], \ {i, 0, NTerms}]\)], "Input"],

Cell["Define a function to use as an example:", "Text"],

Cell[BoxData[
    \(myfunction[x_\ ]\  := \((x*\((2 - x)\)*\((1 - x)\)^2)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OriginalPlot = \ 
      Plot[myfunction[x], {x, 0, 2}, 
        PlotStyle \[Rule] {Hue[1], Thickness[0.015]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 2.35443 [
[.2619 .00222 -14.5 -20 ]
[.2619 .00222 14.5 0 ]
[.5 .00222 -7 -20 ]
[.5 .00222 7 0 ]
[.7381 .00222 -14.5 -20 ]
[.7381 .00222 14.5 0 ]
[.97619 .00222 -7 -20 ]
[.97619 .00222 7 0 ]
[.01131 .13244 -39 -10 ]
[.01131 .13244 0 10 ]
[.01131 .25016 -29 -10 ]
[.01131 .25016 0 10 ]
[.01131 .36788 -39 -10 ]
[.01131 .36788 0 10 ]
[.01131 .4856 -29 -10 ]
[.01131 .4856 0 10 ]
[.01131 .60332 -39 -10 ]
[.01131 .60332 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
gsave
.2619 .00222 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .01472 m
.5 .02097 L
s
gsave
.5 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 .01472 m
.7381 .02097 L
s
gsave
.7381 .00222 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.02381 .13244 m
.03006 .13244 L
s
gsave
.01131 .13244 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.02381 .25016 m
.03006 .25016 L
s
gsave
.01131 .25016 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.02381 .36788 m
.03006 .36788 L
s
gsave
.01131 .36788 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.02381 .4856 m
.03006 .4856 L
s
gsave
.01131 .4856 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03826 m
.02756 .03826 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .08535 m
.02756 .08535 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .17953 m
.02756 .17953 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .2737 m
.02756 .2737 L
s
.02381 .29725 m
.02756 .29725 L
s
.02381 .32079 m
.02756 .32079 L
s
.02381 .34434 m
.02756 .34434 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .46206 m
.02756 .46206 L
s
.02381 .50915 m
.02756 .50915 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57978 m
.02756 .57978 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.015 w
.02381 .01472 m
.04262 .18291 L
.06244 .3242 L
.08255 .4336 L
.09409 .48241 L
.10458 .51874 L
.11396 .54515 L
.12415 .56772 L
.12975 .57759 L
.13491 .58517 L
.13982 .59108 L
.14509 .59607 L
.14768 .59803 L
.15014 .59959 L
.15253 .60085 L
.15476 .60178 L
.15685 .60245 L
.15802 .60274 L
.15909 .60295 L
.16026 .60313 L
.16152 .60326 L
.16272 .60332 L
.16381 .60332 L
.16501 .60326 L
.16629 .60314 L
.16749 .60296 L
.1686 .60275 L
.17129 .60202 L
.17384 .60108 L
.17892 .59848 L
.18444 .5946 L
.19384 .58565 L
.20421 .57263 L
.22522 .53764 L
.26542 .44741 L
.30411 .34571 L
.34525 .2371 L
.38488 .14428 L
.42298 .07469 L
.4426 .04843 L
.4535 .03696 L
.46355 .02843 L
.47379 .02183 L
.47918 .01921 L
.48489 .01708 L
.48728 .01639 L
.48985 .01578 L
.49227 .01533 L
.49449 .01503 L
.49583 .0149 L
Mistroke
.49708 .0148 L
.4978 .01477 L
.49845 .01474 L
.4992 .01472 L
.4999 .01472 L
.50119 .01473 L
.50237 .01477 L
.50367 .01486 L
.50433 .01491 L
.50504 .01498 L
.50756 .01531 L
.5103 .01582 L
.51289 .01644 L
.51527 .01714 L
.52459 .02098 L
.52942 .02367 L
.53475 .02718 L
.54552 .03603 L
.56491 .05764 L
.58578 .08863 L
.62697 .1702 L
.66664 .26774 L
.7048 .36967 L
.74542 .47398 L
.76419 .51635 L
.78451 .55517 L
.79565 .57244 L
.8059 .58537 L
.8157 .59472 L
.82064 .59821 L
.82324 .5997 L
.82606 .60104 L
.82878 .60205 L
.82997 .6024 L
.83129 .60272 L
.83253 .60296 L
.8337 .60314 L
.83493 .60326 L
.83562 .6033 L
.83625 .60332 L
.83737 .60331 L
.83841 .60326 L
.83956 .60315 L
.84078 .60298 L
.84207 .60272 L
.84328 .60241 L
.84555 .60166 L
.84808 .60055 L
.85077 .59905 L
.85558 .59552 L
Mistroke
.86076 .59045 L
.86646 .5833 L
.8766 .56626 L
.88588 .54554 L
.89659 .51506 L
.90676 .47914 L
.92658 .38787 L
.94498 .2754 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00XooonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001oM_oonfX3o`00OgKooo]Z0ol007l4oookJP?o001o0ooonfX5o`00Og;ooo]Z2Ol007l=oook
JP00X_oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001oMOoonfX3o`00OgKooo]Z0ol007l4oookJP?o
001o0_oonfX7o`00Og7ooo]Z2Ol007l=oookJP00X_oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00OgGooo]Z0ol007mfoook
JP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001oLOoonfX4
o`00Oa;ooo]Z002QoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oM?oonfX3o`00
OgKooo]Z0ol007l8oookJP?o001o0ooonfX3o`00Og7ooo]Z1?l007lAoookJP00XOoonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001oM?oonfX3o`00OgKooo]Z0ol007l>oookJP?o001oL_oonfX5o`00O`oo
oo]Z002QoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007mdoookJP?o001oM_oonfX3o`00O`kooo]Z
0ol007mdoookJPCo001o3_oonfX00:7ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07mdoookJP?o001oM_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001oMOoonfX3o`00O`kooo]Z002Q
oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007meoookJP?o001oM_oonfX3o`00O`Wooo]Z1ol007mg
oookJP?o001o3OoonfX00:7ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00OgKooo]Z0ol007mfoook
JP?o001o2OoonfX6o`00Og;ooo]Z0ol007l3oookJP?o001o3OoonfX00:7ooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00OgOooo]Z1_l007mcoookJPKo001o2OoonfX2o`00OgKooo]Z0ol007l3oookJP?o
001o3OoonfX002_ooo]Z1Ol0001boookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OgOo
oo]Z1_l007mcoookJPKo001o2OoonfX2o`00OgKooo]Z1?l007l2oookJP?o001o3OoonfX002_ooo]Z
1Ol0001boookJPOo001o2OoonfX7o`00Og?ooo]Z1?l007meoookJPCo001o2_oonfX7o`00Og7ooo]Z
1ol007l>oookJP00:ooonfX5o`0007?ooo]Z1Ol007l:oookJPOo001oM?oonfX3o`00OgKooo]Z0ol0
07l:oookJPOo001oL_oonfX5o`00O`oooo]Z000[oookJPGo0000oooonf[ooookJQ;ooo]Z000[oook
JPGo0000oooonf[ooookJQ;ooo]Z000[oookJPGo0000oooonf[ooookJQ;ooo]Z000[oookJPGo0000
oooonf[ooookJQ;ooo]Z000YoookJPSoo`00mooonfX=ool00?Kooo]Z2?oo000=oookJP007_oonfX;
o`0000Soo`00l_l0000Fool00?;o00002?oo000<o`00007ooo]Z000NoookJP_o00002?oo003`o`00
01[oo`00l?l00008ool000co00000OoonfX001kooo]Z2ol00008ool00>go00008?oo003]o`0000So
o`003?l00001oookJP007_oonfX;o`0000Soo`00j_l0000Vool00>[o00002?oo000<o`00007ooo]Z
000NoookJP_o00002?oo003Yo`0002Woo`00iol00009ool000co00000OoonfX002Wooo]Z2Ooo001l
oookJP03o`000?oonf[ooo]Z06Oooo]Z;?oo001[oookJP03o`000?oonf[ooo]Z07Sooo]Z2Ooo000=
oookJP00:OoonfX9ool007cooo]Z00?o0000oookJ_oonfX0I_oonfX_ool006Wooo]Z00?o0000oook
J_oonfX0N?oonfX9ool000gooo]Z000YoookJPWoo`00hooonfXbool00>?ooo]Z2Ooo000=oookJP00
:OoonfX9ool00>;ooo]Z5_oo0008oookJQKoo`00h_oonfX9ool000gooo]Z000YoookJPWoo`00hOoo
nfXEool000cooo]Z5Ooo003QoookJPWoo`003OoonfX002Wooo]Z2Ooo003PoookJQ?oo`004_oonfXC
ool00>3ooo]Z2Ooo000=oookJP00:OoonfX9ool00=oooo]Z4Ooo000HoookJQ7oo`00gooonfX8ool0
00kooo]Z000ZoookJPSoo`00gooonfX@ool001_ooo]Z3ooo003NoookJPWoo`003_oonfX002[ooo]Z
2?oo003NoookJPooo`007_oonfX?ool00=gooo]Z2Ooo000>oookJP00:_oonfX9ool00=cooo]Z3ooo
000QoookJPkoo`00g?oonfX9ool000kooo]Z000ZoookJPWoo`00fooonfX>ool002Cooo]Z3_oo003K
oookJPWoo`003_oonfX002[ooo]Z2Ooo003JoookJPkoo`009_oonfX>ool00=[ooo]Z2Ooo000>oook
JP00:_oonfX9ool00=Wooo]Z3_oo000XoookJPkoo`00fOoonfX9ool000kooo]Z000ZoookJPWoo`00
f?oonfX>ool002[ooo]Z3_oo003HoookJPWoo`003_oonfX002[ooo]Z2Ooo003HoookJPkoo`00:_oo
nfX?ool00=Oooo]Z2?oo000?oookJP00:_oonfX9ool00=Oooo]Z3_oo000/oookJPooo`00e_oonfX8
ool000oooo]Z000[oookJPSoo`00e_oonfX>ool002kooo]Z3ooo003DoookJPWoo`003ooonfX002_o
oo]Z2?oo003EoookJPkoo`00<?oonfX?ool00=?ooo]Z2Ooo000?oookJP00:ooonfX9ool00=Cooo]Z
3Ooo000boookJPkoo`00dooonfX9ool000oooo]Z000[oookJPWoo`00dooonfX=ool003Cooo]Z3_oo
003BoookJPWoo`003ooonfX002_ooo]Z2Ooo003BoookJPgoo`00=_oonfX>ool00=7ooo]Z2Ooo000?
oookJP00:ooonfX9ool00=;ooo]Z3Ooo000goookJPgoo`00dOoonfX9ool000oooo]Z000[oookJPWo
o`00dOoonfX=ool003Wooo]Z3Ooo003@oookJPWoo`003ooonfX002_ooo]Z2Ooo003@oookJPgoo`00
>ooonfX=ool00<oooo]Z2?oo000@oookJP00:ooonfX9ool00<oooo]Z3Ooo000moookJPcoo`00c_oo
nfX9ool0013ooo]Z000[oookJP03o`000?oo003oo`0000Koo`00cooonfX=ool003gooo]Z3Ooo003=
oookJPWoo`004?oonfX002_ooo]Z00?o0000ool00?oo00001_oo003>oookJPgoo`00?ooonfX=ool0
0<cooo]Z2Ooo000@oookJP00:ooonfX00ol0003oo`00ool00007ool00<cooo]Z3Ooo0011oookJPco
o`00c?oonfX9ool0013ooo]Z000[oookJP03o`000?oo003oo`0000Ooo`00c?oonfX=ool0047ooo]Z
3Ooo003;oookJPWoo`004?oonfX002_ooo]Z00?o0000ool00?oo00001ooo003;oookJPgoo`00@ooo
nfX<ool00<_ooo]Z2Ooo000@oookJP00:ooonfX00ol0003oo`00ool00007ool00<_ooo]Z3?oo0015
oookJPcoo`00b_oonfX9ool0013ooo]Z000[oookJP03o`000?oo003oo`0000Ooo`00b_oonfX<ool0
04Kooo]Z3Ooo0039oookJPSoo`004OoonfX002_ooo]Z00?o0000ool00?oo00001ooo0039oookJPgo
o`00AooonfX<ool00<Sooo]Z2Ooo000AoookJP00:ooonfX00ol0003oo`00ool00007ool00<Wooo]Z
3?oo0019oookJPcoo`00aooonfX9ool0017ooo]Z000[oookJP;o00002?oo0038oookJPcoo`00B_oo
nfX=ool00<Kooo]Z2Ooo000AoookJP00:ooonfX2o`0000Soo`00b?oonfX<ool004_ooo]Z3?oo0036
oookJPWoo`004OoonfX002_ooo]Z0_l00009ool00<Kooo]Z3?oo001<oookJPgoo`00aOoonfX9ool0
017ooo]Z000[oookJP;o00002Ooo0036oookJPcoo`00COoonfX<ool00<Gooo]Z2Ooo000AoookJP00
:ooonfX2o`0000Woo`00aOoonfX<ool004oooo]Z3?oo0034oookJPWoo`004OoonfX002_ooo]Z0_l0
0009ool00<Cooo]Z3?oo001@oookJPcoo`00a?oonfX8ool001;ooo]Z000[oookJP;o00002Ooo0034
oookJPcoo`00DOoonfX<ool00<?ooo]Z2?oo000BoookJP00:ooonfX2o`0000Woo`00`ooonfX<ool0
05?ooo]Z2ooo0032oookJPWoo`004_oonfX002_ooo]Z0_l00009ool00<?ooo]Z3?oo001CoookJPco
o`00`OoonfX9ool001;ooo]Z000[oookJP?o00002?oo0032oookJPcoo`00EOoonfX;ool00<7ooo]Z
2Ooo000BoookJP00:ooonfX3o`0000Soo`00`_oonfX<ool005Gooo]Z3?oo0030oookJPWoo`004_oo
nfX002_ooo]Z0ol00009ool00<3ooo]Z3?oo001GoookJP_oo`00`?oonfX9ool001;ooo]Z000[oook
JP?o00002Ooo002ooookJPcoo`00F?oonfX<ool00;oooo]Z2Ooo000BoookJP00:ooonfX3o`0000Wo
o`00_ooonfX<ool005Wooo]Z3?oo002noookJPWoo`004_oonfX002_ooo]Z0ol00009ool00;kooo]Z
3?oo001JoookJPcoo`00__oonfX8ool001?ooo]Z000[oookJP?o00002Ooo002noookJPcoo`00Fooo
nfX<ool00;cooo]Z2Ooo000CoookJP00:ooonfX3o`0000Woo`00_OoonfX<ool005cooo]Z3?oo002l
oookJPWoo`004ooonfX002_ooo]Z0ol00009ool00;gooo]Z3?oo001MoookJPcoo`00^ooonfX9ool0
01?ooo]Z000[oookJPCo00002?oo002loookJPcoo`00G_oonfX<ool00;_ooo]Z2Ooo000CoookJP00
:ooonfX4o`0000Soo`00_?oonfX;ool0063ooo]Z3?oo002joookJPWoo`004ooonfX002_ooo]Z1?l0
0009ool00;[ooo]Z3?oo001QoookJP_oo`00^_oonfX9ool001?ooo]Z000[oookJPCo00002Ooo002i
oookJPcoo`00H_oonfX<ool00;Wooo]Z2Ooo000CoookJP00:ooonfX4o`0000Woo`00^OoonfX<ool0
06?ooo]Z2ooo002ioookJPSoo`005?oonfX000Cooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Go
oo]Z1Ol007l9oookJPCo00002Ooo002hoookJPcoo`00I?oonfX<ool00;Oooo]Z2Ooo000DoookJP00
0ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0ooonfX7o`00O`Sooo]Z1?l00009ool00;Sooo]Z
3?oo001UoookJP_oo`00]ooonfX9ool001Cooo]Z0003oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo001o00Cooo]Zo`00Ool0
07oo001o2?oonfX4o`0000Woo`00]ooonfX<ool006Kooo]Z3?oo002foookJPWoo`005?oonfX000;o
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o1ooonfX4o`0000Woo`00]ooonfX<ool006Oooo]Z2ooo002foookJPWoo`005?oonfX000;o
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o1ooonfX5o`0000So
o`00]_oonfX<ool006Sooo]Z3?oo002eoookJPWoo`005?oonfX000;ooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o1ooonfX5o`0000Soo`00]OoonfX<ool006[ooo]Z
2ooo002eoookJPWoo`005?oonfX000;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l2oookJP;o001o0_oonfX4o`00O`Oooo]Z1Ol00009ool00;Cooo]Z3?oo001ZoookJPcoo`00]?oo
nfX9ool001Cooo]Z0002oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX7
o`00O`Sooo]Z1Ol00009ool00;?ooo]Z3?oo001/oookJP_oo`00]?oonfX8ool001Gooo]Z0002oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX6o`00O`Wooo]Z1Ol00009ool0
0;?ooo]Z3?oo001/oookJPcoo`00/_oonfX9ool001Gooo]Z0002oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o0_oonfX2o`00O`gooo]Z1Ol00009ool00;;ooo]Z3?oo001^oookJP_o
o`00/_oonfX9ool001Gooo]Z0003oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0_l007l=oookJPGo00002Ooo002boookJPcoo`00K_oonfX<ool0
0;7ooo]Z2Ooo000EoookJP000ooonfX7o`00O`Sooo]Z1ol007l4oookJPOo001o1ooonfX5o`0000Wo
o`00/_oonfX;ool0073ooo]Z3?oo002`oookJPWoo`005OoonfX000Cooo]Z1Ol007l:oookJPGo001o
1OoonfX7o`00O`Oooo]Z1Ol00009ool00;7ooo]Z2ooo001aoookJPcoo`00/?oonfX9ool001Gooo]Z
000[oookJPGo000000?ooo]Zool00?oo00001_oo002aoookJP_oo`00L_oonfX<ool00:oooo]Z2Ooo
000EoookJP00:ooonfX5o`000003oookJ_oo003oo`0000Koo`00/?oonfX;ool007?ooo]Z3?oo002_
oookJPWoo`005OoonfX002_ooo]Z1Ol000000ooonf[oo`00ool00007ool00:oooo]Z2ooo001doook
JPcoo`00[_oonfX8ool001Kooo]Z000[oookJPGo000000?ooo]Zool00?oo00001ooo002^oookJP_o
o`00MOoonfX<ool00:kooo]Z2?oo000FoookJP00:ooonfX5o`000003oookJ_oo003oo`0000Ooo`00
[_oonfX;ool007Kooo]Z3?oo002/oookJPWoo`005_oonfX002_ooo]Z1Ol000000ooonf[oo`00ool0
0007ool00:kooo]Z2ooo001goookJP_oo`00[?oonfX9ool001Kooo]Z000[oookJPGo000000?ooo]Z
ool00?oo00001ooo002]oookJP_oo`00N?oonfX<ool00:_ooo]Z2Ooo000FoookJP00:ooonfX5o`00
0003oookJ_oo003oo`0000Ooo`00[OoonfX;ool007Wooo]Z2ooo002[oookJPWoo`005_oonfX002_o
oo]Z1Ol000000ooonf[oo`00ool00007ool00:cooo]Z2ooo001joookJPcoo`00Z_oonfX9ool001Ko
oo]Z000[oookJPGo00000_oonfX8ool00:cooo]Z2ooo001koookJP_oo`00Z_oonfX9ool001Kooo]Z
000[oookJPGo00000_oonfX8ool00:_ooo]Z2ooo001loookJPcoo`00ZOoonfX9ool001Kooo]Z000[
oookJPGo00000_oonfX9ool00:[ooo]Z2ooo001moookJP_oo`00ZOoonfX8ool001Oooo]Z000[oook
JPGo00000_oonfX9ool00:[ooo]Z2ooo001moookJP_oo`00Z?oonfX9ool001Oooo]Z000[oookJPGo
00000_oonfX9ool00:Wooo]Z2ooo001ooookJP_oo`00YooonfX9ool001Oooo]Z000[oookJPGo0000
0_oonfX9ool00:Wooo]Z2ooo001ooookJP_oo`00YooonfX9ool001Oooo]Z000[oookJPGo00000_oo
nfX9ool00:Sooo]Z2ooo0021oookJP_oo`00Y_oonfX9ool001Oooo]Z000[oookJPGo00000_oonfX9
ool00:Sooo]Z2ooo0021oookJP_oo`00Y_oonfX9ool001Oooo]Z000[oookJPGo00000_oonfX9ool0
0:Sooo]Z2_oo0023oookJP[oo`00Y_oonfX9ool001Oooo]Z000[oookJPGo00000ooonfX8ool00:Oo
oo]Z2ooo0023oookJP_oo`00YOoonfX9ool001Oooo]Z000[oookJPGo00000ooonfX9ool00:Kooo]Z
2ooo0023oookJP_oo`00YOoonfX8ool001Sooo]Z000[oookJPGo00000ooonfX9ool00:Gooo]Z2ooo
0025oookJP_oo`00XooonfX9ool001Sooo]Z000[oookJPGo00000ooonfX9ool00:Gooo]Z2ooo0025
oookJP_oo`00XooonfX9ool001Sooo]Z000[oookJPGo00000ooonfX9ool00:Cooo]Z2ooo0027oook
JP[oo`00XooonfX9ool001Sooo]Z000[oookJPGo00000ooonfX9ool00:Cooo]Z2ooo0027oookJP_o
o`00X_oonfX9ool001Sooo]Z000[oookJPGo00000ooonfX9ool00:Cooo]Z2ooo0027oookJP_oo`00
X_oonfX9ool001Sooo]Z000[oookJPGo00000ooonfX9ool00:?ooo]Z2ooo0029oookJP_oo`00XOoo
nfX9ool001Sooo]Z000[oookJPGo00001?oonfX9ool00:;ooo]Z2ooo0029oookJP_oo`00XOoonfX9
ool001Sooo]Z000[oookJPGo00001?oonfX9ool00:7ooo]Z2ooo002;oookJP[oo`00XOoonfX8ool0
01Wooo]Z000[oookJPGo00001?oonfX9ool00:7ooo]Z2ooo002;oookJP_oo`00X?oonfX8ool001Wo
oo]Z000[oookJPGo00001?oonfX9ool00:7ooo]Z2_oo002<oookJP_oo`00WooonfX9ool001Wooo]Z
000[oookJPGo00001?oonfX9ool00:3ooo]Z2ooo002=oookJP_oo`00W_oonfX9ool001Wooo]Z000[
oookJPGo00001?oonfX9ool00:3ooo]Z2ooo002=oookJP_oo`00W_oonfX9ool001Wooo]Z000[oook
JPGo00001?oonfX9ool009oooo]Z2ooo002?oookJP[oo`00W_oonfX9ool001Wooo]Z000[oookJPGo
00001OoonfX9ool009kooo]Z2ooo002?oookJP_oo`00WOoonfX9ool001Wooo]Z000[oookJPGo0000
1OoonfX9ool009gooo]Z2ooo002@oookJP_oo`00WOoonfX9ool001Wooo]Z000[oookJPGo00001Ooo
nfX9ool009gooo]Z2ooo002AoookJP_oo`00W?oonfX9ool001Wooo]Z000[oookJPGo00001OoonfX9
ool009gooo]Z2ooo002AoookJP_oo`00W?oonfX8ool001[ooo]Z000[oookJPGo00001OoonfX9ool0
09cooo]Z2ooo002CoookJP[oo`00VooonfX9ool001[ooo]Z000[oookJPGo00001OoonfX9ool009co
oo]Z2ooo002CoookJP_oo`00V_oonfX9ool001[ooo]Z000[oookJPGo00001OoonfX9ool009_ooo]Z
2ooo002DoookJP_oo`00V_oonfX9ool001[ooo]Z000[oookJPGo00001_oonfX9ool009[ooo]Z2ooo
002EoookJP[oo`00V_oonfX9ool001[ooo]Z000[oookJPGo00001_oonfX9ool009Wooo]Z2ooo002F
oookJP_oo`00VOoonfX9ool001[ooo]Z000[oookJPGo00001_oonfX9ool009Wooo]Z2ooo002Goook
JP[oo`00VOoonfX9ool001[ooo]Z000[oookJPGo00001_oonfX9ool009Wooo]Z2ooo002GoookJP_o
o`00V?oonfX9ool001[ooo]Z000[oookJPGo00001_oonfX9ool009Sooo]Z2ooo002HoookJP_oo`00
V?oonfX8ool001_ooo]Z000[oookJPGo00001_oonfX9ool009Sooo]Z2ooo002IoookJP[oo`00Uooo
nfX9ool001_ooo]Z000[oookJPGo00001_oonfX9ool009Oooo]Z2ooo002JoookJP_oo`00U_oonfX9
ool001_ooo]Z000[oookJPGo00001ooonfX9ool009Kooo]Z2ooo002JoookJP_oo`00U_oonfX9ool0
01_ooo]Z000[oookJPGo00001ooonfX9ool009Kooo]Z2_oo002LoookJP_oo`00UOoonfX9ool001_o
oo]Z000[oookJPGo00001ooonfX9ool009Gooo]Z2ooo002LoookJP_oo`00UOoonfX9ool001_ooo]Z
000>oookJPGo001o1?oonfX3o`00O`Gooo]Z0ol007l9oookJPGo00001ooonfX9ool009Gooo]Z2ooo
002MoookJP[oo`00UOoonfX9ool001_ooo]Z000=oookJPOo001o0ooonfX3o`00O`Gooo]Z0ol007l9
oookJPGo00001ooonfX9ool009Cooo]Z2ooo002NoookJP_oo`00U?oonfX9ool001_ooo]Z000=oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol007l9oookJPGo00001ooonfX9
ool009Cooo]Z2ooo002NoookJP_oo`00U?oonfX8ool001cooo]Z000<oookJP?o001o0ooonfX3o`00
O`[ooo]Z0ol007l9oookJPGo00001ooonfX9ool009Cooo]Z2_oo002PoookJP_oo`00TooonfX8ool0
01cooo]Z000<oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJPOo00001_oonfX9ool009;o
oo]Z2ooo002PoookJP_oo`00T_oonfX9ool001cooo]Z000<oookJP?o001o0ooonfX3o`00O`[ooo]Z
0ol007l9oookJPGo00002?oonfX9ool009;ooo]Z2ooo002QoookJP[oo`00T_oonfX9ool001cooo]Z
000<oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJPGo00002?oonfX9ool009;ooo]Z2_oo
002RoookJP_oo`00TOoonfX9ool001cooo]Z000<oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9
oookJPGo00002?oonfX9ool0097ooo]Z2ooo002RoookJP_oo`00TOoonfX9ool001cooo]Z000<oook
JP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJPGo00002?oonfX9ool0097ooo]Z2_oo002Toook
JP_oo`00T?oonfX9ool001cooo]Z000<oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l9oookJPGo
00002?oonfX9ool0093ooo]Z2ooo002ToookJP_oo`00T?oonfX9ool001cooo]Z000=oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX6o`00O`Wooo]Z1Ol00008oookJPWoo`00T?oonfX;ool00:Go
oo]Z2_oo002@oookJPWoo`007?oonfX000gooo]Z1ol007l:oookJPCo001o2OoonfX5o`0000Wooo]Z
2Ooo002?oookJP[oo`00Y_oonfX;ool008oooo]Z2?oo000MoookJP003_oonfX5o`00O`cooo]Z0ol0
07l9oookJPGo00002OoonfX9ool008kooo]Z2ooo002VoookJP_oo`00S_oonfX9ool001gooo]Z000[
oookJPGo00002OoonfX9ool008kooo]Z2ooo002WoookJP_oo`00SOoonfX9ool001gooo]Z000[oook
JPGo00002OoonfX9ool008gooo]Z2ooo002XoookJP_oo`00SOoonfX9ool001gooo]Z000[oookJPGo
00002OoonfX9ool008gooo]Z2ooo002YoookJP[oo`00SOoonfX9ool001gooo]Z000[oookJPGo0000
2OoonfX9ool008gooo]Z2_oo002ZoookJP_oo`00S?oonfX9ool001gooo]Z000[oookJPGo00002Ooo
nfX9ool008cooo]Z2ooo002ZoookJP_oo`00S?oonfX9ool001gooo]Z000[oookJPGo00002_oonfX9
ool008_ooo]Z2ooo002[oookJP[oo`00S?oonfX9ool001gooo]Z000[oookJPGo00002_oonfX9ool0
08[ooo]Z2ooo002/oookJP_oo`00R_oonfX9ool001kooo]Z000[oookJPGo00002_oonfX9ool008[o
oo]Z2ooo002]oookJP[oo`00R_oonfX9ool001kooo]Z000[oookJPGo00002_oonfX9ool008[ooo]Z
2_oo002^oookJP_oo`00ROoonfX9ool001kooo]Z000[oookJPGo00002_oonfX9ool008Wooo]Z2ooo
002^oookJP_oo`00ROoonfX9ool001kooo]Z000[oookJPGo00002_oonfX9ool008Wooo]Z2ooo002_
oookJP[oo`00ROoonfX9ool001kooo]Z000[oookJPGo00002_oonfX9ool008Sooo]Z2ooo002`oook
JP_oo`00R?oonfX9ool001kooo]Z000[oookJPGo00002ooonfX9ool008Oooo]Z2ooo002`oookJP_o
o`00QooonfX:ool001kooo]Z000[oookJPGo00002ooonfX9ool008Oooo]Z2_oo002boookJP_oo`00
Q_oonfX9ool001oooo]Z000[oookJPGo00002ooonfX9ool008Kooo]Z2ooo002boookJP_oo`00Q_oo
nfX9ool001oooo]Z000[oookJPGo00002ooonfX9ool008Kooo]Z2ooo002coookJP[oo`00Q_oonfX9
ool001oooo]Z000[oookJPGo00002ooonfX9ool008Kooo]Z2_oo002doookJP_oo`00QOoonfX9ool0
01oooo]Z000[oookJPGo00002ooonfX9ool008Gooo]Z2ooo002doookJP_oo`00QOoonfX9ool001oo
oo]Z000[oookJPGo00002ooonfX9ool008Gooo]Z2_oo002foookJP[oo`00Q?oonfX:ool001oooo]Z
000[oookJPGo00003?oonfX9ool008?ooo]Z2ooo002foookJP_oo`00PooonfX9ool0023ooo]Z000[
oookJPGo00003?oonfX9ool008?ooo]Z2ooo002goookJP[oo`00PooonfX9ool0023ooo]Z000[oook
JPGo00003?oonfX9ool008?ooo]Z2_oo002hoookJP_oo`00P_oonfX9ool0023ooo]Z000[oookJPGo
00003?oonfX9ool008;ooo]Z2ooo002hoookJP_oo`00P_oonfX9ool0023ooo]Z000[oookJPGo0000
3?oonfX9ool008;ooo]Z2ooo002ioookJP[oo`00P_oonfX9ool0023ooo]Z000[oookJPGo00003?oo
nfX9ool0087ooo]Z2ooo002joookJP_oo`00P?oonfX:ool0023ooo]Z000[oookJPGo00003?oonfX9
ool0087ooo]Z2ooo002joookJP_oo`00P?oonfX9ool0027ooo]Z000[oookJPGo00003OoonfX9ool0
083ooo]Z2_oo002loookJP_oo`00OooonfX9ool0027ooo]Z000[oookJPGo00003OoonfX9ool007oo
oo]Z2ooo002loookJP_oo`00OooonfX9ool0027ooo]Z000[oookJPGo00003OoonfX9ool007oooo]Z
2ooo002moookJP[oo`00OooonfX9ool0027ooo]Z000[oookJPGo00003OoonfX9ool007kooo]Z2ooo
002noookJP_oo`00O_oonfX9ool0027ooo]Z000[oookJPGo00003OoonfX9ool007kooo]Z2ooo002n
oookJP_oo`00OOoonfX:ool0027ooo]Z000[oookJPGo00003OoonfX9ool007kooo]Z2_oo0030oook
JP[oo`00OOoonfX9ool002;ooo]Z000[oookJPGo00003OoonfX:ool007cooo]Z2ooo0030oookJP_o
o`00O?oonfX9ool002;ooo]Z000[oookJPGo00003_oonfX9ool007cooo]Z2ooo0031oookJP[oo`00
O?oonfX9ool002;ooo]Z000[oookJPGo00003_oonfX9ool007cooo]Z2_oo0032oookJP_oo`00Nooo
nfX9ool002;ooo]Z000[oookJPGo00003_oonfX9ool007_ooo]Z2ooo0032oookJP_oo`00NooonfX9
ool002;ooo]Z000[oookJPGo00003_oonfX9ool007_ooo]Z2_oo0034oookJP[oo`00NooonfX9ool0
02;ooo]Z000[oookJPGo00003_oonfX:ool007Wooo]Z2ooo0034oookJP_oo`00NOoonfX9ool002?o
oo]Z000[oookJPGo00003_oonfX:ool007Wooo]Z2ooo0034oookJP_oo`00NOoonfX9ool002?ooo]Z
000[oookJPGo00003ooonfX9ool007Wooo]Z2_oo0036oookJP[oo`00NOoonfX9ool002?ooo]Z000[
oookJPGo00003ooonfX9ool007Sooo]Z2ooo0036oookJP_oo`00N?oonfX9ool002?ooo]Z000[oook
JPGo00003ooonfX9ool007Sooo]Z2ooo0037oookJP[oo`00N?oonfX9ool002?ooo]Z000[oookJPGo
00003ooonfX:ool007Kooo]Z2ooo0038oookJP_oo`00MooonfX9ool002?ooo]Z000[oookJPGo0000
3ooonfX:ool007Kooo]Z2ooo0038oookJP_oo`00M_oonfX:ool002?ooo]Z000[oookJPGo00004?oo
nfX9ool007Kooo]Z2_oo003:oookJP[oo`00M_oonfX9ool002Cooo]Z000[oookJPGo00004?oonfX9
ool007Gooo]Z2ooo003:oookJP_oo`00MOoonfX9ool002Cooo]Z000[oookJPGo00004?oonfX9ool0
07Gooo]Z2ooo003:oookJP_oo`00MOoonfX9ool002Cooo]Z000[oookJPGo00004?oonfX9ool007Go
oo]Z2_oo003<oookJP_oo`00M?oonfX9ool002Cooo]Z000[oookJPGo00004?oonfX:ool007?ooo]Z
2ooo003<oookJP_oo`00M?oonfX9ool002Cooo]Z000[oookJPGo00004OoonfX9ool007?ooo]Z2_oo
003>oookJP[oo`00LooonfX:ool002Cooo]Z000[oookJPGo00004OoonfX9ool007?ooo]Z2_oo003>
oookJP_oo`00L_oonfX9ool002Gooo]Z0004oookJPGo001o1?oonfX3o`00O`Gooo]Z0ol007l5oook
JPGo001o2OoonfX5o`00017ooo]Z2Ooo001boookJP_oo`00c_oonfX;ool007;ooo]Z2Ooo000Uoook
JP000ooonfX7o`00O`?ooo]Z0ol007l5oookJP?o001o1?oonfX7o`00O`Sooo]Z1Ol0000AoookJPWo
o`00L_oonfX:ool00=3ooo]Z2_oo001boookJPWoo`009OoonfX000?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o1OoonfX3o`00O`?ooo]Z1?l007l01?oonf[o001oo`00Ool007l8oook
JPGo00004OoonfX:ool0073ooo]Z2ooo003@oookJP_oo`00LOoonfX9ool002Gooo]Z0002oookJP?o
001o0ooonfX3o`00O`[ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000AoookJP[o
o`00L?oonfX;ool00=7ooo]Z2_oo001aoookJPWoo`009OoonfX000;ooo]Z0ol007l3oookJP?o001o
2_oonfX3o`00O`Wooo]Z0ol007l7oookJPOo00004?oonfX9ool0073ooo]Z2_oo003BoookJP_oo`00
KooonfX:ool002Gooo]Z0002oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJP?o001o1ooo
nfX5o`0001;ooo]Z2Ooo001_oookJP_oo`00d_oonfX;ool006oooo]Z2Ooo000VoookJP000_oonfX3
o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX2o`00O`;ooo]Z1?l007l7oookJPGo00004_oonfX9
ool006oooo]Z2ooo003CoookJP[oo`00KooonfX9ool002Kooo]Z0002oookJP?o001o0ooonfX3o`00
O`[ooo]Z0ol007l4oookJPOo001o2?oonfX5o`0001;ooo]Z2_oo001^oookJP[oo`00e?oonfX;ool0
06kooo]Z2Ooo000VoookJP000_oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX6o`00O`Wo
oo]Z1Ol0000BoookJP[oo`00KOoonfX;ool00=Cooo]Z2ooo001^oookJPWoo`009_oonfX000;ooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00O`Cooo]Z0_l007l=oookJPGo00004ooonfX9ool006gooo]Z
2_oo003FoookJP[oo`00K_oonfX9ool002Kooo]Z0003oookJP?o001o00Cooo]Zo`00Ool007oo001o
2?oonfX6o`00O`Cooo]Z0_l007l=oookJPGo00004ooonfX9ool006gooo]Z2_oo003FoookJP_oo`00
K?oonfX:ool002Kooo]Z0003oookJPOo001o2_oonfX4o`00O`Gooo]Z1ol007l7oookJPGo00004ooo
nfX9ool006cooo]Z2ooo003GoookJP[oo`00K?oonfX9ool002Oooo]Z0004oookJPGo001o3?oonfX3
o`00O`Gooo]Z1ol007l7oookJPGo00004ooonfX9ool006cooo]Z2_oo003HoookJP_oo`00JooonfX9
ool002Oooo]Z000[oookJPGo00004ooonfX:ool006[ooo]Z2ooo003HoookJP_oo`00JooonfX9ool0
02Oooo]Z000[oookJPGo00005?oonfX9ool006[ooo]Z2ooo003IoookJP[oo`00JooonfX9ool002Oo
oo]Z000[oookJPGo00005?oonfX9ool006[ooo]Z2_oo003JoookJP_oo`00JOoonfX:ool002Oooo]Z
000[oookJPGo00005?oonfX9ool006Wooo]Z2ooo003JoookJP_oo`00JOoonfX:ool002Oooo]Z000[
oookJPGo00005?oonfX9ool006Wooo]Z2ooo003KoookJP[oo`00JOoonfX9ool002Sooo]Z000[oook
JPGo00005?oonfX:ool006Sooo]Z2_oo003LoookJP_oo`00J?oonfX9ool002Sooo]Z000[oookJPGo
00005?oonfX:ool006Oooo]Z2ooo003MoookJP[oo`00J?oonfX9ool002Sooo]Z000[oookJPGo0000
5OoonfX9ool006Oooo]Z2_oo003NoookJP_oo`00I_oonfX:ool002Sooo]Z000[oookJPGo00005Ooo
nfX9ool006Oooo]Z2_oo003NoookJP_oo`00I_oonfX:ool002Sooo]Z000[oookJPGo00005OoonfX9
ool006Kooo]Z2ooo003OoookJP[oo`00I_oonfX9ool002Wooo]Z000[oookJPGo00005OoonfX9ool0
06Kooo]Z2_oo003PoookJP_oo`00IOoonfX9ool002Wooo]Z000[oookJPGo00005OoonfX:ool006Co
oo]Z2ooo003PoookJP_oo`00IOoonfX9ool002Wooo]Z000[oookJPGo00005_oonfX9ool006Cooo]Z
2ooo003QoookJP[oo`00I?oonfX:ool002Wooo]Z000[oookJPGo00005_oonfX9ool006Cooo]Z2_oo
003RoookJP_oo`00HooonfX:ool002Wooo]Z000[oookJPGo00005_oonfX9ool006?ooo]Z2ooo003S
oookJP[oo`00HooonfX9ool002[ooo]Z000[oookJPGo00005_oonfX9ool006?ooo]Z2ooo003Soook
JP_oo`00H_oonfX9ool002[ooo]Z000[oookJPGo00005_oonfX:ool006;ooo]Z2_oo003ToookJP_o
o`00H_oonfX9ool002[ooo]Z000[oookJPGo00005_oonfX:ool0067ooo]Z2ooo003UoookJP[oo`00
HOoonfX:ool002[ooo]Z000[oookJPGo00005ooonfX9ool0067ooo]Z2_oo003VoookJP_oo`00H?oo
nfX:ool002[ooo]Z000[oookJPGo00005ooonfX9ool0067ooo]Z2_oo003VoookJP_oo`00H?oonfX9
ool002_ooo]Z000[oookJPGo00005ooonfX9ool0063ooo]Z2ooo003WoookJP[oo`00H?oonfX9ool0
02_ooo]Z000[oookJPGo00005ooonfX:ool005oooo]Z2_oo003XoookJP_oo`00GooonfX9ool002_o
oo]Z000[oookJPGo00005ooonfX:ool005kooo]Z2ooo003YoookJP[oo`00G_oonfX:ool002_ooo]Z
000[oookJPGo00006?oonfX9ool005kooo]Z2ooo003YoookJP_oo`00GOoonfX:ool002_ooo]Z000[
oookJPGo00006?oonfX9ool005kooo]Z2_oo003ZoookJP_oo`00GOoonfX9ool002cooo]Z000[oook
JPGo00006?oonfX9ool005gooo]Z2ooo003[oookJP[oo`00GOoonfX9ool002cooo]Z000[oookJPGo
00006?oonfX:ool005cooo]Z2ooo003[oookJP_oo`00G?oonfX9ool002cooo]Z000[oookJPGo0000
6?oonfX:ool005cooo]Z2_oo003/oookJP_oo`00FooonfX:ool002cooo]Z000[oookJPGo00006Ooo
nfX9ool005_ooo]Z2ooo003]oookJP[oo`00FooonfX:ool002cooo]Z000[oookJPGo00006OoonfX9
ool005_ooo]Z2_oo003^oookJP_oo`00F_oonfX9ool002gooo]Z000[oookJPGo00006OoonfX9ool0
05_ooo]Z2_oo003_oookJP[oo`00F_oonfX9ool002gooo]Z000[oookJPGo00006OoonfX:ool005Wo
oo]Z2ooo003_oookJP_oo`00FOoonfX9ool002gooo]Z000[oookJPGo00006OoonfX:ool005Wooo]Z
2_oo003`oookJP_oo`00F?oonfX:ool002gooo]Z000[oookJPGo00006_oonfX9ool005Sooo]Z2ooo
003aoookJP[oo`00F?oonfX:ool002gooo]Z000[oookJPGo00006_oonfX9ool005Sooo]Z2ooo003a
oookJP_oo`00EooonfX9ool002kooo]Z000[oookJPGo00006_oonfX:ool005Kooo]Z2ooo003boook
JP_oo`00EooonfX9ool002kooo]Z000[oookJPGo00006_oonfX:ool005Kooo]Z2ooo003coookJP[o
o`00EooonfX9ool002kooo]Z000[oookJPGo00006_oonfX:ool005Gooo]Z3?oo003coookJP_oo`00
EOoonfX:ool002kooo]Z000[oookJPGo00006ooonfX9ool005Gooo]Z2ooo003eoookJP[oo`00EOoo
nfX:ool002kooo]Z000[oookJPGo00006ooonfX9ool005Gooo]Z2ooo003eoookJP_oo`00E?oonfX9
ool002oooo]Z000[oookJPGo00006ooonfX:ool005?ooo]Z2ooo003foookJP_oo`00E?oonfX9ool0
02oooo]Z000[oookJPGo00006ooonfX:ool005?ooo]Z2ooo003goookJP[oo`00E?oonfX9ool002oo
oo]Z000[oookJPGo00007?oonfX9ool005;ooo]Z2ooo003hoookJP_oo`00D_oonfX:ool002oooo]Z
000[oookJPGo00007?oonfX9ool005;ooo]Z2ooo003hoookJP_oo`00D_oonfX:ool002oooo]Z000[
oookJPGo00007?oonfX:ool0053ooo]Z2ooo003joookJP[oo`00D_oonfX9ool0033ooo]Z000[oook
JPGo00007?oonfX:ool0053ooo]Z2ooo003joookJP_oo`00DOoonfX9ool0033ooo]Z000[oookJPGo
00007?oonfX:ool004oooo]Z3?oo003koookJP[oo`00DOoonfX9ool0033ooo]Z000[oookJPGo0000
7OoonfX9ool004oooo]Z2ooo003loookJP_oo`00CooonfX:ool0033ooo]Z000[oookJPGo00007Ooo
nfX9ool004kooo]Z3?oo003loookJP_oo`00CooonfX:ool0033ooo]Z000[oookJPGo00007OoonfX:
ool004gooo]Z2ooo003noookJP_oo`00C_oonfX9ool0037ooo]Z000>oookJPGo001o1?oonfX3o`00
O`03oookJ_l007oo001o00Oo001o1ooonfX5o`0001gooo]Z2_oo001=oookJP_oo`00o_oonfX;ool0
04kooo]Z2Ooo000aoookJP003OoonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Oo
oo]Z1Ol0000NoookJPWoo`00C?oonfX;ool00?oooo]Z3?oo001<oookJP[oo`00<OoonfX000gooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l<oookJPGo
00007_oonfX9ool004cooo]Z2ooo003ooookJP7ooo]Z2ooo001<oookJP[oo`00<OoonfX000cooo]Z
0ol007l3oookJP?o001o1ooonfX4o`00O`_ooo]Z1Ol0000NoookJP[oo`00B_oonfX;ool00?oooo]Z
0_oonfX<ool004_ooo]Z2_oo000aoookJP003?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2Ooo
nfX7o`0001cooo]Z2_oo001:oookJP_oo`00oooonfX3oookJP_oo`00B_oonfX:ool003;ooo]Z000<
oookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007l8oookJPGo00007_oonfX:ool004Wooo]Z2ooo003o
oookJPCooo]Z3?oo0019oookJP[oo`00<_oonfX000cooo]Z0ol007l3oookJP?o001o2ooonfX3o`00
O`Sooo]Z1Ol0000OoookJP[oo`00B?oonfX;ool00?oooo]Z1OoonfX;ool004Wooo]Z2_oo000boook
JP003?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0001oooo]Z2_oo0017oookJPco
o`00oooonfX5oookJPcoo`00AooonfX;ool003;ooo]Z000<oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o1ooonfX5o`0001oooo]Z2_oo0017oookJP_oo`00oooonfX7oookJP_oo`00
AooonfX:ool003?ooo]Z000<oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`0001oooo]Z2ooo0015oookJPcoo`00oooonfX7oookJP_oo`00AooonfX:ool003?ooo]Z000=
oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l7oookJPGo00008?oo
nfX:ool004Gooo]Z2ooo003ooookJPWooo]Z2ooo0015oookJP_oo`00<ooonfX000gooo]Z1ol007l8
oookJPOo001o2?oonfX5o`00023ooo]Z2_oo0014oookJPcoo`00oooonfX9oookJP_oo`00AOoonfX:
ool003Cooo]Z000>oookJPGo001o2_oonfX5o`00O`Wooo]Z1Ol0000PoookJP_oo`00@ooonfX;ool0
0?oooo]Z2ooonfX;ool004Cooo]Z2_oo000doookJP00:ooonfX5o`00027ooo]Z2_oo0013oookJP_o
o`00oooonfX;oookJP_oo`00@ooonfX;ool003Cooo]Z000[oookJPGo00008OoonfX:ool004;ooo]Z
2ooo003ooookJPgooo]Z2ooo0012oookJP[oo`00=OoonfX002_ooo]Z1Ol0000QoookJP_oo`00@Ooo
nfX;ool00?oooo]Z3OoonfX;ool004;ooo]Z2_oo000eoookJP00:ooonfX5o`0002;ooo]Z2_oo0010
oookJP_oo`00oooonfX>oookJPcoo`00@?oonfX;ool003Gooo]Z000[oookJPGo00008_oonfX:ool0
043ooo]Z2ooo003ooookJPoooo]Z2ooo0010oookJP[oo`00=_oonfX002_ooo]Z1Ol0000RoookJP_o
o`00?_oonfX;ool00?oooo]Z4?oonfX<ool003oooo]Z2_oo000foookJP00:ooonfX5o`0002?ooo]Z
2_oo000noookJP_oo`00oooonfXAoookJP_oo`00?_oonfX;ool003Kooo]Z000[oookJPGo00008ooo
nfX:ool003gooo]Z3?oo003ooookJQ7ooo]Z3?oo000moookJP[oo`00=ooonfX002_ooo]Z1Ol0000S
oookJP_oo`00??oonfX;ool00?oooo]Z4ooonfX;ool003gooo]Z2_oo000goookJP00:ooonfX5o`00
02Cooo]Z2_oo000koookJPcoo`00oooonfXCoookJPcoo`00>ooonfX;ool003Oooo]Z000[oookJPGo
00009?oonfX:ool003_ooo]Z2ooo003ooookJQGooo]Z2ooo000koookJP[oo`00>?oonfX002_ooo]Z
1Ol0000ToookJP_oo`00>_oonfX;ool00?oooo]Z5OoonfX<ool003[ooo]Z2_oo000hoookJP00:ooo
nfX5o`0002Gooo]Z2_oo000ioookJP_oo`00oooonfXGoookJP_oo`00>OoonfX;ool003Sooo]Z000[
oookJPGo00009OoonfX:ool003Wooo]Z2ooo003ooookJQOooo]Z3?oo000hoookJP[oo`00>OoonfX0
02_ooo]Z1Ol0000UoookJP_oo`00=ooonfX;ool00?oooo]Z6OoonfX;ool003Sooo]Z2_oo000ioook
JP00:ooonfX5o`0002Kooo]Z2_oo000goookJP_oo`00oooonfXIoookJPcoo`00=_oonfX;ool003Wo
oo]Z000[oookJPGo00009_oonfX:ool003Kooo]Z2ooo003ooookJQ_ooo]Z3?oo000eoookJP[oo`00
>_oonfX002_ooo]Z1Ol0000VoookJP_oo`00=OoonfX;ool00?oooo]Z6ooonfX<ool003Gooo]Z2_oo
000joookJP00:ooonfX5o`0002Oooo]Z2_oo000doookJPcoo`00oooonfXLoookJPcoo`00<ooonfX;
ool003[ooo]Z000[oookJPGo00009ooonfX:ool003Cooo]Z2ooo003ooookJQgooo]Z3?oo000coook
JP[oo`00>ooonfX002_ooo]Z1Ol0000WoookJP_oo`00<_oonfX<ool00?oooo]Z7_oonfX<ool003;o
oo]Z2_oo000koookJP00:ooonfX5o`0002Sooo]Z2_oo000aoookJPcoo`00oooonfXOoookJPcoo`00
<OoonfX;ool003_ooo]Z000[oookJPGo0000:?oonfX;ool0033ooo]Z3?oo003ooookJR3ooo]Z3?oo
000`oookJP[oo`00??oonfX002_ooo]Z1Ol0000XoookJP_oo`00;ooonfX<ool00?oooo]Z8_oonfX;
ool002oooo]Z2ooo000loookJP00:ooonfX5o`0002Wooo]Z2_oo000_oookJPcoo`00oooonfXRoook
JPcoo`00;_oonfX;ool003cooo]Z000[oookJPGo0000:OoonfX;ool002gooo]Z3?oo003ooookJRCo
oo]Z2ooo000]oookJP_oo`00?OoonfX002_ooo]Z1Ol0000YoookJP_oo`00;?oonfX=ool00?oooo]Z
9?oonfX<ool002cooo]Z2ooo000moookJP00:ooonfX5o`0002[ooo]Z2ooo000[oookJPcoo`00oooo
nfXVoookJP_oo`00:ooonfX<ool003gooo]Z000[oookJPGo0000:_oonfX;ool002[ooo]Z3?oo003o
oookJROooo]Z3?oo000ZoookJP_oo`00?_oonfX002_ooo]Z1Ol0000[oookJP[oo`00:_oonfX<ool0
0?oooo]Z:?oonfX<ool002Wooo]Z2ooo000noookJP00:ooonfX5o`0002_ooo]Z2ooo000XoookJPco
o`00oooonfXYoookJPcoo`00:?oonfX;ool003oooo]Z000[oookJPGo0000:ooonfX;ool002Sooo]Z
3?oo003ooookJR[ooo]Z3?oo000WoookJP_oo`00?ooonfX002_ooo]Z1Ol0000/oookJP[oo`009ooo
nfX<ool00?oooo]Z:ooonfX=ool002Gooo]Z2ooo0010oookJP00:ooonfX5o`0002cooo]Z2ooo000U
oookJPcoo`00oooonfX]oookJPcoo`009OoonfX;ool0043ooo]Z000[oookJPGo0000;OoonfX:ool0
02Gooo]Z3?oo003ooookJRgooo]Z3Ooo000SoookJP_oo`00@OoonfX002_ooo]Z1Ol0000]oookJP_o
o`008ooonfX<ool00?oooo]Z;ooonfX=ool002;ooo]Z2ooo0011oookJP00:ooonfX5o`0002gooo]Z
3?oo000RoookJPcoo`00oooonfX`oookJPcoo`008OoonfX<ool0047ooo]Z000[oookJPGo0000;_oo
nfX;ool0027ooo]Z3?oo003ooookJS7ooo]Z3Ooo000OoookJPcoo`00@_oonfX002_ooo]Z1Ol0000^
oookJPcoo`007ooonfX=ool00?oooo]Z<_oonfX=ool001kooo]Z3?oo0012oookJP00:ooonfX5o`00
02kooo]Z3?oo000NoookJPgoo`00oooonfXdoookJPgoo`007?oonfX<ool004?ooo]Z000[oookJPGo
0000;ooonfX<ool001cooo]Z3Ooo003ooookJSGooo]Z3Ooo000LoookJPcoo`00@ooonfX002_ooo]Z
1Ol0000_oookJPgoo`006_oonfX>ool00?oooo]Z=_oonfX=ool001[ooo]Z3?oo0014oookJP00:ooo
nfX5o`00033ooo]Z3Ooo000HoookJPkoo`00oooonfXhoookJPgoo`006OoonfX<ool004Cooo]Z000[
oookJPGo0000<OoonfX=ool001Kooo]Z3ooo003ooookJSSooo]Z3_oo000GoookJPcoo`00AOoonfX0
02_ooo]Z1Ol0000aoookJPkoo`005?oonfX?ool00?oooo]Z>_oonfX>ool001Gooo]Z3?oo0016oook
JP00:ooonfX5o`0003;ooo]Z3_oo000BoookJPooo`00oooonfXloookJPkoo`004ooonfX=ool004Ko
oo]Z000[oookJPGo0000<_oonfX?ool0013ooo]Z3ooo003ooookJSkooo]Z3_oo000AoookJPgoo`00
AooonfX002_ooo]Z1Ol0000coookJPooo`003OoonfX@ool00?oooo]Z?ooonfX@ool000kooo]Z3_oo
0017oookJP00:ooonfX5o`0003Cooo]Z3ooo000;oookJQ3oo`00oooonfY1oookJQ3oo`002ooonfX?
ool004Sooo]Z000[oookJPGo0000=OoonfX?ool000Sooo]Z4Ooo003ooookJT?ooo]Z4?oo0009oook
JQ3oo`00B?oonfX002_ooo]Z1Ol0000foookJQ7oo`001?oonfXAool00?oooo]ZAOoonfXAool000Co
oo]Z4_oo0019oookJP001?oonfX5o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`?ooo]Z
1Ol007l9oookJPGo0000=ooonfXTool00?oooo]ZAooonfXUool004[ooo]Z0003oookJPOo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00Oo001o0_oonfX7o`00O`Sooo]Z1Ol0000hoookJR;oo`00oooo
nfY9oookJR?oo`00BooonfX000?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l6oookJPCo001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0003Wooo]Z
8?oo003ooookJT_ooo]Z8Ooo001<oookJP000_oonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o1Ooo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000>_oonfXNool00?oooo]ZCOoonfXOool004gooo]Z0002
oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007l9oookJP?o001o1ooonfX7o`0003Wooo]Z6ooo003o
oookJU7ooo]Z7?oo001>oookJP000_oonfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX3o`00
O`Oooo]Z1Ol0000loookJQWoo`00oooonfYCoookJQWoo`00D?oonfX000;ooo]Z0ol007l3oookJP?o
001o2ooonfX3o`00O`?ooo]Z0_l007l2oookJPCo001o1ooonfX5o`0003gooo]Z5_oo003ooookJUKo
oo]Z5ooo001AoookJP000_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o0_oonfX7o`00O`Sooo]Z
1Ol00010oookJQ;oo`00oooonfYIoookJQ;oo`00E?oonfX000;ooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l2oookJPKo001o2OoonfX5o`0004;ooo]Z3Ooo003ooookJUoooo]Z3_oo
001EoookJP000_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007l=
oookJPGo0000oooonf[ooookJQ;ooo]Z0003oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4
o`00O`;ooo]Z0ol007l2oookJP;o001o3OoonfX5o`000?oooo]ZoooonfXBoookJP000ooonfX7o`00
O`Sooo]Z1ol007l4oookJPOo001o1ooonfX5o`000?oooo]ZoooonfXBoookJP001?oonfX5o`00O`[o
oo]Z1Ol007l5oookJPOo001o1ooonfX5o`000?oooo]ZoooonfXBoookJP00:ooonfX5o`000?oooo]Z
oooonfXBoookJP00:ooonfX5o`000?oooo]ZoooonfXBoookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.178095, -0.0210844, \
0.00389323, 0.000787417}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Now calculate Fourier amplitudes for this function\[Ellipsis]\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(EvenAmplitudeVector[6, \ myfunction, 2]\)\)\)], "Input"],

Cell[BoxData[
    \({2\/15, \(48 - 4\ \[Pi]\^2\)\/\[Pi]\^4, \(3 - \[Pi]\^2\)\/\[Pi]\^4, \(-\
\(\(4\ \((\(-4\) + 
                  3\ \[Pi]\^2)\)\)\/\(27\ \[Pi]\^4\)\)\), \(3 - 4\ \[Pi]\^2\)\
\/\(16\ \[Pi]\^4\), \(48 - 100\ \[Pi]\^2\)\/\(625\ \[Pi]\^4\), \(1 - 3\ \[Pi]\
\^2\)\/\(27\ \[Pi]\^4\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The odd terms should all vanish because the function is even around the \
center x=",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\/2\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OddAmplitudeVector[6, \ myfunction, 2]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(OddBasisVector[NTerms_Integer, var_, \ \ wavelength_]\  := \ 
      Table[Sin[\(2\ \[Pi]\ \ i\ var\)\/wavelength], \ {i, 0, 
          NTerms}]\)], "Input",
  CellTags->"mmtag:17:Fourier_series__basis_functions"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OddBasisVector[6, x, 2]\)], "Input"],

Cell[BoxData[
    \({0, Sin[\[Pi]\ x], Sin[2\ \[Pi]\ x], Sin[3\ \[Pi]\ x], 
      Sin[4\ \[Pi]\ x], Sin[5\ \[Pi]\ x], Sin[6\ \[Pi]\ x]}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(EvenBasisVector[NTerms_Integer, var_, \ \ wavelength_]\  := \ 
      Table[Cos[\(2\ \[Pi]\ \ i\ var\)\/wavelength], \ {i, 0, 
          NTerms}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenBasisVector[6, x, 2]\)], "Input"],

Cell[BoxData[
    \({1, Cos[\[Pi]\ x], Cos[2\ \[Pi]\ x], Cos[3\ \[Pi]\ x], 
      Cos[4\ \[Pi]\ x], Cos[5\ \[Pi]\ x], Cos[6\ \[Pi]\ x]}\)], "Output"]
}, Open  ]],

Cell["\<\
Make the Fourier series representation by taking the dot product of \
the AmplitudeVectors with the BasisVectors:\
\>", "Text"],

Cell[BoxData[
    \(FourierTruncSeries[n_, \ function_, var_\ , \ wavelength_] := \ 
      EvenAmplitudeVector[n, function, wavelength] . 
          EvenBasisVector[n, var, 
            wavelength]\  + \ \[IndentingNewLine]OddAmplitudeVector[n, 
            function, wavelength] . 
          OddBasisVector[n, var, wavelength]\)], "Input",
  CellTags->"mmtag:17:Fourier_series__function_to_create_truncated_series"],

Cell[TextData[{
  "For ",
  StyleBox["myfunction",
    FontWeight->"Bold"],
  " we write the Fourier series out to six terms as:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FourierTruncSeries[6, myfunction, x, 2]\)], "Input"],

Cell[BoxData[
    \(2\/15 + \(\((48 - 4\ \[Pi]\^2)\)\ Cos[\[Pi]\ x]\)\/\[Pi]\^4 + \(\((3 - \
\[Pi]\^2)\)\ Cos[2\ \[Pi]\ x]\)\/\[Pi]\^4 - \(4\ \((\(-4\) + 3\ \[Pi]\^2)\)\ \
Cos[3\ \[Pi]\ x]\)\/\(27\ \[Pi]\^4\) + \(\((3 - 4\ \[Pi]\^2)\)\ Cos[4\ \[Pi]\ \
x]\)\/\(16\ \[Pi]\^4\) + \(\((48 - 100\ \[Pi]\^2)\)\ Cos[5\ \[Pi]\ \
x]\)\/\(625\ \[Pi]\^4\) + \(\((1 - 3\ \[Pi]\^2)\)\ Cos[6\ \[Pi]\ x]\)\/\(27\ \
\[Pi]\^4\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FourierPlot\  = 
      Plot[FourierTruncSeries[3, myfunction, x, 2], {x, \(-2\), 
          4}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.15873 0.0147151 2.32413 [
[.02381 .00222 -13.4688 -20 ]
[.02381 .00222 13.4688 0 ]
[.18254 .00222 -13.4688 -20 ]
[.18254 .00222 13.4688 0 ]
[.5 .00222 -7 -20 ]
[.5 .00222 7 0 ]
[.65873 .00222 -7 -20 ]
[.65873 .00222 7 0 ]
[.81746 .00222 -7 -20 ]
[.81746 .00222 7 0 ]
[.97619 .00222 -7 -20 ]
[.97619 .00222 7 0 ]
[.32877 .13092 -39 -10 ]
[.32877 .13092 0 10 ]
[.32877 .24713 -29 -10 ]
[.32877 .24713 0 10 ]
[.32877 .36333 -39 -10 ]
[.32877 .36333 0 10 ]
[.32877 .47954 -29 -10 ]
[.32877 .47954 0 10 ]
[.32877 .59575 -39 -10 ]
[.32877 .59575 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
gsave
.02381 .00222 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.18254 .01472 m
.18254 .02097 L
s
gsave
.18254 .00222 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .01472 m
.5 .02097 L
s
gsave
.5 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.65873 .01472 m
.65873 .02097 L
s
gsave
.65873 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 .01472 m
.81746 .02097 L
s
gsave
.81746 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.34127 .13092 m
.34752 .13092 L
s
gsave
.32877 .13092 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.34127 .24713 m
.34752 .24713 L
s
gsave
.32877 .24713 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.34127 .36333 m
.34752 .36333 L
s
gsave
.32877 .36333 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.34127 .47954 m
.34752 .47954 L
s
gsave
.32877 .47954 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.34127 .59575 m
.34752 .59575 L
s
gsave
.32877 .59575 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.34127 .03796 m
.34502 .03796 L
s
.34127 .0612 m
.34502 .0612 L
s
.34127 .08444 m
.34502 .08444 L
s
.34127 .10768 m
.34502 .10768 L
s
.34127 .15416 m
.34502 .15416 L
s
.34127 .1774 m
.34502 .1774 L
s
.34127 .20065 m
.34502 .20065 L
s
.34127 .22389 m
.34502 .22389 L
s
.34127 .27037 m
.34502 .27037 L
s
.34127 .29361 m
.34502 .29361 L
s
.34127 .31685 m
.34502 .31685 L
s
.34127 .34009 m
.34502 .34009 L
s
.34127 .38658 m
.34502 .38658 L
s
.34127 .40982 m
.34502 .40982 L
s
.34127 .43306 m
.34502 .43306 L
s
.34127 .4563 m
.34502 .4563 L
s
.34127 .50278 m
.34502 .50278 L
s
.34127 .52602 m
.34502 .52602 L
s
.34127 .54926 m
.34502 .54926 L
s
.34127 .57251 m
.34502 .57251 L
s
.01 w
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .27349 m
.02499 .27384 L
.02605 .27474 L
.02729 .27649 L
.02846 .27882 L
.03053 .28458 L
.03279 .29309 L
.0379 .32034 L
.04262 .35375 L
.06244 .52443 L
.06713 .55744 L
.06972 .57241 L
.07218 .58415 L
.07356 .5896 L
.07507 .59455 L
.07644 .59811 L
.07771 .60061 L
.07903 .60235 L
.08022 .60317 L
.08088 .60332 L
.0816 .60323 L
.0829 .6024 L
.08355 .60166 L
.08425 .60063 L
.08552 .59814 L
.08702 .59414 L
.08839 .58952 L
.09137 .57639 L
.09419 .56024 L
.09917 .5239 L
.10458 .47505 L
.12396 .26929 L
.13426 .17482 L
.14005 .13345 L
.14536 .10384 L
.15007 .08402 L
.15523 .06857 L
.15783 .06292 L
.16061 .05823 L
.16323 .0549 L
.16561 .05263 L
.16806 .05094 L
.17031 .04982 L
.17148 .04938 L
.17278 .04898 L
.17415 .04865 L
.17539 .04841 L
.17657 .04824 L
.17769 .04811 L
.17888 .04802 L
Mistroke
.18017 .04794 L
.18129 .04791 L
.18248 .04789 L
.18361 .0479 L
.18463 .04793 L
.18584 .04799 L
.18696 .04807 L
.1882 .0482 L
.18952 .04838 L
.19091 .04864 L
.19222 .04896 L
.19341 .04931 L
.19468 .04978 L
.19698 .05091 L
.1991 .05235 L
.20139 .05441 L
.20391 .05744 L
.20662 .06174 L
.20909 .06678 L
.21176 .07358 L
.21467 .08281 L
.21958 .10318 L
.22475 .13169 L
.23505 .21073 L
.2444 .30359 L
.25531 .42194 L
.2601 .47114 L
.26536 .51931 L
.26987 .55356 L
.27235 .56904 L
.2747 .58123 L
.27598 .58678 L
.27737 .59194 L
.27853 .59552 L
.27981 .59869 L
.28101 .60093 L
.28229 .6025 L
.28347 .60323 L
.28458 .60326 L
.2858 .60258 L
.28648 .60187 L
.28713 .60099 L
.28842 .5986 L
.2898 .59515 L
.29231 .58658 L
.29459 .57634 L
.30015 .54279 L
.30539 .50221 L
.31421 .42417 L
.32369 .34443 L
Mistroke
.32647 .3249 L
.32912 .30878 L
.3317 .29571 L
.33409 .28612 L
.33634 .27948 L
.3376 .27682 L
.33875 .27507 L
.34 .27389 L
.34071 .27357 L
.34136 .2735 L
.34256 .27391 L
.34383 .27512 L
.34507 .27706 L
.34619 .27947 L
.34873 .28709 L
.35107 .29677 L
.35329 .30809 L
.36368 .38318 L
.37388 .4741 L
.37947 .52105 L
.38471 .55819 L
.38927 .58258 L
.39052 .58774 L
.39184 .59242 L
.39307 .59606 L
.39419 .59875 L
.39544 .60103 L
.39613 .60195 L
.39678 .60261 L
.39793 .60325 L
.39918 .60319 L
.39984 .60284 L
.40056 .6022 L
.40132 .60125 L
.40202 .6001 L
.40328 .59741 L
.40464 .59365 L
.407 .58493 L
.40958 .57243 L
.41427 .54228 L
.42306 .46496 L
.43408 .34754 L
.44444 .23929 L
.45374 .15936 L
.45897 .12451 L
.46378 .09933 L
.46849 .08067 L
.47289 .06809 L
.47541 .06269 L
.47771 .05877 L
Mistroke
.48036 .05527 L
.48286 .05281 L
.4853 .05107 L
.48652 .05039 L
.48788 .04978 L
.48903 .04935 L
.49027 .04897 L
.49143 .04868 L
.49251 .04847 L
.49385 .04826 L
.49462 .04817 L
.49531 .0481 L
.4966 .048 L
.49731 .04796 L
.49798 .04793 L
.49923 .0479 L
.50038 .0479 L
.50165 .04792 L
.50228 .04794 L
.50298 .04797 L
.50429 .04806 L
.50549 .04818 L
.50681 .04836 L
.50822 .04861 L
.50944 .04889 L
.51058 .04922 L
.51185 .04967 L
.51318 .05025 L
.51552 .05159 L
.51766 .05326 L
.51996 .05564 L
.52248 .05906 L
.52523 .06394 L
.52772 .06958 L
.5304 .07711 L
.53332 .08716 L
.5385 .11047 L
.5434 .13932 L
.55285 .21386 L
.56326 .31866 L
.57425 .43759 L
.57906 .48563 L
.5843 .53138 L
.58681 .54999 L
.58947 .5671 L
.59178 .57941 L
.59427 .58997 L
.59561 .5944 L
.59683 .59769 L
.598 .60014 L
Mistroke
.59924 .60197 L
.60035 .60296 L
.60139 .60332 L
.60252 .60308 L
.60374 .60211 L
.60442 .60124 L
.60514 .60007 L
.60643 .59733 L
.60782 .59349 L
.60936 .5882 L
.6121 .57611 L
.61467 .56194 L
.62463 .48712 L
.63358 .40706 L
.64313 .33025 L
.64596 .31232 L
.64863 .29817 L
.65102 .28802 L
.65226 .28378 L
.65362 .27994 L
.65489 .27714 L
.65608 .27523 L
.65734 .27397 L
.65804 .27361 L
.65869 .27349 L
.65983 .2738 L
.66108 .27487 L
.66226 .27658 L
.66336 .27878 L
.66574 .28553 L
.66798 .29426 L
.67308 .32202 L
.67806 .35782 L
.68343 .40305 L
.6935 .49289 L
.69883 .53549 L
.70177 .55561 L
.70454 .57186 L
.70714 .58432 L
.70851 .5897 L
.70996 .59447 L
.71118 .5977 L
.71183 .59913 L
.71253 .60043 L
.71375 .60214 L
.7149 .60306 L
.71613 .60331 L
.71683 .60311 L
.71748 .6027 L
.71867 .6014 L
Mistroke
.71993 .59923 L
.72118 .5963 L
.72235 .59285 L
.72454 .58459 L
.72711 .57205 L
.72982 .55564 L
.73468 .51901 L
.74563 .41188 L
.75584 .30112 L
.7655 .20583 L
.77418 .13859 L
.77908 .10987 L
.78361 .08924 L
.78811 .07396 L
.79067 .06733 L
.79307 .06231 L
.79543 .05837 L
.79791 .05516 L
.80063 .05256 L
.80313 .05085 L
.80444 .05017 L
.80563 .04966 L
.80691 .04921 L
.8083 .04882 L
.80959 .04854 L
.81078 .04834 L
.81191 .04819 L
.81312 .04807 L
.81441 .04798 L
.81514 .04794 L
.81581 .04792 L
.8171 .04789 L
.81832 .0479 L
.81901 .04791 L
.81974 .04794 L
.82106 .04801 L
.82187 .04807 L
.82263 .04815 L
.82404 .04832 L
.82521 .04852 L
.82646 .04878 L
.82872 .04944 L
.83009 .04999 L
.8314 .05063 L
.83384 .0522 L
.83641 .05451 L
.83879 .05738 L
.8414 .06149 L
.84417 .06714 L
.84871 .0798 L
Mistroke
.85296 .09611 L
.85763 .11955 L
.86265 .15162 L
.87275 .23662 L
.88377 .35178 L
.8943 .464 L
.89927 .5107 L
.90385 .54708 L
.90871 .5768 L
.91127 .58823 L
.91257 .59286 L
.91397 .5969 L
.9152 .59965 L
.91632 .60149 L
.91745 .60271 L
.91852 .60326 L
.91976 .60318 L
.92091 .60241 L
.92217 .6008 L
.9228 .59969 L
.92351 .59823 L
.92622 .59039 L
.92871 .58021 L
.93432 .54795 L
.94447 .46615 L
.97619 .27349 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP008?oonfX9o`00Oe3ooo]Z0ol007nRoook
JP?o001oCooonfX9o`00Odkooo]Z1Ol007mDoookJP?o001o7OoonfX0023ooo]Z2Ol007m@oookJP?o
001oX_oonfX3o`00Odoooo]Z2Ol007m=oookJPOo001oDooonfX3o`00Oagooo]Z000PoookJPCo001o
EOoonfX3o`00Oj;ooo]Z0ol007m?oookJPCo001oDOoonfX3o`00O`?ooo]Z0ol007mBoookJP?o001o
7OoonfX001Cooo]Z2_l007l3oookJPCo001oA?oonfX:o`00O`Kooo]Z0ol007nRoookJP?o001oD?oo
nfX4o`00Oe3ooo]Z0ol007l3oookJP?o001oCOoonfX9o`00Oacooo]Z000DoookJP[o001o1?oonfX5
o`00Od;ooo]Z2_l007l6oookJP?o001oX_oonfX3o`00Oe7ooo]Z1Ol007mDoookJP?o001oCOoonfX9
o`00Oacooo]Z000ToookJPCo001oDOoonfX3o`00Oj;ooo]Z0ol007mCoookJPCo001oDooonfX3o`00
Odgooo]Z0_l007l3oookJP?o001o7OoonfX002Gooo]Z0ol007mAoookJP?o001oX_oonfX3o`00OeCo
oo]Z0ol007mAoookJPCo001oCooonfX2o`00O`;ooo]Z0ol007lMoookJP009_oonfX3o`00Oe3ooo]Z
0ol007nRoookJP?o001oEOoonfX3o`00Oe3ooo]Z0ol007m@oookJP?o001o00Cooo]Zo`00Ool007oo
001o7OoonfX0023ooo]Z0ol007l3oookJP?o001oD?oonfX3o`00Oj;ooo]Z0ol007m?oookJP?o001o
0ooonfX3o`00Oe;ooo]Z0_l007m@oookJP;o001o00Cooo]Zo`00Ool007oo001o7OoonfX0023ooo]Z
0ol007l3oookJP?o001oCOoonfX6o`00Oioooo]Z1_l007m?oookJP?o001o0ooonfX3o`00Odcooo]Z
0ol007l3oookJP?o001oD?oonfX5o`00Oagooo]Z000PoookJPCo001o0_oonfX3o`00Odgooo]Z1_l0
07m;oookJPGo0000CooonfX6o`00Odoooo]Z1?l007l2oookJP?o001oC?oonfX3o`00O`?ooo]Z0ol0
07m@oookJPGo001o7OoonfX0027ooo]Z1ol007m@oookJPCo001oBooonfX5o`00057ooo]Z1?l007m@
oookJPOo001oC_oonfX7o`00Oe;ooo]Z1?l007lMoookJP008_oonfX5o`00Oe;ooo]Z0ol007m;oook
JPGo0000D_oonfX3o`00Oe7ooo]Z1Ol007m@oookJPGo001oE?oonfX3o`00Oagooo]Z0037oookJPGo
0000oooonfYeoookJP00aooonfX5o`000?oooo]ZMOoonfX00<Oooo]Z1Ol0003ooookJWGooo]Z0037
oookJPGo0000oooonfYeoookJP00aooonfX5o`000?oooo]ZMOoonfX000oooo]Zool0003oo`0002?o
00004?oonfX000oooo]Zool0003oo`0002?o00004?oonfX000oooo]Zool0003oo`0002?o00004?oo
nfX000oooo]Zool0003oo`0002?o00004?oonfX000oooo]Zool0003oo`0002?o00004?oonfX001ko
oo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1@oookJPGo0000DooonfX00ol0003o
oo]ZoookJP1CoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003o
oo]ZoookJP0MoookJP007_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z053ooo]Z
1Ol0001CoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Z
oookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z0037oookJPGo0000oooonfYeoookJP00aooonfX5
o`000?oooo]ZMOoonfX00<Oooo]Z1Ol0003ooookJWGooo]Z0037oookJPGo0000oooonfYeoookJP00
aooonfX5o`000?oooo]ZMOoonfX00<Oooo]Z1Ol0003ooookJWGooo]Z0037oookJPGo0000oooonfYe
oookJP00aooonfX5o`000?oooo]ZMOoonfX00<Oooo]Z1Ol0003ooookJWGooo]Z0037oookJPGo0000
oooonfYeoookJP00aooonfX5o`000?oooo]ZMOoonfX00<Oooo]Z1Ol0003ooookJWGooo]Z001^oook
JP_o0000C_oonfX5o`0004kooo]Z2ol0002PoookJP_o0000L?oonfX006_ooo]Z4_l0001:oookJPGo
0000B_oonfXBo`0009Wooo]Z4_l0001]oookJP00J_oonfXDo`0004Wooo]Z1Ol00019oookJQGo0000
U_oonfXDo`0006cooo]Z001XoookJQOo0000B?oonfX5o`0004Oooo]Z6?l0002DoookJQKo0000Jooo
nfX006Oooo]Z2_l00005oookJP[o0000AooonfX5o`0004Kooo]Z2ol00004oookJP_o0000T_oonfX:
o`0000Cooo]Z2ol0001YoookJP00IooonfX7o`0000cooo]Z1ol00016oookJPGo0000A_oonfX8o`00
00_ooo]Z1ol0002AoookJPSo00002ooonfX8o`0006Sooo]Z001VoookJPOo00003_oonfX6o`0004Ko
oo]Z1Ol00015oookJPOo00003ooonfX6o`0008oooo]Z1ol0000>oookJPOo0000J?oonfX006Gooo]Z
1_l0000AoookJPKo0000AOoonfX5o`0004Gooo]Z1Ol0000BoookJPGo0000SooonfX6o`00013ooo]Z
1ol0001WoookJP00I?oonfX7o`0001;ooo]Z1_l00014oookJPGo0000A?oonfX6o`0001;ooo]Z1_l0
002=oookJPKo00004ooonfX5o`0006Oooo]Z001ToookJPKo00004ooonfX6o`0004Cooo]Z1Ol00014
oookJPGo00005?oonfX6o`0008cooo]Z1Ol0000DoookJPGo0000IooonfX006?ooo]Z1_l0000Eoook
JPKo0000@ooonfX5o`0004?ooo]Z1_l0000DoookJPKo0000RooonfX6o`0001Gooo]Z1Ol0001Voook
JP00HooonfX5o`0001Oooo]Z1Ol00013oookJPGo0000@_oonfX6o`0001Kooo]Z1_l0002:oookJPGo
00005_oonfX6o`0006Gooo]Z001SoookJPGo00005ooonfX5o`0004?ooo]Z1Ol00012oookJPKo0000
5ooonfX5o`0008[ooo]Z1Ol0000FoookJPKo0000IOoonfX006;ooo]Z1Ol0000IoookJPGo0000@_oo
nfX5o`0004;ooo]Z1Ol0000HoookJPGo0000ROoonfX5o`0001Sooo]Z1_l0001ToookJP00H_oonfX5
o`0001Wooo]Z1Ol00012oookJPGo0000@OoonfX5o`0001[ooo]Z1?l00028oookJPKo00006OoonfX5
o`0006Cooo]Z001RoookJPGo00006OoonfX5o`0004;ooo]Z1Ol00011oookJPGo00006_oonfX5o`00
08Oooo]Z1_l0000IoookJPGo0000I?oonfX0067ooo]Z1Ol0000KoookJPGo0000@OoonfX5o`00047o
oo]Z1Ol0000JoookJPGo0000QooonfX5o`0001_ooo]Z1Ol0001SoookJP00HOoonfX5o`0001_ooo]Z
1Ol00011oookJPGo0000@?oonfX5o`0001_ooo]Z1Ol00026oookJPGo00007?oonfX5o`0006?ooo]Z
001QoookJPGo00006ooonfX5o`00047ooo]Z1Ol00010oookJPGo00007?oonfX5o`0008Gooo]Z1Ol0
000LoookJPGo0000HooonfX0063ooo]Z1Ol0000MoookJPGo0000@?oonfX5o`00043ooo]Z1Ol0000L
oookJPGo0000QOoonfX5o`0001gooo]Z1?l0001SoookJP00H?oonfX5o`0001gooo]Z1Ol00010oook
JPGo0000@?oonfX4o`0001gooo]Z1Ol00025oookJPCo00007_oonfX5o`0006;ooo]Z001PoookJPGo
00007OoonfX5o`00043ooo]Z1Ol0000ooookJPGo00007_oonfX5o`0008Cooo]Z1?l0000NoookJPGo
0000H_oonfX0063ooo]Z1?l0000OoookJPGo0000?ooonfX5o`0003oooo]Z1Ol0000NoookJPGo0000
PooonfX5o`0001kooo]Z1Ol0001RoookJP00GooonfX5o`0001oooo]Z1Ol0000ooookJPGo0000?ooo
nfX5o`0001kooo]Z1Ol00023oookJPGo00007ooonfX4o`0006;ooo]Z001OoookJPGo00007ooonfX5
o`0003oooo]Z1Ol0000noookJPGo00008?oonfX5o`0008;ooo]Z1Ol0000OoookJPCo0000H_oonfX0
05oooo]Z1Ol0000PoookJPGo0000?_oonfX5o`0003kooo]Z1Ol0000PoookJPGo0000P_oonfX4o`00
023ooo]Z1Ol0001QoookJP00GooonfX4o`00027ooo]Z1Ol0000noookJPGo0000?_oonfX5o`00023o
oo]Z1Ol00022oookJPCo00008?oonfX5o`00067ooo]Z001OoookJPCo00008OoonfX5o`0003kooo]Z
1Ol0000moookJPGo00008_oonfX4o`00087ooo]Z1Ol0000PoookJPGo0000HOoonfX005kooo]Z1Ol0
000RoookJPCo0000?_oonfX5o`0003gooo]Z1Ol0000RoookJPGo0000P?oonfX5o`00027ooo]Z1?l0
001QoookJP00G_oonfX5o`0002;ooo]Z1Ol0000moookJPGo0000?OoonfX5o`0002;ooo]Z1Ol00020
oookJPGo00008OoonfX5o`00063ooo]Z001NoookJPGo00008_oonfX5o`0003gooo]Z1Ol0000moook
JPCo00008ooonfX5o`00083ooo]Z1?l0000RoookJPGo0000H?oonfX005kooo]Z1?l0000SoookJPGo
0000?OoonfX5o`0003gooo]Z1?l0000ToookJPCo0000P?oonfX4o`0002;ooo]Z1Ol0001PoookJP00
G_oonfX4o`0002Cooo]Z1?l0000moookJPGo0000??oonfX5o`0002Cooo]Z1?l0001ooookJPGo0000
8ooonfX4o`00063ooo]Z001NoookJPCo00009?oonfX5o`0003cooo]Z1Ol0000loookJPGo00009?oo
nfX5o`0007kooo]Z1Ol0000SoookJPGo0000GooonfX005gooo]Z1Ol0000ToookJPGo0000??oonfX5
o`0003cooo]Z1Ol0000ToookJPGo0000O_oonfX5o`0002?ooo]Z1Ol0001OoookJP00GOoonfX5o`00
02Cooo]Z1Ol0000loookJPGo0000??oonfX4o`0002Gooo]Z1Ol0001noookJPCo00009?oonfX5o`00
05oooo]Z001MoookJPGo00009OoonfX4o`0003cooo]Z1Ol0000loookJPCo00009_oonfX4o`0007ko
oo]Z1?l0000UoookJPCo0000GooonfX005gooo]Z1?l0000VoookJPCo0000??oonfX5o`0003cooo]Z
1?l0000VoookJPCo0000OOoonfX5o`0002Gooo]Z1?l0001OoookJP00GOoonfX4o`0002Kooo]Z1Ol0
000koookJPGo0000??oonfX4o`0002Kooo]Z1?l0001moookJPGo00009OoonfX5o`0005kooo]Z001L
oookJPGo00009_oonfX5o`0003_ooo]Z1Ol0000koookJPGo00009_oonfX5o`0007cooo]Z1Ol0000U
oookJPGo0000G_oonfX005cooo]Z1Ol0000VoookJPGo0000>ooonfX5o`0003_ooo]Z1Ol0000Voook
JPGo0000O?oonfX4o`0002Kooo]Z1Ol0001NoookJP00G?oonfX5o`0002Oooo]Z1?l0000koookJPGo
0000>ooonfX5o`0002Kooo]Z1Ol0001loookJPCo00009ooonfX4o`0005kooo]Z001LoookJPCo0000
:?oonfX4o`0001Cooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Gooo]Z1Ol007l9oookJPGo0000
>ooonfX4o`0002Sooo]Z1?l0001koookJPGo00009ooonfX4o`0005kooo]Z001LoookJPCo0000:?oo
nfX5o`0001;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`?ooo]Z1ol007l8oookJPGo0000>ooo
nfX4o`0002Sooo]Z1?l0001koookJPGo00009ooonfX5o`0005gooo]Z001KoookJPGo0000:?oonfX5
o`0001;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3o`00O`04oookJ_l0
07oo001oo`00O`;ooo]Z1?l007l01?oonf[o001oo`00Ool007l8oookJPGo0000>ooonfX4o`0002So
oo]Z1?l0001koookJPGo00009ooonfX5o`0005gooo]Z001KoookJPGo0000:?oonfX5o`00017ooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o1ooonfX5o`0003_ooo]Z1?l0000XoookJPCo0000NooonfX4o`0002Sooo]Z1Ol0001MoookJP00
FooonfX5o`0002Wooo]Z1?l0000AoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX3o`00O`Oooo]Z1ol0000hoookJPGo0000:?oonfX4o`0007_ooo]Z1?l0000YoookJPCo0000
GOoonfX005_ooo]Z1?l0000ZoookJPCo00004OoonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0ol007l7oookJPGo0000>_oonfX5o`0002Sooo]Z1Ol0001ioookJPGo0000:Ooo
nfX4o`0005gooo]Z001KoookJPCo0000:_oonfX4o`00017ooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l2oookJP;o001o0_oonfX4o`00O`Oooo]Z1Ol0000joookJPGo0000:?oonfX5
o`0007Wooo]Z1Ol0000YoookJPGo0000G?oonfX005_ooo]Z1?l0000ZoookJPCo00004OoonfX3o`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000>_oonfX4o`00
02Wooo]Z1Ol0001ioookJPGo0000:OoonfX5o`0005cooo]Z001KoookJPCo0000:_oonfX5o`00013o
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJPKo001o2OoonfX5o`0003[o
oo]Z1?l0000ZoookJPCo0000NOoonfX4o`0002[ooo]Z1Ol0001LoookJP00F_oonfX5o`0002[ooo]Z
1Ol0000@oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX2o`00O`gooo]Z
1Ol0000joookJPCo0000:_oonfX4o`0007Wooo]Z1?l0000[oookJPCo0000G?oonfX005[ooo]Z1Ol0
000ZoookJPGo00004OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP;o001o3OoonfX5o`0003Wooo]Z1Ol0000ZoookJPCo0000NOoonfX4o`0002_o
oo]Z1?l0001LoookJP00F_oonfX5o`0002_ooo]Z1?l0000AoookJPOo001o2?oonfX7o`00O`Cooo]Z
1ol007l7oookJPGo0000>OoonfX5o`0002[ooo]Z1?l0001ioookJPCo0000:ooonfX4o`0005cooo]Z
001JoookJPCo0000;?oonfX4o`0001;ooo]Z1Ol007l:oookJPGo001o1OoonfX7o`00O`Oooo]Z1Ol0
000ioookJPGo0000:_oonfX5o`0007Oooo]Z1Ol0000[oookJPGo0000FooonfX005[ooo]Z1?l0000/
oookJPCo0000>OoonfX5o`0003Wooo]Z1?l0000[oookJPGo0000MooonfX5o`0002_ooo]Z1Ol0001K
oookJP00F_oonfX4o`0002cooo]Z1?l0000ioookJPGo0000>OoonfX4o`0002_ooo]Z1Ol0001goook
JPGo0000:ooonfX5o`0005_ooo]Z001JoookJPCo0000;?oonfX4o`0003Wooo]Z1Ol0000ioookJPCo
0000;?oonfX4o`0007Oooo]Z1?l0000]oookJPCo0000FooonfX005Wooo]Z1Ol0000/oookJPCo0000
>OoonfX5o`0003Sooo]Z1Ol0000/oookJPCo0000MooonfX4o`0002gooo]Z1?l0001KoookJP00FOoo
nfX5o`0002cooo]Z1Ol0000hoookJPGo0000>?oonfX5o`0002cooo]Z1?l0001goookJPCo0000;Ooo
nfX4o`0005_ooo]Z001IoookJPGo0000;?oonfX5o`0003Sooo]Z1Ol0000hoookJPGo0000;?oonfX4
o`0007Oooo]Z1?l0000]oookJPCo0000FooonfX005Wooo]Z1?l0000]oookJPGo0000>?oonfX5o`00
03Sooo]Z1?l0000]oookJPGo0000MOoonfX5o`0002gooo]Z1?l0001KoookJP00FOoonfX4o`0002ko
oo]Z1?l0000hoookJPGo0000>?oonfX4o`0002gooo]Z1Ol0001eoookJPGo0000;OoonfX5o`0005[o
oo]Z001IoookJPCo0000;_oonfX4o`0003Sooo]Z1Ol0000hoookJPCo0000;OoonfX5o`0007Gooo]Z
1Ol0000]oookJPGo0000F_oonfX005Wooo]Z1?l0000^oookJPCo0000>?oonfX5o`0003Sooo]Z1?l0
000^oookJPCo0000MOoonfX4o`0002kooo]Z1Ol0001JoookJP00FOoonfX4o`0002kooo]Z1?l0000h
oookJPGo0000=ooonfX5o`0002kooo]Z1?l0001eoookJPCo0000;ooonfX4o`0005[ooo]Z001Hoook
JPGo0000;_oonfX4o`0003Sooo]Z1Ol0000goookJPGo0000;_oonfX4o`0007Gooo]Z1?l0000_oook
JPCo0000F_oonfX005Sooo]Z1Ol0000^oookJPGo0000=ooonfX5o`0003Oooo]Z1Ol0000^oookJPCo
0000MOoonfX4o`0002oooo]Z1?l0001JoookJP00F?oonfX5o`0002kooo]Z1Ol0000goookJPGo0000
=ooonfX4o`0002oooo]Z1Ol0001coookJPGo0000;ooonfX4o`0005[ooo]Z001HoookJPCo0000;ooo
nfX5o`0003Oooo]Z1Ol0000goookJPCo0000;ooonfX5o`0007?ooo]Z1Ol0000_oookJPCo0000F_oo
nfX005Sooo]Z1?l0000`oookJPCo0000=ooonfX5o`0003Oooo]Z1?l0000_oookJPGo0000LooonfX5
o`0002oooo]Z1?l0001JoookJP00F?oonfX4o`00033ooo]Z1?l0000goookJPGo0000=ooonfX4o`00
033ooo]Z1?l0001coookJPCo0000<?oonfX5o`0005Wooo]Z001HoookJPCo0000<?oonfX4o`0003Oo
oo]Z1Ol0000goookJPCo0000<?oonfX4o`0007?ooo]Z1?l0000`oookJPGo0000FOoonfX005Sooo]Z
1?l0000`oookJPCo0000=ooonfX5o`0003Oooo]Z1?l0000`oookJPCo0000LooonfX4o`00033ooo]Z
1Ol0001IoookJP00EooonfX5o`00033ooo]Z1?l0000goookJPGo0000=_oonfX5o`00033ooo]Z1Ol0
001boookJPCo0000<OoonfX4o`0005Wooo]Z001GoookJPGo0000<?oonfX4o`0003Oooo]Z1Ol0000f
oookJPGo0000<?oonfX5o`00077ooo]Z1Ol0000aoookJPCo0000FOoonfX005Oooo]Z1Ol0000`oook
JPGo0000=_oonfX5o`0003Kooo]Z1Ol0000`oookJPGo0000LOoonfX5o`00037ooo]Z1?l0001Ioook
JP00EooonfX4o`00037ooo]Z1Ol0000foookJPGo0000=_oonfX4o`0003;ooo]Z1?l0001aoookJPGo
0000<OoonfX4o`0005Wooo]Z001GoookJPCo0000<OoonfX5o`0003Kooo]Z1Ol0000foookJPCo0000
<_oonfX4o`00077ooo]Z1?l0000boookJPCo0000FOoonfX005Oooo]Z1?l0000boookJPCo0000=_oo
nfX5o`0003Kooo]Z1?l0000boookJPCo0000LOoonfX4o`0003;ooo]Z1?l0001IoookJP00EooonfX4
o`0003;ooo]Z1?l0000foookJPGo0000=_oonfX4o`0003;ooo]Z1?l0001aoookJPCo0000<_oonfX5
o`0005Sooo]Z001GoookJPCo0000<_oonfX4o`0003Kooo]Z1Ol0000foookJPCo0000<_oonfX5o`00
073ooo]Z1?l0000boookJPGo0000F?oonfX005Oooo]Z1?l0000boookJPCo0000=_oonfX5o`0003Go
oo]Z1Ol0000boookJPGo0000KooonfX5o`0003;ooo]Z1Ol0001HoookJP00E_oonfX5o`0003;ooo]Z
1?l0000foookJPGo0000=OoonfX5o`0003;ooo]Z1Ol0001_oookJPGo0000<ooonfX4o`0005Sooo]Z
001FoookJPGo0000<_oonfX4o`0003Kooo]Z1Ol0000eoookJPGo0000<ooonfX4o`0006oooo]Z1Ol0
000coookJPCo0000F?oonfX005Kooo]Z1Ol0000boookJPGo0000=OoonfX5o`0003Gooo]Z1?l0000d
oookJPCo0000KooonfX4o`0003Cooo]Z1?l0001HoookJP00E_oonfX4o`0003?ooo]Z1Ol0000eoook
JPGo0000=OoonfX4o`0003Cooo]Z1?l0001_oookJPCo0000=?oonfX4o`0005Sooo]Z001FoookJPCo
0000<ooonfX5o`0003Gooo]Z1Ol0000eoookJPCo0000=?oonfX4o`0006oooo]Z1?l0000doookJPCo
0000F?oonfX005Kooo]Z1?l0000doookJPCo0000=OoonfX5o`0003Gooo]Z1?l0000doookJPGo0000
K_oonfX4o`0003Cooo]Z1?l0001HoookJP00E_oonfX4o`0003Cooo]Z1?l0000eoookJPGo0000=Ooo
nfX4o`0003Cooo]Z1Ol0001^oookJPCo0000=?oonfX5o`0005Oooo]Z001FoookJPCo0000=?oonfX4
o`0003Gooo]Z1Ol0000eoookJPCo0000=?oonfX5o`0006kooo]Z1?l0000doookJPGo0000EooonfX0
05Gooo]Z1Ol0000doookJPCo0000=OoonfX5o`0003Cooo]Z1Ol0000eoookJPCo0000KOoonfX5o`00
03Cooo]Z1Ol0001GoookJP00EOoonfX5o`0003Cooo]Z1?l0000eoookJPGo0000=?oonfX5o`0003Go
oo]Z1?l0001]oookJPGo0000=OoonfX4o`0005Oooo]Z001EoookJPGo0000=?oonfX4o`0003Gooo]Z
1Ol0000doookJPGo0000=OoonfX4o`0006gooo]Z1Ol0000eoookJPCo0000EooonfX005Gooo]Z1?l0
000eoookJPGo0000=?oonfX5o`0003Cooo]Z1?l0000foookJPCo0000KOoonfX4o`0003Kooo]Z1?l0
001GoookJP00EOoonfX4o`0003Gooo]Z1Ol0000doookJPGo0000=?oonfX4o`0003Kooo]Z1?l0001]
oookJPCo0000=_oonfX4o`0005Oooo]Z001EoookJPCo0000=OoonfX5o`0003Cooo]Z1Ol0000doook
JPCo0000=_oonfX4o`0006gooo]Z1?l0000foookJPCo0000EooonfX005Gooo]Z1?l0000foookJPCo
0000=?oonfX5o`0003Cooo]Z1?l0000foookJPGo0000K?oonfX4o`0003Kooo]Z1?l0001GoookJP00
EOoonfX4o`0003Kooo]Z1?l0000doookJPGo0000=?oonfX4o`0003Kooo]Z1Ol0001/oookJPCo0000
=_oonfX5o`0005Kooo]Z001EoookJPCo0000=_oonfX4o`0003Cooo]Z1Ol0000doookJPCo0000=_oo
nfX5o`0006cooo]Z1?l0000foookJPGo0000E_oonfX005Cooo]Z1Ol0000foookJPCo0000=?oonfX5
o`0003?ooo]Z1Ol0000goookJPCo0000K?oonfX4o`0003Kooo]Z1Ol0001FoookJP00E?oonfX5o`00
03Kooo]Z1?l0000doookJPGo0000<ooonfX5o`0003Oooo]Z1?l0001/oookJPCo0000=ooonfX4o`00
05Kooo]Z001DoookJPGo0000=_oonfX4o`0003Cooo]Z1Ol0000coookJPGo0000=ooonfX4o`0006_o
oo]Z1Ol0000goookJPCo0000E_oonfX005Cooo]Z1?l0000goookJPCo0000=?oonfX5o`0003?ooo]Z
1?l0000hoookJPCo0000JooonfX5o`0003Oooo]Z1?l0001FoookJP00E?oonfX4o`0003Oooo]Z1Ol0
000coookJPGo0000<ooonfX4o`0003Sooo]Z1?l0001[oookJPGo0000=ooonfX4o`0005Kooo]Z001D
oookJPCo0000=ooonfX5o`0001Kooo]Z1Ol007l4oookJP?o001o1OoonfX3o`00O`Wooo]Z1Ol0000c
oookJPCo0000>?oonfX4o`0006_ooo]Z1?l0000hoookJPCo0000E_oonfX005Cooo]Z1?l0000goook
JPGo00005OoonfX7o`00O`?ooo]Z0ol007l5oookJP?o001o2OoonfX5o`0003?ooo]Z1?l0000hoook
JPCo0000JooonfX4o`0003Sooo]Z1?l0001FoookJP00E?oonfX4o`0003Sooo]Z1?l0000EoookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol007l9oookJPGo0000<ooonfX4o`00
03Sooo]Z1?l0001[oookJPCo0000>?oonfX4o`0005Kooo]Z001CoookJPGo0000>?oonfX4o`0001Co
oo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Wooo]Z1Ol0000coookJPCo0000>?oonfX5o`0006[o
oo]Z1?l0000hoookJPGo0000EOoonfX005?ooo]Z1Ol0000hoookJPCo00005?oonfX3o`00O`?ooo]Z
0ol007l:oookJP?o001o2OoonfX7o`00033ooo]Z1Ol0000hoookJPGo0000J_oonfX4o`0003Sooo]Z
1Ol0001EoookJP00DooonfX5o`0003Sooo]Z1?l0000DoookJP?o001o0ooonfX3o`00O`[ooo]Z0ol0
07l9oookJPGo0000<_oonfX5o`0003Sooo]Z1Ol0001ZoookJPCo0000>?oonfX5o`0005Gooo]Z001C
oookJPCo0000>OoonfX4o`0001Cooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Wooo]Z1Ol0000b
oookJPGo0000>OoonfX4o`0006[ooo]Z1?l0000ioookJPCo0000EOoonfX005?ooo]Z1?l0000ioook
JPCo00005?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2OoonfX5o`0003;ooo]Z1?l0000joook
JPCo0000JOoonfX5o`0003Wooo]Z1?l0001EoookJP00DooonfX4o`0003Wooo]Z1?l0000DoookJP?o
001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJPGo0000<_oonfX4o`0003[ooo]Z1?l0001YoookJPGo
0000>OoonfX4o`0005Gooo]Z001CoookJPCo0000>OoonfX5o`0001?ooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00O`Wooo]Z1Ol0000boookJPCo0000>_oonfX4o`0006Wooo]Z1Ol0000ioookJPCo0000
EOoonfX005?ooo]Z1?l0000ioookJPGo00005?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
1_l007l9oookJPGo0000<_oonfX4o`0003[ooo]Z1?l0001YoookJPCo0000>_oonfX4o`0005Gooo]Z
001CoookJPCo0000>OoonfX5o`0001Cooo]Z1ol007l:oookJPCo001o2OoonfX5o`0003;ooo]Z1?l0
000joookJPCo0000JOoonfX4o`0003[ooo]Z1?l0001EoookJP00D_oonfX5o`0003[ooo]Z1?l0000E
oookJPGo001o3?oonfX3o`00O`Wooo]Z1Ol0000boookJPCo0000>_oonfX4o`0006Wooo]Z1?l0000j
oookJPCo0000EOoonfX005;ooo]Z1Ol0000joookJPCo0000<_oonfX5o`0003;ooo]Z1?l0000joook
JPCo0000JOoonfX4o`0003[ooo]Z1Ol0001DoookJP00D_oonfX5o`0003[ooo]Z1?l0000boookJPGo
0000<OoonfX5o`0003[ooo]Z1Ol0001XoookJPCo0000>_oonfX5o`0005Cooo]Z001BoookJPCo0000
>ooonfX4o`0003;ooo]Z1Ol0000aoookJPGo0000>_oonfX5o`0006Sooo]Z1?l0000joookJPGo0000
E?oonfX005;ooo]Z1?l0000koookJPCo0000<_oonfX5o`00037ooo]Z1Ol0000joookJPGo0000J?oo
nfX4o`0003_ooo]Z1?l0001DoookJP007?oonfX5o`00037ooo]Z1?l0000koookJPCo0000<_oonfX5
o`00037ooo]Z1?l0000loookJPCo0000<OoonfX5o`00037ooo]Z1Ol0000koookJPCo0000<_oonfX4
o`0001kooo]Z000LoookJPGo0000<OoonfX4o`0003_ooo]Z1?l0000aoookJPOo0000<?oonfX4o`00
03cooo]Z1?l0000`oookJPOo0000<?oonfX5o`0003_ooo]Z1?l0000boookJPCo00007_oonfX001co
oo]Z1_l0000`oookJPCo0000>ooonfX5o`0002oooo]Z2?l0000`oookJPCo0000??oonfX4o`00033o
oo]Z2?l0000_oookJPGo0000>ooonfX4o`0003;ooo]Z1?l0000NoookJP007?oonfX7o`0002oooo]Z
1?l0000koookJPGo0000;ooonfX9o`0002oooo]Z1?l0000loookJPCo0000;ooonfX9o`0002oooo]Z
1?l0000loookJPCo0000<_oonfX4o`0001kooo]Z000MoookJPKo0000;ooonfX4o`0003_ooo]Z1Ol0
000_oookJPWo0000;ooonfX4o`0003cooo]Z1?l0000_oookJPWo0000;ooonfX4o`0003cooo]Z1?l0
000aoookJPGo00007_oonfX001kooo]Z1_l0000]oookJPGo0000??oonfX4o`0002kooo]Z2_l0000_
oookJPCo0000??oonfX4o`0002kooo]Z2ol0000^oookJPCo0000??oonfX4o`00037ooo]Z1Ol0000N
oookJP007ooonfX5o`0002gooo]Z1Ol0000loookJPCo0000;_oonfX;o`0002kooo]Z1?l0000loook
JPCo0000;_oonfX5o`000003oookJ_l0003o000000?o0000;_oonfX4o`0003cooo]Z1?l0000aoook
JPGo00007_oonfX001oooo]Z1Ol0000]oookJPGo0000??oonfX4o`0002gooo]Z3?l0000]oookJPGo
0000??oonfX4o`0002gooo]Z1_l000000ooonf[o0000o`000003o`0002kooo]Z1?l0000loookJPGo
0000<?oonfX4o`0001oooo]Z000PoookJPCo0000;OoonfX4o`0003gooo]Z1?l0000]oookJPco0000
;OoonfX5o`0003cooo]Z1Ol0000/oookJPGo00000ooonfX5o`0002gooo]Z1?l0000loookJPGo0000
<?oonfX4o`0001oooo]Z000PoookJPGo0000;?oonfX4o`0003gooo]Z1?l0000]oookJPgo0000;?oo
nfX5o`0003cooo]Z1Ol0000/oookJPGo00000ooonfX5o`0002gooo]Z1?l0000loookJPGo0000<?oo
nfX4o`0001oooo]Z000PoookJPGo0000;?oonfX4o`0003gooo]Z1?l0000/oookJPko0000;?oonfX4
o`0003gooo]Z1Ol0000/oookJPCo00001?oonfX5o`0002gooo]Z1?l0000moookJPCo0000;ooonfX5
o`0001oooo]Z000PoookJPGo0000;?oonfX4o`0003gooo]Z1?l0000/oookJPko0000;?oonfX4o`00
03kooo]Z1?l0000[oookJPGo00001OoonfX5o`0002_ooo]Z1Ol0000moookJPCo0000;ooonfX5o`00
01oooo]Z000QoookJPCo0000;?oonfX4o`0003gooo]Z1Ol0000[oookJPoo0000:ooonfX4o`0003ko
oo]Z1?l0000[oookJPGo00001OoonfX5o`0002_ooo]Z1Ol0000moookJPCo0000;ooonfX5o`0001oo
oo]Z000QoookJPGo0000:ooonfX4o`0003gooo]Z1Ol0000[oookJPCo000000?ooo]Zo`000?l00000
2?l0000[oookJPCo0000?_oonfX4o`0002_ooo]Z1Ol00005oookJPGo0000:ooonfX5o`0003gooo]Z
1?l0000_oookJPCo00008?oonfX0027ooo]Z1Ol0000[oookJPCo0000?OoonfX5o`0002_ooo]Z1?l0
00000ooonf[o0000o`000008o`0002_ooo]Z1?l0000noookJPCo0000:ooonfX4o`0000Oooo]Z1?l0
000[oookJPCo0000?_oonfX4o`0002oooo]Z1?l0000PoookJP008OoonfX5o`0002_ooo]Z1?l0000n
oookJPCo0000:ooonfX4o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000000_l0000[
oookJPCo0000?_oonfX4o`0002_ooo]Z1?l00007oookJPCo0000:ooonfX4o`0003kooo]Z1?l0000_
oookJPCo00008?oonfX002;ooo]Z1?l0000ZoookJPGo0000?_oonfX4o`0002[ooo]Z1Ol000000ooo
nf[o0000o`000003o`000003oookJ_l0003o000000?o0000:OoonfX5o`0003kooo]Z1?l0000[oook
JPCo00001ooonfX5o`0002[ooo]Z1?l0000noookJPCo0000;_oonfX5o`00023ooo]Z000RoookJPCo
0000:_oonfX5o`0003kooo]Z1?l0000ZoookJPGo000000?ooo]Zo`000?l000000ol000000ooonf[o
0000o`000003o`0002Wooo]Z1Ol0000noookJPCo0000:ooonfX4o`0000Oooo]Z1Ol0000ZoookJPCo
0000?_oonfX5o`0002gooo]Z1Ol0000PoookJP008_oonfX5o`0002Wooo]Z1Ol0000noookJPCo0000
:_oonfX5o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000000ol0000YoookJPGo0000
?_oonfX4o`0002[ooo]Z1Ol00007oookJPGo0000:_oonfX4o`0003kooo]Z1Ol0000]oookJPGo0000
8?oonfX002;ooo]Z1Ol0000YoookJPCo0000?ooonfX4o`0002[ooo]Z1?l00002oookJPGo00000_oo
nfX4o`0002Wooo]Z1?l0000ooookJPGo0000:OoonfX5o`0000Sooo]Z1?l0000ZoookJPCo0000?_oo
nfX5o`0002gooo]Z1?l0000QoookJP008_oonfX5o`0002Wooo]Z1?l0000ooookJPCo0000:_oonfX4
o`0000;ooo]Z1Ol00002oookJPCo0000:OoonfX4o`0003oooo]Z1Ol0000YoookJPGo00002?oonfX4
o`0002[ooo]Z1?l0000ooookJPCo0000;OoonfX4o`00027ooo]Z000SoookJPCo0000:OoonfX4o`00
03oooo]Z1?l0000ZoookJPCo00000_oonfX5o`0000;ooo]Z1?l0000YoookJPCo0000?ooonfX5o`00
02Wooo]Z1?l00009oookJPCo0000:_oonfX4o`0003oooo]Z1?l0000]oookJPCo00008OoonfX002?o
oo]Z1?l0000YoookJPCo0000?ooonfX5o`0002Sooo]Z1Ol00002oookJPGo00000_oonfX4o`0002Wo
oo]Z1?l00010oookJPCo0000:OoonfX4o`0000Wooo]Z1?l0000YoookJPGo0000?ooonfX4o`0002co
oo]Z1Ol0000QoookJP008ooonfX5o`0002Sooo]Z1?l0000ooookJPGo0000:?oonfX5o`0000;ooo]Z
1Ol00002oookJPCo0000:OoonfX4o`00043ooo]Z1?l0000YoookJPCo00002OoonfX5o`0002Sooo]Z
1Ol0000ooookJPCo0000;?oonfX5o`00027ooo]Z000SoookJPGo0000:?oonfX4o`0003oooo]Z1Ol0
000XoookJPGo00000_oonfX5o`0000;ooo]Z1Ol0000XoookJPCo0000@?oonfX4o`0002Sooo]Z1Ol0
0009oookJPGo0000:?oonfX5o`0003oooo]Z1?l0000/oookJPGo00008OoonfX002?ooo]Z1Ol0000X
oookJPCo0000@?oonfX4o`0002Sooo]Z1?l00003oookJPGo00000_oonfX5o`0002Sooo]Z1?l00010
oookJPCo0000:?oonfX5o`0000Wooo]Z1Ol0000XoookJPCo0000@?oonfX4o`0002cooo]Z1?l0000R
oookJP009?oonfX4o`0002Sooo]Z1?l00010oookJPCo0000:?oonfX4o`0000?ooo]Z1Ol00002oook
JPGo00009ooonfX5o`00043ooo]Z1?l0000XoookJPGo00002_oonfX4o`0002Sooo]Z1?l00010oook
JPCo0000;?oonfX4o`0002;ooo]Z000ToookJPCo00009ooonfX5o`00043ooo]Z1?l0000WoookJPGo
00000ooonfX5o`0000?ooo]Z1?l0000WoookJPGo0000@?oonfX4o`0002Sooo]Z1?l0000;oookJPCo
0000:?oonfX4o`00043ooo]Z1Ol0000[oookJPCo00008_oonfX002Cooo]Z1?l0000WoookJPGo0000
@?oonfX4o`0002Oooo]Z1Ol00003oookJPGo00000ooonfX4o`0002Oooo]Z1Ol00010oookJPCo0000
:?oonfX4o`0000_ooo]Z1?l0000XoookJPCo0000@?oonfX5o`0002_ooo]Z1?l0000RoookJP009?oo
nfX4o`0002Oooo]Z1Ol00010oookJPCo00009ooonfX5o`0000?ooo]Z1Ol00003oookJPCo00009ooo
nfX4o`00047ooo]Z1?l0000WoookJPGo00002ooonfX4o`0002Sooo]Z1?l00010oookJPGo0000:_oo
nfX5o`0002;ooo]Z000ToookJPGo00009_oonfX4o`00047ooo]Z1?l0000WoookJPCo00001?oonfX5
o`0000?ooo]Z1?l0000WoookJPCo0000@OoonfX5o`0002Kooo]Z1Ol0000;oookJPGo00009ooonfX4
o`00047ooo]Z1?l0000ZoookJPGo00008_oonfX002Cooo]Z1Ol0000VoookJPCo0000@OoonfX4o`00
02Oooo]Z1?l00004oookJPGo00000ooonfX4o`0002Oooo]Z1?l00011oookJPGo00009_oonfX5o`00
00_ooo]Z1Ol0000WoookJPCo0000@OoonfX4o`0002[ooo]Z1Ol0000RoookJP009?oonfX5o`0002Ko
oo]Z1?l00011oookJPCo00009ooonfX4o`0000Cooo]Z1Ol00003oookJPGo00009_oonfX4o`00047o
oo]Z1Ol0000VoookJPCo00003?oonfX5o`0002Oooo]Z1?l00011oookJPCo0000:_oonfX4o`0002?o
oo]Z000UoookJPCo00009_oonfX4o`00047ooo]Z1Ol0000VoookJPCo00001?oonfX5o`0000?ooo]Z
1Ol0000VoookJPCo0000@_oonfX4o`0002Kooo]Z1?l0000=oookJPCo00009ooonfX4o`00047ooo]Z
1?l0000ZoookJPCo00008ooonfX002Gooo]Z1?l0000VoookJPCo0000@OoonfX5o`0002Gooo]Z1Ol0
0004oookJPGo00000ooonfX5o`0002Kooo]Z1?l00012oookJPCo00009_oonfX4o`0000gooo]Z1?l0
000VoookJPGo0000@OoonfX4o`0002[ooo]Z1?l0000SoookJP009OoonfX4o`0002Kooo]Z1?l00011
oookJPGo00009OoonfX5o`0000Cooo]Z1Ol00004oookJPCo00009_oonfX4o`0004;ooo]Z1?l0000V
oookJPCo00003OoonfX4o`0002Kooo]Z1Ol00011oookJPCo0000:OoonfX5o`0002?ooo]Z000Uoook
JPCo00009_oonfX4o`0004;ooo]Z1?l0000UoookJPGo00001?oonfX5o`0000Cooo]Z1?l0000Uoook
JPGo0000@_oonfX4o`0002Gooo]Z1Ol0000=oookJPGo00009OoonfX5o`00047ooo]Z1?l0000Yoook
JPGo00008ooonfX002Gooo]Z1?l0000VoookJPCo0000@_oonfX4o`0002Gooo]Z1?l00005oookJPGo
00001?oonfX4o`0002Gooo]Z1Ol00012oookJPCo00009OoonfX5o`0000gooo]Z1Ol0000UoookJPCo
0000@_oonfX4o`0002Wooo]Z1Ol0000SoookJP009OoonfX4o`0002Gooo]Z1Ol00012oookJPCo0000
9OoonfX4o`0000Gooo]Z1Ol00004oookJPCo00009OoonfX5o`0004;ooo]Z1?l0000UoookJPGo0000
3OoonfX5o`0002Gooo]Z1?l00012oookJPGo0000:?oonfX4o`0002Cooo]Z000UoookJPGo00009?oo
nfX5o`0004;ooo]Z1?l0000UoookJPCo00001OoonfX5o`0000Cooo]Z1?l0000UoookJPCo0000@ooo
nfX4o`0002Gooo]Z1?l0000?oookJPCo00009OoonfX4o`0004;ooo]Z1Ol0000XoookJPCo00009?oo
nfX002Gooo]Z1Ol0000ToookJPGo0000@_oonfX4o`0002Gooo]Z1?l00005oookJPGo00001?oonfX5
o`0002Cooo]Z1?l00013oookJPCo00009OoonfX4o`0000oooo]Z1?l0000UoookJPCo0000@_oonfX5
o`0002Sooo]Z1?l0000ToookJP009OoonfX5o`0002Cooo]Z1?l00013oookJPCo00009OoonfX4o`00
00Gooo]Z1Ol00004oookJPGo00009?oonfX4o`0004?ooo]Z1Ol0000ToookJPCo00003ooonfX4o`00
02Gooo]Z1?l00013oookJPCo00009ooonfX5o`0002Cooo]Z000VoookJPCo00009?oonfX4o`0004?o
oo]Z1?l0000UoookJPCo00001OoonfX5o`0000Cooo]Z1Ol0000ToookJPCo0000@ooonfX5o`0002Co
oo]Z1?l0000?oookJPCo00009OoonfX4o`0004?ooo]Z1?l0000WoookJPGo00009?oonfX002Kooo]Z
1?l0000ToookJPCo0000@ooonfX4o`0002Cooo]Z1Ol00005oookJPGo00001OoonfX4o`0002Cooo]Z
1?l00013oookJPGo00009?oonfX4o`0000oooo]Z1Ol0000ToookJPCo0000@ooonfX4o`0002Oooo]Z
1Ol0000ToookJP009_oonfX4o`0002Cooo]Z1?l00013oookJPGo00008ooonfX5o`0000Gooo]Z1Ol0
0005oookJPCo00009?oonfX4o`0004Cooo]Z1?l0000SoookJPGo00003ooonfX5o`0002Cooo]Z1?l0
0013oookJPCo00009ooonfX4o`0002Gooo]Z000VoookJPCo00009?oonfX4o`0004?ooo]Z1Ol00006
oookJPGo001o1?oonfX3o`00O`Gooo]Z0ol007l5oookJPCo001o1Ol00005oookJPGo00001OoonfX4
o`0002Cooo]Z1?l00014oookJPCo00008ooonfX5o`0000oooo]Z1Ol0000ToookJPCo0000@ooonfX4
o`0002Oooo]Z1?l0000UoookJP009_oonfX4o`0002Cooo]Z1?l00013oookJPGo00001OoonfX7o`00
O`?ooo]Z0ol007l5oookJP?o001o1?oonfX5o`00O`Co00001_oonfX5o`0000Gooo]Z1?l0000Soook
JPGo0000A?oonfX4o`0002?ooo]Z1Ol0000@oookJPCo00008ooonfX5o`0004?ooo]Z1?l0000Woook
JPCo00009OoonfX002Kooo]Z1?l0000ToookJPCo0000A?oonfX4o`0000Gooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o1OoonfX3o`00O`?ooo]Z1?l007l00ooonf[o001oo`000003o`00
00Kooo]Z1Ol00005oookJPCo00008ooonfX5o`0004Cooo]Z1?l0000SoookJPCo00004OoonfX4o`00
02?ooo]Z1Ol00013oookJPCo00009_oonfX5o`0002Gooo]Z000VoookJPGo00008ooonfX4o`0004Co
oo]Z1?l00004oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l3oookJP?o001o0ooonfX4o`0000Ko
oo]Z1Ol00005oookJPGo00008_oonfX5o`0004Cooo]Z1?l0000SoookJPCo00004OoonfX4o`0002?o
oo]Z1Ol00013oookJPGo00009OoonfX5o`0002Gooo]Z000VoookJPGo00008_oonfX5o`0004Cooo]Z
1?l00004oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJPCo00001_oonfX7o`0000?ooo]Z
1Ol0000RoookJPCo0000AOoonfX4o`0002?ooo]Z1?l0000AoookJPCo00008ooonfX4o`0004Cooo]Z
1Ol0000UoookJPGo00009OoonfX002Kooo]Z1Ol0000RoookJPGo0000A?oonfX4o`0000Cooo]Z0ol0
07l3oookJP?o001o2_oonfX3o`00O`Wooo]Z1?l00006oookJPGo00001OoonfX5o`0002;ooo]Z1?l0
0015oookJPCo00008ooonfX4o`00017ooo]Z1Ol0000RoookJPCo0000A?oonfX5o`0002Gooo]Z1?l0
000VoookJP009ooonfX4o`0002;ooo]Z1Ol00014oookJPCo00001?oonfX3o`00O`?ooo]Z0ol007l:
oookJP?o001o1?oonfX2o`00O`;ooo]Z00?o001oo`000?l000000_l00006oookJPGo00001_oonfX4
o`0002;ooo]Z1?l00015oookJPCo00008ooonfX4o`00017ooo]Z1Ol0000RoookJPCo0000AOoonfX4
o`0002Gooo]Z1?l0000VoookJP009ooonfX4o`0002;ooo]Z1?l00015oookJPCo00001?oonfX3o`00
O`?ooo]Z0ol007l:oookJP?o001o1?oonfX4o`00O`Go00001_oonfX5o`0000Kooo]Z1?l0000Roook
JPCo0000AOoonfX5o`00027ooo]Z1Ol0000AoookJPGo00008_oonfX4o`0004Gooo]Z1?l0000Uoook
JPCo00009_oonfX002Oooo]Z1?l0000RoookJPCo0000AOoonfX4o`0000Cooo]Z0ol007l3oookJP?o
001o2_oonfX3o`00O`Cooo]Z1?l007l5o`0000Kooo]Z1Ol00006oookJPCo00008_oonfX4o`0004Go
oo]Z1Ol0000QoookJPGo00004_oonfX4o`0002;ooo]Z1?l00015oookJPCo00009?oonfX5o`0002Ko
oo]Z000WoookJPCo00008_oonfX4o`0004Gooo]Z1Ol00003oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l4oookJP;o001o0_oonfX5o`0000Kooo]Z1Ol00006oookJPCo00008_oonfX4o`0004Gooo]Z
1Ol0000QoookJPGo00004_oonfX4o`0002;ooo]Z1?l00015oookJPCo00009?oonfX5o`0002Kooo]Z
000WoookJPCo00008_oonfX4o`0004Gooo]Z1Ol00004oookJP?o001o00Cooo]Zo`00Ool007oo001o
2?oonfX6o`00O`Cooo]Z0_l007l2oookJPCo00001ooonfX5o`0000Kooo]Z1?l0000RoookJPCo0000
A_oonfX4o`00027ooo]Z1?l0000CoookJPCo00008_oonfX4o`0004Gooo]Z1?l0000ToookJPGo0000
9_oonfX002Oooo]Z1?l0000RoookJPCo0000AOoonfX5o`0000Cooo]Z1ol007l:oookJPCo001o1Ooo
nfX3o`00O`Co00001ooonfX5o`0000Kooo]Z1Ol0000QoookJPCo0000A_oonfX4o`00027ooo]Z1?l0
000CoookJPCo00008_oonfX4o`0004Gooo]Z1?l0000ToookJPCo00009ooonfX002Oooo]Z1Ol0000Q
oookJPCo0000A_oonfX4o`0000Gooo]Z1Ol007l<oookJP?o001o1OoonfX3o`00O`Co00001ooonfX5
o`0000Kooo]Z1Ol0000PoookJPGo0000A_oonfX4o`00027ooo]Z1?l0000CoookJPCo00008_oonfX4
o`0004Gooo]Z1?l0000ToookJPCo00009ooonfX002Oooo]Z1Ol0000QoookJPCo0000A_oonfX4o`00
027ooo]Z1?l00007oookJPGo00001_oonfX5o`00023ooo]Z1Ol00016oookJPCo00008OoonfX4o`00
01?ooo]Z1Ol0000PoookJPGo0000AOoonfX5o`0002?ooo]Z1?l0000WoookJP009ooonfX5o`00027o
oo]Z1?l00016oookJPCo00008OoonfX4o`0000Oooo]Z1Ol00007oookJPCo00008?oonfX5o`0004Ko
oo]Z1?l0000QoookJPCo00004ooonfX5o`00023ooo]Z1Ol00015oookJPGo00008_oonfX5o`0002Oo
oo]Z000XoookJPCo00008?oonfX5o`0004Kooo]Z1?l0000PoookJPGo00001ooonfX5o`0000Oooo]Z
1?l0000PoookJPCo0000AooonfX4o`00027ooo]Z1?l0000CoookJPGo00008?oonfX5o`0004Gooo]Z
1Ol0000RoookJPGo00009ooonfX002Sooo]Z1?l0000PoookJPGo0000A_oonfX4o`00023ooo]Z1Ol0
0007oookJPGo00001ooonfX4o`00023ooo]Z1?l00017oookJPCo00008?oonfX5o`0001Cooo]Z1?l0
000PoookJPCo0000AooonfX4o`0002;ooo]Z1Ol0000WoookJP00:?oonfX4o`00023ooo]Z1Ol00016
oookJPCo00008?oonfX5o`0000Oooo]Z1Ol00007oookJPCo00008?oonfX4o`0004Oooo]Z1Ol0000O
oookJPGo00005?oonfX4o`00023ooo]Z1?l00017oookJPCo00008_oonfX4o`0002Sooo]Z000Xoook
JPCo00008?oonfX4o`0004Oooo]Z1?l0000PoookJPCo00002?oonfX5o`0000Oooo]Z1?l0000Poook
JPCo0000AooonfX5o`0001oooo]Z1Ol0000DoookJPCo00008?oonfX4o`0004Oooo]Z1?l0000Roook
JPCo0000:?oonfX002Sooo]Z1?l0000PoookJPCo0000AooonfX4o`00023ooo]Z1?l00008oookJPGo
00001ooonfX5o`0001oooo]Z1?l00017oookJPGo00007ooonfX4o`0001Gooo]Z1?l0000PoookJPCo
0000AooonfX4o`0002;ooo]Z1?l0000XoookJP00:?oonfX5o`0001oooo]Z1?l00017oookJPGo0000
7ooonfX4o`0000Sooo]Z1Ol00007oookJPGo00007ooonfX4o`0004Sooo]Z1?l0000OoookJPCo0000
5OoonfX4o`00023ooo]Z1?l00017oookJPCo00008OoonfX5o`0002Sooo]Z000XoookJPGo00007ooo
nfX4o`0004Oooo]Z1Ol0000OoookJPCo00002?oonfX5o`0000Oooo]Z1Ol0000OoookJPCo0000B?oo
nfX4o`0001oooo]Z1?l0000EoookJPCo00008?oonfX4o`0004Oooo]Z1?l0000QoookJPGo0000:?oo
nfX002Sooo]Z1Ol0000OoookJPCo0000AooonfX5o`0001oooo]Z1?l00008oookJPGo00002?oonfX4
o`0001kooo]Z1Ol00018oookJPCo00007ooonfX4o`0001Gooo]Z1Ol0000OoookJPCo0000AooonfX4
o`00027ooo]Z1Ol0000XoookJP00:OoonfX4o`0001oooo]Z1?l00018oookJPCo00007ooonfX4o`00
00Sooo]Z1Ol00008oookJPCo00007_oonfX5o`0004Sooo]Z1?l0000OoookJPCo00005OoonfX5o`00
01oooo]Z1?l00017oookJPGo00008?oonfX4o`0002Wooo]Z000YoookJPCo00007ooonfX4o`0004So
oo]Z1?l0000NoookJPGo00002?oonfX5o`0000Sooo]Z1?l0000NoookJPGo0000B?oonfX4o`0001ko
oo]Z1Ol0000EoookJPGo00007ooonfX4o`0004Oooo]Z1Ol0000PoookJPCo0000:OoonfX002Wooo]Z
1?l0000OoookJPCo0000B?oonfX4o`0001kooo]Z1Ol00008oookJPGo00002?oonfX4o`0001kooo]Z
1?l00019oookJPCo00007_oonfX5o`0001Kooo]Z1?l0000NoookJPGo0000AooonfX5o`00023ooo]Z
1?l0000YoookJP00:OoonfX4o`0001kooo]Z1Ol00018oookJPCo00007_oonfX5o`0000Sooo]Z1Ol0
0008oookJPCo00007_oonfX4o`0004Wooo]Z1?l0000NoookJPGo00005_oonfX4o`0001kooo]Z1Ol0
0018oookJPCo00007ooonfX5o`0002Wooo]Z000YoookJPCo00007_oonfX5o`0004Sooo]Z1?l0000N
oookJPCo00002OoonfX5o`0000Sooo]Z1Ol0000MoookJPCo0000BOoonfX4o`0001kooo]Z1?l0000G
oookJPCo00007_oonfX5o`0004Sooo]Z1?l0000OoookJPGo0000:OoonfX002Wooo]Z1Ol0000Moook
JPGo0000B?oonfX4o`0001kooo]Z1?l00009oookJPGo00002?oonfX5o`0001gooo]Z1?l00019oook
JPGo00007OoonfX4o`0001Oooo]Z1?l0000NoookJPCo0000BOoonfX4o`0001oooo]Z1Ol0000Yoook
JP00:OoonfX5o`0001gooo]Z1?l00019oookJPCo00007_oonfX4o`0000Wooo]Z1Ol00008oookJPGo
00007OoonfX4o`0004Wooo]Z1Ol0000MoookJPCo00005ooonfX4o`0001kooo]Z1?l00019oookJPCo
00007ooonfX4o`0002[ooo]Z000YoookJPGo00007OoonfX4o`0004Wooo]Z1?l0000NoookJPCo0000
2OoonfX5o`0000Wooo]Z1?l0000MoookJPCo0000BOoonfX5o`0001gooo]Z1?l0000GoookJPCo0000
7_oonfX4o`0004Wooo]Z1?l0000OoookJPCo0000:_oonfX002[ooo]Z1?l0000MoookJPCo0000BOoo
nfX5o`0001gooo]Z1?l00009oookJPGo00002OoonfX4o`0001gooo]Z1?l0001:oookJPCo00007Ooo
nfX4o`0001Oooo]Z1Ol0000MoookJPCo0000BOoonfX4o`0001oooo]Z1?l0000ZoookJP00:_oonfX4
o`0001gooo]Z1?l00019oookJPGo00007OoonfX4o`0000Wooo]Z1Ol00009oookJPCo00007OoonfX4
o`0004[ooo]Z1?l0000LoookJPGo00005ooonfX5o`0001gooo]Z1?l00019oookJPCo00007_oonfX5
o`0002[ooo]Z000ZoookJPCo00007OoonfX4o`0004Wooo]Z1Ol0000LoookJPGo00002OoonfX5o`00
00Wooo]Z1?l0000LoookJPGo0000B_oonfX4o`0001cooo]Z1Ol0000GoookJPGo00007OoonfX4o`00
04Wooo]Z1?l0000NoookJPGo0000:_oonfX002[ooo]Z1?l0000MoookJPCo0000B_oonfX4o`0001co
oo]Z1Ol00009oookJPGo00002OoonfX4o`0001cooo]Z1Ol0001:oookJPCo00007?oonfX5o`0001So
oo]Z1?l0000MoookJPCo0000BOoonfX5o`0001gooo]Z1Ol0000ZoookJP00:_oonfX4o`0001gooo]Z
1?l0001:oookJPCo00007?oonfX5o`0000Wooo]Z1Ol00009oookJPGo00006ooonfX5o`0004[ooo]Z
1?l0000LoookJPCo00006OoonfX4o`0001gooo]Z1?l00019oookJPGo00007OoonfX4o`0002_ooo]Z
000ZoookJPCo00007OoonfX4o`0004[ooo]Z1?l0000LoookJPCo00002_oonfX5o`0000Wooo]Z1Ol0
000KoookJPCo0000BooonfX4o`0001cooo]Z1?l0000IoookJPCo00007?oonfX5o`0004Wooo]Z1Ol0
000MoookJPCo0000:ooonfX002[ooo]Z1Ol0000KoookJPGo0000B_oonfX4o`0001cooo]Z1?l0000:
oookJPGo00002OoonfX5o`0001_ooo]Z1?l0001;oookJPCo00007?oonfX4o`0001Wooo]Z1?l0000L
oookJPGo0000B_oonfX4o`0001gooo]Z1?l0000[oookJP00:_oonfX5o`0001_ooo]Z1Ol0001:oook
JPCo00007?oonfX4o`0000[ooo]Z1Ol0000:oookJPCo00006ooonfX4o`0004_ooo]Z1?l0000Loook
JPCo00006OoonfX4o`0001cooo]Z1Ol0001:oookJPCo00007OoonfX4o`0002_ooo]Z000ZoookJPGo
00006ooonfX5o`0004[ooo]Z1?l0000LoookJPCo00002_oonfX5o`0000[ooo]Z1?l0000KoookJPCo
0000BooonfX5o`0001_ooo]Z1?l0000IoookJPCo00007?oonfX4o`0004_ooo]Z1?l0000LoookJPGo
0000:ooonfX002_ooo]Z1?l0000KoookJPCo0000BooonfX5o`0001_ooo]Z1?l0000:oookJPGo0000
2_oonfX4o`0001_ooo]Z1?l0001;oookJPGo00006ooonfX4o`0001Wooo]Z1Ol0000KoookJPCo0000
BooonfX4o`0001cooo]Z1Ol0000[oookJP00:ooonfX4o`0001_ooo]Z1?l0001;oookJPGo00006_oo
nfX5o`0000[ooo]Z1Ol0000:oookJPCo00006ooonfX4o`0004_ooo]Z1Ol0000JoookJPGo00006Ooo
nfX5o`0001_ooo]Z1?l0001;oookJPCo00007?oonfX5o`0002_ooo]Z000[oookJPCo00006ooonfX4
o`0004_ooo]Z1Ol0000JoookJPGo00002_oonfX5o`0000[ooo]Z1?l0000KoookJPCo0000C?oonfX4
o`0001[ooo]Z1Ol0000IoookJPGo00006ooonfX4o`0004_ooo]Z1?l0000LoookJPCo0000;?oonfX0
02_ooo]Z1?l0000KoookJPCo0000C?oonfX4o`0001[ooo]Z1Ol0000:oookJPGo00002_oonfX4o`00
01[ooo]Z1Ol0001<oookJPCo00006_oonfX5o`0001[ooo]Z1?l0000KoookJPCo0000BooonfX4o`00
01cooo]Z1?l0000/oookJP00:ooonfX4o`0001_ooo]Z1?l0001<oookJPCo00006_oonfX4o`0000_o
oo]Z1Ol0000:oookJPGo00006OoonfX5o`0004cooo]Z1?l0000JoookJPCo00006ooonfX4o`0001_o
oo]Z1?l0001;oookJPGo00006ooonfX4o`0002cooo]Z000[oookJPGo00006_oonfX4o`0004cooo]Z
1?l0000JoookJPCo00002ooonfX5o`0000[ooo]Z1Ol0000IoookJPGo0000C?oonfX4o`0001[ooo]Z
1?l0000KoookJPCo00006_oonfX5o`0004_ooo]Z1Ol0000JoookJPGo0000;?oonfX002_ooo]Z1Ol0
000JoookJPCo0000C?oonfX4o`0001[ooo]Z1?l0000;oookJPGo00002_oonfX5o`0001Wooo]Z1?l0
001=oookJPCo00006_oonfX4o`0001_ooo]Z1?l0000JoookJPGo0000BooonfX5o`0001[ooo]Z1Ol0
000/oookJP00:ooonfX5o`0001[ooo]Z1?l0001<oookJPCo00006_oonfX4o`0000_ooo]Z1Ol0000;
oookJPCo00006OoonfX4o`0004gooo]Z1?l0000JoookJPCo00006ooonfX4o`0001[ooo]Z1Ol0001<
oookJPCo00006_oonfX5o`0002cooo]Z000/oookJPCo00006OoonfX5o`0004cooo]Z1?l0000Joook
JPCo00002ooonfX5o`0000_ooo]Z1?l0000IoookJPCo0000COoonfX5o`0001Wooo]Z1?l0000Koook
JPCo00006_oonfX4o`0004gooo]Z1?l0000JoookJPCo0000;OoonfX002cooo]Z1?l0000IoookJPGo
0000C?oonfX5o`0001Wooo]Z1?l0000;oookJPGo00002ooonfX4o`0001Wooo]Z1?l0001=oookJPGo
00006?oonfX5o`0001_ooo]Z1?l0000JoookJPCo0000COoonfX4o`0001[ooo]Z1?l0000]oookJP00
;?oonfX4o`0001Wooo]Z1Ol0001<oookJPGo00006?oonfX5o`0000_ooo]Z1Ol0000;oookJPCo0000
6OoonfX4o`0004gooo]Z1Ol0000HoookJPGo00006ooonfX5o`0001Wooo]Z1?l0001=oookJPCo0000
6_oonfX4o`0002gooo]Z000/oookJPCo00006OoonfX4o`0004gooo]Z1Ol0000HoookJPGo00002ooo
nfX5o`0000_ooo]Z1?l0000IoookJPCo0000C_oonfX4o`0001Sooo]Z1Ol0000KoookJPGo00006Ooo
nfX4o`0004gooo]Z1?l0000IoookJPGo0000;OoonfX002cooo]Z1?l0000IoookJPCo0000C_oonfX4
o`0001Sooo]Z1Ol0000;oookJPGo00002ooonfX5o`0001Sooo]Z1?l0001>oookJPCo00006?oonfX4
o`0001cooo]Z1Ol0000IoookJPCo0000COoonfX4o`0001Wooo]Z1Ol0000]oookJP00;?oonfX5o`00
01Sooo]Z1?l0001>oookJPCo00006?oonfX4o`0000cooo]Z1Ol0000;oookJPGo00006?oonfX4o`00
04kooo]Z1?l0000HoookJPCo00007OoonfX4o`0001Wooo]Z1?l0001=oookJPCo00006OoonfX5o`00
02gooo]Z000/oookJPGo00006?oonfX4o`0004kooo]Z1?l0000HoookJPCo00003?oonfX5o`0000_o
oo]Z1Ol0000GoookJPGo0000C_oonfX4o`0001Sooo]Z1?l0000MoookJPCo00006OoonfX4o`0004go
oo]Z1Ol0000HoookJPCo0000;_oonfX002cooo]Z1Ol0000HoookJPCo0000C_oonfX4o`0001Sooo]Z
1?l0000<oookJPGo00003?oonfX4o`0001Oooo]Z1Ol0001>oookJPCo00006?oonfX4o`0001gooo]Z
1?l0000HoookJPGo0000COoonfX5o`0001Sooo]Z1?l0000^oookJP00;OoonfX4o`0001Sooo]Z1?l0
001>oookJPCo00006?oonfX4o`0000cooo]Z1Ol0000<oookJPCo00005ooonfX5o`0004kooo]Z1?l0
000HoookJPCo00007OoonfX4o`0001Sooo]Z1Ol0001=oookJPGo00006?oonfX4o`0002kooo]Z000]
oookJPCo00006?oonfX4o`0004kooo]Z1?l0000HoookJPCo00003?oonfX5o`0000cooo]Z1?l0000G
oookJPCo0000CooonfX5o`0001Oooo]Z1?l0000MoookJPCo00006?oonfX5o`0004kooo]Z1?l0000G
oookJPGo0000;_oonfX002gooo]Z1?l0000HoookJPCo0000C_oonfX5o`0001Kooo]Z1Ol0000<oook
JPGo00003?oonfX4o`0001Oooo]Z1?l0001?oookJPGo00005_oonfX5o`0001gooo]Z1?l0000Hoook
JPCo0000CooonfX4o`0001Oooo]Z1Ol0000^oookJP00;OoonfX4o`0001Oooo]Z1Ol0001>oookJPGo
00005_oonfX5o`0000cooo]Z1Ol0000<oookJPCo00005ooonfX4o`0004oooo]Z1Ol0000FoookJPGo
00007OoonfX4o`0001Sooo]Z1?l0001?oookJPCo00005ooonfX5o`0002kooo]Z000]oookJPCo0000
5ooonfX5o`0004kooo]Z1Ol0000FoookJPGo00003?oonfX5o`0000cooo]Z1Ol0000FoookJPCo0000
D?oonfX4o`0001Kooo]Z1Ol0000MoookJPGo00005ooonfX4o`0004oooo]Z1?l0000GoookJPCo0000
;ooonfX002gooo]Z1?l0000GoookJPGo0000CooonfX4o`0001Kooo]Z1?l0000=oookJPGo00003?oo
nfX5o`0001Kooo]Z1?l0001@oookJPCo00005_oonfX4o`0001kooo]Z1Ol0000GoookJPCo0000Cooo
nfX4o`0001Oooo]Z1?l0000_oookJP00;OoonfX5o`0001Kooo]Z1?l0001@oookJPCo00005_oonfX4
o`0000gooo]Z1Ol0000<oookJPGo00005_oonfX4o`00053ooo]Z1?l0000FoookJPCo00007_oonfX5
o`0001Oooo]Z1?l0001?oookJPCo00005ooonfX4o`0002oooo]Z000]oookJPGo00005_oonfX4o`00
053ooo]Z1?l0000:oookJPGo001o1?oonfX3o`00O`Co00001_l007l7oookJPGo00003OoonfX4o`00
01Kooo]Z1?l0001@oookJPCo00005_oonfX4o`0001oooo]Z1?l0000GoookJPCo0000CooonfX4o`00
01Oooo]Z1?l0000_oookJP00;OoonfX5o`0001Kooo]Z1?l0001@oookJPCo00002OoonfX7o`00O`?o
oo]Z0ol007l4o`0000Ko001o1ooonfX5o`0000gooo]Z1?l0000EoookJPGo0000D?oonfX4o`0001Ko
oo]Z1?l0000OoookJPCo00005_oonfX5o`0004oooo]Z1?l0000FoookJPGo0000;ooonfX002kooo]Z
1?l0000FoookJPCo0000D?oonfX4o`0000Wooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o1?l000000ol007oooo]ZoookJP0:oookJPGo00003OoonfX4o`0001Gooo]Z1Ol0001@oookJPCo
00005_oonfX4o`0001oooo]Z1?l0000FoookJPGo0000CooonfX5o`0001Gooo]Z1Ol0000_oookJP00
;_oonfX4o`0001Kooo]Z1?l0001@oookJPCo00002?oonfX3o`00O`?ooo]Z0ol007l4oookJPGo0000
0_l007l;oookJPGo00003OoonfX4o`0001Gooo]Z1Ol0001@oookJPGo00005OoonfX4o`0001oooo]Z
1?l0000FoookJPGo0000CooonfX5o`0001Gooo]Z1Ol0000_oookJP00;_oonfX4o`0001Kooo]Z1?l0
001@oookJPCo00002?oonfX3o`00O`?ooo]Z0ol007l4oookJPGo00001?l007l9oookJPOo00002ooo
nfX4o`0001Gooo]Z1?l0001AoookJPGo00005?oonfX5o`0001oooo]Z1?l0000FoookJPCo0000D?oo
nfX5o`0001Gooo]Z1?l0000`oookJP00;_oonfX4o`0001Kooo]Z1?l0001@oookJPCo00002?oonfX3
o`00O`?ooo]Z0ol007l4oookJPGo000000?ooo]Zo`00Ool007l00_l007l8oookJPGo00003OoonfX5
o`0001Cooo]Z1?l0001AoookJPGo00005?oonfX5o`0001oooo]Z1?l0000FoookJPCo0000DOoonfX4
o`0001Gooo]Z1?l0000`oookJP00;_oonfX4o`0001Gooo]Z1Ol0001@oookJPGo00001ooonfX3o`00
O`?ooo]Z0ol007l4oookJPCo00000ooonfX3o`00O`Sooo]Z1Ol0000=oookJPGo00005?oonfX4o`00
05;ooo]Z1?l0000DoookJPGo00007ooonfX5o`0001Gooo]Z1?l0001AoookJPCo00005OoonfX4o`00
033ooo]Z000^oookJPGo00005?oonfX5o`00053ooo]Z1Ol00007oookJP?o001o0ooonfX3o`00O`Co
oo]Z1?l00004oookJP?o001o1ooonfX5o`0000gooo]Z1Ol0000DoookJPCo0000D_oonfX4o`0001Co
oo]Z1?l0000PoookJPGo00005OoonfX4o`00057ooo]Z1?l0000EoookJPCo0000<?oonfX002kooo]Z
1Ol0000DoookJPGo0000D?oonfX5o`0000Oooo]Z0ol007l3oookJP?o001o1?oonfX4o`000004o`00
Oooonf[ooo]ZoookJP?o001o1ooonfX5o`0000kooo]Z1?l0000DoookJPCo0000D_oonfX4o`0001Co
oo]Z1?l0000PoookJPGo00005OoonfX4o`00057ooo]Z1?l0000DoookJPGo0000<?oonfX002kooo]Z
1Ol0000DoookJPCo0000D_oonfX4o`0000Oooo]Z0ol007l3oookJP?o001o1?oonfX4o`000004o`00
Oooonf[ooo]ZoookJP?o001o1ooonfX5o`0000kooo]Z1?l0000DoookJPCo0000D_oonfX4o`0001Co
oo]Z1?l0000QoookJPCo00005OoonfX4o`00057ooo]Z1?l0000DoookJPGo0000<?oonfX002oooo]Z
1?l0000DoookJPCo0000D_oonfX4o`0000Sooo]Z0ol007l01?oonf[o001oo`00Ool007l5oookJPCo
00000_l007l2oookJP?o001o1ooonfX5o`0000kooo]Z1?l0000DoookJPCo0000D_oonfX4o`0001Co
oo]Z1?l0000QoookJPCo00005OoonfX4o`00057ooo]Z1?l0000DoookJPGo0000<?oonfX002oooo]Z
1?l0000DoookJPCo0000D_oonfX4o`0000Sooo]Z1ol007l5oookJPCo00001_l007l8oookJPGo0000
3_oonfX4o`0001Cooo]Z1?l0001BoookJPCo00005?oonfX4o`00027ooo]Z1?l0000DoookJPGo0000
DOoonfX4o`0001Cooo]Z1?l0000aoookJP00;ooonfX4o`0001Cooo]Z1?l0001BoookJPCo00002Ooo
nfX5o`00O`Gooo]Z1Ol00005o`00O`Wooo]Z1Ol0000>oookJPCo00004ooonfX5o`0005;ooo]Z1?l0
000CoookJPGo00008OoonfX4o`0001Cooo]Z1Ol0001AoookJPCo00005?oonfX4o`00037ooo]Z000_
oookJPCo00005?oonfX4o`0005;ooo]Z1?l0000CoookJPGo00003_oonfX5o`0000kooo]Z1Ol0000B
oookJPGo0000D_oonfX5o`0001;ooo]Z1Ol0000QoookJPCo00005?oonfX5o`00057ooo]Z1?l0000D
oookJPCo0000<OoonfX002oooo]Z1?l0000DoookJPCo0000D_oonfX4o`0001?ooo]Z1Ol0000>oook
JPGo00003_oonfX5o`0001;ooo]Z1Ol0001BoookJPGo00004_oonfX5o`00027ooo]Z1?l0000Doook
JPCo0000D_oonfX4o`0001Cooo]Z1?l0000aoookJP00;ooonfX5o`0001;ooo]Z1Ol0001BoookJPCo
00004ooonfX4o`0000oooo]Z1Ol0000>oookJPGo00004_oonfX4o`0005?ooo]Z1Ol0000BoookJPCo
00008_oonfX5o`0001?ooo]Z1?l0001BoookJPGo00004_oonfX5o`00037ooo]Z000_oookJPGo0000
4_oonfX5o`0005;ooo]Z1?l0000CoookJPCo00003ooonfX5o`0000oooo]Z1?l0000BoookJPCo0000
E?oonfX4o`0001;ooo]Z1?l0000RoookJPGo00004ooonfX4o`0005;ooo]Z1Ol0000BoookJPGo0000
<OoonfX002oooo]Z1Ol0000BoookJPGo0000D_oonfX4o`0001?ooo]Z1?l0000?oookJPGo00003ooo
nfX4o`0001;ooo]Z1?l0001DoookJPCo00004_oonfX4o`0002;ooo]Z1Ol0000CoookJPCo0000D_oo
nfX5o`0001;ooo]Z1Ol0000aoookJP00<?oonfX4o`0001;ooo]Z1?l0001CoookJPCo00004ooonfX4
o`0000oooo]Z1Ol0000?oookJPCo00004_oonfX4o`0005Cooo]Z1?l0000BoookJPCo00008ooonfX4
o`0001?ooo]Z1?l0001CoookJPCo00004_oonfX4o`0003;ooo]Z000`oookJPCo00004_oonfX4o`00
05?ooo]Z1Ol0000BoookJPCo00003ooonfX5o`0000oooo]Z1?l0000BoookJPCo0000E?oonfX4o`00
01;ooo]Z1?l0000SoookJPCo00004ooonfX4o`0005?ooo]Z1?l0000BoookJPCo0000<_oonfX0033o
oo]Z1?l0000BoookJPCo0000DooonfX5o`00017ooo]Z1Ol0000?oookJPGo00003ooonfX4o`0001;o
oo]Z1?l0001DoookJPCo00004OoonfX5o`0002?ooo]Z1?l0000BoookJPGo0000DooonfX4o`0001;o
oo]Z1?l0000boookJP00<?oonfX4o`0001;ooo]Z1?l0001CoookJPGo00004OoonfX5o`0000oooo]Z
1Ol0000?oookJPCo00004_oonfX4o`0005Cooo]Z1?l0000AoookJPGo00008ooonfX4o`0001;ooo]Z
1Ol0001CoookJPCo00004_oonfX4o`0003;ooo]Z000`oookJPCo00004_oonfX4o`0005Cooo]Z1?l0
000AoookJPGo00003ooonfX5o`0000oooo]Z1Ol0000@oookJPGo0000E?oonfX4o`00017ooo]Z1Ol0
000SoookJPGo00004OoonfX5o`0005?ooo]Z1?l0000BoookJPCo0000<_oonfX0033ooo]Z1?l0000B
oookJPCo0000E?oonfX4o`00017ooo]Z1?l0000@oookJPGo00003ooonfX5o`00013ooo]Z1Ol0001D
oookJPCo00004OoonfX4o`0002Cooo]Z1Ol0000AoookJPCo0000E?oonfX4o`00017ooo]Z1Ol0000b
oookJP00<?oonfX5o`00013ooo]Z1Ol0001DoookJPCo00004OoonfX4o`00013ooo]Z1Ol0000?oook
JPGo00004?oonfX5o`0005Cooo]Z1?l0000AoookJPCo00009?oonfX5o`00017ooo]Z1?l0001Doook
JPGo00004?oonfX5o`0003;ooo]Z000`oookJPGo00004?oonfX5o`0005Cooo]Z1?l0000AoookJPCo
00004?oonfX5o`00013ooo]Z1?l0000@oookJPCo0000EOoonfX4o`00017ooo]Z1?l0000UoookJPCo
00004OoonfX4o`0005Cooo]Z1Ol0000@oookJPGo0000<_oonfX0033ooo]Z1Ol0000@oookJPGo0000
E?oonfX4o`00017ooo]Z1?l0000@oookJPGo00004?oonfX4o`00013ooo]Z1?l0001EoookJPGo0000
4?oonfX4o`0002Gooo]Z1?l0000AoookJPCo0000E?oonfX5o`00013ooo]Z1?l0000coookJP00<Ooo
nfX4o`00013ooo]Z1?l0001EoookJPCo00004?oonfX5o`00013ooo]Z1Ol0000@oookJPCo00004?oo
nfX4o`0005Gooo]Z1Ol0000@oookJPCo00009OoonfX4o`00017ooo]Z1?l0001EoookJPCo00004?oo
nfX4o`0003?ooo]Z000aoookJPCo00004?oonfX4o`0005Gooo]Z1?l0000@oookJPGo00004?oonfX5
o`00013ooo]Z1?l0000@oookJPCo0000EOoonfX5o`0000oooo]Z1Ol0000UoookJPCo00004?oonfX5
o`0005Gooo]Z1?l0000@oookJPCo0000<ooonfX0037ooo]Z1?l0000@oookJPCo0000EOoonfX5o`00
00oooo]Z1Ol0000@oookJPGo00004?oonfX5o`0000oooo]Z1?l0001FoookJPCo00003ooonfX5o`00
02Gooo]Z1?l0000@oookJPGo0000EOoonfX4o`00013ooo]Z1?l0000coookJP00<OoonfX4o`00013o
oo]Z1?l0001EoookJPGo00003ooonfX4o`00017ooo]Z1Ol0000@oookJPGo00003ooonfX4o`0005Ko
oo]Z1?l0000?oookJPGo00009OoonfX5o`0000oooo]Z1Ol0001EoookJPCo00003ooonfX5o`0003?o
oo]Z000aoookJPCo00003ooonfX5o`0005Gooo]Z1Ol0000?oookJPCo00004OoonfX5o`00013ooo]Z
1Ol0000?oookJPCo0000E_oonfX4o`0000oooo]Z1?l0000VoookJPGo00003ooonfX4o`0005Kooo]Z
1Ol0000>oookJPGo0000<ooonfX0037ooo]Z1Ol0000>oookJPGo0000E_oonfX4o`0000oooo]Z1?l0
000AoookJPGo00004OoonfX4o`0000oooo]Z1?l0001FoookJPCo00003ooonfX4o`0002Kooo]Z1Ol0
000?oookJPCo0000E_oonfX5o`0000kooo]Z1Ol0000coookJP00<OoonfX5o`0000kooo]Z1Ol0001F
oookJPCo00003ooonfX4o`00017ooo]Z1Ol0000AoookJPCo00003_oonfX5o`0005Kooo]Z1?l0000?
oookJPCo00009ooonfX4o`0000oooo]Z1?l0001FoookJPGo00003_oonfX4o`0003Cooo]Z000aoook
JPGo00003_oonfX4o`0005Oooo]Z1?l0000>oookJPGo00004OoonfX5o`00017ooo]Z1?l0000>oook
JPGo0000E_oonfX5o`0000kooo]Z1?l0000WoookJPCo00003ooonfX4o`0005Oooo]Z1?l0000>oook
JPCo0000=?oonfX003;ooo]Z1?l0000>oookJPCo0000EooonfX5o`0000gooo]Z1Ol0000AoookJPGo
00004OoonfX4o`0000kooo]Z1Ol0001FoookJPGo00003_oonfX4o`0002Oooo]Z1?l0000>oookJPGo
0000EooonfX4o`0000kooo]Z1?l0000doookJP00<_oonfX4o`0000kooo]Z1?l0001GoookJPGo0000
3OoonfX5o`00017ooo]Z1Ol0000AoookJPGo00003OoonfX4o`0005Oooo]Z1Ol0000>oookJPCo0000
9ooonfX4o`0000kooo]Z1Ol0001GoookJPCo00003_oonfX4o`0003Cooo]Z000boookJPCo00003_oo
nfX4o`0005Oooo]Z1Ol0000=oookJPCo00004_oonfX5o`00017ooo]Z1Ol0000=oookJPCo0000F?oo
nfX4o`0000gooo]Z1Ol0000WoookJPGo00003OoonfX5o`0005Oooo]Z1?l0000=oookJPGo0000=?oo
nfX003;ooo]Z1?l0000=oookJPGo0000F?oonfX4o`0000gooo]Z1?l0000BoookJPGo00004OoonfX5
o`0000gooo]Z1?l0001HoookJPCo00003OoonfX5o`0002Oooo]Z1Ol0000=oookJPCo0000F?oonfX5
o`0000cooo]Z1Ol0000doookJP00<_oonfX4o`0000gooo]Z1Ol0001HoookJPCo00003OoonfX4o`00
01;ooo]Z1Ol0000BoookJPCo00003OoonfX4o`0005Sooo]Z1Ol0000<oookJPGo00009ooonfX5o`00
00gooo]Z1?l0001HoookJPGo00003?oonfX5o`0003Cooo]Z000boookJPCo00003OoonfX5o`0005So
oo]Z1?l0000=oookJPCo00004_oonfX5o`0001;ooo]Z1?l0000=oookJPCo0000F?oonfX5o`0000co
oo]Z1?l0000YoookJPCo00003OoonfX4o`0005Sooo]Z1Ol0000<oookJPCo0000=OoonfX003;ooo]Z
1Ol0000<oookJPCo0000FOoonfX5o`0000_ooo]Z1Ol0000BoookJPGo00004_oonfX4o`0000cooo]Z
1Ol0001HoookJPGo00003?oonfX4o`0002Wooo]Z1?l0000=oookJPCo0000FOoonfX4o`0000cooo]Z
1?l0000eoookJP00<_oonfX5o`0000cooo]Z1?l0001IoookJPGo00002ooonfX5o`0001;ooo]Z1Ol0
000BoookJPCo00003?oonfX5o`0005Wooo]Z1?l0000<oookJPCo0000:OoonfX5o`0000_ooo]Z1Ol0
001IoookJPCo00003?oonfX4o`0003Gooo]Z000boookJPGo00003?oonfX4o`0005Wooo]Z1Ol0000;
oookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000;oookJPGo0000FOoonfX4o`0000cooo]Z1?l0000Y
oookJPGo00002ooonfX5o`0005Wooo]Z1?l0000<oookJPCo0000=OoonfX003?ooo]Z1?l0000<oook
JPCo0000F_oonfX4o`0000_ooo]Z1?l0000CoookJPGo00004_oonfX5o`0000_ooo]Z1?l0001Joook
JPCo00003?oonfX4o`0002Wooo]Z1Ol0000;oookJPGo0000FOoonfX5o`0000[ooo]Z1Ol0000eoook
JP00<ooonfX4o`0000_ooo]Z1Ol0001JoookJPCo00002ooonfX4o`0001?ooo]Z1Ol0000BoookJPGo
00002ooonfX4o`0005[ooo]Z1?l0000;oookJPGo0000:_oonfX4o`0000_ooo]Z1?l0001JoookJPGo
00002_oonfX5o`0003Gooo]Z000coookJPCo00002ooonfX5o`0005[ooo]Z1?l0000;oookJPCo0000
4ooonfX5o`0001?ooo]Z1?l0000:oookJPGo0000F_oonfX5o`0000[ooo]Z1Ol0000ZoookJPCo0000
2ooonfX4o`0005[ooo]Z1Ol0000:oookJPGo0000=OoonfX003?ooo]Z1?l0000;oookJPGo0000F_oo
nfX4o`0000[ooo]Z1Ol0000CoookJPGo00004ooonfX4o`0000[ooo]Z1Ol0001JoookJPGo00002_oo
nfX5o`0002[ooo]Z1?l0000;oookJPCo0000FooonfX4o`0000[ooo]Z1?l0000foookJP00<ooonfX5
o`0000[ooo]Z1?l0001KoookJPGo00002OoonfX5o`0001?ooo]Z1Ol0000CoookJPCo00002_oonfX5
o`0005[ooo]Z1Ol0000:oookJPCo0000:ooonfX4o`0000_ooo]Z1?l0001KoookJPCo00002_oonfX4
o`0003Kooo]Z000coookJPGo00002_oonfX4o`0005_ooo]Z1Ol00009oookJPGo00004ooonfX5o`00
01?ooo]Z1?l0000:oookJPCo0000G?oonfX4o`0000[ooo]Z1?l0000[oookJPGo00002OoonfX5o`00
05_ooo]Z1Ol00008oookJPGo0000=_oonfX003?ooo]Z1Ol0000:oookJPCo0000FooonfX5o`0000Wo
oo]Z1?l0000DoookJPGo00004ooonfX5o`0000Wooo]Z1?l0001LoookJPCo00002_oonfX4o`0002_o
oo]Z1Ol00009oookJPGo0000FooonfX5o`0000Sooo]Z1Ol0000foookJP00=?oonfX4o`0000[ooo]Z
1?l0001LoookJPCo00002OoonfX4o`0001Cooo]Z1Ol0000CoookJPGo00002?oonfX5o`0005cooo]Z
1?l00009oookJPGo0000:ooonfX5o`0000Wooo]Z1Ol0001KoookJPGo00002?oonfX5o`0003Kooo]Z
000doookJPGo00002?oonfX5o`0005cooo]Z1?l00009oookJPCo00005?oonfX5o`0001?ooo]Z1Ol0
0008oookJPGo0000G?oonfX4o`0000Wooo]Z1Ol0000/oookJPCo00002OoonfX4o`0005gooo]Z1?l0
0008oookJPCo0000=ooonfX003Cooo]Z1Ol00008oookJPGo0000G?oonfX4o`0000Sooo]Z1Ol0000D
oookJPGo00005?oonfX4o`0000Sooo]Z1Ol0001LoookJPGo00002?oonfX5o`0002cooo]Z1?l00009
oookJPCo0000GOoonfX4o`0000Sooo]Z1?l0000goookJP00=?oonfX5o`0000Sooo]Z1Ol0001Loook
JPCo00002?oonfX5o`0001Cooo]Z1Ol0000DoookJPCo00002?oonfX4o`0005gooo]Z1Ol00007oook
JPGo0000;OoonfX4o`0000Wooo]Z1?l0001MoookJPGo00001ooonfX4o`0003Oooo]Z000eoookJPCo
00002?oonfX4o`0005gooo]Z1Ol00007oookJPGo00005?oonfX5o`0001Cooo]Z1?l00008oookJPCo
0000GOoonfX5o`0000Oooo]Z1Ol0000]oookJPCo00002OoonfX4o`0005gooo]Z1Ol00006oookJPGo
0000=ooonfX003Gooo]Z1?l00008oookJPCo0000GOoonfX5o`0000Oooo]Z1?l0000EoookJPGo0000
5?oonfX4o`0000Sooo]Z1?l0001NoookJPGo00001_oonfX5o`0002gooo]Z1Ol00007oookJPGo0000
GOoonfX5o`0000Kooo]Z1Ol0000goookJP00=OoonfX5o`0000Oooo]Z1?l0001MoookJPGo00001ooo
nfX4o`0001Gooo]Z1Ol0000DoookJPGo00001_oonfX5o`0005kooo]Z1Ol00006oookJPCo0000;_oo
nfX5o`0000Oooo]Z1Ol0001NoookJPCo00001_oonfX5o`0003Oooo]Z000eoookJPGo00001_oonfX5
o`0005kooo]Z1?l00007oookJPCo00005OoonfX5o`0001Cooo]Z1Ol00006oookJPGo0000G_oonfX5
o`0000Kooo]Z1?l0000^oookJPGo00001ooonfX5o`0005kooo]Z1?l00006oookJPCo0000>?oonfX0
03Gooo]Z1Ol00006oookJPGo0000G_oonfX4o`0000Kooo]Z1Ol0000EoookJPGo00005?oonfX5o`00
00Kooo]Z1Ol0001OoookJPCo00001OoonfX5o`0002oooo]Z1Ol00005oookJPGo0000GooonfX4o`00
00Kooo]Z1?l0000hoookJP00=_oonfX4o`0000Kooo]Z1Ol0001NoookJPGo00001OoonfX5o`0001Go
oo]Z1Ol0000EoookJPCo00001_oonfX4o`00063ooo]Z1?l00005oookJPGo0000;ooonfX5o`0000Go
oo]Z1Ol0001OoookJPGo00001OoonfX4o`0003Sooo]Z000foookJPCo00001OoonfX5o`0005oooo]Z
1Ol00005oookJPGo00005OoonfX5o`0001Gooo]Z1Ol00005oookJPCo0000H?oonfX5o`0000Cooo]Z
1Ol0000_oookJPGo00001OoonfX5o`0005oooo]Z1Ol00004oookJPGo0000>?oonfX003Kooo]Z1Ol0
0004oookJPGo0000GooonfX5o`0000Gooo]Z1?l0000FoookJPGo00005OoonfX5o`0000Gooo]Z1?l0
001PoookJPGo00001?oonfX4o`00037ooo]Z1?l00005oookJPCo0000H?oonfX5o`0000Cooo]Z1Ol0
000hoookJP00=_oonfX5o`0000Cooo]Z1Ol0001LoookJPCo001o1Ol00003o`00O`03oookJ_l0003o
000000;o00001Ol007l3oookJPGo001o2OoonfX5o`0001Gooo]Z1_l00003oookJPGo0000H?oonfX5
o`0000Cooo]Z1?l0000aoookJPCo00001?oonfX5o`00067ooo]Z1?l00004oookJPGo0000>?oonfX0
03Kooo]Z1_l00002oookJPGo0000G?oonfX5o`00O`Go00000ol007l5o`0000Go001o0_oonfX7o`00
O`Sooo]Z1Ol0000FoookJPGo00000ooonfX5o`00067ooo]Z1?l00003oookJPGo0000<OoonfX4o`00
00Cooo]Z1Ol0001QoookJPGo00000ooonfX4o`0003Wooo]Z000goookJPGo00000_oonfX5o`0005co
oo]Z0ol007l00ooonf[o001oo`000004o`0000?o001o1Ol00006oookJPCo001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0001Kooo]Z1Ol00003oookJPGo0000HOoonfX5o`0000;ooo]Z1Ol0000aoook
JPGo00000ooonfX5o`00067ooo]Z1Ol00002oookJPGo0000>OoonfX003Oooo]Z1Ol00002oookJPGo
0000FooonfX3o`00O`?ooo]Z00?o001oo`000?l000000ol00002oookJPGo000000?o001ooookJ_oo
nfX00ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo00005ooonfX4o`0000?ooo]Z1?l0001RoookJPGo
00000_oonfX5o`00037ooo]Z1Ol00002oookJPGo0000H_oonfX5o`0000;ooo]Z1Ol0000ioookJP00
>?oonfX4o`000003oookJ_l0003o000000?o0000G?oonfX3o`00O`?ooo]Z00?o001oo`000?l00000
0ol000000ooonf[o0000o`000003o`0000Co001o2OoonfX3o`00O`Oooo]Z1ol0000EoookJPGo0000
00?ooo]Zo`000?l000000ol0001RoookJPGo000000?ooo]Zo`000?l000000ol0000boookJPKo0000
00?ooo]Zo`000?l000000ol0001SoookJPCo000000?ooo]Zo`000?l000001?l0000ioookJP00>?oo
nfX:o`0005cooo]Z0ol007l3oookJP03o`00Ool0003o000000?o000000?ooo]Zo`000?l000000ol0
00000ooonf[o001oo`00O`02o`00O`Sooo]Z0ol007l7oookJPGo00005ooonfX;o`0006?ooo]Z2_l0
000coookJP_o0000HooonfX:o`0003[ooo]Z000hoookJP[o0000G?oonfX3o`00O`?ooo]Z0_l007l:
o`0000;ooo]Z0ol007l3oookJP;o001o0_oonfX4o`00O`Oooo]Z1Ol0000GoookJP_o0000HooonfX:
o`0003?ooo]Z2_l0001ToookJP[o0000>_oonfX003Sooo]Z2Ol0001MoookJP?o001o0ooonfX2o`00
O`Wo00001?oonfX3o`00O`;ooo]Z1ol007l8oookJPGo00006?oonfX9o`0006Cooo]Z2Ol0000eoook
JPWo0000I?oonfX9o`0003_ooo]Z000ioookJPSo0000GOoonfX3o`00O`?ooo]Z0_l007l9o`000004
o`00Oooonf[ooo]ZoookJP?o001o0_oonfX6o`00O`Wooo]Z1Ol0000HoookJPSo0000I_oonfX8o`00
03Gooo]Z2Ol0001UoookJPSo0000>ooonfX003[ooo]Z1_l0001NoookJP?o001o0ooonfX3o`00O`Oo
00000_l007l3oookJP?o001o0_oonfX2o`00O`gooo]Z1Ol0000IoookJPOo0000IooonfX6o`0003Oo
oo]Z1ol0001WoookJPOo0000>ooonfX003_ooo]Z1?l0001PoookJP?o001o00Cooo]Zo`00Ool007oo
001o0_oonfX5o`0000Co001o0_oonfX3o`00O`;ooo]Z0_l007l=oookJPGo00006_oonfX5o`0006So
oo]Z1Ol0000ioookJPGo0000J?oonfX5o`0003gooo]Z002OoookJPOo001o2?oonfX7o`00O`Cooo]Z
1ol007l7oookJPGo0000oooonfYeoookJP00X?oonfX5o`00O`[ooo]Z1Ol007l5oookJPOo001o1ooo
nfX5o`000?oooo]ZMOoonfX00<Oooo]Z1Ol0003ooookJWGooo]Z0037oookJPGo0000oooonfYeoook
JP00aooonfX5o`000?oooo]ZMOoonfX00<Oooo]Z1Ol0003ooookJWGooo]Z0037oookJPGo0000oooo
nfYeoookJP00aooonfX5o`000?oooo]ZMOoonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-2.35721, -0.0213279, \
0.0116772, 0.000797515}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note the periodicity of the plot above.  The wavelength is 2. Only three \
terms were calculated in the Fourier series representation of ",
  StyleBox["myfunction",
    FontWeight->"Bold"],
  ". Below the Fourier series and the exact function are shown superposed."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[OriginalPlot, FourierPlot]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.15873 0.0147151 2.32413 [
[.02381 .00222 -13.4688 -20 ]
[.02381 .00222 13.4688 0 ]
[.18254 .00222 -13.4688 -20 ]
[.18254 .00222 13.4688 0 ]
[.5 .00222 -7 -20 ]
[.5 .00222 7 0 ]
[.65873 .00222 -7 -20 ]
[.65873 .00222 7 0 ]
[.81746 .00222 -7 -20 ]
[.81746 .00222 7 0 ]
[.97619 .00222 -7 -20 ]
[.97619 .00222 7 0 ]
[.32877 .13092 -39 -10 ]
[.32877 .13092 0 10 ]
[.32877 .24713 -29 -10 ]
[.32877 .24713 0 10 ]
[.32877 .36333 -39 -10 ]
[.32877 .36333 0 10 ]
[.32877 .47954 -29 -10 ]
[.32877 .47954 0 10 ]
[.32877 .59575 -39 -10 ]
[.32877 .59575 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
gsave
.02381 .00222 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.18254 .01472 m
.18254 .02097 L
s
gsave
.18254 .00222 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .01472 m
.5 .02097 L
s
gsave
.5 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.65873 .01472 m
.65873 .02097 L
s
gsave
.65873 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 .01472 m
.81746 .02097 L
s
gsave
.81746 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.34127 .13092 m
.34752 .13092 L
s
gsave
.32877 .13092 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.34127 .24713 m
.34752 .24713 L
s
gsave
.32877 .24713 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.34127 .36333 m
.34752 .36333 L
s
gsave
.32877 .36333 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.34127 .47954 m
.34752 .47954 L
s
gsave
.32877 .47954 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.34127 .59575 m
.34752 .59575 L
s
gsave
.32877 .59575 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.34127 .03796 m
.34502 .03796 L
s
.34127 .0612 m
.34502 .0612 L
s
.34127 .08444 m
.34502 .08444 L
s
.34127 .10768 m
.34502 .10768 L
s
.34127 .15416 m
.34502 .15416 L
s
.34127 .1774 m
.34502 .1774 L
s
.34127 .20065 m
.34502 .20065 L
s
.34127 .22389 m
.34502 .22389 L
s
.34127 .27037 m
.34502 .27037 L
s
.34127 .29361 m
.34502 .29361 L
s
.34127 .31685 m
.34502 .31685 L
s
.34127 .34009 m
.34502 .34009 L
s
.34127 .38658 m
.34502 .38658 L
s
.34127 .40982 m
.34502 .40982 L
s
.34127 .43306 m
.34502 .43306 L
s
.34127 .4563 m
.34502 .4563 L
s
.34127 .50278 m
.34502 .50278 L
s
.34127 .52602 m
.34502 .52602 L
s
.34127 .54926 m
.34502 .54926 L
s
.34127 .57251 m
.34502 .57251 L
s
.01 w
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.015 w
.34127 .01472 m
.34754 .18074 L
.35415 .32022 L
.36085 .42821 L
.3647 .47639 L
.36819 .51226 L
.37132 .53832 L
.37472 .56061 L
.37658 .57034 L
.3783 .57783 L
.37994 .58366 L
.3817 .58859 L
.38256 .59052 L
.38338 .59207 L
.38418 .5933 L
.38492 .59422 L
.38562 .59488 L
.38601 .59517 L
.38636 .59538 L
.38675 .59556 L
.38717 .59568 L
.38757 .59574 L
.38794 .59574 L
.38834 .59569 L
.38876 .59556 L
.38916 .59539 L
.38953 .59518 L
.39043 .59446 L
.39128 .59353 L
.39297 .59096 L
.39481 .58714 L
.39795 .5783 L
.4014 .56545 L
.40841 .53091 L
.42181 .44184 L
.4347 .34145 L
.44842 .23424 L
.46163 .14262 L
.47433 .07392 L
.48087 .048 L
.4845 .03667 L
.48785 .02826 L
.49126 .02174 L
.49306 .01915 L
.49496 .01705 L
.49576 .01637 L
.49662 .01577 L
.49742 .01533 L
.49816 .01503 L
.49861 .01489 L
Mistroke
.49903 .0148 L
.49927 .01476 L
.49948 .01474 L
.49973 .01472 L
.49997 .01472 L
.5004 .01473 L
.50079 .01477 L
.50122 .01485 L
.50144 .01491 L
.50168 .01498 L
.50252 .0153 L
.50343 .0158 L
.5043 .01642 L
.50509 .0171 L
.5082 .0209 L
.50981 .02355 L
.51158 .02702 L
.51517 .03576 L
.52164 .05709 L
.52859 .08768 L
.54232 .1682 L
.55555 .26448 L
.56827 .3651 L
.58181 .46807 L
.58806 .50989 L
.59484 .54821 L
.59855 .56526 L
.60197 .57802 L
.60523 .58725 L
.60688 .5907 L
.60775 .59217 L
.60869 .59349 L
.60959 .59449 L
.60999 .59483 L
.61043 .59515 L
.61084 .59539 L
.61123 .59556 L
.61164 .59568 L
.61187 .59572 L
.61208 .59574 L
.61246 .59574 L
.6128 .59569 L
.61319 .59558 L
.61359 .5954 L
.61402 .59515 L
.61443 .59485 L
.61518 .59411 L
.61603 .59301 L
.61692 .59153 L
.61853 .58804 L
Mistroke
.62025 .58304 L
.62215 .57598 L
.62553 .55916 L
.62863 .5387 L
.6322 .50862 L
.63559 .47316 L
.64219 .38306 L
.64833 .27205 L
.65873 .01472 L
Mfstroke
0 g
.0075 w
.02381 .27349 m
.02499 .27384 L
.02605 .27474 L
.02729 .27649 L
.02846 .27882 L
.03053 .28458 L
.03279 .29309 L
.0379 .32034 L
.04262 .35375 L
.06244 .52443 L
.06713 .55744 L
.06972 .57241 L
.07218 .58415 L
.07356 .5896 L
.07507 .59455 L
.07644 .59811 L
.07771 .60061 L
.07903 .60235 L
.08022 .60317 L
.08088 .60332 L
.0816 .60323 L
.0829 .6024 L
.08355 .60166 L
.08425 .60063 L
.08552 .59814 L
.08702 .59414 L
.08839 .58952 L
.09137 .57639 L
.09419 .56024 L
.09917 .5239 L
.10458 .47505 L
.12396 .26929 L
.13426 .17482 L
.14005 .13345 L
.14536 .10384 L
.15007 .08402 L
.15523 .06857 L
.15783 .06292 L
.16061 .05823 L
.16323 .0549 L
.16561 .05263 L
.16806 .05094 L
.17031 .04982 L
.17148 .04938 L
.17278 .04898 L
.17415 .04865 L
.17539 .04841 L
.17657 .04824 L
.17769 .04811 L
.17888 .04802 L
Mistroke
.18017 .04794 L
.18129 .04791 L
.18248 .04789 L
.18361 .0479 L
.18463 .04793 L
.18584 .04799 L
.18696 .04807 L
.1882 .0482 L
.18952 .04838 L
.19091 .04864 L
.19222 .04896 L
.19341 .04931 L
.19468 .04978 L
.19698 .05091 L
.1991 .05235 L
.20139 .05441 L
.20391 .05744 L
.20662 .06174 L
.20909 .06678 L
.21176 .07358 L
.21467 .08281 L
.21958 .10318 L
.22475 .13169 L
.23505 .21073 L
.2444 .30359 L
.25531 .42194 L
.2601 .47114 L
.26536 .51931 L
.26987 .55356 L
.27235 .56904 L
.2747 .58123 L
.27598 .58678 L
.27737 .59194 L
.27853 .59552 L
.27981 .59869 L
.28101 .60093 L
.28229 .6025 L
.28347 .60323 L
.28458 .60326 L
.2858 .60258 L
.28648 .60187 L
.28713 .60099 L
.28842 .5986 L
.2898 .59515 L
.29231 .58658 L
.29459 .57634 L
.30015 .54279 L
.30539 .50221 L
.31421 .42417 L
.32369 .34443 L
Mistroke
.32647 .3249 L
.32912 .30878 L
.3317 .29571 L
.33409 .28612 L
.33634 .27948 L
.3376 .27682 L
.33875 .27507 L
.34 .27389 L
.34071 .27357 L
.34136 .2735 L
.34256 .27391 L
.34383 .27512 L
.34507 .27706 L
.34619 .27947 L
.34873 .28709 L
.35107 .29677 L
.35329 .30809 L
.36368 .38318 L
.37388 .4741 L
.37947 .52105 L
.38471 .55819 L
.38927 .58258 L
.39052 .58774 L
.39184 .59242 L
.39307 .59606 L
.39419 .59875 L
.39544 .60103 L
.39613 .60195 L
.39678 .60261 L
.39793 .60325 L
.39918 .60319 L
.39984 .60284 L
.40056 .6022 L
.40132 .60125 L
.40202 .6001 L
.40328 .59741 L
.40464 .59365 L
.407 .58493 L
.40958 .57243 L
.41427 .54228 L
.42306 .46496 L
.43408 .34754 L
.44444 .23929 L
.45374 .15936 L
.45897 .12451 L
.46378 .09933 L
.46849 .08067 L
.47289 .06809 L
.47541 .06269 L
.47771 .05877 L
Mistroke
.48036 .05527 L
.48286 .05281 L
.4853 .05107 L
.48652 .05039 L
.48788 .04978 L
.48903 .04935 L
.49027 .04897 L
.49143 .04868 L
.49251 .04847 L
.49385 .04826 L
.49462 .04817 L
.49531 .0481 L
.4966 .048 L
.49731 .04796 L
.49798 .04793 L
.49923 .0479 L
.50038 .0479 L
.50165 .04792 L
.50228 .04794 L
.50298 .04797 L
.50429 .04806 L
.50549 .04818 L
.50681 .04836 L
.50822 .04861 L
.50944 .04889 L
.51058 .04922 L
.51185 .04967 L
.51318 .05025 L
.51552 .05159 L
.51766 .05326 L
.51996 .05564 L
.52248 .05906 L
.52523 .06394 L
.52772 .06958 L
.5304 .07711 L
.53332 .08716 L
.5385 .11047 L
.5434 .13932 L
.55285 .21386 L
.56326 .31866 L
.57425 .43759 L
.57906 .48563 L
.5843 .53138 L
.58681 .54999 L
.58947 .5671 L
.59178 .57941 L
.59427 .58997 L
.59561 .5944 L
.59683 .59769 L
.598 .60014 L
Mistroke
.59924 .60197 L
.60035 .60296 L
.60139 .60332 L
.60252 .60308 L
.60374 .60211 L
.60442 .60124 L
.60514 .60007 L
.60643 .59733 L
.60782 .59349 L
.60936 .5882 L
.6121 .57611 L
.61467 .56194 L
.62463 .48712 L
.63358 .40706 L
.64313 .33025 L
.64596 .31232 L
.64863 .29817 L
.65102 .28802 L
.65226 .28378 L
.65362 .27994 L
.65489 .27714 L
.65608 .27523 L
.65734 .27397 L
.65804 .27361 L
.65869 .27349 L
.65983 .2738 L
.66108 .27487 L
.66226 .27658 L
.66336 .27878 L
.66574 .28553 L
.66798 .29426 L
.67308 .32202 L
.67806 .35782 L
.68343 .40305 L
.6935 .49289 L
.69883 .53549 L
.70177 .55561 L
.70454 .57186 L
.70714 .58432 L
.70851 .5897 L
.70996 .59447 L
.71118 .5977 L
.71183 .59913 L
.71253 .60043 L
.71375 .60214 L
.7149 .60306 L
.71613 .60331 L
.71683 .60311 L
.71748 .6027 L
.71867 .6014 L
Mistroke
.71993 .59923 L
.72118 .5963 L
.72235 .59285 L
.72454 .58459 L
.72711 .57205 L
.72982 .55564 L
.73468 .51901 L
.74563 .41188 L
.75584 .30112 L
.7655 .20583 L
.77418 .13859 L
.77908 .10987 L
.78361 .08924 L
.78811 .07396 L
.79067 .06733 L
.79307 .06231 L
.79543 .05837 L
.79791 .05516 L
.80063 .05256 L
.80313 .05085 L
.80444 .05017 L
.80563 .04966 L
.80691 .04921 L
.8083 .04882 L
.80959 .04854 L
.81078 .04834 L
.81191 .04819 L
.81312 .04807 L
.81441 .04798 L
.81514 .04794 L
.81581 .04792 L
.8171 .04789 L
.81832 .0479 L
.81901 .04791 L
.81974 .04794 L
.82106 .04801 L
.82187 .04807 L
.82263 .04815 L
.82404 .04832 L
.82521 .04852 L
.82646 .04878 L
.82872 .04944 L
.83009 .04999 L
.8314 .05063 L
.83384 .0522 L
.83641 .05451 L
.83879 .05738 L
.8414 .06149 L
.84417 .06714 L
.84871 .0798 L
Mistroke
.85296 .09611 L
.85763 .11955 L
.86265 .15162 L
.87275 .23662 L
.88377 .35178 L
.8943 .464 L
.89927 .5107 L
.90385 .54708 L
.90871 .5768 L
.91127 .58823 L
.91257 .59286 L
.91397 .5969 L
.9152 .59965 L
.91632 .60149 L
.91745 .60271 L
.91852 .60326 L
.91976 .60318 L
.92091 .60241 L
.92217 .6008 L
.9228 .59969 L
.92351 .59823 L
.92622 .59039 L
.92871 .58021 L
.93432 .54795 L
.94447 .46615 L
.97619 .27349 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP008?oonfX9o`00Oe3ooo]Z0ol007nRoook
JP?o001oCooonfX9o`00Odkooo]Z1Ol007mDoookJP?o001o7OoonfX0023ooo]Z2Ol007m@oookJP?o
001oX_oonfX3o`00Odoooo]Z2Ol007m=oookJPOo001oDooonfX3o`00Oagooo]Z000PoookJPCo001o
EOoonfX3o`00Oj;ooo]Z0ol007m?oookJPCo001oDOoonfX3o`00O`?ooo]Z0ol007mBoookJP?o001o
7OoonfX001Cooo]Z2_l007l3oookJPCo001oA?oonfX:o`00O`Kooo]Z0ol007nRoookJP?o001oD?oo
nfX4o`00Oe3ooo]Z0ol007l3oookJP?o001oCOoonfX9o`00Oacooo]Z000DoookJP[o001o1?oonfX5
o`00Od;ooo]Z2_l007l6oookJP?o001oX_oonfX3o`00Oe7ooo]Z1Ol007mDoookJP?o001oCOoonfX9
o`00Oacooo]Z000ToookJPCo001oDOoonfX3o`00Oj;ooo]Z0ol007mCoookJPCo001oDooonfX3o`00
Odgooo]Z0_l007l3oookJP?o001o7OoonfX002Gooo]Z0ol007mAoookJP?o001oX_oonfX3o`00OeCo
oo]Z0ol007mAoookJPCo001oCooonfX2o`00O`;ooo]Z0ol007lMoookJP009_oonfX3o`00Oe3ooo]Z
0ol007nRoookJP?o001oEOoonfX3o`00Oe3ooo]Z0ol007m@oookJP?o001o00Cooo]Zo`00Ool007oo
001o7OoonfX0023ooo]Z0ol007l3oookJP?o001oD?oonfX3o`00Oj;ooo]Z0ol007m?oookJP?o001o
0ooonfX3o`00Oe;ooo]Z0_l007m@oookJP;o001o00Cooo]Zo`00Ool007oo001o7OoonfX0023ooo]Z
0ol007l3oookJP?o001oCOoonfX6o`00Oioooo]Z1_l007m?oookJP?o001o0ooonfX3o`00Odcooo]Z
0ol007l3oookJP?o001oD?oonfX5o`00Oagooo]Z000PoookJPCo001o0_oonfX3o`00Odgooo]Z1_l0
07m;oookJPGo0000CooonfX6o`00Odoooo]Z1?l007l2oookJP?o001oC?oonfX3o`00O`?ooo]Z0ol0
07m@oookJPGo001o7OoonfX0027ooo]Z1ol007m@oookJPCo001oBooonfX5o`00057ooo]Z1?l007m@
oookJPOo001oC_oonfX7o`00Oe;ooo]Z1?l007lMoookJP008_oonfX5o`00Oe;ooo]Z0ol007m;oook
JPGo0000D_oonfX3o`00Oe7ooo]Z1Ol007m@oookJPGo001oE?oonfX3o`00Oagooo]Z0037oookJPGo
0000oooonfYeoookJP00aooonfX5o`000?oooo]ZMOoonfX00<Oooo]Z1Ol0003ooookJWGooo]Z0037
oookJPGo0000oooonfYeoookJP00aOoonfX8ool004gooo]Z2_oo001=oookJPSoo`00aooonfX000oo
oo]Z]_l00008ool004co00003?oo001<o`0000Soo`00]ol0000@oookJP003ooonfZfo`0000Soo`00
Bol0000>ool004_o00002?oo002go`00013ooo]Z000?oookJ[Ko00002?oo001:o`0000ooo`00Bol0
0008ool00;Oo00004?oonfX000oooo]Z]_l00008ool004Wo00004Ooo001:o`0000Soo`00]ol0000@
oookJP003ooonfZfo`0000Soo`00BOl0000Bool004Wo00002?oo002go`00013ooo]Z000NoookJP03
o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0C_oonfX8ool004Sooo]Z4ooo0019oookJPSo
o`00DOoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z000NoookJP03o`00
0?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0C_oonfX8ool004Sooo]Z5?oo0018oookJPSoo`00
DOoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z0035oookJPSoo`00Aooo
nfXEool004Sooo]Z2?oo0037oookJP00aOoonfX8ool004Oooo]Z5_oo0017oookJPSoo`00aooonfX0
0<Gooo]Z2?oo0017oookJQKoo`00AooonfX8ool00<Oooo]Z0035oookJPSoo`00A_oonfX;ool00003
oookJ_oo003oo`0000Woo`00AooonfX8ool00<Oooo]Z0035oookJPWoo`00AOoonfX;ool000;ooo]Z
2ooo0016oookJPSoo`00aooonfX00<Gooo]Z2Ooo0015oookJP[oo`000ooonfX;ool004Gooo]Z2Ooo
0037oookJP00aOoonfX9ool004Cooo]Z2ooo0004oookJP_oo`00A?oonfX9ool00<Oooo]Z0035oook
JPWoo`00A?oonfX:ool000Gooo]Z2ooo0014oookJPWoo`00aooonfX00<Gooo]Z2Ooo0014oookJP[o
o`001_oonfX:ool004Cooo]Z2Ooo0037oookJP00aOoonfX9ool004?ooo]Z2ooo0006oookJP_oo`00
@ooonfX9ool00<Oooo]Z0035oookJPWoo`00@ooonfX:ool000Oooo]Z2ooo0013oookJPWoo`00aooo
nfX00<Kooo]Z2?oo0013oookJP[oo`002?oonfX:ool004?ooo]Z2Ooo0037oookJP00K_oonfX;o`00
04gooo]Z2?oo0013oookJPWoo`002ol00009ool004;ooo]Z2?oo001=oookJP_o0000L?oonfX006_o
oo]Z4_l00019oookJPSoo`00@_oonfX6ool001;o00001_oo0012oookJPSoo`00BOoonfXBo`0006go
oo]Z001ZoookJQCo0000B?oonfX8ool004;ooo]Z1Ooo000Eo`0000Coo`00@_oonfX8ool004Sooo]Z
5?l0001/oookJP00J?oonfXGo`0004Oooo]Z2?oo0012oookJP?oo`006?l00004ool0047ooo]Z2?oo
0017oookJQKo0000JooonfX006Oooo]Z2_l00005oookJP[o0000A_oonfX8ool0047ooo]Z0ooo000;
o`0000Cooo]Z2ol00003ool0047ooo]Z2?oo0016oookJP[o00001?oonfX;o`0006Wooo]Z001Woook
JPOo00003?oonfX7o`0004Gooo]Z2?oo0011oookJP?oo`002?l0000;oookJPOo00000ooo0011oook
JPSoo`00AOoonfX8o`0000_ooo]Z2?l0001XoookJP00I_oonfX7o`0000kooo]Z1_l00015oookJPSo
o`00@OoonfX2ool000Oo000000?oo`00oookJ_oonfX02_oonfX2ool000Ko00000_oo0011oookJPSo
o`00A?oonfX7o`0000kooo]Z1ol0001XoookJP00IOoonfX6o`00017ooo]Z1_l00014oookJPSoo`00
@OoonfX2ool000Go00000ooo000=oookJP;oo`001Ol00003ool0043ooo]Z2?oo0014oookJPKo0000
4?oonfX7o`0006Oooo]Z001ToookJPOo00004_oonfX6o`0004?ooo]Z2?oo0010oookJP;oo`001_l0
0002ool000kooo]Z0_oo0006o`0000;oo`00@?oonfX8ool004?ooo]Z1_l0000CoookJPGo0000Iooo
nfX006Cooo]Z1_l0000CoookJPKo0000@ooonfX8ool0043ooo]Z0_oo0005o`0000?oo`003_oonfX3
ool000Ko000000?oo`00oookJ_oonfX0?_oonfX8ool004?ooo]Z1Ol0000DoookJPGo0000IooonfX0
06?ooo]Z1_l0000EoookJPKo0000@_oonfX8ool0043ooo]Z00?oo`00o`000?l000001?l00003ool0
00oooo]Z0_oo0006o`000003ool00?oonf[ooo]Z03kooo]Z2?oo0012oookJPKo00005OoonfX5o`00
06Kooo]Z001SoookJPGo00005ooonfX5o`0004;ooo]Z2?oo000ooookJP03ool00?l0003o000000Co
00000ooo000@oookJP?oo`001_l00010oookJPSoo`00@_oonfX5o`0001Kooo]Z1_l0001UoookJP00
HooonfX5o`0001Oooo]Z1Ol00012oookJPSoo`00?ooonfX00ooo003o0000o`000004o`0000?oo`00
4?oonfX4ool000Go000000?oo`00oookJ_oonfX0?OoonfX8ool004;ooo]Z1Ol0000FoookJPKo0000
IOoonfX006;ooo]Z1Ol0000IoookJPGo0000@OoonfX8ool003oooo]Z00?oo`00o`000?l000000ol0
0004ool0013ooo]Z1?oo0005o`000003ool00?oonf[ooo]Z03gooo]Z2?oo0011oookJPGo00006?oo
nfX6o`0006Cooo]Z001RoookJPGo00006OoonfX5o`00047ooo]Z2?oo000ooookJPGo00001Ooo000A
oookJPCoo`001?l000000ooo003ooo]ZoookJP0moookJPSoo`00@?oonfX6o`0001Wooo]Z1Ol0001T
oookJP00H_oonfX5o`0001Wooo]Z1Ol00011oookJPWoo`00?_oonfX5o`0000Coo`004_oonfX4ool0
00Go0000?ooonfX8ool0043ooo]Z1_l0000IoookJPGo0000I?oonfX0067ooo]Z1Ol0000KoookJPGo
0000@?oonfX9ool003gooo]Z00?oo`00o`000?l000000ol00004ool001;ooo]Z1?oo0005o`0003ko
oo]Z2Ooo0010oookJPGo00006ooonfX5o`0006?ooo]Z001QoookJPGo00006ooonfX5o`00043ooo]Z
2Ooo000moookJPGo00001Ooo000BoookJPCoo`001Ol0000noookJPWoo`00?ooonfX5o`0001cooo]Z
1Ol0001SoookJP00HOoonfX5o`0001_ooo]Z1Ol00010oookJPWoo`00?OoonfX5o`0000Coo`004ooo
nfX5ool000Go0000?OoonfX9ool003oooo]Z1Ol0000LoookJPGo0000HooonfX0063ooo]Z1Ol0000M
oookJPGo0000?ooonfX9ool003gooo]Z1Ol00004ool001Cooo]Z1?oo0005o`0003gooo]Z2Ooo000o
oookJPGo00007OoonfX4o`0006?ooo]Z001PoookJPGo00007OoonfX5o`0003oooo]Z2Ooo000moook
JPCo00001Ooo000DoookJPCoo`001Ol0000moookJPWoo`00?ooonfX4o`0001kooo]Z1Ol0001Roook
JP00H?oonfX5o`0001gooo]Z1Ol0000ooookJPWoo`00??oonfX5o`0000Goo`005?oonfX5ool000Go
0000??oonfX9ool003oooo]Z1?l0000NoookJPGo0000H_oonfX0063ooo]Z1?l0000OoookJPGo0000
?ooonfX8ool003cooo]Z1Ol00005ool001Cooo]Z1Ooo0005o`0003cooo]Z2Ooo000noookJPGo0000
7_oonfX5o`0006;ooo]Z001OoookJPGo00007ooonfX5o`0003oooo]Z2?oo000loookJPGo00001?oo
000EoookJPGoo`001Ol0000loookJPSoo`00?ooonfX5o`0001oooo]Z1?l0001RoookJP00GooonfX5
o`0001oooo]Z1Ol0000ooookJPSoo`00>ooonfX5o`0000Goo`005OoonfX6ool000Go0000>ooonfX8
ool003oooo]Z1Ol0000OoookJPCo0000H_oonfX005oooo]Z1Ol0000PoookJPGo0000?_oonfX8ool0
03_ooo]Z1Ol00005ool001Kooo]Z1Ooo0005o`0003_ooo]Z2?oo000ooookJPCo00008?oonfX5o`00
067ooo]Z001OoookJPCo00008OoonfX5o`0003kooo]Z2?oo000koookJPGo00001Ooo000FoookJPGo
o`001Ol0000koookJPSoo`00?ooonfX4o`00023ooo]Z1Ol0001QoookJP00GooonfX4o`00027ooo]Z
1Ol0000noookJPSoo`00>_oonfX5o`0000Koo`005_oonfX6ool000Co0000>ooonfX8ool003kooo]Z
1Ol0000PoookJPGo0000HOoonfX005kooo]Z1Ol0000RoookJPCo0000?_oonfX8ool003[ooo]Z1Ol0
0005ool001Oooo]Z1_oo0005o`0003[ooo]Z2?oo000noookJPGo00008OoonfX4o`00067ooo]Z001N
oookJPGo00008_oonfX5o`0003gooo]Z2?oo000joookJPGo00001Ooo000GoookJPKoo`001Ol0000j
oookJPSoo`00?_oonfX5o`00027ooo]Z1Ol0001PoookJP00G_oonfX5o`0002;ooo]Z1Ol0000moook
JPSoo`00>_oonfX4o`0000Koo`005ooonfX6ool000Go0000>_oonfX8ool003kooo]Z1?l0000Roook
JPGo0000H?oonfX005kooo]Z1?l0000SoookJPGo0000?OoonfX8ool003[ooo]Z1?l00006ool001So
oo]Z1_oo0004o`0003[ooo]Z2?oo000noookJPCo00008_oonfX5o`00063ooo]Z001NoookJPCo0000
9?oonfX4o`0003gooo]Z2?oo000ioookJPGo00001_oo000HoookJPKoo`001?l0000joookJPSoo`00
?OoonfX5o`0002?ooo]Z1?l0001PoookJP00G_oonfX4o`0002Cooo]Z1Ol0000loookJPSoo`00>Ooo
nfX5o`0000Goo`006OoonfX6ool000Go0000>OoonfX8ool003gooo]Z1Ol0000SoookJPGo0000Gooo
nfX005gooo]Z1Ol0000ToookJPGo0000??oonfX8ool003Wooo]Z1Ol00005ool001Wooo]Z1_oo0005
o`0003Wooo]Z2?oo000moookJPGo00008ooonfX5o`0005oooo]Z001MoookJPGo00009?oonfX5o`00
03cooo]Z2?oo000ioookJPCo00001_oo000IoookJPKoo`001Ol0000ioookJPSoo`00?OoonfX4o`00
02Cooo]Z1Ol0001OoookJP00GOoonfX5o`0002Gooo]Z1?l0000loookJPSoo`00>OoonfX4o`0000Ko
o`006_oonfX6ool000Co0000>OoonfX8ool003gooo]Z1?l0000UoookJPCo0000GooonfX005gooo]Z
1?l0000VoookJPCo0000??oonfX9ool003Sooo]Z1?l00006ool001[ooo]Z1_oo0004o`0003Wooo]Z
2?oo000loookJPGo00009OoonfX4o`0005oooo]Z001MoookJPCo00009_oonfX5o`0003_ooo]Z2Ooo
000hoookJPCo00001Ooo000KoookJPKoo`001?l0000ioookJPSoo`00??oonfX5o`0002Gooo]Z1Ol0
001NoookJP00G?oonfX5o`0002Kooo]Z1Ol0000koookJPWoo`00=ooonfX5o`0000Goo`006ooonfX6
ool000Go0000=ooonfX9ool003cooo]Z1Ol0000UoookJPGo0000G_oonfX005cooo]Z1Ol0000Voook
JPGo0000>ooonfX9ool003Oooo]Z1Ol00005ool001_ooo]Z1_oo0005o`0003Oooo]Z2Ooo000loook
JPCo00009_oonfX5o`0005kooo]Z001LoookJPGo00009ooonfX4o`0003_ooo]Z2Ooo000goookJPGo
00001Ooo000LoookJPGoo`001Ol0000goookJPWoo`00??oonfX4o`0002Oooo]Z1?l0001NoookJP00
G?oonfX4o`0002Sooo]Z1?l0000DoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l5oookJPGo001o
2OoonfX9ool003Oooo]Z1?l00006ool001cooo]Z1_oo0004o`0003Oooo]Z2Ooo000koookJPGo0000
9ooonfX4o`0005kooo]Z001LoookJPCo0000:?oonfX5o`0001;ooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`?ooo]Z1ol007l8oookJPWoo`00=ooonfX4o`0000Koo`007?oonfX6ool000Co0000=ooo
nfX9ool003_ooo]Z1Ol0000WoookJPGo0000GOoonfX005_ooo]Z1Ol0000XoookJPGo00004_oonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o
0_oonfX4o`00O`04oookJ_l007oo001oo`00O`Sooo]Z00?o0000ool00?oo00001_oo000goookJPCo
00001Ooo000MoookJPKoo`001?l0000goookJPWoo`00>ooonfX5o`0002Oooo]Z1Ol0001MoookJP00
FooonfX5o`0002Sooo]Z1Ol0000AoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z00?o0000ool00?oo00001_oo000goookJPCo
00001Ooo000MoookJPKoo`001?l0000goookJPWoo`00>ooonfX4o`0002Sooo]Z1Ol0001MoookJP00
FooonfX5o`0002Wooo]Z1?l0000AoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX3o`00O`Oooo]Z00?o0000ool00?oo00001_oo000foookJPGo00001Ooo000MoookJPKoo`00
1?l0000goookJPSoo`00??oonfX4o`0002Wooo]Z1?l0001MoookJP00FooonfX4o`0002[ooo]Z1?l0
000AoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`Oooo]Z00?o
0000ool00?oo00001_oo000foookJPGo00001Ooo000NoookJPGoo`001Ol0000foookJPSoo`00>ooo
nfX5o`0002Wooo]Z1?l0001MoookJP00FooonfX4o`0002[ooo]Z1?l0000AoookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX2o`00O`;ooo]Z1?l007l7oookJP03o`000?oo003o
o`0000Koo`00=_oonfX5o`0000Goo`007_oonfX5ool000Go0000=_oonfX8ool003_ooo]Z1Ol0000Y
oookJPGo0000G?oonfX005_ooo]Z1?l0000ZoookJPCo00004OoonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJP03o`000?oo003oo`0000Koo`00=_oonfX4o`00
00Goo`007ooonfX5ool000Go0000=_oonfX8ool003_ooo]Z1Ol0000YoookJPGo0000G?oonfX005_o
oo]Z1?l0000ZoookJPGo00004?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;o
oo]Z1_l007l9oookJP03o`000?oo003oo`0000Koo`00=_oonfX4o`0000Goo`007ooonfX6ool000Co
0000=_oonfX8ool003_ooo]Z1?l0000ZoookJPGo0000G?oonfX005[ooo]Z1Ol0000ZoookJPGo0000
4?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007l=oookJP03o`00
0?oo003oo`0000Koo`00=_oonfX4o`0000Goo`007ooonfX6ool000Co0000=_oonfX8ool003_ooo]Z
1?l0000[oookJPCo0000G?oonfX005[ooo]Z1Ol0000ZoookJPGo00004OoonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP;o001o3OoonfX00ol0003o
o`00ool00006ool003Gooo]Z1Ol00005ool0023ooo]Z1Ooo0004o`0003Kooo]Z2?oo000koookJPCo
0000:ooonfX4o`0005cooo]Z001JoookJPGo0000:ooonfX4o`00017ooo]Z1ol007l8oookJPOo001o
1?oonfX7o`00O`Oooo]Z00?o0000ool00?oo00001_oo000eoookJPGo00001Ooo000PoookJPGoo`00
1?l0000foookJPSoo`00>ooonfX4o`0002_ooo]Z1?l0001LoookJP00F_oonfX4o`0002cooo]Z1?l0
000BoookJPGo001o2_oonfX5o`00O`Gooo]Z1ol007l7oookJP03o`000?oo003oo`0000Koo`00=Ooo
nfX5o`0000Coo`008OoonfX5ool000Go0000=OoonfX8ool003[ooo]Z1Ol0000[oookJPGo0000Fooo
nfX005[ooo]Z1?l0000/oookJPCo0000>OoonfX00ol0003oo`00ool00006ool003Gooo]Z1?l00005
ool0027ooo]Z1Ooo0005o`0003Gooo]Z2?oo000joookJPGo0000:ooonfX5o`0005_ooo]Z001Joook
JPCo0000;?oonfX4o`0003Wooo]Z00?o0000ool00?oo00001_oo000eoookJPCo00001Ooo000Qoook
JPGoo`001Ol0000eoookJPSoo`00>_oonfX5o`0002_ooo]Z1Ol0001KoookJP00F_oonfX4o`0002co
oo]Z1?l0000ioookJP03o`000?oo003oo`0000Koo`00=OoonfX4o`0000Goo`008OoonfX6ool000Co
0000=OoonfX8ool003[ooo]Z1?l0000]oookJPCo0000FooonfX005Wooo]Z1Ol0000/oookJPCo0000
>OoonfX00ol0003oo`00ool00006ool003Cooo]Z1Ol00005ool002;ooo]Z1Ooo0004o`0003Gooo]Z
2?oo000joookJPCo0000;OoonfX4o`0005_ooo]Z001IoookJPGo0000;?oonfX5o`0003Sooo]Z00?o
0000ool00?oo00001_oo000doookJPGo00001Ooo000RoookJPGoo`001?l0000eoookJPSoo`00>_oo
nfX4o`0002gooo]Z1?l0001KoookJP00FOoonfX5o`0002cooo]Z1Ol0000hoookJP03o`000?oo003o
o`0000Ooo`00<ooonfX5o`0000Goo`008_oonfX5ool000Co0000=OoonfX8ool003[ooo]Z1?l0000]
oookJPCo0000FooonfX005Wooo]Z1?l0000]oookJPGo0000>?oonfX00ol0003oo`00ool00007ool0
03?ooo]Z1?l00005ool002?ooo]Z1Ooo0005o`0003Cooo]Z2?oo000ioookJPGo0000;OoonfX4o`00
05_ooo]Z001IoookJPCo0000;_oonfX4o`0003Sooo]Z00?o0000ool00?oo00001ooo000coookJPCo
00001Ooo000SoookJPGoo`001Ol0000coookJPWoo`00>OoonfX5o`0002gooo]Z1Ol0001JoookJP00
FOoonfX4o`0002kooo]Z1?l0000hoookJP03o`000?oo003oo`0000Ooo`00<ooonfX4o`0000Goo`00
9?oonfX4ool000Go0000<ooonfX9ool003Wooo]Z1Ol0000]oookJPGo0000F_oonfX005Wooo]Z1?l0
000^oookJPCo0000>?oonfX00ol0003oo`00ool00007ool003?ooo]Z1?l00005ool002Cooo]Z1Ooo
0004o`0003?ooo]Z2Ooo000ioookJPCo0000;_oonfX5o`0005[ooo]Z001IoookJPCo0000;_oonfX4
o`0003Sooo]Z00?o0000ool00?oo00001ooo000boookJPGo00001Ooo000ToookJPGoo`001?l0000c
oookJPWoo`00>OoonfX4o`0002oooo]Z1?l0001JoookJP00F?oonfX5o`0002kooo]Z1?l0000hoook
JP03o`000?oo003oo`0000Ooo`00<_oonfX5o`0000Goo`009?oonfX5ool000Co0000<ooonfX9ool0
03Wooo]Z1?l0000_oookJPCo0000F_oonfX005Sooo]Z1Ol0000^oookJPGo0000=ooonfX2o`0000So
o`00<_oonfX5o`0000Goo`009?oonfX5ool000Co0000<ooonfX9ool003Wooo]Z1?l0000_oookJPCo
0000F_oonfX005Sooo]Z1Ol0000^oookJPGo0000=ooonfX2o`0000Soo`00<_oonfX4o`0000Goo`00
9_oonfX4ool000Go0000<_oonfX9ool003Sooo]Z1Ol0000_oookJPCo0000F_oonfX005Sooo]Z1?l0
000_oookJPGo0000=ooonfX2o`0000Soo`00<_oonfX4o`0000Goo`009_oonfX4ool000Go0000<_oo
nfX8ool003Wooo]Z1Ol0000_oookJPCo0000F_oonfX005Sooo]Z1?l0000`oookJPCo0000=ooonfX2
o`0000Soo`00<_oonfX4o`0000Goo`009_oonfX4ool000Go0000<_oonfX8ool003Wooo]Z1Ol0000_
oookJPCo0000F_oonfX005Sooo]Z1?l0000`oookJPCo0000=ooonfX2o`0000Soo`00<_oonfX4o`00
00Goo`009_oonfX5ool000Co0000<_oonfX8ool003Wooo]Z1?l0000`oookJPGo0000FOoonfX005So
oo]Z1?l0000`oookJPCo0000=ooonfX2o`0000Soo`00<_oonfX4o`0000Goo`009_oonfX5ool000Co
0000<_oonfX8ool003Wooo]Z1?l0000`oookJPGo0000FOoonfX005Sooo]Z1?l0000`oookJPCo0000
=ooonfX2o`0000Soo`00<_oonfX4o`0000Goo`009_oonfX5ool000Co0000<_oonfX8ool003Wooo]Z
1?l0000`oookJPGo0000FOoonfX005Oooo]Z1Ol0000`oookJPCo0000=ooonfX2o`0000Soo`00<Ooo
nfX5o`0000Goo`009_oonfX5ool000Go0000<OoonfX8ool003Wooo]Z1?l0000aoookJPCo0000FOoo
nfX005Oooo]Z1Ol0000`oookJPCo0000=ooonfX2o`0000Soo`00<OoonfX5o`0000Coo`00:?oonfX4
ool000Go0000<OoonfX8ool003Sooo]Z1Ol0000aoookJPCo0000FOoonfX005Oooo]Z1Ol0000`oook
JPGo0000=_oonfX2o`0000Soo`00<OoonfX5o`0000Coo`00:?oonfX4ool000Go0000<OoonfX8ool0
03Sooo]Z1Ol0000aoookJPCo0000FOoonfX005Oooo]Z1?l0000aoookJPGo0000=_oonfX2o`0000So
o`00<OoonfX4o`0000Goo`00:?oonfX5ool000Co0000<OoonfX8ool003Sooo]Z1Ol0000aoookJPCo
0000FOoonfX005Oooo]Z1?l0000aoookJPGo0000=_oonfX2o`0000Soo`00<OoonfX4o`0000Goo`00
:?oonfX5ool000Co0000<OoonfX8ool003Sooo]Z1?l0000boookJPCo0000FOoonfX005Oooo]Z1?l0
000boookJPCo0000=_oonfX2o`0000Soo`00<OoonfX4o`0000Goo`00:?oonfX5ool000Co0000<Ooo
nfX8ool003Sooo]Z1?l0000boookJPCo0000FOoonfX005Oooo]Z1?l0000boookJPCo0000=_oonfX2
o`0000Soo`00<OoonfX4o`0000Goo`00:?oonfX5ool000Co0000<OoonfX8ool003Sooo]Z1?l0000b
oookJPGo0000F?oonfX005Oooo]Z1?l0000boookJPCo0000=_oonfX2o`0000Soo`00<OoonfX4o`00
00Goo`00:?oonfX5ool000Go0000<?oonfX8ool003Sooo]Z1?l0000boookJPGo0000F?oonfX005Oo
oo]Z1?l0000boookJPCo0000=_oonfX2o`0000Soo`00<?oonfX5o`0000Coo`00:_oonfX4ool000Go
0000<?oonfX8ool003Oooo]Z1Ol0000boookJPGo0000F?oonfX005Kooo]Z1Ol0000boookJPCo0000
=_oonfX2o`0000Woo`00;ooonfX5o`0000Coo`00:_oonfX4ool000Go0000<?oonfX8ool003Oooo]Z
1Ol0000coookJPCo0000F?oonfX005Kooo]Z1Ol0000boookJPCo0000=_oonfX2o`0000Woo`00;ooo
nfX5o`0000Coo`00:_oonfX5ool000Co0000<?oonfX8ool003Oooo]Z1Ol0000coookJPCo0000F?oo
nfX005Kooo]Z1Ol0000boookJPGo0000=OoonfX2o`0000Woo`00;ooonfX4o`0000Goo`00:_oonfX5
ool000Co0000;ooonfX9ool003Oooo]Z1?l0000doookJPCo0000F?oonfX005Kooo]Z1?l0000coook
JPGo0000=OoonfX2o`0000Woo`00;ooonfX4o`0000Goo`00:_oonfX5ool000Co0000;ooonfX9ool0
03Oooo]Z1?l0000doookJPCo0000F?oonfX005Kooo]Z1?l0000coookJPGo0000=OoonfX2o`0000Wo
o`00;ooonfX4o`0000Goo`00:_oonfX5ool000Co0000;ooonfX9ool003Oooo]Z1?l0000doookJPCo
0000F?oonfX005Kooo]Z1?l0000doookJPCo0000=OoonfX2o`0000Woo`00;ooonfX4o`0000Goo`00
:_oonfX5ool000Go0000;_oonfX9ool003Oooo]Z1?l0000doookJPCo0000F?oonfX005Kooo]Z1?l0
000doookJPCo0000=OoonfX2o`0000Woo`00;_oonfX00ooo003o0000o`000002o`0000Coo`00:ooo
nfX5ool000Go0000;_oonfX9ool003Oooo]Z1?l0000doookJPGo0000EooonfX005Kooo]Z1?l0000d
oookJPCo0000=OoonfX3o`0000Soo`00;_oonfX00ooo003o0000o`000002o`0000Coo`00;?oonfX4
ool000Go0000;_oonfX9ool003Oooo]Z1?l0000doookJPGo0000EooonfX005Gooo]Z1Ol0000doook
JPCo0000=OoonfX3o`0000Soo`00;_oonfX5o`0000Coo`00;?oonfX5ool000Co0000;_oonfX9ool0
03Kooo]Z1Ol0000doookJPGo0000EooonfX005Gooo]Z1Ol0000doookJPCo0000=OoonfX3o`0000So
o`00;_oonfX5o`0000Coo`00;?oonfX5ool000Co0000;_oonfX8ool003Oooo]Z1Ol0000eoookJPCo
0000EooonfX005Gooo]Z1Ol0000doookJPCo0000=OoonfX3o`0000Soo`00;_oonfX5o`0000Coo`00
;?oonfX5ool000Co0000;_oonfX8ool003Oooo]Z1Ol0000eoookJPCo0000EooonfX005Gooo]Z1?l0
000eoookJPGo0000=?oonfX3o`0000Soo`00;_oonfX4o`0000Goo`00;?oonfX5ool000Co0000;_oo
nfX8ool003Oooo]Z1?l0000foookJPCo0000EooonfX005Gooo]Z1?l0000eoookJPGo0000=?oonfX3
o`0000Soo`00;_oonfX4o`0000Goo`00;?oonfX5ool000Co0000;_oonfX8ool003Oooo]Z1?l0000f
oookJPCo0000EooonfX005Gooo]Z1?l0000eoookJPGo0000=?oonfX3o`0000Soo`00;OoonfX00ooo
003o0000o`000002o`0000Coo`00;OoonfX5ool000Co0000;_oonfX8ool003Oooo]Z1?l0000foook
JPCo0000EooonfX005Gooo]Z1?l0000foookJPCo0000=?oonfX3o`0000Soo`00;OoonfX00ooo003o
0000o`000002o`0000Coo`00;_oonfX4ool000Go0000;OoonfX8ool003Oooo]Z1?l0000foookJPCo
0000EooonfX005Gooo]Z1?l0000foookJPCo0000=?oonfX3o`0000Soo`00;OoonfX00ooo003o0000
o`000002o`0000Coo`00;_oonfX4ool000Go0000;OoonfX8ool003Oooo]Z1?l0000foookJPGo0000
E_oonfX005Gooo]Z1?l0000foookJPCo0000=?oonfX3o`0000Soo`00;OoonfX00ooo003o0000o`00
0002o`0000Coo`00;_oonfX4ool000Go0000;OoonfX8ool003Oooo]Z1?l0000foookJPGo0000E_oo
nfX005Cooo]Z1Ol0000foookJPCo0000=?oonfX3o`0000Soo`00;OoonfX5o`0000Coo`00;_oonfX5
ool000Co0000;OoonfX8ool003Oooo]Z1?l0000foookJPGo0000E_oonfX005Cooo]Z1Ol0000foook
JPCo0000=?oonfX3o`0000Soo`00;OoonfX5o`0000Coo`00;_oonfX5ool000Co0000;OoonfX8ool0
03Oooo]Z1?l0000goookJPCo0000E_oonfX005Cooo]Z1Ol0000foookJPCo0000=?oonfX3o`0000So
o`00;OoonfX5o`0000Coo`00;_oonfX5ool000Co0000;OoonfX8ool003Kooo]Z1Ol0000goookJPCo
0000E_oonfX005Cooo]Z1?l0000goookJPCo0000=?oonfX3o`0000Soo`00;OoonfX4o`0000Coo`00
;ooonfX5ool000Co0000;OoonfX8ool003Kooo]Z1Ol0000goookJPCo0000E_oonfX005Cooo]Z1?l0
000goookJPGo0000<ooonfX3o`0000Soo`00;?oonfX00ooo003o0000o`000002o`0000Coo`00<?oo
nfX4ool000Co0000;OoonfX8ool003Kooo]Z1Ol0000goookJPCo0000E_oonfX005Cooo]Z1?l0000g
oookJPGo00005_oonfX5o`00O`Cooo]Z0ol007l5oookJP?o001o2OoonfX3o`0000Soo`00;?oonfX0
0ooo003o0000o`000002o`0000Coo`00<?oonfX4ool000Co000000?oo`00oookJ_oonfX0:_oonfX8
ool003Kooo]Z1?l0000hoookJPCo0000E_oonfX005Cooo]Z1?l0000goookJPGo00005OoonfX7o`00
O`?ooo]Z0ol007l5oookJP?o001o2OoonfX3o`0000Soo`00;?oonfX00ooo003o0000o`000002o`00
00Coo`00<?oonfX4ool000Co000000?oo`00oookJ_oonfX0:_oonfX8ool003Kooo]Z1?l0000hoook
JPCo0000E_oonfX005Cooo]Z1?l0000hoookJPCo00005OoonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l5oookJP?o001o2OoonfX3o`0000Soo`00;?oonfX00ooo003o0000o`000002o`00
00Coo`00<?oonfX4ool000Co000000?oo`00oookJ_oonfX0:_oonfX8ool003Kooo]Z1?l0000hoook
JPCo0000E_oonfX005?ooo]Z1Ol0000hoookJPCo00005?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o
001o2OoonfX3o`0000Woo`00:ooonfX00ooo003o0000o`000002o`0000Coo`00<?oonfX4ool000Go
0000:ooonfX9ool003Kooo]Z1?l0000hoookJPGo0000EOoonfX005?ooo]Z1Ol0000hoookJPCo0000
5?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2OoonfX3o`0000Woo`00:ooonfX5o`0000Coo`00
<?oonfX4ool000Go0000:ooonfX9ool003Kooo]Z1?l0000hoookJPGo0000EOoonfX005?ooo]Z1Ol0
000hoookJPCo00005?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2OoonfX3o`0000Woo`00:ooo
nfX5o`0000Coo`00<?oonfX4ool000Go0000:ooonfX9ool003Kooo]Z1?l0000hoookJPGo0000EOoo
nfX005?ooo]Z1?l0000ioookJPCo00005?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2OoonfX3
o`0000Woo`00:ooonfX5o`0000?oo`00<OoonfX5ool000Co0000:ooonfX9ool003Kooo]Z1?l0000i
oookJPCo0000EOoonfX005?ooo]Z1?l0000ioookJPCo00005?oonfX3o`00O`?ooo]Z0ol007l:oook
JP?o001o2OoonfX3o`0000Woo`00:_oonfX00ooo003o0000o`000002o`0000Coo`00<_oonfX4ool0
00Co000000?oo`00oookJ_oonfX0:?oonfX9ool003Gooo]Z1Ol0000ioookJPCo0000EOoonfX005?o
oo]Z1?l0000ioookJPCo00005?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2OoonfX3o`0000Wo
o`00:_oonfX00ooo003o0000o`000002o`0000Coo`00<_oonfX4ool000Co000000?oo`00oookJ_oo
nfX0:?oonfX9ool003Gooo]Z1Ol0000ioookJPCo0000EOoonfX005?ooo]Z1?l0000ioookJPGo0000
4ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2OoonfX3o`0000Woo`00:_oonfX00ooo003o0000
o`000002o`0000Coo`00<_oonfX4ool000Co000000?oo`00oookJ_oonfX0:?oonfX9ool003Gooo]Z
1Ol0000ioookJPCo0000EOoonfX005?ooo]Z1?l0000ioookJPGo00005?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z1_l007l9oookJPCo00002?oo000ZoookJP03ool00?l0003o000000;o0000
1?oo000boookJPCoo`001?l000000ooo003ooo]ZoookJP0XoookJPSoo`00=_oonfX4o`0003[ooo]Z
1?l0001EoookJP00DooonfX4o`0003Wooo]Z1Ol0000DoookJPOo001o2_oonfX4o`00O`Wooo]Z1?l0
0008ool002[ooo]Z00?oo`00o`000?l000000_l00004ool003;ooo]Z1?oo0004o`000003ool00?oo
nf[ooo]Z02Sooo]Z2?oo000foookJPCo0000>_oonfX4o`0005Gooo]Z001BoookJPGo0000>_oonfX4
o`0001Gooo]Z1Ol007l<oookJP?o001o2OoonfX4o`0000Soo`00:_oonfX00ooo003o0000o`000002
o`0000Coo`00<_oonfX4ool000Co000000?oo`00oookJ_oonfX0:?oonfX8ool003Kooo]Z1?l0000j
oookJPCo0000EOoonfX005;ooo]Z1Ol0000joookJPCo0000<_oonfX4o`0000Soo`00:_oonfX00ooo
003o0000o`000002o`0000Coo`00<_oonfX4ool000Co000000?oo`00oookJ_oonfX0:?oonfX8ool0
03Kooo]Z1?l0000joookJPGo0000E?oonfX005;ooo]Z1Ol0000joookJPCo0000<_oonfX4o`0000So
o`00:_oonfX5o`0000?oo`00=?oonfX3ool000Go0000:_oonfX8ool003Kooo]Z1?l0000joookJPGo
0000E?oonfX005;ooo]Z1?l0000koookJPCo0000<_oonfX4o`0000Soo`00:_oonfX5o`0000?oo`00
=?oonfX3ool000Go000000?oo`00oookJ_oonfX09ooonfX8ool003Kooo]Z1?l0000joookJPGo0000
E?oonfX005;ooo]Z1?l0000koookJPCo0000<_oonfX4o`0000Soo`00:OoonfX00ooo003o0000o`00
0003o`0000?oo`00=?oonfX3ool000Go000000?oo`00oookJ_oonfX09ooonfX8ool003Kooo]Z1?l0
000koookJPCo0000E?oonfX001cooo]Z1Ol0000aoookJPCo0000>ooonfX4o`0003;ooo]Z1Ol00007
ool002Wooo]Z00?oo`00o`000?l000000_l00004ool003Cooo]Z1?oo0004o`000003ool00?oonf[o
oo]Z02Oooo]Z1ooo0005o`00037ooo]Z1Ol0000koookJPCo0000<_oonfX4o`0001kooo]Z000Loook
JPGo0000<OoonfX4o`0003_ooo]Z1?l0000aoookJPOo00001_oo000YoookJP03ool00?l0003o0000
00;o00001?oo000doookJPCoo`001?l000000ooo003ooo]ZoookJP0WoookJPKoo`001ol0000`oook
JPGo0000>ooonfX4o`0003;ooo]Z1?l0000NoookJP007?oonfX6o`00033ooo]Z1?l0000koookJPGo
0000;ooonfX8o`0000Koo`00:OoonfX00ooo003o0000o`000002o`0000Coo`00=?oonfX4ool000Co
000000?oo`00oookJ_oonfX09ooonfX6ool000So0000;ooonfX5o`0003_ooo]Z1?l0000boookJPCo
00007_oonfX001cooo]Z1ol0000_oookJPCo0000>ooonfX5o`0002oooo]Z2Ol00005ool002Wooo]Z
00?oo`00o`000?l000000_l00004ool003Cooo]Z1?oo0004o`000003ool00?oonf[ooo]Z02Oooo]Z
1Ooo0009o`0002oooo]Z1?l0000loookJPCo0000<_oonfX4o`0001kooo]Z000MoookJPKo0000;ooo
nfX4o`0003_ooo]Z1Ol0000_oookJPWo00001Ooo000YoookJP03ool00?l0003o000000;o00001?oo
000doookJPCoo`001?l000000ooo003ooo]ZoookJP0WoookJPGoo`002Ol0000_oookJPCo0000??oo
nfX4o`00037ooo]Z1Ol0000NoookJP007_oonfX6o`0002gooo]Z1Ol0000loookJPCo0000;_oonfX:
o`0000Goo`00:OoonfX00ooo003o0000o`000002o`0000Coo`00=OoonfX3ool000Co000000?oo`00
oookJ_oonfX09ooonfX4ool000_o0000;_oonfX4o`0003cooo]Z1?l0000aoookJPGo00007_oonfX0
01oooo]Z1Ol0000]oookJPGo0000??oonfX4o`0002kooo]Z2ol00004ool002Wooo]Z00?oo`00o`00
0?l000000_l00003ool003Kooo]Z0ooo0004o`0000;oo`00:?oonfX4ool000Go000000?ooo]Zo`00
0?l000000ol0000^oookJPCo0000??oonfX4o`00037ooo]Z1Ol0000NoookJP007ooonfX5o`0002go
oo]Z1Ol0000loookJPCo0000;OoonfX<o`0000Coo`00:?oonfX00ooo003o0000o`000003o`0000?o
o`00=_oonfX3ool000Co00000_oo000XoookJP?oo`001_l000000ooonf[o0000o`000003o`0002ko
oo]Z1?l0000loookJPGo0000<?oonfX4o`0001oooo]Z000PoookJPCo0000;OoonfX4o`0003gooo]Z
1?l0000]oookJPco00001?oo000XoookJP03ool00?l0003o000000?o00000ooo000foookJP?oo`00
1Ol000000ooo003ooo]ZoookJP0UoookJPCoo`001Ol00003oookJPGo0000;OoonfX4o`0003cooo]Z
1Ol0000`oookJPCo00007ooonfX0023ooo]Z1Ol0000/oookJPCo0000?OoonfX4o`0002gooo]Z3Ol0
0003ool002Sooo]Z00?oo`00o`000?l000000ol00003ool003Kooo]Z0ooo0005o`000003ool00?oo
nf[ooo]Z02Gooo]Z1?oo0005o`0000?ooo]Z1Ol0000]oookJPCo0000??oonfX5o`00033ooo]Z1?l0
000OoookJP008?oonfX5o`0002cooo]Z1?l0000moookJPCo0000;?oonfX>o`0000?oo`00:?oonfX0
0ooo003o0000o`000002o`0000Coo`00=_oonfX3ool000Go000000?oo`00oookJ_oonfX09OoonfX4
ool000Co000000Coo`00oookJ_oonf[ooo]Z1Ol0000]oookJPCo0000?OoonfX4o`0002oooo]Z1Ol0
000OoookJP008?oonfX5o`0002cooo]Z1?l0000moookJPCo0000;?oonfX>o`0000Coo`009ooonfX0
0ooo003o0000o`000002o`0000Coo`00=_oonfX4ool000Co000000?oo`00oookJ_oonfX09OoonfX3
ool000Go000000?oo`00oookJ_oonfX00_oonfX5o`0002_ooo]Z1Ol0000moookJPCo0000;ooonfX5
o`0001oooo]Z000QoookJPCo0000;?oonfX4o`0003gooo]Z1Ol0000[oookJPWo000000?oo`00o`00
0?l000000ol00003ool002Oooo]Z00?oo`00o`000?l000000_l00004ool003Kooo]Z1?oo0004o`00
0003ool00?oonf[ooo]Z02Gooo]Z0ooo0005o`000003ool00?oonf[ooo]Z00;ooo]Z1Ol0000[oook
JPGo0000?OoonfX4o`0002oooo]Z1Ol0000OoookJP008OoonfX5o`0002_ooo]Z1?l0000moookJPGo
0000:ooonfX4o`000003oookJ_l0003o000000;o000000?oo`00o`000?l000000ol00003ool002Oo
oo]Z00?oo`00o`000?l000000_l00004ool003Oooo]Z0ooo0004o`0000;oo`009_oonfX3ool000Go
000000?oo`00oookJ_oonfX00_oonfX5o`0002_ooo]Z1Ol0000moookJPCo0000;ooonfX4o`00023o
oo]Z000QoookJPGo0000:ooonfX4o`0003gooo]Z1Ol0000[oookJPCo000000?ooo]Zo`000?l00000
0_l000000ooo003o0000o`000003o`0000?oo`009ooonfX00ooo003o0000o`000002o`0000?oo`00
>?oonfX3ool000Co00000_oo000VoookJP?oo`001?l00002ool000Gooo]Z1?l0000[oookJPCo0000
?_oonfX4o`0002oooo]Z1?l0000PoookJP008OoonfX5o`0002_ooo]Z1?l0000noookJPCo0000:ooo
nfX4o`000003oookJ_l0003o000000;o00000_oo0004o`0000?oo`009_oonfX2ool000Co00000ooo
000hoookJP?oo`001?l00002ool002Kooo]Z0ooo0004o`000003ool00?oonf[ooo]Z00Cooo]Z1?l0
000[oookJPCo0000?_oonfX4o`0002oooo]Z1?l0000PoookJP008_oonfX4o`0002[ooo]Z1Ol0000n
oookJPCo0000:_oonfX5o`000003oookJ_l0003o000000;o00000_oo0005o`0000;oo`009_oonfX0
0ooo003o0000o`000003o`0000?oo`00>?oonfX3ool000Co00000_oo000VoookJP?oo`001?l00000
0ooo003ooo]ZoookJP04oookJPGo0000:_oonfX4o`0003kooo]Z1?l0000^oookJPGo00008?oonfX0
02;ooo]Z1?l0000ZoookJPGo0000?_oonfX4o`0002[ooo]Z1Ol000000ooonf[o0000o`000002o`00
00;oo`001Ol00002ool002Kooo]Z00?oo`00o`000?l000000ol00003ool003Sooo]Z0ooo0004o`00
00;oo`009_oonfX3ool000Co000000?oo`00oookJ_oonfX01?oonfX5o`0002[ooo]Z1?l0000noook
JPGo0000;OoonfX5o`00023ooo]Z000RoookJPGo0000:OoonfX5o`0003kooo]Z1?l0000ZoookJPGo
000000?ooo]Zo`000?l000000ol000000ooo003o0000o`000003o`0000;oo`009_oonfX00ooo003o
0000o`000003o`0000?oo`00>?oonfX3ool000Co00000_oo000VoookJP;oo`001Ol000000ooo003o
oo]ZoookJP04oookJPGo0000:_oonfX4o`0003kooo]Z1Ol0000]oookJPGo00008?oonfX002;ooo]Z
1Ol0000YoookJPCo0000?ooonfX4o`0002[ooo]Z1?l00002oookJPGo00000_oo0004o`0000;oo`00
9_oonfX00ooo003o0000o`000002o`0000Coo`00>?oonfX3ool000Go000000?oo`00oookJ_oonfX0
9?oonfX2ool000Go000000?oo`00oookJ_oonfX01OoonfX4o`0002[ooo]Z1?l0000noookJPGo0000
;OoonfX4o`00027ooo]Z000RoookJPGo0000:OoonfX4o`0003oooo]Z1?l0000ZoookJPCo00000_oo
nfX5o`0000;oo`001?l00002ool002Kooo]Z00?oo`00o`000?l000000_l00004ool003Wooo]Z0_oo
0005o`000003ool00?oonf[ooo]Z02Cooo]Z0_oo0005o`000003ool00?oonf[ooo]Z00Gooo]Z1?l0
000ZoookJPCo0000?ooonfX4o`0002gooo]Z1?l0000QoookJP008ooonfX4o`0002Wooo]Z1?l0000o
oookJPCo0000:_oonfX4o`0000;ooo]Z1Ol00002ool000Co00000_oo000VoookJP03ool00?l0003o
000000;o00001?oo000ioookJP;oo`001Ol00002ool002Gooo]Z0_oo0004o`0000;oo`001ooonfX4
o`0002[ooo]Z1?l0000ooookJPCo0000;OoonfX4o`00027ooo]Z000SoookJPCo0000:OoonfX4o`00
03oooo]Z1Ol0000XoookJPGo00000_oonfX5o`0000;oo`001?l00002ool002Kooo]Z00?oo`00o`00
0?l000000_l00003ool003[ooo]Z0ooo0004o`0000;oo`009OoonfX2ool000Co00000_oo0007oook
JPCo0000:OoonfX5o`0003oooo]Z1?l0000/oookJPGo00008OoonfX002?ooo]Z1Ol0000XoookJPCo
0000?ooonfX5o`0002Sooo]Z1Ol00002oookJPGo00000_oo0004o`0000;oo`009_oonfX00ooo003o
0000o`000002o`0000?oo`00>_oonfX3ool000Co00000_oo000UoookJP;oo`001?l00002ool000Oo
oo]Z1Ol0000XoookJPGo0000?ooonfX4o`0002cooo]Z1Ol0000QoookJP008ooonfX5o`0002Sooo]Z
1?l0000ooookJPGo0000:?oonfX5o`0000;ooo]Z1Ol00002ool000Go000000?oo`00oookJ_oonfX0
8ooonfX2ool000Co00000ooo000joookJP?oo`001?l00002ool002Gooo]Z00?oo`00o`000?l00000
0ol00002ool000Oooo]Z1Ol0000XoookJPGo0000?ooonfX4o`0002cooo]Z1Ol0000QoookJP008ooo
nfX5o`0002Sooo]Z1?l00010oookJPCo0000:?oonfX4o`0000?ooo]Z1Ol00002ool000Go000000?o
o`00oookJ_oonfX08ooonfX2ool000Co00000ooo000joookJP?oo`001?l00002ool002Gooo]Z00?o
o`00o`000?l000000ol00002ool000Oooo]Z1Ol0000XoookJPCo0000@?oonfX4o`0002cooo]Z1?l0
000RoookJP009?oonfX4o`0002Sooo]Z1?l00010oookJPCo0000:?oonfX4o`0000?ooo]Z1Ol00002
ool000Go000000?oo`00oookJ_oonfX08ooonfX00ooo003o0000o`000003o`0000?oo`00>_oonfX3
ool000Co00000_oo000UoookJP03ool00?l0003o000000?o00000_oo0008oookJPCo0000:?oonfX4
o`00043ooo]Z1?l0000/oookJPCo00008_oonfX002Cooo]Z1?l0000WoookJPGo0000@?oonfX4o`00
02Oooo]Z1Ol00003oookJPGo00000ooo0004o`000003ool00?oonf[ooo]Z02?ooo]Z00?oo`00o`00
0?l000000ol00003ool003[ooo]Z0ooo0004o`0000;oo`009OoonfX00ooo003o0000o`000002o`00
00?oo`002?oonfX4o`0002Sooo]Z1?l00010oookJPGo0000:ooonfX4o`0002;ooo]Z000ToookJPCo
00009ooonfX5o`00043ooo]Z1?l0000WoookJPGo00000ooonfX5o`0000?oo`001?l000000ooo003o
oo]ZoookJP0SoookJP03ool00?l0003o000000?o00000ooo000koookJP;oo`001?l00002ool002Co
oo]Z0_oo0004o`0000?oo`002?oonfX4o`0002Sooo]Z1?l00010oookJPGo0000:ooonfX4o`0002;o
oo]Z000ToookJPCo00009ooonfX5o`00043ooo]Z1?l0000WoookJPGo00000ooonfX5o`0000?oo`00
1?l000000ooo003ooo]ZoookJP0SoookJP03ool00?l0003o000000;o00001?oo000koookJP;oo`00
1?l00003ool002?ooo]Z00?oo`00o`000?l000000ol00003ool000Sooo]Z1?l0000XoookJPCo0000
@?oonfX5o`0002[ooo]Z1Ol0000RoookJP009?oonfX5o`0002Kooo]Z1?l00011oookJPCo00009ooo
nfX4o`0000Cooo]Z1Ol00003ool000Co000000?oo`00oookJ_oonfX08ooonfX00ooo003o0000o`00
0002o`0000Coo`00>ooonfX2ool000Go00000_oo000SoookJP03ool00?l0003o000000?o00000ooo
0008oookJPGo00009ooonfX4o`00047ooo]Z1?l0000ZoookJPGo00008_oonfX002Cooo]Z1Ol0000V
oookJPCo0000@OoonfX4o`0002Oooo]Z1?l00004oookJPGo00000ooo0004o`0000;oo`009?oonfX0
0ooo003o0000o`000002o`0000?oo`00??oonfX2ool000Go00000_oo000SoookJP03ool00?l0003o
000000?o00000ooo0008oookJPGo00009ooonfX4o`00047ooo]Z1?l0000ZoookJPGo00008_oonfX0
02Cooo]Z1Ol0000VoookJPCo0000@OoonfX4o`0002Oooo]Z1?l00004oookJPGo00000ooo0005o`00
0003ool00?oonf[ooo]Z027ooo]Z0_oo0004o`0000?oo`00??oonfX2ool000Go00000_oo000Soook
JP03ool00?l0003o000000;o00001?oo0008oookJPGo00009ooonfX4o`00047ooo]Z1?l0000Zoook
JPCo00008ooonfX002Gooo]Z1?l0000VoookJPCo0000@OoonfX5o`0002Kooo]Z1?l00004oookJPGo
00000ooo0005o`000003ool00?oonf[ooo]Z027ooo]Z0_oo0004o`0000?oo`00??oonfX3ool000Co
00000_oo000SoookJP03ool00?l0003o000000;o00001?oo0009oookJPCo00009ooonfX4o`00047o
oo]Z1?l0000ZoookJPCo00008ooonfX002Gooo]Z1?l0000VoookJPCo0000@OoonfX5o`0002Gooo]Z
1Ol00004oookJPGo00000ooo0005o`000003ool00?oonf[ooo]Z027ooo]Z0_oo0004o`0000?oo`00
??oonfX3ool000Co00000_oo000SoookJP03ool00?l0003o000000;o00001?oo0009oookJPCo0000
9_oonfX5o`00047ooo]Z1?l0000ZoookJPCo00008ooonfX002Gooo]Z1?l0000VoookJPCo0000@Ooo
nfX5o`0002Gooo]Z1Ol00004oookJPGo00001?oo0004o`000003ool00?oonf[ooo]Z027ooo]Z0_oo
0004o`0000?oo`00??oonfX3ool000Co00000_oo000SoookJP03ool00?l0003o000000;o00000ooo
000:oookJPCo00009_oonfX5o`00047ooo]Z1?l0000YoookJPGo00008ooonfX002Gooo]Z1?l0000V
oookJPCo0000@_oonfX4o`0002Gooo]Z1Ol00004oookJPGo00001?oo0004o`000003ool00?oonf[o
oo]Z027ooo]Z00?oo`00o`000?l000000ol00003ool003gooo]Z0_oo0004o`0000?oo`008_oonfX5
o`0000?oo`002_oonfX5o`0002Gooo]Z1Ol00011oookJPCo0000:OoonfX5o`0002?ooo]Z000Uoook
JPCo00009_oonfX4o`0004;ooo]Z1?l0000UoookJPCo00001OoonfX5o`0000Coo`001?l000000ooo
003ooo]ZoookJP0QoookJP03ool00?l0003o000000?o00000ooo000moookJP;oo`001?l00003ool0
02;ooo]Z1Ol00003ool000[ooo]Z1Ol0000UoookJPCo0000@_oonfX4o`0002Wooo]Z1Ol0000Soook
JP009OoonfX4o`0002Gooo]Z1Ol00012oookJPCo00009OoonfX4o`0000Gooo]Z1Ol000001?oonf[o
o`00ool00?oo0004o`000003ool00?oonf[ooo]Z027ooo]Z00?oo`00o`000?l000000ol00003ool0
03gooo]Z0_oo0004o`0000?oo`008_oonfX5o`0000?oo`002_oonfX5o`0002Gooo]Z1?l00012oook
JPGo0000:?oonfX4o`0002Cooo]Z000UoookJPGo00009?oonfX5o`0004;ooo]Z1?l0000UoookJPCo
00001OoonfX5o`000004oookJ_oo003oo`00ool000Co000000?oo`00oookJ_oonfX08OoonfX00ooo
003o0000o`000002o`0000?oo`00?_oonfX2ool000Co00000ooo000RoookJPCo00001?oo000;oook
JPCo00009OoonfX4o`0004;ooo]Z1Ol0000XoookJPCo00009?oonfX002Gooo]Z1Ol0000ToookJPGo
0000@_oonfX4o`0002Gooo]Z1?l00005oookJPGo000000Cooo]Zool00?oo003oo`001Ol0000Roook
JP;oo`001?l00003ool003kooo]Z0_oo0004o`0000?oo`008_oonfX4o`0000Coo`002ooonfX4o`00
02Gooo]Z1?l00012oookJPGo0000:?oonfX4o`0002Cooo]Z000UoookJPGo00009?oonfX4o`0004?o
oo]Z1?l0000UoookJPCo00001OoonfX5o`000004oookJ_oo003oo`00ool000Go00008_oonfX2ool0
00Co00000ooo000noookJP;oo`001Ol00002ool002;ooo]Z1?l00004ool000_ooo]Z1?l0000Uoook
JPCo0000@ooonfX4o`0002Oooo]Z1Ol0000ToookJP009_oonfX4o`0002Cooo]Z1?l00013oookJPCo
00009OoonfX4o`0000Gooo]Z1Ol000001?oonf[oo`00ool00?oo0005o`0002;ooo]Z0_oo0004o`00
00?oo`00?_oonfX2ool000Go00000_oo000RoookJPCo00001?oo000;oookJPCo00009OoonfX4o`00
04?ooo]Z1?l0000WoookJPGo00009?oonfX002Kooo]Z1?l0000ToookJPCo0000@ooonfX4o`0002Co
oo]Z1Ol00005oookJPGo000000?ooo]Zool00?oo00000_oo0004o`0002;ooo]Z0_oo0004o`0000?o
o`00?ooonfX00ooo003o0000o`000003o`0000;oo`008_oonfX4o`0000Coo`002ooonfX5o`0002Co
oo]Z1?l00013oookJPCo00009ooonfX5o`0002Cooo]Z000VoookJPCo00009?oonfX4o`0004?ooo]Z
1Ol0000SoookJPGo00001OoonfX5o`000003oookJ_oo003oo`0000;oo`001?l0000RoookJP;oo`00
1?l00003ool003oooo]Z0_oo0004o`0000?oo`008?oonfX5o`0000Coo`002ooonfX5o`0002Cooo]Z
1?l00013oookJPCo00009ooonfX4o`0002Gooo]Z000VoookJPCo00009?oonfX4o`0004?ooo]Z1Ol0
0006oookJPGo001o1?oonfX3o`00O`Gooo]Z0ol007l5oookJPCo001o1Ol00005oookJPGo000000?o
oo]Zool00?oo00000_oo0004o`0002;ooo]Z0_oo0004o`0000?oo`00?ooonfX2ool000Co00000ooo
000PoookJPGo00001?oo000;oookJPGo00009?oonfX4o`0004?ooo]Z1?l0000WoookJPCo00009Ooo
nfX002Kooo]Z1?l0000ToookJPCo0000@ooonfX5o`0000Gooo]Z1ol007l3oookJP?o001o1OoonfX3
o`00O`Cooo]Z1Ol007l4o`0000Kooo]Z1Ol000000ooonf[oo`00ool00002ool000Co000000?oo`00
oookJ_oonfX07ooonfX00ooo003o0000o`000003o`0000?oo`00?ooonfX2ool000Co00000ooo000P
oookJPGo00001?oo000<oookJPCo00008ooonfX5o`0004?ooo]Z1?l0000WoookJPCo00009OoonfX0
02Kooo]Z1?l0000ToookJPCo0000A?oonfX4o`0000Gooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o1OoonfX3o`00O`?ooo]Z1?l007l00ooonf[o001oo`000003o`0000Kooo]Z1Ol00000
0ooonf[oo`00ool00002ool000Co000000?oo`00oookJ_oonfX07ooonfX00ooo003o0000o`000003
o`0000;oo`00@?oonfX2ool000Co00000ooo000PoookJPCo00001Ooo000<oookJPCo00008ooonfX5
o`0004?ooo]Z1?l0000VoookJPGo00009OoonfX002Kooo]Z1Ol0000SoookJPCo0000A?oonfX4o`00
00Cooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`?ooo]Z0ol007l3oookJPCo00001_oonfX5o`00
0003oookJ_oo003oo`0000;oo`001Ol0000PoookJP;oo`001Ol00002ool0043ooo]Z0_oo0004o`00
00?oo`008?oonfX4o`0000Goo`003?oonfX4o`0002?ooo]Z1Ol00013oookJPGo00009OoonfX5o`00
02Gooo]Z000VoookJPGo00008_oonfX5o`0004Cooo]Z1?l00004oookJP?o001o0ooonfX3o`00O`[o
oo]Z0ol007l9oookJPCo00001_oonfX6o`0000Coo`001Ol0000PoookJP;oo`001?l00003ool0043o
oo]Z0_oo0004o`0000?oo`008?oonfX4o`0000Goo`003?oonfX4o`0002?ooo]Z1?l00014oookJPGo
00009OoonfX5o`0002Gooo]Z000VoookJPGo00008_oonfX5o`0004Cooo]Z1?l00004oookJP?o001o
0ooonfX3o`00O`[ooo]Z0ol007l9oookJPCo00001_oonfX5o`000003oookJ_oo003oo`0000;oo`00
1Ol0000PoookJP;oo`001?l00003ool0043ooo]Z0_oo0004o`0000?oo`008?oonfX4o`0000Goo`00
3?oonfX5o`0002;ooo]Z1?l00014oookJPGo00009OoonfX4o`0002Kooo]Z000WoookJPCo00008_oo
nfX5o`0004Cooo]Z1?l00004oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJP;o001o0_oo
nfX00ol007oo0000o`000002o`0000Kooo]Z1Ol000000ooonf[oo`00ool00003ool000Co00008?oo
nfX2ool000Co00000ooo0011oookJP03ool00?l0003o000000;o00000ooo000PoookJPCo00001Ooo
000<oookJPGo00008_oonfX4o`0004Gooo]Z1?l0000UoookJPCo00009_oonfX002Oooo]Z1?l0000R
oookJPCo0000AOoonfX4o`0000Cooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1?l007l5
o`0000Kooo]Z1Ol000000ooonf[oo`00ool00003ool000Co00008?oonfX2ool000Co00000ooo0011
oookJP03ool00?l0003o000000?o00000ooo000NoookJPGo00001Ooo000<oookJPGo00008_oonfX4
o`0004Gooo]Z1?l0000UoookJPCo00009_oonfX002Oooo]Z1?l0000RoookJPCo0000AOoonfX4o`00
00Cooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1?l007l5o`0000Kooo]Z1Ol00002oook
JPCoo`001?l0000PoookJP;oo`001?l00003ool0047ooo]Z00?oo`00o`000?l000000ol00003ool0
01kooo]Z1Ol00005ool000gooo]Z1?l0000RoookJPCo0000AOoonfX4o`0002Cooo]Z1Ol0000Voook
JP009ooonfX4o`0002;ooo]Z1?l00015oookJPGo00000ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo
001o1?oonfX2o`00O`;ooo]Z1Ol00006oookJPGo00000_oonfX4ool000Co00008?oonfX2ool000Co
00000ooo0011oookJP03ool00?l0003o000000?o00000ooo000NoookJPGo00001Ooo000=oookJPCo
00008_oonfX4o`0004Gooo]Z1?l0000ToookJPGo00009_oonfX002Oooo]Z1?l0000RoookJPCo0000
AOoonfX5o`0000Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPKo001o1?oonfX2o`00O`;o
oo]Z1?l00007oookJPGo00000_oonfX4ool000Co00007ooonfX3ool000Co00000_oo0012oookJP;o
o`001?l00003ool001kooo]Z1?l00005ool000kooo]Z1?l0000RoookJPCo0000AOoonfX4o`0002Co
oo]Z1Ol0000VoookJP009ooonfX4o`0002;ooo]Z1?l00015oookJPGo00001?oonfX7o`00O`[ooo]Z
1?l007l5oookJP?o001o1?l00007oookJPGo00000_oonfX4ool000Go00007_oonfX3ool000Co0000
0_oo0012oookJP;oo`001?l00003ool001kooo]Z1?l00005ool000kooo]Z1?l0000RoookJPCo0000
AOoonfX4o`0002Cooo]Z1?l0000WoookJP009ooonfX5o`00027ooo]Z1?l00016oookJPCo00001Ooo
nfX5o`00O`cooo]Z0ol007l5oookJP?o001o1?l00007oookJPGo00000_oonfX4ool000Go00007_oo
nfX2ool000Go00000_oo0012oookJP;oo`001?l00003ool001kooo]Z1?l00005ool000kooo]Z1?l0
000RoookJPCo0000AOoonfX4o`0002Cooo]Z1?l0000WoookJP009ooonfX5o`00027ooo]Z1?l00016
oookJPCo00008OoonfX4o`0000Oooo]Z1Ol00002oookJPCoo`001Ol0000NoookJP;oo`001Ol00002
ool004;ooo]Z0_oo0004o`0000?oo`007_oonfX4o`0000Goo`003_oonfX5o`00023ooo]Z1Ol00015
oookJPGo00008ooonfX4o`0002Oooo]Z000WoookJPGo00008OoonfX4o`0004Kooo]Z1?l0000Qoook
JPCo00001ooonfX5o`0000;ooo]Z1Ooo0004o`0001kooo]Z0_oo0005o`0000;oo`00@ooonfX00ooo
003o0000o`000002o`0000?oo`007_oonfX4o`0000Goo`003_oonfX5o`00023ooo]Z1Ol00015oook
JPGo00008_oonfX5o`0002Oooo]Z000XoookJPCo00008?oonfX5o`0004Kooo]Z1?l0000PoookJPGo
00001ooonfX5o`0000;ooo]Z1Ooo0004o`0001kooo]Z0_oo0004o`0000?oo`00@ooonfX00ooo003o
0000o`000002o`0000Coo`007OoonfX4o`0000Goo`003_oonfX5o`00023ooo]Z1Ol00015oookJPGo
00008_oonfX5o`0002Oooo]Z000XoookJPCo00008?oonfX5o`0004Kooo]Z1?l0000PoookJPGo0000
1ooonfX5o`0000;ooo]Z1Ooo0004o`0001kooo]Z0_oo0004o`0000?oo`00@ooonfX00ooo003o0000
o`000002o`0000Coo`007?oonfX5o`0000Goo`003ooonfX4o`00023ooo]Z1?l00017oookJPCo0000
8_oonfX5o`0002Oooo]Z000XoookJPCo00008?oonfX5o`0004Kooo]Z1?l0000PoookJPGo00001ooo
nfX5o`0000;ooo]Z1Ooo0004o`0001kooo]Z0_oo0004o`0000;oo`00A?oonfX00ooo003o0000o`00
0003o`0000?oo`007?oonfX5o`0000Goo`003ooonfX4o`00023ooo]Z1?l00017oookJPCo00008_oo
nfX4o`0002Sooo]Z000XoookJPCo00008?oonfX4o`0004Oooo]Z1?l0000PoookJPCo00002?oonfX5
o`0000;ooo]Z1Ooo0004o`0001gooo]Z0ooo0004o`0000;oo`00A?oonfX00ooo003o0000o`000003
o`0000?oo`007?oonfX5o`0000Goo`003ooonfX4o`00023ooo]Z1?l00017oookJPCo00008_oonfX4
o`0002Sooo]Z000XoookJPCo00008?oonfX4o`0004Oooo]Z1?l0000PoookJPCo00002?oonfX5o`00
00;ooo]Z1Ooo0005o`0001cooo]Z0ooo0004o`0000;oo`00A?oonfX00ooo003o0000o`000003o`00
00?oo`007?oonfX4o`0000Koo`003ooonfX4o`00023ooo]Z1?l00017oookJPCo00008_oonfX4o`00
02Sooo]Z000XoookJPGo00007ooonfX4o`0004Oooo]Z1Ol0000OoookJPCo00002?oonfX5o`0000;o
oo]Z1Ooo0005o`0001cooo]Z0ooo0004o`0000;oo`00A?oonfX2ool000Co00000ooo000LoookJPCo
00001_oo000?oookJPCo00008?oonfX4o`0004Oooo]Z1?l0000QoookJPGo0000:?oonfX002Sooo]Z
1Ol0000OoookJPCo0000AooonfX5o`0001oooo]Z1?l00008oookJPGo00000_oonfX5ool000Go0000
7?oonfX3ool000Co00000_oo0014oookJP;oo`001?l00003ool001cooo]Z1?l00006ool000oooo]Z
1?l0000PoookJPCo0000AooonfX4o`00027ooo]Z1Ol0000XoookJP00:?oonfX5o`0001oooo]Z1?l0
0017oookJPGo00007ooonfX4o`0000Sooo]Z1Ol00003oookJPGoo`001?l0000LoookJP;oo`001Ol0
0002ool004Gooo]Z00?oo`00o`000?l000000_l00003ool001cooo]Z1?l00006ool000oooo]Z1Ol0
000OoookJPCo0000AooonfX4o`00027ooo]Z1Ol0000XoookJP00:OoonfX4o`0001oooo]Z1?l00018
oookJPCo00007ooonfX4o`0000Sooo]Z1Ol00003oookJPGoo`001?l0000LoookJP;oo`001Ol00002
ool004Gooo]Z00?oo`00o`000?l000000_l00004ool001_ooo]Z1?l00006ool000oooo]Z1Ol0000O
oookJPCo0000AooonfX5o`00023ooo]Z1?l0000YoookJP00:OoonfX4o`0001oooo]Z1?l00018oook
JPCo00007_oonfX5o`0000Sooo]Z1Ol00003oookJPGoo`001?l0000LoookJP;oo`001Ol00002ool0
04Gooo]Z00?oo`00o`000?l000000_l00004ool001[ooo]Z1Ol00006ool000oooo]Z1Ol0000Ooook
JPCo0000AooonfX5o`00023ooo]Z1?l0000YoookJP00:OoonfX4o`0001oooo]Z1?l00018oookJPCo
00007_oonfX5o`0000Sooo]Z1Ol00003oookJPGoo`001?l0000LoookJP;oo`001?l00002ool004Ko
oo]Z00?oo`00o`000?l000000_l00004ool001[ooo]Z1Ol00006ool0013ooo]Z1?l0000NoookJPGo
0000AooonfX5o`00023ooo]Z1?l0000YoookJP00:OoonfX4o`0001kooo]Z1Ol00018oookJPCo0000
7_oonfX5o`0000Sooo]Z1Ol00003oookJPGoo`001?l0000KoookJP?oo`001?l00002ool004Kooo]Z
00?oo`00o`000?l000000_l00004ool001[ooo]Z1Ol00005ool0017ooo]Z1?l0000NoookJPGo0000
B?oonfX4o`0001oooo]Z1Ol0000YoookJP00:OoonfX4o`0001kooo]Z1Ol00018oookJPCo00007_oo
nfX4o`0000Wooo]Z1Ol00003oookJPGoo`001Ol0000JoookJP?oo`001?l00002ool004Kooo]Z00?o
o`00o`000?l000000_l00004ool001[ooo]Z1?l00006ool0017ooo]Z1?l0000NoookJPGo0000B?oo
nfX4o`0001oooo]Z1Ol0000YoookJP00:OoonfX5o`0001gooo]Z1Ol00018oookJPCo00007_oonfX4
o`0000Wooo]Z1Ol00003oookJPGoo`001Ol0000JoookJP?oo`001?l00002ool004Kooo]Z00?oo`00
o`000?l000000ol00003ool001[ooo]Z1?l00006ool0017ooo]Z1?l0000NoookJPCo0000BOoonfX4
o`0001oooo]Z1Ol0000YoookJP00:OoonfX5o`0001gooo]Z1?l00019oookJPCo00007_oonfX4o`00
00Wooo]Z1Ol00003oookJPGoo`001Ol0000JoookJP?oo`001?l00002ool004Kooo]Z00?oo`00o`00
0?l000000ol00003ool001[ooo]Z1?l00006ool0017ooo]Z1?l0000NoookJPCo0000BOoonfX4o`00
01oooo]Z1?l0000ZoookJP00:OoonfX5o`0001gooo]Z1?l00019oookJPCo00007_oonfX4o`0000Wo
oo]Z1Ol00003oookJPKoo`001?l0000JoookJP?oo`001?l00002ool004Oooo]Z1Ol00003ool001[o
oo]Z1?l00006ool0017ooo]Z1?l0000NoookJPCo0000BOoonfX4o`0001oooo]Z1?l0000ZoookJP00
:_oonfX4o`0001gooo]Z1?l00019oookJPGo00007OoonfX4o`0000Wooo]Z1Ol00003oookJPKoo`00
1?l0000JoookJP?oo`001?l00002ool004Oooo]Z00?oo`00o`000?l000000_l00004ool001Wooo]Z
1?l00006ool0017ooo]Z1Ol0000MoookJPCo0000BOoonfX4o`0001oooo]Z1?l0000ZoookJP00:_oo
nfX4o`0001gooo]Z1?l00019oookJPGo00007OoonfX4o`0000Wooo]Z1Ol00003oookJPKoo`001?l0
000JoookJP?oo`001?l00002ool004Oooo]Z00?oo`00o`000?l000000_l00004ool001Sooo]Z1Ol0
0006ool0017ooo]Z1Ol0000MoookJPCo0000BOoonfX4o`0001kooo]Z1Ol0000ZoookJP00:_oonfX4
o`0001gooo]Z1?l00019oookJPGo00007?oonfX5o`0000Wooo]Z1Ol00003oookJPKoo`001?l0000I
oookJP?oo`001Ol000000ooo003ooo]ZoookJP16oookJP03ool00?l0003o000000;o00001?oo000H
oookJPGo00001_oo000AoookJPGo00007OoonfX4o`0004Wooo]Z1?l0000NoookJPGo0000:_oonfX0
02[ooo]Z1?l0000MoookJPCo0000B_oonfX4o`0001cooo]Z1Ol00009oookJPGo00000ooonfX6ool0
00Co00006OoonfX3ool000Go000000?oo`00oookJ_oonfX0A_oonfX00ooo003o0000o`000002o`00
00Coo`006?oonfX5o`0000Koo`004_oonfX4o`0001gooo]Z1?l00019oookJPGo00007OoonfX5o`00
02[ooo]Z000ZoookJPCo00007OoonfX4o`0004[ooo]Z1?l0000LoookJPGo00002OoonfX5o`0000?o
oo]Z1_oo0005o`0001Sooo]Z0ooo0005o`000003ool00?oonf[ooo]Z04Kooo]Z00?oo`00o`000?l0
00000_l00004ool001Sooo]Z1?l00007ool001;ooo]Z1?l0000MoookJPCo0000BOoonfX5o`0001go
oo]Z1?l0000[oookJP00:_oonfX4o`0001gooo]Z1?l0001:oookJPCo00007?oonfX4o`0000[ooo]Z
1Ol00003oookJPKoo`001Ol0000HoookJP?oo`001?l00002ool004Sooo]Z00?oo`00o`000?l00000
0_l00004ool001Sooo]Z1?l00007ool001;ooo]Z1?l0000LoookJPGo0000BOoonfX5o`0001gooo]Z
1?l0000[oookJP00:_oonfX5o`0001_ooo]Z1Ol0001:oookJPCo00007?oonfX4o`0000[ooo]Z1Ol0
0004oookJPGoo`001Ol0000HoookJP?oo`001?l00002ool004Sooo]Z00?oo`00o`000?l000000_l0
0004ool001Sooo]Z1?l00007ool001;ooo]Z1?l0000LoookJPGo0000B_oonfX4o`0001gooo]Z1?l0
000[oookJP00:_oonfX5o`0001_ooo]Z1Ol0001:oookJPCo00007?oonfX4o`0000[ooo]Z1Ol00004
oookJPKoo`001?l0000HoookJP?oo`001?l00002ool004Wooo]Z1?l00004ool001Sooo]Z1?l00006
ool001?ooo]Z1?l0000LoookJPGo0000B_oonfX4o`0001gooo]Z1?l0000[oookJP00:_oonfX5o`00
01_ooo]Z1Ol0001:oookJPCo00007?oonfX4o`0000[ooo]Z1Ol00004oookJPKoo`001?l0000Hoook
JP?oo`001?l00002ool004Wooo]Z1Ol00004ool001Oooo]Z1?l00006ool001?ooo]Z1?l0000Loook
JPCo0000BooonfX4o`0001cooo]Z1Ol0000[oookJP00:ooonfX4o`0001_ooo]Z1?l0001;oookJPGo
00006ooonfX4o`0000[ooo]Z1Ol00004oookJPKoo`001?l0000HoookJP?oo`001?l000000ooo003o
oo]ZoookJP18oookJPGo00001?oo000GoookJPCo00001_oo000CoookJPGo00006ooonfX4o`0004_o
oo]Z1?l0000LoookJPGo0000:ooonfX002_ooo]Z1?l0000KoookJPCo0000BooonfX5o`0001[ooo]Z
1Ol0000:oookJPGo00001?oonfX6ool000Co00005ooonfX4ool000Co000000?oo`00oookJ_oonfX0
B?oonfX5o`0000Coo`005_oonfX5o`0000Koo`004ooonfX5o`0001_ooo]Z1?l0001;oookJPCo0000
7?oonfX5o`0002_ooo]Z000[oookJPCo00006ooonfX4o`0004_ooo]Z1Ol0000JoookJPGo00002_oo
nfX5o`0000Cooo]Z1_oo0004o`0001Oooo]Z1?oo0004o`000003ool00?oonf[ooo]Z04Sooo]Z00?o
o`00o`000?l000000_l00004ool001Kooo]Z1Ol00006ool001?ooo]Z1Ol0000KoookJPCo0000Booo
nfX4o`0001cooo]Z1?l0000/oookJP00:ooonfX4o`0001_ooo]Z1?l0001<oookJPCo00006_oonfX5
o`0000[ooo]Z1Ol00004oookJPKoo`001?l0000GoookJP?oo`001Ol000000ooo003ooo]ZoookJP18
oookJP03ool00?l0003o000000;o00001?oo000FoookJPGo00001_oo000DoookJPCo00006ooonfX4
o`0004_ooo]Z1?l0000LoookJPCo0000;?oonfX002_ooo]Z1?l0000KoookJPCo0000C?oonfX4o`00
01[ooo]Z1?l0000;oookJPGo00001?oonfX6ool000Go00005_oonfX3ool000Go000000?oo`00oook
J_oonfX0B?oonfX00ooo003o0000o`000002o`0000Coo`005_oonfX4o`0000Ooo`005?oonfX4o`00
01_ooo]Z1?l0001;oookJPGo00006ooonfX4o`0002cooo]Z000[oookJPGo00006_oonfX4o`0004co
oo]Z1?l0000JoookJPCo00002ooonfX5o`0000Cooo]Z1_oo0005o`0001Kooo]Z0ooo0005o`000003
ool00?oonf[ooo]Z04Sooo]Z00?oo`00o`000?l000000_l00004ool001Kooo]Z1?l00007ool001Co
oo]Z1?l0000JoookJPGo0000BooonfX5o`0001[ooo]Z1Ol0000/oookJP00:ooonfX5o`0001[ooo]Z
1?l0001<oookJPCo00006_oonfX4o`0000_ooo]Z1Ol00004oookJPKoo`001Ol0000FoookJP?oo`00
1?l00002ool004_ooo]Z1?l00004ool001Kooo]Z1?l00007ool001Cooo]Z1?l0000JoookJPGo0000
BooonfX5o`0001[ooo]Z1Ol0000/oookJP00:ooonfX5o`0001[ooo]Z1?l0001<oookJPCo00006_oo
nfX4o`0000_ooo]Z1Ol00004oookJPOoo`001?l0000FoookJP?oo`001?l00002ool004_ooo]Z1?l0
0005ool001Gooo]Z1?l00007ool001Cooo]Z1?l0000JoookJPGo0000C?oonfX4o`0001[ooo]Z1Ol0
000/oookJP00;?oonfX4o`0001Wooo]Z1Ol0001<oookJPCo00006_oonfX4o`0000_ooo]Z1Ol00004
oookJPOoo`001?l0000EoookJPCoo`001?l000000ooo003ooo]ZoookJP1:oookJPGo00001?oo000E
oookJPCo00001ooo000DoookJPCo00006_oonfX4o`0004gooo]Z1?l0000JoookJPCo0000;OoonfX0
02cooo]Z1?l0000IoookJPGo0000C?oonfX5o`0001Wooo]Z1?l0000;oookJPGo00001?oonfX7ool0
00Co00005OoonfX4ool000Co000000?oo`00oookJ_oonfX0B_oonfX5o`0000Coo`005?oonfX5o`00
00Ooo`005?oonfX4o`0001[ooo]Z1?l0001=oookJPCo00006_oonfX4o`0002gooo]Z000/oookJPCo
00006OoonfX5o`0004cooo]Z1Ol0000HoookJPGo00002ooonfX5o`0000Gooo]Z1_oo0004o`0001Go
oo]Z1?oo0004o`000003ool00?oonf[ooo]Z04[ooo]Z1Ol00004ool001Cooo]Z1Ol00007ool001Co
oo]Z1Ol0000IoookJPCo0000COoonfX4o`0001[ooo]Z1?l0000]oookJP00;?oonfX4o`0001Wooo]Z
1?l0001=oookJPGo00006?oonfX5o`0000_ooo]Z1Ol00005oookJPKoo`001?l0000EoookJPCoo`00
1?l000000ooo003ooo]ZoookJP1:oookJP03ool00?l0003o000000;o00001?oo000DoookJPGo0000
1_oo000EoookJPGo00006OoonfX4o`0004gooo]Z1?l0000IoookJPGo0000;OoonfX002cooo]Z1?l0
000IoookJPCo0000C_oonfX4o`0001Sooo]Z1Ol0000;oookJPGo00001OoonfX6ool000Go00005?oo
nfX4ool000Co000000?oo`00oookJ_oonfX0B_oonfX00ooo003o0000o`000002o`0000Coo`005?oo
nfX4o`0000Ooo`005OoonfX5o`0001Wooo]Z1?l0001=oookJPCo00006OoonfX5o`0002gooo]Z000/
oookJPGo00006?oonfX4o`0004kooo]Z1?l0000HoookJPCo00003?oonfX5o`0000Gooo]Z1_oo0005
o`0001Cooo]Z1?oo0004o`000003ool00?oonf[ooo]Z04[ooo]Z00?oo`00o`000?l000000_l00004
ool001Cooo]Z1?l00007ool001Kooo]Z1?l0000IoookJPCo0000COoonfX4o`0001Wooo]Z1Ol0000]
oookJP00;?oonfX5o`0001Sooo]Z1?l0001>oookJPCo00006?oonfX4o`0000cooo]Z1Ol00005oook
JPKoo`001Ol0000DoookJP?oo`001Ol000000ooo003ooo]ZoookJP1;oookJPCo00001?oo000Doook
JPCo00001ooo000FoookJPCo00006OoonfX4o`0004gooo]Z1Ol0000HoookJPCo0000;_oonfX002co
oo]Z1Ol0000HoookJPCo0000C_oonfX4o`0001Sooo]Z1?l0000<oookJPGo00001OoonfX7ool000Co
00004ooonfX4ool000Go0000C_oonfX4o`0000Goo`004ooonfX4o`0000Ooo`005_oonfX4o`0001So
oo]Z1Ol0001=oookJPGo00006?oonfX4o`0002kooo]Z000]oookJPCo00006?oonfX4o`0004kooo]Z
1?l0000HoookJPCo00003?oonfX5o`0000Gooo]Z1ooo0004o`0001?ooo]Z1?oo0005o`0004kooo]Z
1?l00005ool001?ooo]Z1?l00007ool001Kooo]Z1?l0000HoookJPGo0000COoonfX5o`0001Sooo]Z
1?l0000^oookJP00;OoonfX4o`0001Sooo]Z1?l0001>oookJPCo00006?oonfX4o`0000cooo]Z1Ol0
0005oookJPOoo`001?l0000CoookJPCoo`001?l000000ooo003ooo]ZoookJP1<oookJPGo00001?oo
000CoookJPCo00001ooo000FoookJPCo00006?oonfX5o`0004kooo]Z1?l0000GoookJPGo0000;_oo
nfX002gooo]Z1?l0000HoookJPCo0000C_oonfX5o`0001Kooo]Z1Ol0000<oookJPGo00001OoonfX7
ool000Co00004ooonfX4ool000Co000000?oo`00oookJ_oonfX0C?oonfX5o`0000Coo`004_oonfX5
o`0000Ooo`005_oonfX4o`0001Sooo]Z1?l0001?oookJPCo00005ooonfX5o`0002kooo]Z000]oook
JPCo00005ooonfX5o`0004kooo]Z1Ol0000FoookJPGo00003?oonfX5o`0000Gooo]Z1ooo0004o`00
01?ooo]Z1?oo0004o`000003ool00?oonf[ooo]Z04cooo]Z1Ol00004ool001;ooo]Z1Ol00007ool0
01Kooo]Z1?l0000HoookJPCo0000CooonfX4o`0001Oooo]Z1Ol0000^oookJP00;OoonfX4o`0001Oo
oo]Z1Ol0001>oookJPGo00005_oonfX5o`0000cooo]Z1Ol00005oookJPOoo`001Ol0000BoookJPCo
o`001?l000000ooo003ooo]ZoookJP1<oookJP03ool00?l0003o000000;o00001?oo000BoookJPGo
00001ooo000FoookJPGo00005ooonfX4o`0004oooo]Z1?l0000GoookJPCo0000;ooonfX002gooo]Z
1?l0000GoookJPGo0000CooonfX4o`0001Kooo]Z1?l0000=oookJPGo00001OoonfX7ool000Go0000
4_oonfX4ool000Co000000?oo`00oookJ_oonfX0C?oonfX00ooo003o0000o`000002o`0000Coo`00
4_oonfX4o`0000Soo`005_oonfX5o`0001Oooo]Z1?l0001?oookJPCo00005ooonfX4o`0002oooo]Z
000]oookJPGo00005_oonfX4o`00053ooo]Z1?l0000FoookJPCo00003OoonfX5o`0000Gooo]Z1ooo
0005o`00017ooo]Z1Ooo0004o`00053ooo]Z1?l00005ool0017ooo]Z1?l00008ool001Kooo]Z1Ol0
000GoookJPCo0000CooonfX4o`0001Oooo]Z1?l0000_oookJP00;OoonfX5o`0001Kooo]Z1?l0001@
oookJPCo00002_oonfX5o`00O`Cooo]Z0ol007l4o`0000Ko001o1ooonfX5o`0000Kooo]Z1ooo0004
o`00017ooo]Z1Ooo0004o`00053ooo]Z1?l00005ool0017ooo]Z1?l00007ool001Sooo]Z1?l0000G
oookJPCo0000CooonfX4o`0001Oooo]Z1?l0000_oookJP00;OoonfX5o`0001Kooo]Z1?l0001@oook
JPCo00002OoonfX7o`00O`?ooo]Z0ol007l4o`0000Ko001o1ooonfX5o`0000Kooo]Z1ooo0004o`00
017ooo]Z1?oo0005o`00053ooo]Z1?l00005ool0017ooo]Z1?l00007ool001Sooo]Z1?l0000Foook
JPGo0000CooonfX4o`0001Kooo]Z1Ol0000_oookJP00;_oonfX4o`0001Kooo]Z1?l0001@oookJPCo
00002OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l4o`000003o`00Oooonf[ooo]Z
00[ooo]Z1Ol00006oookJPOoo`001?l0000AoookJPCoo`001Ol0001@oookJPCo00001Ooo000Aoook
JPCo00001ooo000HoookJPCo00005_oonfX5o`0004oooo]Z1Ol0000EoookJPGo0000;ooonfX002ko
oo]Z1?l0000FoookJPCo0000D?oonfX4o`0000Sooo]Z0ol007l3oookJP?o001o1?oonfX5o`0000;o
001o2ooonfX5o`0000Kooo]Z1ooo0004o`00017ooo]Z1?oo0005o`00053ooo]Z1Ol00004ool0017o
oo]Z1?l00007ool001Sooo]Z1?l0000FoookJPGo0000CooonfX5o`0001Gooo]Z1Ol0000_oookJP00
;_oonfX4o`0001Kooo]Z1?l0001@oookJPCo00002?oonfX3o`00O`?ooo]Z0ol007l4oookJPGo0000
1?l007l9oookJPOo00001?oonfX7ool000Co00004OoonfX4ool000Co000000?oo`00oookJ_oonfX0
C_oonfX5o`0000Goo`003ooonfX5o`0000Ooo`006?oonfX4o`0001Kooo]Z1?l0001@oookJPGo0000
5OoonfX4o`00033ooo]Z000^oookJPCo00005_oonfX4o`00053ooo]Z1?l00008oookJP?o001o0ooo
nfX3o`00O`Cooo]Z1Ol000000ooonf[o001oo`00O`02o`00O`Sooo]Z1Ol00006oookJPOoo`001Ol0
000@oookJPCoo`001?l000000ooo003ooo]ZoookJP1>oookJPGo00001Ooo000?oookJPGo00001ooo
000HoookJPCo00005_oonfX4o`00057ooo]Z1?l0000EoookJPCo0000<?oonfX002kooo]Z1?l0000E
oookJPGo0000D?oonfX5o`0000Oooo]Z0ol007l3oookJP?o001o1?oonfX4o`0000?ooo]Z0ol007l8
oookJPGo00001_oonfX7ool000Go00003ooonfX5ool000Co0000D_oonfX4o`0000Goo`003ooonfX5
o`0000Ooo`006?oonfX5o`0001Gooo]Z1?l0001AoookJPCo00005OoonfX4o`00033ooo]Z000^oook
JPGo00005?oonfX5o`00053ooo]Z1Ol00007oookJP?o001o0ooonfX3o`00O`Cooo]Z1?l00004oook
JP?o001o1ooonfX5o`0000Kooo]Z1ooo0005o`0000oooo]Z1Ooo0004o`0005;ooo]Z1?l00005ool0
00oooo]Z1?l00008ool001Sooo]Z1Ol0000EoookJPCo0000DOoonfX4o`0001Gooo]Z1?l0000`oook
JP00;_oonfX5o`0001Cooo]Z1Ol0001@oookJPGo00001ooonfX3o`00O`?ooo]Z0ol007l4oookJPCo
000000Co001ooookJ_oonf[ooo]Z0ol007l7oookJPGo00001_oonfX8ool000Co00003ooonfX5ool0
00Co0000D_oonfX4o`0000Goo`003ooonfX4o`0000Soo`006?oonfX5o`0001Gooo]Z1?l0001Aoook
JPCo00005?oonfX5o`00033ooo]Z000^oookJPGo00005?oonfX4o`0005;ooo]Z1?l00007oookJP?o
001o0ooonfX3o`00O`Cooo]Z1?l000001?l007oooo]ZoookJ_oonfX3o`00O`Oooo]Z1Ol00006oook
JPSoo`001?l0000?oookJPGoo`001?l0001BoookJPCo00001Ooo000?oookJPCo00002?oo000Ioook
JPCo00005OoonfX4o`00057ooo]Z1?l0000DoookJPGo0000<?oonfX002oooo]Z1?l0000DoookJPCo
0000D_oonfX4o`0000Sooo]Z0ol007l01?oonf[o001oo`00Ool007l5oookJPCo00000_l007l2oook
JP?o001o1ooonfX5o`0000Kooo]Z2?oo0004o`0000oooo]Z1Ooo0004o`0005;ooo]Z1?l00006ool0
00kooo]Z1?l00008ool001Wooo]Z1?l0000EoookJPCo0000DOoonfX4o`0001Cooo]Z1Ol0000`oook
JP00;ooonfX4o`0001Cooo]Z1?l0001BoookJPCo00002?oonfX7o`00O`Gooo]Z1?l00006o`00O`So
oo]Z1Ol00006oookJPSoo`001?l0000?oookJPGoo`001?l0001BoookJPCo00001_oo000>oookJPCo
00001ooo000JoookJPCo00005?oonfX5o`00057ooo]Z1?l0000DoookJPCo0000<OoonfX002oooo]Z
1?l0000DoookJPCo0000D_oonfX4o`0000Wooo]Z1Ol007l5oookJPGo00001Ol007l9oookJPGo0000
1ooonfX7ool000Co00003ooonfX4ool000Go0000D_oonfX4o`0000Koo`003OoonfX5o`0000Ooo`00
6_oonfX4o`0001Cooo]Z1Ol0001AoookJPCo00005?oonfX4o`00037ooo]Z000_oookJPCo00005?oo
nfX4o`0005;ooo]Z1?l0000CoookJPGo00003_oonfX5o`0000Oooo]Z1ooo0005o`0000gooo]Z1Ooo
0005o`0005;ooo]Z1Ol00005ool000gooo]Z1Ol00007ool001[ooo]Z1?l0000DoookJPGo0000DOoo
nfX4o`0001Cooo]Z1?l0000aoookJP00;ooonfX4o`0001Cooo]Z1?l0001BoookJPCo00004ooonfX5
o`0000kooo]Z1Ol00007oookJPOoo`001Ol0000=oookJPGoo`001Ol0001BoookJPGo00001Ooo000=
oookJPGo00001ooo000JoookJPCo00005?oonfX4o`0005;ooo]Z1?l0000DoookJPCo0000<OoonfX0
02oooo]Z1Ol0000BoookJPGo0000D_oonfX4o`0001?ooo]Z1?l0000?oookJPGo00001ooonfX7ool0
00Go00003OoonfX5ool000Co0000DooonfX5o`0000Koo`003?oonfX4o`0000Soo`006_oonfX5o`00
01?ooo]Z1?l0001BoookJPGo00004_oonfX5o`00037ooo]Z000_oookJPGo00004_oonfX5o`0005;o
oo]Z1?l0000CoookJPCo00003ooonfX5o`0000Oooo]Z2?oo0004o`0000gooo]Z1Ooo0004o`0005Co
oo]Z1?l00006ool000cooo]Z1?l00008ool001[ooo]Z1Ol0000CoookJPCo0000D_oonfX5o`0001;o
oo]Z1Ol0000aoookJP00;ooonfX5o`0001;ooo]Z1Ol0001BoookJPCo00004ooonfX4o`0000oooo]Z
1Ol00007oookJPSoo`001?l0000=oookJPGoo`001?l0001DoookJPCo00001_oo000<oookJPCo0000
2?oo000JoookJPGo00004ooonfX4o`0005;ooo]Z1Ol0000BoookJPGo0000<OoonfX0033ooo]Z1?l0
000BoookJPCo0000DooonfX4o`0001?ooo]Z1?l0000?oookJPGo00001ooonfX8ool000Co00003Ooo
nfX5ool000Co0000E?oonfX4o`0000Koo`003?oonfX4o`0000Soo`006ooonfX4o`0001?ooo]Z1?l0
001CoookJPCo00004_oonfX4o`0003;ooo]Z000`oookJPCo00004_oonfX4o`0005?ooo]Z1Ol0000B
oookJPCo00003ooonfX5o`0000Oooo]Z2?oo0004o`0000gooo]Z1Ooo0004o`0005Cooo]Z1?l00006
ool000cooo]Z1?l00008ool001_ooo]Z1?l0000CoookJPCo0000DooonfX4o`0001;ooo]Z1?l0000b
oookJP00<?oonfX4o`0001;ooo]Z1?l0001CoookJPGo00004OoonfX5o`0000oooo]Z1Ol00007oook
JPSoo`001?l0000<oookJPKoo`001?l0001DoookJPCo00001_oo000;oookJPGo00001ooo000Loook
JPCo00004_oonfX5o`0005?ooo]Z1?l0000BoookJPCo0000<_oonfX0033ooo]Z1?l0000BoookJPCo
0000DooonfX5o`00017ooo]Z1Ol0000?oookJPGo00001ooonfX8ool000Co00003?oonfX6ool000Co
0000E?oonfX4o`0000Ooo`002_oonfX5o`0000Ooo`007?oonfX4o`0001;ooo]Z1Ol0001CoookJPCo
00004_oonfX4o`0003;ooo]Z000`oookJPCo00004_oonfX4o`0005Cooo]Z1?l0000AoookJPGo0000
3ooonfX5o`0000Sooo]Z1ooo0005o`0000_ooo]Z1Ooo0005o`0005Cooo]Z1?l00007ool000[ooo]Z
1Ol00007ool001cooo]Z1Ol0000AoookJPGo0000DooonfX4o`0001;ooo]Z1?l0000boookJP00<?oo
nfX4o`0001;ooo]Z1?l0001DoookJPCo00004OoonfX4o`00013ooo]Z1Ol00008oookJPOoo`001Ol0
000;oookJPGoo`001Ol0001DoookJPCo00001ooo000:oookJPCo00002?oo000LoookJPGo00004Ooo
nfX4o`0005Cooo]Z1?l0000AoookJPGo0000<_oonfX0033ooo]Z1Ol0000@oookJPGo0000E?oonfX4
o`00017ooo]Z1?l0000@oookJPGo00002?oonfX7ool000Go00002ooonfX5ool000Go0000E?oonfX4
o`0000Ooo`002_oonfX4o`0000Soo`007?oonfX5o`00017ooo]Z1?l0001DoookJPGo00004?oonfX5
o`0003;ooo]Z000`oookJPGo00004?oonfX5o`0005Cooo]Z1?l0000AoookJPCo00004?oonfX5o`00
00Sooo]Z2?oo0004o`0000_ooo]Z1Ooo0004o`0005Gooo]Z1?l00007ool000[ooo]Z1?l00008ool0
01gooo]Z1?l0000AoookJPCo0000E?oonfX5o`00013ooo]Z1Ol0000boookJP00<?oonfX5o`00013o
oo]Z1Ol0001DoookJPCo00004OoonfX4o`00013ooo]Z1Ol00008oookJPSoo`001?l0000;oookJPGo
o`001?l0001EoookJPGo00001_oo000:oookJPCo00002?oo000MoookJPCo00004OoonfX4o`0005Co
oo]Z1Ol0000@oookJPCo0000<ooonfX0037ooo]Z1?l0000@oookJPCo0000EOoonfX4o`00013ooo]Z
1Ol0000@oookJPGo00002?oonfX8ool000Co00002_oonfX6ool000Co0000EOoonfX5o`0000Koo`00
2_oonfX4o`0000Soo`007OoonfX4o`00017ooo]Z1?l0001EoookJPCo00004?oonfX4o`0003?ooo]Z
000aoookJPCo00004?oonfX4o`0005Gooo]Z1?l0000@oookJPGo00004?oonfX5o`0000Sooo]Z2?oo
0004o`0000[ooo]Z1_oo0004o`0005Gooo]Z1Ol00007ool000Sooo]Z1Ol00008ool001gooo]Z1?l0
000@oookJPGo0000EOoonfX4o`00013ooo]Z1?l0000coookJP00<OoonfX4o`00013ooo]Z1?l0001E
oookJPGo00003ooonfX5o`00013ooo]Z1Ol00008oookJPSoo`001Ol00009oookJPKoo`001?l0001F
oookJPCo00001ooo0008oookJPGo00001ooo000NoookJPCo00004?oonfX5o`0005Gooo]Z1?l0000@
oookJPCo0000<ooonfX0037ooo]Z1?l0000@oookJPCo0000EOoonfX5o`0000oooo]Z1?l0000Aoook
JPGo00002OoonfX7ool000Go00002OoonfX6ool000Co0000E_oonfX4o`0000Ooo`002?oonfX5o`00
00Ooo`007_oonfX5o`0000oooo]Z1Ol0001EoookJPCo00003ooonfX5o`0003?ooo]Z000aoookJPCo
00003ooonfX5o`0005Gooo]Z1Ol0000?oookJPCo00004OoonfX5o`0000Wooo]Z1ooo0005o`0000Wo
oo]Z1_oo0004o`0005Kooo]Z1?l00007ool000Sooo]Z1?l00008ool001kooo]Z1Ol0000?oookJPCo
0000E_oonfX5o`0000kooo]Z1Ol0000coookJP00<OoonfX5o`0000kooo]Z1Ol0001FoookJPCo0000
3ooonfX4o`00017ooo]Z1Ol00009oookJPSoo`001?l00008oookJPOoo`001?l0001FoookJPCo0000
1ooo0008oookJPCo00002?oo000NoookJPGo00003ooonfX4o`0005Kooo]Z1Ol0000>oookJPGo0000
<ooonfX0037ooo]Z1Ol0000>oookJPGo0000E_oonfX4o`0000oooo]Z1?l0000AoookJPGo00002Ooo
nfX8ool000Co00002?oonfX6ool000Go0000E_oonfX4o`0000Ooo`002?oonfX4o`0000Soo`007ooo
nfX4o`0000oooo]Z1?l0001FoookJPGo00003_oonfX4o`0003Cooo]Z000aoookJPGo00003_oonfX4
o`0005Oooo]Z1?l0000>oookJPGo00004OoonfX5o`0000Wooo]Z2?oo0004o`0000Sooo]Z1_oo0005
o`0005Kooo]Z1Ol00006ool000Sooo]Z1?l00008ool001oooo]Z1?l0000?oookJPCo0000EooonfX4
o`0000kooo]Z1?l0000doookJP00<_oonfX4o`0000kooo]Z1?l0001GoookJPGo00003OoonfX5o`00
017ooo]Z1Ol00009oookJPSoo`001?l00008oookJPKoo`001Ol0001FoookJPGo00001ooo0007oook
JPCo00002?oo000OoookJPCo00003_oonfX5o`0005Oooo]Z1?l0000>oookJPCo0000=?oonfX003;o
oo]Z1?l0000>oookJPCo0000EooonfX5o`0000gooo]Z1Ol0000AoookJPGo00002OoonfX8ool000Go
00001ooonfX6ool000Co0000EooonfX5o`0000Ooo`001ooonfX4o`0000Soo`007ooonfX4o`0000ko
oo]Z1Ol0001GoookJPCo00003_oonfX4o`0003Cooo]Z000boookJPCo00003_oonfX4o`0005Oooo]Z
1Ol0000=oookJPCo00004_oonfX5o`0000[ooo]Z1ooo0005o`0000Kooo]Z1ooo0004o`0005Sooo]Z
1?l00007ool000Kooo]Z1Ol00007ool0023ooo]Z1Ol0000=oookJPGo0000EooonfX4o`0000gooo]Z
1Ol0000doookJP00<_oonfX4o`0000gooo]Z1Ol0001HoookJPCo00003OoonfX4o`0001;ooo]Z1Ol0
000:oookJPOoo`001Ol00006oookJPOoo`001?l0001HoookJPCo00001ooo0006oookJPGo00001ooo
000PoookJPGo00003OoonfX4o`0005Sooo]Z1Ol0000<oookJPGo0000=?oonfX003;ooo]Z1?l0000=
oookJPGo0000F?oonfX4o`0000gooo]Z1?l0000BoookJPGo00002_oonfX8ool000Co00001_oonfX7
ool000Co0000F?oonfX5o`0000Koo`001_oonfX5o`0000Ooo`008?oonfX5o`0000gooo]Z1?l0001H
oookJPGo00003?oonfX5o`0003Cooo]Z000boookJPCo00003OoonfX5o`0005Sooo]Z1?l0000=oook
JPCo00004_oonfX5o`0000[ooo]Z2?oo0004o`0000Kooo]Z1ooo0004o`0005Sooo]Z1Ol00006ool0
00Kooo]Z1?l00008ool0027ooo]Z1?l0000=oookJPCo0000F?oonfX5o`0000cooo]Z1?l0000eoook
JP00<_oonfX5o`0000cooo]Z1?l0001IoookJPGo00002ooonfX5o`0001;ooo]Z1Ol0000:oookJPSo
o`001?l00005oookJPOoo`001Ol0001HoookJPGo00001ooo0005oookJPCo00002?oo000QoookJPCo
00003OoonfX4o`0005Wooo]Z1?l0000<oookJPCo0000=OoonfX003;ooo]Z1Ol0000<oookJPCo0000
FOoonfX5o`0000_ooo]Z1Ol0000BoookJPGo00002_oonfX8ool000Co00001OoonfX7ool000Go0000
FOoonfX4o`0000Ooo`001OoonfX4o`0000Soo`008OoonfX5o`0000_ooo]Z1Ol0001IoookJPCo0000
3?oonfX4o`0003Gooo]Z000boookJPGo00003?oonfX4o`0005Wooo]Z1Ol0000;oookJPGo00004_oo
nfX5o`0000[ooo]Z2?oo0005o`0000Cooo]Z1ooo0005o`0005Wooo]Z1?l00007ool000Gooo]Z1?l0
0008ool0027ooo]Z1Ol0000;oookJPGo0000FOoonfX4o`0000cooo]Z1?l0000eoookJP00<ooonfX4
o`0000cooo]Z1?l0001JoookJPCo00002ooonfX4o`0001?ooo]Z1Ol0000:oookJPSoo`001Ol00004
oookJPOoo`001?l0001JoookJPCo00001ooo0005oookJPCo00002?oo000QoookJPGo00002ooonfX5
o`0005Wooo]Z1Ol0000:oookJPGo0000=OoonfX003?ooo]Z1?l0000;oookJPGo0000F_oonfX4o`00
00_ooo]Z1?l0000CoookJPGo00002_oonfX8ool000Go00001?oonfX7ool000Co0000F_oonfX4o`00
00Ooo`001?oonfX5o`0000Soo`008_oonfX4o`0000_ooo]Z1?l0001JoookJPGo00002_oonfX5o`00
03Gooo]Z000coookJPCo00002ooonfX5o`0005[ooo]Z1?l0000;oookJPCo00004ooonfX5o`0000[o
oo]Z2Ooo0004o`0000?ooo]Z1ooo0005o`0005[ooo]Z1Ol00007ool000?ooo]Z1Ol00007ool002?o
oo]Z1?l0000;oookJPCo0000F_oonfX5o`0000[ooo]Z1Ol0000eoookJP00<ooonfX4o`0000_ooo]Z
1Ol0001JoookJPCo00002_oonfX5o`0001?ooo]Z1Ol0000;oookJPSoo`001?l00003oookJPOoo`00
1Ol0001JoookJPGo00001ooo0003oookJPGo00001ooo000SoookJPCo00002ooonfX4o`0005_ooo]Z
1?l0000:oookJPCo0000=_oonfX003?ooo]Z1Ol0000:oookJPCo0000FooonfX5o`0000Wooo]Z1Ol0
000CoookJPGo00002ooonfX8ool000Co00000ooonfX7ool000Go0000F_oonfX5o`0000Ooo`000ooo
nfX4o`0000Soo`008ooonfX4o`0000_ooo]Z1?l0001KoookJPCo00002_oonfX4o`0003Kooo]Z000c
oookJPGo00002_oonfX4o`0005_ooo]Z1Ol00009oookJPGo00004ooonfX5o`0000_ooo]Z2?oo0004
o`0000?ooo]Z1ooo0004o`0005cooo]Z1?l00007ool000?ooo]Z1?l00008ool002?ooo]Z1Ol00009
oookJPGo0000FooonfX5o`0000Sooo]Z1Ol0000foookJP00<ooonfX5o`0000[ooo]Z1?l0001Koook
JPGo00002OoonfX4o`0001Cooo]Z1Ol0000;oookJPSoo`001Ol000000ooonf[oo`00ool00006ool0
00Co0000G?oonfX4o`0000Soo`000_oonfX4o`0000Soo`008ooonfX5o`0000Wooo]Z1Ol0001Koook
JPGo00002?oonfX5o`0003Kooo]Z000doookJPCo00002_oonfX4o`0005cooo]Z1?l00009oookJPCo
00005?oonfX5o`0000_ooo]Z2?oo0005o`000003oookJ_oo003oo`0000Goo`001Ol0001LoookJPCo
00002?oo00000ooonf[o0000o`000003o`0000Soo`008ooonfX5o`0000Wooo]Z1Ol0001KoookJPGo
00002?oonfX5o`0003Kooo]Z000doookJPGo00002?oonfX5o`0005cooo]Z1?l00009oookJPCo0000
5?oonfX5o`0000_ooo]Z2?oo0005o`000003oookJ_oo003oo`0000Goo`001Ol0001LoookJPCo0000
2?oo00000ooonf[o0000o`000003o`0000Soo`009?oonfX4o`0000Wooo]Z1?l0001MoookJPCo0000
2?oonfX4o`0003Oooo]Z000doookJPGo00002?oonfX5o`0005cooo]Z1?l00008oookJPGo00005?oo
nfX5o`0000_ooo]Z2Ooo0004o`0000Soo`001Ol0001LoookJPGo00002?oo0005o`0000Soo`009?oo
nfX4o`0000Wooo]Z1?l0001MoookJPCo00002?oonfX4o`0003Oooo]Z000doookJPGo00002?oonfX5
o`0005cooo]Z1?l00008oookJPGo00005?oonfX5o`0000_ooo]Z2Ooo0004o`0000Soo`001?l0001M
oookJPGo00001ooo0005o`0000Soo`009OoonfX4o`0000Wooo]Z1?l0001MoookJPGo00001ooonfX4
o`0003Oooo]Z000eoookJPCo00002?oonfX4o`0005gooo]Z1Ol00007oookJPGo00005?oonfX5o`00
00cooo]Z2?oo0004o`0000Soo`001?l0001MoookJPGo00001ooo0005o`0000Soo`009OoonfX4o`00
00Wooo]Z1?l0001MoookJPGo00001_oonfX5o`0003Oooo]Z000eoookJPCo00002?oonfX4o`0005go
oo]Z1Ol00007oookJPCo00005OoonfX5o`0000cooo]Z2?oo0004o`0000Soo`001?l0001NoookJPGo
00001_oo0005o`0000Soo`009OoonfX5o`0000Oooo]Z1Ol0001MoookJPGo00001_oonfX5o`0003Oo
oo]Z000eoookJPGo00001ooonfX4o`0005gooo]Z1Ol00007oookJPCo00005OoonfX5o`0000cooo]Z
2?oo0005o`0000Koo`001Ol0001NoookJPGo00001_oo0004o`0000Woo`009OoonfX5o`0000Oooo]Z
1Ol0001NoookJPCo00001_oonfX5o`0003Oooo]Z000eoookJPGo00001_oonfX5o`0005kooo]Z1?l0
0007oookJPCo00005OoonfX5o`0000cooo]Z2?oo0005o`0000Koo`001Ol0001NoookJPGo00001_oo
0004o`0000Woo`009OoonfX5o`0000Oooo]Z1Ol0001NoookJPCo00001_oonfX4o`0003Sooo]Z000e
oookJPGo00001_oonfX5o`0005kooo]Z1?l00006oookJPGo00005OoonfX5o`0000cooo]Z2?oo0005
o`0000Koo`001Ol0001OoookJPCo00001Ooo0005o`0000Soo`009ooonfX5o`0000Gooo]Z1Ol0001O
oookJPCo00001_oonfX4o`0003Sooo]Z000foookJPCo00001_oonfX5o`0005kooo]Z1Ol00005oook
JPGo00005OoonfX5o`0000gooo]Z2?oo0004o`0000Koo`001?l0001PoookJPCo00001Ooo0005o`00
00Soo`009ooonfX5o`0000Gooo]Z1Ol0001OoookJPGo00001OoonfX4o`0003Sooo]Z000foookJPCo
00001OoonfX5o`0005oooo]Z1Ol00005oookJPGo00005OoonfX5o`0000gooo]Z2?oo0005o`0000Go
o`001?l0001PoookJPGo00001?oo0005o`0000Soo`009ooonfX5o`0000Gooo]Z1Ol0001OoookJPGo
00001?oonfX5o`0003Sooo]Z000foookJPGo00001?oonfX5o`0005oooo]Z1Ol00005oookJPCo0000
5_oonfX5o`0000gooo]Z2?oo0005o`0000Goo`001?l0001PoookJPGo00001?oo0004o`0000Woo`00
:?oonfX4o`0000Gooo]Z1?l0001PoookJPGo00001?oonfX5o`0003Sooo]Z000foookJPGo00001?oo
nfX5o`0005cooo]Z1?l007l5o`0000?o001o00?ooo]Zo`000?l000000_l00005o`00O`?ooo]Z1Ol0
07l9oookJPGo00003_oonfX7ool000Ko00000ooo0005o`00063ooo]Z1Ol00004ool000Co00002?oo
000YoookJPCo00001?oonfX5o`00067ooo]Z1?l00004oookJPGo0000>?oonfX003Kooo]Z1_l00002
oookJPGo0000G?oonfX5o`00O`Go00000ol007l5o`0000Go001o0_oonfX7o`00O`Sooo]Z1Ol0000>
oookJPSoo`001Ol00003ool000Go0000HOoonfX4o`0000?oo`001Ol00008ool002Wooo]Z1?l00004
oookJPGo0000HOoonfX5o`0000?ooo]Z1?l0000ioookJP00=ooonfX5o`0000;ooo]Z1Ol0001Loook
JP?o001o00?ooo]Zo`00Ool000001?l00003o`00O`Go00001_oonfX4o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z1Ol0000>oookJPSoo`001Ol00003ool000Go0000HOoonfX5o`0000;oo`001Ol00008
ool002Wooo]Z1Ol00003oookJPGo0000HOoonfX5o`0000;ooo]Z1Ol0000ioookJP00=ooonfX5o`00
00;ooo]Z1Ol0001KoookJP?o001o0ooonfX00ol007oo0000o`000003o`0000;ooo]Z1Ol000000ol0
07oooo]ZoookJP03oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000?oookJPSoo`001?l00003ool0
00Co0000H_oonfX5o`0000;oo`001Ol00007ool002[ooo]Z1Ol00002oookJPGo0000H_oonfX5o`00
00;ooo]Z1Ol0000ioookJP00>?oonfX4o`000003oookJ_l0003o000000?o0000G?oonfX3o`00O`?o
oo]Z00?o001oo`000?l000000ol000000ooonf[o0000o`000003o`0000Co001o2OoonfX3o`00O`Oo
oo]Z1ol0000=oookJPSoo`001Ol000000ooo003o0000o`000003o`0006;ooo]Z1Ol000000ooo003o
0000o`000003o`0000Soo`00:_oonfX6o`000003oookJ_l0003o000000?o0000HooonfX4o`000003
oookJ_l0003o000000Co0000>OoonfX003Sooo]Z2_l0001LoookJP?o001o0ooonfX00ol007oo0000
o`000003o`000003oookJ_l0003o000000?o000000?ooo]Zo`00Ool007l00_l007l8oookJP?o001o
1ooonfX5o`00013ooo]Z1ooo000;o`0006?ooo]Z2_l00008ool002_ooo]Z2ol0001SoookJP[o0000
>_oonfX003Sooo]Z2_l0001LoookJP?o001o0ooonfX2o`00O`[o00000_oonfX3o`00O`?ooo]Z0_l0
07l2oookJPCo001o1ooonfX5o`00013ooo]Z1ooo000;o`0006?ooo]Z2_l00007ool002cooo]Z2_l0
001ToookJP[o0000>_oonfX003Sooo]Z2Ol0001MoookJP?o001o0ooonfX2o`00O`Wo00001?oonfX3
o`00O`;ooo]Z1ol007l8oookJPGo00004OoonfX7ool000Wo0000I?oonfX9o`0000Ooo`00;_oonfX9
o`0006Cooo]Z2Ol0000koookJP00>OoonfX8o`0005gooo]Z0ol007l3oookJP;o001o2Ol000001?l0
07oooo]ZoookJ_oonfX3o`00O`;ooo]Z1_l007l9oookJPGo00004_oonfX6ool000So0000I_oonfX8
o`0000Koo`00;ooonfX9o`0006Gooo]Z2?l0000koookJP00>_oonfX6o`0005kooo]Z0ol007l3oook
JP?o001o1ol00002o`00O`?ooo]Z0ol007l2oookJP;o001o3OoonfX5o`0001Wooo]Z1ol0001Woook
JPKo0000=ooonfX7o`0006Oooo]Z1ol0000koookJP00>ooonfX4o`00063ooo]Z0ol007l01?oonf[o
001oo`00Ool007l2oookJPGo00001?l007l2oookJP?o001o0_oonfX2o`00O`gooo]Z1Ol0000Joook
JPGo0000J?oonfX5o`0003Wooo]Z1Ol0001XoookJPGo0000?OoonfX009oooo]Z1ol007l8oookJPOo
001o1?oonfX7o`00O`Oooo]Z1Ol0003ooookJWGooo]Z002PoookJPGo001o2_oonfX5o`00O`Gooo]Z
1ol007l7oookJPGo0000oooonfYeoookJP00aooonfX5o`000?oooo]ZMOoonfX00<Oooo]Z1Ol0003o
oookJWGooo]Z0037oookJPGo0000oooonfYeoookJP00aooonfX5o`000?oooo]ZMOoonfX00<Oooo]Z
1Ol0003ooookJWGooo]Z0037oookJPGo0000oooonfYeoookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-2.35721, -0.0213279, \
0.0116772, 0.000797515}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now the calculation is repeated but retaining 6 terms in the Fourier \
series representation and hopefully obtaining a more accurate representation \
of ",
  StyleBox["myfunction",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FourierPlot\  = 
      Plot[FourierTruncSeries[6, myfunction, x, 2], {x, \(-2\), 
          4}]\)], "Input",
  CellTags->"mmtag:17:Fourier_series__example_plot"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.15873 0.0249899 2.24154 [
[.02381 .01249 -13.4688 -20 ]
[.02381 .01249 13.4688 0 ]
[.18254 .01249 -13.4688 -20 ]
[.18254 .01249 13.4688 0 ]
[.5 .01249 -7 -20 ]
[.5 .01249 7 0 ]
[.65873 .01249 -7 -20 ]
[.65873 .01249 7 0 ]
[.81746 .01249 -7 -20 ]
[.81746 .01249 7 0 ]
[.97619 .01249 -7 -20 ]
[.97619 .01249 7 0 ]
[.32877 .13707 -39 -10 ]
[.32877 .13707 0 10 ]
[.32877 .24914 -29 -10 ]
[.32877 .24914 0 10 ]
[.32877 .36122 -39 -10 ]
[.32877 .36122 0 10 ]
[.32877 .4733 -29 -10 ]
[.32877 .4733 0 10 ]
[.32877 .58538 -39 -10 ]
[.32877 .58538 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .02499 m
.02381 .03124 L
s
gsave
.02381 .01249 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.18254 .02499 m
.18254 .03124 L
s
gsave
.18254 .01249 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .02499 m
.5 .03124 L
s
gsave
.5 .01249 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.65873 .02499 m
.65873 .03124 L
s
gsave
.65873 .01249 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 .02499 m
.81746 .03124 L
s
gsave
.81746 .01249 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 .02499 m
.97619 .03124 L
s
gsave
.97619 .01249 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .02499 m
.05556 .02874 L
s
.0873 .02499 m
.0873 .02874 L
s
.11905 .02499 m
.11905 .02874 L
s
.15079 .02499 m
.15079 .02874 L
s
.21429 .02499 m
.21429 .02874 L
s
.24603 .02499 m
.24603 .02874 L
s
.27778 .02499 m
.27778 .02874 L
s
.30952 .02499 m
.30952 .02874 L
s
.37302 .02499 m
.37302 .02874 L
s
.40476 .02499 m
.40476 .02874 L
s
.43651 .02499 m
.43651 .02874 L
s
.46825 .02499 m
.46825 .02874 L
s
.53175 .02499 m
.53175 .02874 L
s
.56349 .02499 m
.56349 .02874 L
s
.59524 .02499 m
.59524 .02874 L
s
.62698 .02499 m
.62698 .02874 L
s
.69048 .02499 m
.69048 .02874 L
s
.72222 .02499 m
.72222 .02874 L
s
.75397 .02499 m
.75397 .02874 L
s
.78571 .02499 m
.78571 .02874 L
s
.84921 .02499 m
.84921 .02874 L
s
.88095 .02499 m
.88095 .02874 L
s
.9127 .02499 m
.9127 .02874 L
s
.94444 .02499 m
.94444 .02874 L
s
.01 w
0 .02499 m
1 .02499 L
s
.25 Mabswid
.34127 .13707 m
.34752 .13707 L
s
gsave
.32877 .13707 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.34127 .24914 m
.34752 .24914 L
s
gsave
.32877 .24914 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.34127 .36122 m
.34752 .36122 L
s
gsave
.32877 .36122 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.34127 .4733 m
.34752 .4733 L
s
gsave
.32877 .4733 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.34127 .58538 m
.34752 .58538 L
s
gsave
.32877 .58538 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.34127 .04741 m
.34502 .04741 L
s
.34127 .06982 m
.34502 .06982 L
s
.34127 .09224 m
.34502 .09224 L
s
.34127 .11465 m
.34502 .11465 L
s
.34127 .15948 m
.34502 .15948 L
s
.34127 .1819 m
.34502 .1819 L
s
.34127 .20431 m
.34502 .20431 L
s
.34127 .22673 m
.34502 .22673 L
s
.34127 .27156 m
.34502 .27156 L
s
.34127 .29398 m
.34502 .29398 L
s
.34127 .31639 m
.34502 .31639 L
s
.34127 .33881 m
.34502 .33881 L
s
.34127 .38364 m
.34502 .38364 L
s
.34127 .40605 m
.34502 .40605 L
s
.34127 .42847 m
.34502 .42847 L
s
.34127 .45088 m
.34502 .45088 L
s
.34127 .49571 m
.34502 .49571 L
s
.34127 .51813 m
.34502 .51813 L
s
.34127 .54054 m
.34502 .54054 L
s
.34127 .56296 m
.34502 .56296 L
s
.34127 .00257 m
.34502 .00257 L
s
.34127 .60779 m
.34502 .60779 L
s
.01 w
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .16315 m
.04262 .37259 L
.04754 .45464 L
.0522 .52073 L
.05477 .54975 L
.05613 .56255 L
.05756 .57417 L
.05877 .58237 L
.0601 .58977 L
.06131 .59503 L
.06244 .59875 L
.06309 .60034 L
.06379 .60168 L
.06506 .60309 L
.06631 .60326 L
.06746 .60244 L
.06817 .60152 L
.06883 .60038 L
.07007 .5976 L
.07286 .58885 L
.08255 .54574 L
.09326 .50012 L
.09912 .47479 L
.10458 .44567 L
.11415 .37519 L
.12466 .27965 L
.13351 .20699 L
.14313 .15017 L
.15358 .10578 L
.16348 .06508 L
.16816 .04631 L
.17072 .03702 L
.17312 .02936 L
.17533 .0235 L
.17736 .01933 L
.17846 .0176 L
.17961 .01621 L
.18077 .01526 L
.18204 .01476 L
.18336 .01483 L
.18458 .01544 L
.18521 .01596 L
.18591 .01669 L
.18732 .01867 L
.18857 .02093 L
.1899 .02387 L
.19231 .03041 L
.20165 .0653 L
.21252 .10989 L
.2226 .15334 L
Mistroke
.22751 .18014 L
.23273 .21544 L
.24377 .31045 L
.25425 .40244 L
.26388 .4645 L
.26889 .48794 L
.27419 .50977 L
.28533 .55881 L
.28998 .57991 L
.29254 .58998 L
.29496 .59747 L
.29633 .60053 L
.2971 .60179 L
.29782 .60264 L
.29908 .60332 L
.29972 .60323 L
.30042 .60278 L
.30168 .60098 L
.3024 .59938 L
.30305 .59753 L
.30425 .59311 L
.30551 .58701 L
.30809 .56974 L
.31053 .54751 L
.31508 .49145 L
.32529 .32424 L
.32958 .25626 L
.33193 .22459 L
.33412 .20001 L
.33649 .17994 L
.33774 .17234 L
.33845 .16905 L
.33909 .16668 L
.34022 .16398 L
.34144 .16318 L
.3426 .16447 L
.34367 .16744 L
.34485 .1726 L
.34608 .18015 L
.34829 .19875 L
.35068 .22537 L
.35328 .26101 L
.36231 .41071 L
.36747 .49156 L
.3703 .52853 L
.37298 .55701 L
.37547 .57737 L
.37688 .58618 L
.37818 .59262 L
.37927 .59681 L
Mistroke
.38047 .60017 L
.38173 .60236 L
.38291 .60326 L
.38415 .60308 L
.38485 .60252 L
.38548 .60173 L
.38671 .59952 L
.38787 .5967 L
.39048 .58824 L
.3933 .57674 L
.40317 .53154 L
.41275 .49173 L
.4217 .44771 L
.42629 .41747 L
.43121 .3786 L
.44165 .28389 L
.44696 .23774 L
.4526 .19568 L
.46272 .14029 L
.4729 .09827 L
.48398 .05271 L
.48858 .03564 L
.491 .02815 L
.49354 .02182 L
.4949 .01919 L
.49562 .01803 L
.49639 .01698 L
.49709 .01619 L
.49774 .01561 L
.49899 .01489 L
.50025 .01473 L
.50096 .01488 L
.50162 .01517 L
.50283 .01611 L
.5041 .01763 L
.50531 .01957 L
.50664 .02221 L
.50904 .02827 L
.51355 .04317 L
.52369 .08435 L
.53313 .12262 L
.54201 .16333 L
.54699 .19292 L
.55236 .23227 L
.56174 .31509 L
.57175 .40276 L
.57705 .44009 L
.58273 .47145 L
.59308 .51561 L
.60272 .55848 L
Mistroke
.60544 .57109 L
.60839 .58386 L
.611 .59336 L
.61242 .59748 L
.61312 .59916 L
.61376 .60047 L
.61495 .6023 L
.61624 .60326 L
.61691 .6033 L
.61764 .60297 L
.61834 .60228 L
.61898 .60129 L
.6202 .59844 L
.62131 .59471 L
.62259 .58899 L
.6238 .58217 L
.62621 .56435 L
.62845 .54263 L
.63356 .47667 L
.64387 .30563 L
.64845 .23669 L
.6507 .20923 L
.65278 .1889 L
.65394 .17997 L
.65518 .17248 L
.65641 .16714 L
.65712 .16508 L
.65778 .16383 L
.65893 .16318 L
.65997 .16431 L
.66113 .16742 L
.66234 .17278 L
.66357 .18036 L
.66491 .19091 L
.66734 .21574 L
.67188 .27824 L
.68207 .44847 L
.68671 .51563 L
.68925 .54521 L
.69163 .56747 L
.69365 .5821 L
.69469 .58807 L
.69582 .5934 L
.69706 .59785 L
.69823 .60082 L
.69938 .60258 L
.70044 .60328 L
.70173 .60301 L
.70238 .60245 L
.70309 .60152 L
Mistroke
.70435 .59914 L
.70553 .59618 L
.70818 .58734 L
.71102 .57556 L
.72099 .52997 L
.73066 .48983 L
.73961 .44503 L
.74455 .41159 L
.7498 .3689 L
.76088 .26802 L
.77057 .19228 L
.77602 .16035 L
.78101 .13663 L
.79051 .09768 L
.80051 .05644 L
.80474 .04018 L
.80925 .02601 L
.81058 .02275 L
.81184 .02013 L
.81307 .01805 L
.8142 .01657 L
.81527 .01555 L
.81641 .01491 L
.81755 .01472 L
.8188 .01503 L
.8201 .01593 L
.8213 .01727 L
.82262 .0193 L
.82402 .02205 L
.82638 .02792 L
.82898 .03599 L
.83827 .07239 L
.84917 .11685 L
.85395 .13678 L
.85918 .16178 L
.86858 .22249 L
.87849 .30856 L
.88941 .40427 L
.89934 .46724 L
.90416 .48943 L
.9094 .51096 L
.91891 .55255 L
.9242 .5769 L
.92709 .58865 L
.92851 .59352 L
.9298 .59728 L
.93098 .60001 L
.93211 .60191 L
.93329 .60307 L
.93458 .60325 L
Mistroke
.93591 .60214 L
.93665 .6009 L
.93732 .59938 L
.93862 .59528 L
.93985 .59 L
.94212 .57645 L
.94424 .55926 L
.94906 .50451 L
.95878 .3486 L
.9631 .2774 L
.96718 .22048 L
.96944 .1961 L
.97063 .18572 L
.9719 .17673 L
.97296 .1709 L
.97413 .16632 L
.97519 .1639 L
.97619 .16315 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP006ooonfX9o`00Oe;ooo]Z0ol007nUoook
JP?o001oD?oonfX9o`00Oe3ooo]Z1Ol007mEoookJP?o001o6OoonfX001_ooo]Z2Ol007mBoookJP?o
001oYOoonfX3o`00Oe3ooo]Z2Ol007m?oookJPOo001oE?oonfX3o`00OaWooo]Z000KoookJPCo001o
EooonfX3o`00OjGooo]Z0ol007m@oookJPCo001oDooonfX3o`00O`?ooo]Z0ol007mCoookJP?o001o
6OoonfX000oooo]Z2_l007l3oookJPCo001oA_oonfX:o`00O`Kooo]Z0ol007nUoookJP?o001oDOoo
nfX4o`00Oe;ooo]Z0ol007l3oookJP?o001oC_oonfX9o`00OaSooo]Z000?oookJP[o001o1?oonfX5
o`00OdCooo]Z2_l007l6oookJP?o001oYOoonfX3o`00Oe;ooo]Z1Ol007mFoookJP?o001oC_oonfX9
o`00OaSooo]Z000OoookJPCo001oDooonfX3o`00Odgooo]Z1Ol0001CoookJP?o001oE?oonfX4o`00
OeGooo]Z0ol007m>oookJP;o001o0ooonfX3o`00OaWooo]Z000PoookJP?o001oDooonfX3o`00Odgo
oo]Z1Ol0001CoookJP?o001oEOoonfX3o`00Oe?ooo]Z1?l007m@oookJP;o001o0_oonfX3o`00OaWo
oo]Z000QoookJP?o001oD_oonfX3o`00Odgooo]Z1Ol0001CoookJP?o001oE_oonfX3o`00Oe;ooo]Z
0ol007mAoookJP?o001o00Cooo]Zo`00Ool007oo001o6OoonfX001_ooo]Z0ol007l3oookJP?o001o
D_oonfX3o`00Odgooo]Z1Ol0001CoookJP?o001oD?oonfX3o`00O`?ooo]Z0ol007mDoookJP;o001o
DOoonfX2o`00O`04oookJ_l007oo001oo`00OaWooo]Z000KoookJP?o001o0ooonfX3o`00Odoooo]Z
1_l007m=oookJPGo0000D?oonfX6o`00Oe3ooo]Z0ol007l3oookJP?o001oC_oonfX3o`00O`?ooo]Z
0ol007mAoookJPGo001o6OoonfX001_ooo]Z1?l007l2oookJP?o001oCooonfX6o`00Odgooo]Z1Ol0
001@oookJPKo001oD?oonfX4o`00O`;ooo]Z0ol007m>oookJP?o001o0ooonfX3o`00Oe7ooo]Z1Ol0
07lIoookJP007?oonfX7o`00Oe;ooo]Z1?l007m=oookJPGo0000D_oonfX4o`00Oe7ooo]Z1ol007m@
oookJPOo001oDooonfX4o`00OaWooo]Z000MoookJPGo001oE?oonfX3o`00Odgooo]Z1Ol0001Coook
JP?o001oD_oonfX5o`00Oe;ooo]Z1Ol007mEoookJP?o001o6OoonfX00<Kooo]Z1Ol0003ooookJWKo
oo]Z001^oookJPKo0000D_oonfX5o`00057ooo]Z1_l0002XoookJPOo0000KooonfX006gooo]Z2?l0
001AoookJPGo0000D?oonfX8o`000:Kooo]Z2?l0001_oookJP00K?oonfX9o`00057ooo]Z1Ol0001?
oookJP[o0000YOoonfX9o`0006kooo]Z001/oookJP[o0000D?oonfX5o`0004oooo]Z2_l0002Toook
JP[o0000K_oonfX000_ooo]Zool0003oo`0002_o00003?oonfX000_ooo]Zool0003oo`0002_o0000
3?oonfX000_ooo]Zool0003oo`0002_o00003?oonfX000_ooo]Zool0003oo`0002_o00003?oonfX0
00_ooo]Zool0003oo`0002_o00003?oonfX001[ooo]Z00?o0000oookJ_oonfX0COoonfX5o`0000;o
oo]Z00?o0000oookJ_l000001?l0001>oookJPGo0000COoonfX4o`0000?ooo]Z00?o0000oookJ_oo
nfX01?l0001@oookJP03o`000?oonf[ooo]Z04gooo]Z1Ol00002oookJP03o`000?oonf[ooo]Z00Co
0000D?oonfX00ol0003ooo]ZoookJP0IoookJP006_oonfX00ol0003ooo]ZoookJP1<oookJPGo0000
0ooonfX00ol0003ooo]ZoookJP04o`0004kooo]Z1Ol0001<oookJPGo00000ooonfX00ol0003ooo]Z
oookJP05o`0004oooo]Z00?o0000oookJ_oonfX0COoonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0
1Ol0001?oookJP03o`000?oonf[ooo]Z01Wooo]Z001YoookJPGo00001_oonfX5o`0004gooo]Z1Ol0
001<oookJPGo00001_oonfX5o`0009kooo]Z1Ol00006oookJPGo0000JooonfX006Sooo]Z1_l00006
oookJPGo0000COoonfX5o`0004cooo]Z1Ol00006oookJPGo0000W_oonfX5o`0000Kooo]Z1Ol0001[
oookJP00J?oonfX5o`0000Oooo]Z1Ol0001=oookJPGo0000C?oonfX4o`0000Sooo]Z1?l0002Noook
JPGo00001ooonfX4o`0006_ooo]Z001XoookJPGo00002?oonfX4o`0004gooo]Z1Ol0001;oookJPGo
00002?oonfX5o`0009cooo]Z1Ol00008oookJPGo0000J_oonfX006Oooo]Z1Ol00009oookJPGo0000
C?oonfX5o`0004_ooo]Z1Ol00008oookJPGo0000W?oonfX5o`0000Sooo]Z1Ol0001ZoookJP00Iooo
nfX5o`0000Wooo]Z1Ol0001<oookJPGo0000BooonfX5o`0000Sooo]Z1Ol0002LoookJPGo00002?oo
nfX5o`0006[ooo]Z001WoookJPGo00002OoonfX5o`0004cooo]Z1Ol0001:oookJPGo00002_oonfX4
o`0009_ooo]Z1Ol0000:oookJPGo0000JOoonfX006Oooo]Z1?l0000;oookJPCo0000C?oonfX5o`00
04[ooo]Z1Ol0000:oookJPGo0000V_oonfX5o`0000[ooo]Z1Ol0001YoookJP00IooonfX4o`0000_o
oo]Z1Ol0001;oookJPGo0000B_oonfX5o`0000[ooo]Z1Ol0002JoookJPGo00002_oonfX5o`0006Wo
oo]Z001VoookJPGo00002ooonfX5o`0004_ooo]Z1Ol00019oookJPGo00002ooonfX5o`0009[ooo]Z
1?l0000<oookJPGo0000J?oonfX006Kooo]Z1Ol0000;oookJPGo0000BooonfX5o`0004Wooo]Z1Ol0
000<oookJPCo0000V_oonfX4o`0000cooo]Z1Ol0001XoookJP00I_oonfX5o`0000cooo]Z1?l0001;
oookJPGo0000BOoonfX5o`0000cooo]Z1Ol0002HoookJPGo00003?oonfX5o`0006Sooo]Z001Uoook
JPGo00003OoonfX5o`0004[ooo]Z1Ol00019oookJPCo00003OoonfX5o`0009Sooo]Z1Ol0000=oook
JPCo0000J?oonfX006Gooo]Z1Ol0000=oookJPGo0000B_oonfX5o`0004Sooo]Z1Ol0000=oookJPGo
0000V?oonfX5o`0000gooo]Z1Ol0001WoookJP00IOoonfX5o`0000gooo]Z1Ol0001:oookJPGo0000
B?oonfX5o`0000kooo]Z1?l0002HoookJPCo00003_oonfX5o`0006Oooo]Z001ToookJPGo00003ooo
nfX4o`0004[ooo]Z1Ol00018oookJPGo00003_oonfX5o`0009Kooo]Z1Ol0000>oookJPGo0000Iooo
nfX006Cooo]Z1Ol0000?oookJPGo0000BOoonfX5o`0004Sooo]Z1?l0000?oookJPGo0000U_oonfX5
o`0000oooo]Z1Ol0001VoookJP00I?oonfX5o`0000oooo]Z1Ol00019oookJPGo0000AooonfX5o`00
00oooo]Z1Ol0002FoookJPGo00003ooonfX5o`0006Kooo]Z001ToookJPCo00004?oonfX5o`0004Wo
oo]Z1Ol00017oookJPGo00004?oonfX5o`0009Cooo]Z1Ol0000@oookJPGo0000I_oonfX006?ooo]Z
1Ol0000AoookJPCo0000BOoonfX5o`0004Oooo]Z1Ol0000@oookJPGo0000U?oonfX5o`00017ooo]Z
1Ol0001UoookJP00HooonfX5o`00017ooo]Z1Ol00018oookJPGo0000AooonfX4o`00017ooo]Z1Ol0
002DoookJPGo00004OoonfX5o`0006Gooo]Z001SoookJPGo00004OoonfX5o`0004Sooo]Z1Ol00016
oookJPGo00004_oonfX4o`0009Cooo]Z1?l0000BoookJPGo0000IOoonfX006?ooo]Z1?l0000Boook
JPGo0000B?oonfX5o`0004Kooo]Z1Ol0000BoookJPGo0000T_oonfX5o`0001?ooo]Z1?l0001Uoook
JP00HooonfX4o`0001?ooo]Z1?l00018oookJPGo0000A_oonfX5o`0001;ooo]Z1Ol0002BoookJPGo
00004ooonfX5o`0006Cooo]Z001RoookJPGo00004ooonfX5o`0004Oooo]Z1Ol00016oookJPCo0000
4ooonfX5o`0009;ooo]Z1Ol0000CoookJPGo0000I?oonfX006;ooo]Z1Ol0000CoookJPGo0000Aooo
nfX5o`0004Kooo]Z1?l0000DoookJPCo0000T_oonfX4o`0001Cooo]Z1Ol0001ToookJP00H_oonfX5
o`0001?ooo]Z1Ol00017oookJPGo0000AOoonfX5o`0001Cooo]Z1Ol0002@oookJPGo00005OoonfX4
o`0006Cooo]Z001RoookJPCo00005OoonfX4o`0004Oooo]Z1Ol00015oookJPGo00005?oonfX5o`00
093ooo]Z1Ol0000EoookJPGo0000HooonfX0067ooo]Z1Ol0000EoookJPGo0000A_oonfX5o`0004Go
oo]Z1Ol0000DoookJPGo0000T?oonfX5o`0001Gooo]Z1Ol0001SoookJP00HOoonfX5o`0001Gooo]Z
1Ol00016oookJPGo0000AOoonfX4o`0001Kooo]Z1?l0002?oookJPGo00005_oonfX5o`0006?ooo]Z
001QoookJPGo00005OoonfX5o`0004Kooo]Z1Ol00014oookJPGo00005_oonfX5o`0008kooo]Z1Ol0
000GoookJPCo0000HooonfX0067ooo]Z1?l0000GoookJPCo0000A_oonfX5o`0004Cooo]Z1Ol0000F
oookJPGo0000S_oonfX5o`0001Oooo]Z1Ol0001RoookJP00HOoonfX4o`0001Oooo]Z1Ol00015oook
JPGo0000A?oonfX5o`0001Kooo]Z1Ol0002>oookJPCo00006?oonfX5o`0006;ooo]Z001PoookJPGo
00005ooonfX5o`0004Gooo]Z1Ol00014oookJPCo00006?oonfX4o`0008gooo]Z1Ol0000HoookJPGo
0000H_oonfX0063ooo]Z1Ol0000GoookJPGo0000AOoonfX5o`0004?ooo]Z1Ol0000HoookJPGo0000
S?oonfX5o`0001Wooo]Z1?l0001RoookJP00H?oonfX5o`0001Sooo]Z1?l00015oookJPGo0000@ooo
nfX5o`0001Sooo]Z1Ol0002<oookJPGo00006OoonfX4o`0006;ooo]Z001PoookJPCo00006OoonfX5
o`0004Cooo]Z1Ol00013oookJPGo00006?oonfX5o`0008cooo]Z1?l0000JoookJPGo0000HOoonfX0
063ooo]Z1?l0000IoookJPGo0000A?oonfX5o`0004?ooo]Z1?l0000JoookJPCo0000RooonfX5o`00
01[ooo]Z1Ol0001QoookJP00GooonfX5o`0001Wooo]Z1Ol00014oookJPGo0000@_oonfX5o`0001[o
oo]Z1Ol0002:oookJPGo00006_oonfX5o`00067ooo]Z001OoookJPGo00006_oonfX4o`0004Cooo]Z
1Ol00012oookJPGo00006_oonfX5o`0008[ooo]Z1Ol0000KoookJPCo0000HOoonfX005oooo]Z1Ol0
000JoookJPGo0000@ooonfX5o`0004;ooo]Z1Ol0000JoookJPGo0000R_oonfX4o`0001cooo]Z1Ol0
001PoookJP00GooonfX4o`0001_ooo]Z1Ol00013oookJPGo0000@_oonfX4o`0001cooo]Z1?l0002:
oookJPCo00007?oonfX5o`00063ooo]Z001NoookJPGo00006ooonfX5o`0004?ooo]Z1Ol00012oook
JPCo00007?oonfX4o`0008Wooo]Z1Ol0000LoookJPGo0000H?oonfX005kooo]Z1Ol0000LoookJPCo
0000@ooonfX5o`00047ooo]Z1Ol0000LoookJPGo0000R?oonfX5o`0001gooo]Z1?l0001PoookJP00
G_oonfX5o`0001cooo]Z1Ol00012oookJPGo0000@OoonfX5o`0001cooo]Z1Ol00028oookJPGo0000
7OoonfX5o`0005oooo]Z001NoookJPCo00007OoonfX5o`0004;ooo]Z1Ol00011oookJPGo00007?oo
nfX5o`0008Sooo]Z1?l0000NoookJPGo0000GooonfX005gooo]Z1Ol0000MoookJPGo0000@_oonfX5
o`00047ooo]Z1?l0000NoookJPCo0000QooonfX5o`0001kooo]Z1Ol0001OoookJP00GOoonfX5o`00
01kooo]Z1?l00012oookJPGo0000@?oonfX5o`0001kooo]Z1Ol00026oookJPGo00007ooonfX4o`00
05oooo]Z001MoookJPGo00007_oonfX5o`00047ooo]Z1Ol00010oookJPGo00007_oonfX5o`0008Ko
oo]Z1Ol0000OoookJPCo0000GooonfX005gooo]Z1?l0000OoookJPGo0000@OoonfX5o`00043ooo]Z
1Ol0000NoookJPGo0000Q_oonfX4o`00023ooo]Z1Ol0001NoookJP00G?oonfX5o`0001oooo]Z1Ol0
0011oookJPGo0000@?oonfX4o`00023ooo]Z1?l00025oookJPGo00008?oonfX5o`0005kooo]Z001L
oookJPGo00008?oonfX4o`00047ooo]Z1Ol00010oookJPCo00008?oonfX5o`0008Cooo]Z1Ol0000P
oookJPGo0000G_oonfX005cooo]Z1Ol0000PoookJPGo0000@?oonfX5o`0003oooo]Z1Ol0000Poook
JPGo0000Q?oonfX5o`00027ooo]Z1?l0001NoookJP00G?oonfX4o`00027ooo]Z1Ol0000HoookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l5oookJPGo001o2_oonfX5o`0003oooo]Z1Ol0000PoookJPGo
0000Q?oonfX4o`0002;ooo]Z1?l0001NoookJP00FooonfX5o`00027ooo]Z1Ol0000GoookJPOo001o
0ooonfX3o`00O`;ooo]Z1ol007l3oookJPOo001o2OoonfX5o`0003oooo]Z1Ol0000QoookJPCo0000
Q?oonfX4o`0002;ooo]Z1Ol0001MoookJP00FooonfX5o`0002;ooo]Z1?l0000GoookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo
001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0003oooo]Z1?l0000RoookJPCo0000PooonfX5o`00
02;ooo]Z1Ol0001MoookJP00FooonfX5o`0002;ooo]Z1Ol0000EoookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Sooo]Z1Ol0000ooook
JPCo00008_oonfX5o`0008;ooo]Z1Ol0000RoookJPGo0000GOoonfX005_ooo]Z1?l0000SoookJPGo
00005OoonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z0ol007l8oookJPKo
0000?OoonfX5o`0002;ooo]Z1Ol00022oookJPGo00008ooonfX4o`0005gooo]Z001JoookJPGo0000
8ooonfX5o`0001Gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o
2?oonfX5o`0003kooo]Z1Ol0000RoookJPGo0000P_oonfX4o`0002Cooo]Z1?l0001MoookJP00F_oo
nfX5o`0002Cooo]Z1?l0000EoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oo
nfX2o`00O`;ooo]Z1?l007l8oookJPGo0000?_oonfX5o`0002?ooo]Z1?l00021oookJPGo00009?oo
nfX5o`0005cooo]Z001JoookJPGo00009?oonfX5o`0001Cooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0003kooo]Z1?l0000ToookJPGo0000P?oonfX5
o`0002Cooo]Z1Ol0001LoookJP00F_oonfX4o`0002Gooo]Z1Ol0000DoookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o0_oonfX6o`00O`[ooo]Z1Ol0000moookJPGo00009?oonfX5o`00
083ooo]Z1Ol0000ToookJPGo0000G?oonfX005Wooo]Z1Ol0000UoookJPGo00005?oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007l>oookJPGo0000?OoonfX5o`0002Co
oo]Z1Ol00020oookJPCo00009_oonfX4o`0005cooo]Z001IoookJPGo00009_oonfX4o`0001Gooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX2o`00
O`kooo]Z1Ol0000moookJPGo00009OoonfX4o`0007oooo]Z1Ol0000VoookJPGo0000FooonfX005Wo
oo]Z1Ol0000VoookJPGo00005?oonfX7o`00O`Sooo]Z1ol007l4oookJPOo001o2?oonfX5o`0003go
oo]Z1?l0000VoookJPGo0000O_oonfX5o`0002Kooo]Z1Ol0001KoookJP00FOoonfX4o`0002Oooo]Z
1Ol0000EoookJPGo001o2_oonfX5o`00O`Gooo]Z1ol007l8oookJPGo0000?OoonfX4o`0002Kooo]Z
1Ol0001noookJPGo00009_oonfX5o`0005_ooo]Z001IoookJPCo00009ooonfX5o`0003gooo]Z1Ol0
000loookJPGo00009_oonfX5o`0007kooo]Z1?l0000XoookJPCo0000FooonfX005Sooo]Z1Ol0000X
oookJPCo0000?OoonfX5o`0003cooo]Z1Ol0000WoookJPCo0000O_oonfX4o`0002Sooo]Z1?l0001K
oookJP00F?oonfX5o`0002Sooo]Z1Ol0000loookJPGo0000??oonfX5o`0002Oooo]Z1?l0001moook
JPGo0000:?oonfX5o`0005[ooo]Z001HoookJPGo0000:?oonfX5o`0003cooo]Z1Ol0000loookJPCo
0000:?oonfX5o`0007cooo]Z1Ol0000XoookJPGo0000F_oonfX001Sooo]Z1?l0000loookJPCo0000
:OoonfX5o`0003cooo]Z1Ol0000loookJPCo0000:?oonfX5o`0003cooo]Z1?l0000loookJPGo0000
:?oonfX5o`0003cooo]Z1?l0000JoookJP006?oonfX4o`0003cooo]Z1?l0000ZoookJPCo0000>ooo
nfX6o`0003_ooo]Z1Ol0000XoookJPGo0000>ooonfX6o`0003_ooo]Z1?l0000ZoookJPCo0000??oo
nfX4o`0001[ooo]Z000HoookJPCo0000??oonfX4o`0002[ooo]Z1?l0000koookJPKo0000>ooonfX5
o`0002Wooo]Z1?l0000koookJPKo0000>ooonfX4o`0002[ooo]Z1?l0000koookJPGo00006_oonfX0
01Sooo]Z1?l0000koookJPGo0000:_oonfX5o`0003Wooo]Z1ol0000koookJPGo0000:OoonfX4o`00
03_ooo]Z1_l0000joookJPGo0000:_oonfX5o`0003[ooo]Z1Ol0000JoookJP006?oonfX4o`0003_o
oo]Z1Ol0000ZoookJPGo0000>OoonfX7o`0003_ooo]Z1?l0000ZoookJPGo0000>OoonfX7o`0003[o
oo]Z1Ol0000ZoookJPGo0000>OoonfX6o`0001[ooo]Z000HoookJPCo0000>ooonfX5o`0002[ooo]Z
1Ol0000ioookJPSo0000>_oonfX4o`0002[ooo]Z1Ol0000ioookJPSo0000>OoonfX5o`0002[ooo]Z
1Ol0000ioookJPGo00006ooonfX001Sooo]Z1?l0000koookJPCo0000;?oonfX4o`0003Wooo]Z2?l0
000ioookJPGo0000:_oonfX5o`0003Wooo]Z2?l0000ioookJPCo0000;?oonfX4o`0003Wooo]Z1Ol0
000KoookJP006?oonfX5o`0003[ooo]Z1?l0000/oookJPCo0000>OoonfX8o`0003Wooo]Z1Ol0000[
oookJPCo0000>OoonfX8o`0003Wooo]Z1?l0000/oookJPCo0000>OoonfX4o`0001cooo]Z000Hoook
JPGo0000>_oonfX4o`0002cooo]Z1Ol0000goookJP[o0000>?oonfX5o`0002_ooo]Z1?l0000hoook
JP[o0000=ooonfX5o`0002cooo]Z1?l0000ioookJPCo00007?oonfX001Sooo]Z1Ol0000ioookJPGo
0000;?oonfX5o`0003Oooo]Z2_l0000hoookJPCo0000;?oonfX5o`0003Oooo]Z2_l0000goookJPGo
0000;?oonfX4o`0003Wooo]Z1?l0000LoookJP006OoonfX4o`0003Wooo]Z1Ol0000/oookJPGo0000
=ooonfX:o`0003Sooo]Z1?l0000/oookJPGo0000=ooonfX:o`0003Oooo]Z1Ol0000/oookJPGo0000
>?oonfX4o`0001cooo]Z000IoookJPCo0000>OoonfX5o`0002gooo]Z1?l0000goookJP[o0000=ooo
nfX5o`0002cooo]Z1Ol0000goookJPCo00000_oonfX4o`0003Oooo]Z1?l0000]oookJPGo0000=ooo
nfX5o`0001cooo]Z000IoookJPCo0000>OoonfX4o`0002kooo]Z1?l0000goookJP[o0000=ooonfX5
o`0002gooo]Z1?l0000goookJPCo00000_oonfX4o`0003Oooo]Z1?l0000]oookJPGo0000=ooonfX5
o`0001cooo]Z000IoookJPCo0000>OoonfX4o`0002kooo]Z1?l0000goookJP[o0000=ooonfX5o`00
02gooo]Z1?l0000goookJPCo00000_oonfX4o`0003Oooo]Z1?l0000^oookJPCo0000=ooonfX5o`00
01cooo]Z000IoookJPCo0000>OoonfX4o`0002kooo]Z1?l0000goookJP[o0000=ooonfX4o`0002ko
oo]Z1?l0000goookJPCo00000_oonfX4o`0003Kooo]Z1Ol0000^oookJPCo0000=ooonfX4o`0001go
oo]Z000IoookJPCo0000>OoonfX4o`0002kooo]Z1?l0000foookJP_o0000=ooonfX4o`0002kooo]Z
1Ol0000foookJPCo00000_oonfX4o`0003Kooo]Z1Ol0000^oookJPCo0000=ooonfX4o`0001gooo]Z
000IoookJPCo0000>?oonfX5o`0002kooo]Z1Ol0000eoookJPco0000=OoonfX5o`0002kooo]Z1Ol0
000foookJPCo00000_oonfX4o`0003Kooo]Z1Ol0000^oookJPCo0000=ooonfX4o`0001gooo]Z000I
oookJPCo0000>?oonfX5o`0002kooo]Z1Ol0000eoookJPco0000=OoonfX5o`0002kooo]Z1Ol0000f
oookJPCo00000_oonfX4o`0003Kooo]Z1?l0000_oookJPGo0000=_oonfX4o`0001gooo]Z000Ioook
JPGo0000=ooonfX5o`0002kooo]Z1Ol0000eoookJPco0000=OoonfX5o`0002oooo]Z1?l0000foook
JPCo00000_oonfX4o`0003Kooo]Z1?l0000_oookJPGo0000=_oonfX4o`0001gooo]Z000IoookJPGo
0000=ooonfX4o`00033ooo]Z1?l0000eoookJPco0000=OoonfX4o`00033ooo]Z1?l0000foookJPCo
00000_oonfX5o`0003Gooo]Z1?l0000_oookJPGo0000=_oonfX4o`0001gooo]Z000IoookJPGo0000
=ooonfX4o`00033ooo]Z1?l0000eoookJPco0000=OoonfX4o`00033ooo]Z1?l0000eoookJPGo0000
0_oonfX5o`0003Gooo]Z1?l0000`oookJPCo0000=_oonfX4o`0001gooo]Z000JoookJPCo0000=ooo
nfX4o`00033ooo]Z1?l0000eoookJPco0000=OoonfX4o`00033ooo]Z1Ol0000doookJPGo00000_oo
nfX5o`0003Cooo]Z1Ol0000`oookJPCo0000=_oonfX4o`0001gooo]Z000JoookJPCo0000=_oonfX5
o`00033ooo]Z1?l0000eoookJPco0000=OoonfX4o`00033ooo]Z1Ol0000doookJPGo00000ooonfX4
o`0003Cooo]Z1Ol0000`oookJPCo0000=OoonfX5o`0001gooo]Z000JoookJPCo0000=_oonfX5o`00
033ooo]Z1?l0000eoookJPco0000=?oonfX5o`00033ooo]Z1Ol0000doookJPCo00001?oonfX4o`00
03Cooo]Z1Ol0000`oookJPCo0000=OoonfX5o`0001gooo]Z000JoookJPCo0000=_oonfX5o`00033o
oo]Z1?l0000eoookJPco0000=?oonfX5o`00037ooo]Z1?l0000doookJPCo00001?oonfX4o`0003Co
oo]Z1?l0000aoookJPGo0000=?oonfX5o`0001gooo]Z000JoookJPCo0000=_oonfX4o`00037ooo]Z
1Ol0000doookJPco0000=?oonfX5o`00037ooo]Z1?l0000doookJPCo00001?oonfX4o`0003Cooo]Z
1?l0000aoookJPGo0000=?oonfX4o`0001kooo]Z000JoookJPCo0000=_oonfX4o`00037ooo]Z1Ol0
000doookJPco0000=?oonfX4o`0003;ooo]Z1?l0000doookJPCo00001?oonfX5o`0003?ooo]Z1?l0
000aoookJPGo0000=?oonfX4o`0001kooo]Z000JoookJPCo0000=_oonfX4o`00037ooo]Z1Ol0000d
oookJPco0000=?oonfX4o`0003;ooo]Z1?l0000doookJPCo00001?oonfX5o`0003?ooo]Z1?l0000b
oookJPCo0000=?oonfX4o`0001kooo]Z000JoookJPCo0000=_oonfX4o`0003;ooo]Z1?l0000coook
JPko0000<ooonfX4o`0003;ooo]Z1Ol0000coookJPCo00001?oonfX5o`0003?ooo]Z1?l0000boook
JPCo0000=?oonfX4o`0001kooo]Z000JoookJPCo0000=OoonfX5o`0003;ooo]Z1?l0000coookJPko
0000<ooonfX4o`0003;ooo]Z1Ol0000coookJPCo00001OoonfX4o`0003?ooo]Z1?l0000boookJPCo
0000<ooonfX5o`0001kooo]Z000JoookJPGo0000=?oonfX5o`0003;ooo]Z1?l0000coookJPko0000
<_oonfX5o`0003;ooo]Z1Ol0000boookJPGo00001OoonfX4o`0003;ooo]Z1Ol0000boookJPCo0000
<ooonfX5o`0001kooo]Z000JoookJPGo0000=?oonfX5o`0003;ooo]Z1?l0000coookJPCo000000?o
oo]Zo`000?l000001ol0000boookJPGo0000<ooonfX4o`0003;ooo]Z1Ol00005oookJPCo0000<_oo
nfX5o`0003;ooo]Z1Ol0000boookJPGo00007_oonfX001[ooo]Z1Ol0000doookJPCo0000<ooonfX4
o`0003?ooo]Z1?l000000ooonf[o0000o`000007o`0003;ooo]Z1Ol0000coookJPCo0000<_oonfX5
o`0000Gooo]Z1?l0000boookJPGo0000<_oonfX5o`0003;ooo]Z1?l0000OoookJP006ooonfX4o`00
03Cooo]Z1?l0000coookJPCo0000<ooonfX4o`000003oookJ_l0003o000000Oo0000<_oonfX4o`00
03Cooo]Z1?l0000boookJPCo00001_oonfX4o`0003;ooo]Z1?l0000coookJPGo0000<_oonfX4o`00
01oooo]Z000KoookJPCo0000=?oonfX4o`0003?ooo]Z1Ol0000boookJPCo000000?ooo]Zo`000?l0
00001ol0000boookJPCo0000=?oonfX4o`0003;ooo]Z1?l00006oookJPCo0000<_oonfX4o`0003Co
oo]Z1?l0000boookJPCo00007ooonfX001_ooo]Z1?l0000doookJPCo0000<ooonfX5o`0003;ooo]Z
1?l000000ooonf[o0000o`000007o`0003;ooo]Z1?l0000doookJPGo0000<OoonfX4o`0000Kooo]Z
1?l0000boookJPCo0000=?oonfX4o`0003;ooo]Z1?l0000OoookJP006ooonfX4o`0003Cooo]Z1?l0
000coookJPGo0000<_oonfX4o`000003oookJ_l0003o000000Oo0000<_oonfX4o`0003Cooo]Z1Ol0
000aoookJPCo00001_oonfX4o`0003;ooo]Z1?l0000doookJPCo0000<_oonfX4o`0001oooo]Z000K
oookJPCo0000<ooonfX5o`0003Cooo]Z1?l0000boookJPCo000000?ooo]Zo`000?l000001ol0000b
oookJPCo0000=?oonfX5o`00037ooo]Z1?l00006oookJPCo0000<_oonfX4o`0003Cooo]Z1?l0000b
oookJPCo00007ooonfX001_ooo]Z1?l0000coookJPGo0000=?oonfX4o`0003;ooo]Z1?l000000ooo
nf[o0000o`000007o`00037ooo]Z1Ol0000eoookJPCo0000<?oonfX5o`0000Kooo]Z1Ol0000`oook
JPGo0000=?oonfX5o`00037ooo]Z1?l0000OoookJP006ooonfX4o`0003?ooo]Z1Ol0000doookJPCo
0000<_oonfX4o`000003oookJ_l0003o000000Oo0000<OoonfX5o`0003Gooo]Z1?l0000`oookJPGo
00001_oonfX5o`00033ooo]Z1Ol0000doookJPGo0000<OoonfX4o`0001oooo]Z000KoookJPCo0000
<ooonfX4o`0003Gooo]Z1?l0000boookJPCo000000?ooo]Zo`000?l000002?l0000`oookJPGo0000
=OoonfX4o`00033ooo]Z1Ol00006oookJPGo0000<?oonfX5o`0003Cooo]Z1Ol0000aoookJPCo0000
7ooonfX001_ooo]Z1Ol0000boookJPCo0000=OoonfX4o`0003;ooo]Z1?l000000ooonf[o0000o`00
0008o`00033ooo]Z1?l0000foookJPCo0000<?oonfX4o`0000Sooo]Z1?l0000`oookJPCo0000=_oo
nfX4o`00033ooo]Z1Ol0000OoookJP006ooonfX5o`0003;ooo]Z1?l0000eoookJPCo0000<_oonfX4
o`000003oookJ_l0003o000000So0000<?oonfX4o`0003Kooo]Z1?l0000`oookJPCo00002?oonfX4
o`00033ooo]Z1?l0000foookJPCo0000<?oonfX5o`0001oooo]Z000KoookJPGo0000<_oonfX4o`00
03Gooo]Z1Ol0000`oookJPGo000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000002o`00
033ooo]Z1?l0000foookJPCo0000<?oonfX4o`0000Sooo]Z1?l0000`oookJPCo0000=_oonfX4o`00
033ooo]Z1Ol0000OoookJP007?oonfX4o`0003;ooo]Z1?l0000eoookJPGo00006?oonfX5o`00O`Co
oo]Z0ol007l5oookJP?o001o1?oonfX5o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l0
00000_l0000`oookJPCo0000=_oonfX5o`0002oooo]Z1?l00008oookJPCo0000<?oonfX4o`0003Ko
oo]Z1?l0000`oookJPCo00008?oonfX001cooo]Z1?l0000aoookJPGo0000=OoonfX5o`0001Oooo]Z
1ol007l3oookJP?o001o1OoonfX3o`00O`Cooo]Z1Ol000000ooonf[o0000o`000003o`000003oook
J_l0003o000000;o0000<?oonfX4o`0003Kooo]Z1Ol0000_oookJPCo00002?oonfX4o`00033ooo]Z
1?l0000foookJPCo0000<?oonfX4o`00023ooo]Z000LoookJPCo0000<OoonfX5o`0003Kooo]Z1?l0
000GoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol007l4oookJPCo0000
0_oonfX5o`000003oookJ_l0003o000000;o0000;ooonfX5o`0003Kooo]Z1Ol0000_oookJPCo0000
2?oonfX4o`0002oooo]Z1Ol0000foookJPGo0000;ooonfX4o`00023ooo]Z000LoookJPCo0000<Ooo
nfX5o`0003Kooo]Z1?l0000FoookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJPCo00000_oo
nfX5o`000003oookJ_l0003o000000;o0000;ooonfX5o`0003Oooo]Z1?l0000_oookJPCo00002?oo
nfX4o`0002oooo]Z1Ol0000foookJPGo0000;ooonfX4o`00023ooo]Z000LoookJPCo0000<OoonfX4
o`0003Oooo]Z1?l0000FoookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJPCo00000_oonfX:
o`0002oooo]Z1Ol0000goookJPCo0000;ooonfX4o`0000Sooo]Z1?l0000_oookJPGo0000=_oonfX5
o`0002oooo]Z1?l0000PoookJP007?oonfX4o`00037ooo]Z1?l0000goookJPCo00005_oonfX3o`00
O`?ooo]Z0ol007l:oookJP?o001o1?oonfX4o`0000;ooo]Z1Ol000000ooonf[o0000o`000002o`00
02oooo]Z1?l0000hoookJPCo0000;ooonfX4o`0000Sooo]Z1?l0000_oookJPCo0000>?oonfX4o`00
02oooo]Z1?l0000PoookJP007?oonfX4o`00037ooo]Z1?l0000goookJPCo00005_oonfX3o`00O`?o
oo]Z0ol007l:oookJP?o001o1?oonfX4o`0000;ooo]Z1Ol000000ooonf[o0000o`000003o`0002ko
oo]Z1?l0000hoookJPCo0000;ooonfX4o`0000Sooo]Z1?l0000_oookJPCo0000>?oonfX4o`0002oo
oo]Z1?l0000PoookJP007?oonfX4o`00037ooo]Z1?l0000goookJPCo00005_oonfX3o`00O`?ooo]Z
0ol007l:oookJP?o001o1?oonfX4o`0000;ooo]Z1Ol000000ooonf[o0000o`000003o`0002kooo]Z
1?l0000hoookJPCo0000;_oonfX5o`0000Sooo]Z1?l0000_oookJPCo0000>?oonfX4o`0002oooo]Z
1?l0000PoookJP007?oonfX4o`00037ooo]Z1?l0000goookJPGo00005OoonfX3o`00O`?ooo]Z0ol0
07l:oookJP?o001o1?oonfX4o`0000;ooo]Z1Ol000000ooonf[o0000o`000003o`0002kooo]Z1?l0
000hoookJPCo0000;_oonfX5o`0000Sooo]Z1?l0000_oookJPCo0000>?oonfX4o`0002oooo]Z1?l0
000PoookJP007?oonfX5o`0002oooo]Z1Ol0000goookJPGo00005OoonfX3o`00O`?ooo]Z0ol007l7
oookJPKo001o1?oonfX4o`0000;ooo]Z1Ol00002oookJPCo0000;_oonfX4o`0003Sooo]Z1Ol0000]
oookJPGo00002?oonfX4o`0002oooo]Z1?l0000hoookJPCo0000;ooonfX4o`00023ooo]Z000Loook
JPGo0000;ooonfX5o`0003Oooo]Z1Ol0000FoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX6
o`00O`Cooo]Z1?l00002oookJPGo00000_oonfX4o`0002gooo]Z1Ol0000hoookJPGo0000;OoonfX4
o`0000Wooo]Z1?l0000_oookJPCo0000>?oonfX5o`0002kooo]Z1?l0000PoookJP007?oonfX5o`00
02oooo]Z1Ol0000hoookJPCo00005_oonfX7o`00O`[ooo]Z1?l007l4oookJPCo00000_oonfX5o`00
00;ooo]Z1?l0000]oookJPGo0000>?oonfX5o`0002gooo]Z1?l00009oookJPGo0000;OoonfX5o`00
03Sooo]Z1Ol0000^oookJPCo00008?oonfX001gooo]Z1?l0000_oookJPCo0000>OoonfX4o`0001Oo
oo]Z1Ol007l<oookJP?o001o1?oonfX4o`0000;ooo]Z1Ol00002oookJPCo0000;OoonfX5o`0003Wo
oo]Z1?l0000]oookJPCo00002OoonfX5o`0002gooo]Z1Ol0000hoookJPGo0000;OoonfX5o`00023o
oo]Z000MoookJPCo0000;ooonfX4o`0003Wooo]Z1?l0000_oookJPCo00000_oonfX5o`0000;ooo]Z
1?l0000]oookJPCo0000>_oonfX4o`0002gooo]Z1?l00009oookJPGo0000;OoonfX5o`0003Wooo]Z
1?l0000]oookJPGo00008?oonfX001gooo]Z1?l0000_oookJPCo0000>OoonfX4o`0002kooo]Z1Ol0
0002oookJPGo00000_oonfX4o`0002gooo]Z1?l0000joookJPCo0000;OoonfX4o`0000[ooo]Z1?l0
000]oookJPCo0000>_oonfX4o`0002gooo]Z1Ol0000PoookJP007OoonfX4o`0002oooo]Z1?l0000i
oookJPCo0000;_oonfX5o`0000;ooo]Z1Ol00002oookJPCo0000;OoonfX4o`0003[ooo]Z1?l0000]
oookJPCo00002_oonfX4o`0002gooo]Z1?l0000joookJPCo0000;OoonfX4o`00027ooo]Z000Moook
JPCo0000;ooonfX4o`0003Wooo]Z1Ol0000]oookJPGo00000_oonfX5o`0000;ooo]Z1?l0000]oook
JPCo0000>_oonfX4o`0002gooo]Z1?l0000:oookJPCo0000;OoonfX4o`0003[ooo]Z1?l0000]oook
JPCo00008OoonfX001gooo]Z1?l0000^oookJPGo0000>OoonfX5o`0002gooo]Z1?l00003oookJPGo
00000_oonfX4o`0002gooo]Z1?l0000joookJPCo0000;OoonfX4o`0000[ooo]Z1?l0000]oookJPCo
0000>_oonfX5o`0002cooo]Z1?l0000QoookJP007OoonfX4o`0002kooo]Z1Ol0000ioookJPGo0000
;OoonfX4o`0000?ooo]Z1Ol00002oookJPCo0000;OoonfX4o`0003[ooo]Z1Ol0000/oookJPCo0000
2_oonfX4o`0002gooo]Z1?l0000joookJPGo0000;?oonfX4o`00027ooo]Z000MoookJPCo0000;_oo
nfX5o`0003[ooo]Z1?l0000]oookJPCo00000ooonfX5o`0000;ooo]Z1?l0000/oookJPGo0000>_oo
nfX5o`0002cooo]Z1?l0000:oookJPCo0000;OoonfX4o`0003[ooo]Z1Ol0000/oookJPCo00008Ooo
nfX001gooo]Z1Ol0000]oookJPCo0000>ooonfX4o`0002gooo]Z1?l00003oookJPGo00000_oonfX4
o`0002cooo]Z1Ol0000joookJPGo0000;?oonfX4o`0000[ooo]Z1?l0000/oookJPGo0000>ooonfX4
o`0002cooo]Z1?l0000QoookJP007OoonfX5o`0002gooo]Z1?l0000koookJPCo0000;OoonfX4o`00
00?ooo]Z1Ol00002oookJPGo0000:ooonfX5o`0003_ooo]Z1?l0000/oookJPCo00002_oonfX4o`00
02cooo]Z1Ol0000koookJPCo0000;?oonfX4o`00027ooo]Z000MoookJPGo0000;OoonfX4o`0003_o
oo]Z1?l0000]oookJPCo00000ooonfX5o`0000;ooo]Z1Ol0000[oookJPCo0000??oonfX4o`0002co
oo]Z1?l0000:oookJPCo0000;?oonfX5o`0003_ooo]Z1?l0000/oookJPCo00008OoonfX001kooo]Z
1?l0000]oookJPCo0000>ooonfX4o`0002gooo]Z1?l00003oookJPGo00000_oonfX5o`0002_ooo]Z
1?l0000loookJPCo0000;?oonfX4o`0000[ooo]Z1?l0000/oookJPCo0000??oonfX4o`0002cooo]Z
1?l0000QoookJP007_oonfX4o`0002gooo]Z1?l0000koookJPCo0000;OoonfX4o`0000?ooo]Z1Ol0
0003oookJPCo0000:ooonfX4o`0003cooo]Z1?l0000/oookJPCo00002_oonfX4o`0002cooo]Z1?l0
000loookJPCo0000;?oonfX4o`00027ooo]Z000NoookJPCo0000;?oonfX5o`0003_ooo]Z1Ol0000/
oookJPCo00000ooonfX5o`0000?ooo]Z1?l0000[oookJPCo0000??oonfX4o`0002cooo]Z1?l0000:
oookJPCo0000;?oonfX4o`0003cooo]Z1Ol0000[oookJPCo00008OoonfX001kooo]Z1?l0000/oook
JPGo0000>ooonfX5o`0002cooo]Z1?l00003oookJPGo00000ooonfX4o`0002_ooo]Z1?l0000loook
JPCo0000:ooonfX5o`0000[ooo]Z1?l0000/oookJPCo0000??oonfX5o`0002_ooo]Z1?l0000Qoook
JP007_oonfX4o`0002cooo]Z1Ol0000koookJPGo0000:ooonfX5o`0000?ooo]Z1Ol00003oookJPCo
0000:_oonfX5o`0003cooo]Z1Ol0000ZoookJPGo00002_oonfX4o`0002cooo]Z1?l0000loookJPGo
0000:ooonfX4o`00027ooo]Z000NoookJPCo0000;?oonfX4o`0003gooo]Z1?l0000[oookJPGo0000
0ooonfX5o`0000?ooo]Z1?l0000ZoookJPGo0000??oonfX5o`0002[ooo]Z1Ol0000:oookJPGo0000
:ooonfX4o`0003gooo]Z1?l0000[oookJPCo00008OoonfX001kooo]Z1?l0000/oookJPCo0000?Ooo
nfX4o`0002_ooo]Z1Ol00003oookJPGo00000ooonfX4o`0002[ooo]Z1Ol0000loookJPGo0000:_oo
nfX4o`0000_ooo]Z1Ol0000ZoookJPGo0000?OoonfX4o`0002_ooo]Z1?l0000QoookJP007_oonfX4
o`0002cooo]Z1?l0000moookJPCo0000:ooonfX4o`0000Cooo]Z1Ol00003oookJPCo0000:_oonfX4
o`0003kooo]Z1?l0000ZoookJPCo00002ooonfX5o`0002[ooo]Z1Ol0000moookJPCo0000:_oonfX5
o`00027ooo]Z000NoookJPCo0000;?oonfX4o`0003gooo]Z1?l0000[oookJPCo00001?oonfX5o`00
00?ooo]Z1?l0000ZoookJPCo0000?_oonfX4o`0002[ooo]Z1?l0000<oookJPCo0000:_oonfX5o`00
03gooo]Z1?l0000ZoookJPGo00008OoonfX001kooo]Z1Ol0000[oookJPCo0000?OoonfX4o`0002_o
oo]Z1?l00004oookJPGo00000ooonfX4o`0002[ooo]Z1?l0000noookJPCo0000:_oonfX4o`0000co
oo]Z1?l0000ZoookJPCo0000?_oonfX4o`0002[ooo]Z1Ol0000QoookJP007_oonfX5o`0002_ooo]Z
1?l0000moookJPCo0000:ooonfX4o`0000Cooo]Z1Ol00003oookJPCo0000:_oonfX4o`0003kooo]Z
1?l0000ZoookJPCo00003?oonfX4o`0002[ooo]Z1?l0000noookJPGo0000:OoonfX4o`0002;ooo]Z
000NoookJPGo0000:_oonfX5o`0003gooo]Z1Ol0000ZoookJPCo00001?oonfX5o`0000?ooo]Z1?l0
000ZoookJPCo0000?_oonfX4o`0002[ooo]Z1?l0000<oookJPCo0000:_oonfX4o`0003kooo]Z1Ol0
000YoookJPCo00008_oonfX001oooo]Z1?l0000ZoookJPGo0000?OoonfX5o`0002[ooo]Z1?l00004
oookJPGo00000ooonfX4o`0002[ooo]Z1?l0000noookJPCo0000:_oonfX4o`0000cooo]Z1?l0000Z
oookJPCo0000?_oonfX5o`0002Wooo]Z1?l0000RoookJP007ooonfX4o`0002[ooo]Z1Ol0000moook
JPGo0000:_oonfX4o`0000Cooo]Z1Ol00003oookJPCo0000:OoonfX5o`0003kooo]Z1Ol0000Yoook
JPCo00003?oonfX4o`0002[ooo]Z1?l0000ooookJPCo0000:OoonfX4o`0002;ooo]Z000OoookJPCo
0000:_oonfX4o`0003oooo]Z1?l0000ZoookJPCo00001?oonfX5o`0000?ooo]Z1?l0000YoookJPGo
0000?_oonfX5o`0002Wooo]Z1?l0000<oookJPCo0000:_oonfX4o`0003oooo]Z1?l0000YoookJPCo
00008_oonfX001oooo]Z1?l0000ZoookJPCo0000?ooonfX4o`0002[ooo]Z1?l00004oookJPGo0000
0ooonfX4o`0002Wooo]Z1Ol0000noookJPGo0000:OoonfX4o`0000cooo]Z1?l0000YoookJPGo0000
?ooonfX4o`0002Wooo]Z1?l0000RoookJP007ooonfX4o`0002[ooo]Z1?l0000ooookJPCo0000:_oo
nfX4o`0000Cooo]Z1Ol00003oookJPCo0000:OoonfX4o`00043ooo]Z1?l0000YoookJPCo00003?oo
nfX4o`0002Wooo]Z1Ol0000ooookJPCo0000:OoonfX4o`0002;ooo]Z000OoookJPCo0000:_oonfX4
o`0003oooo]Z1?l0000YoookJPGo00001?oonfX5o`0000?ooo]Z1?l0000YoookJPCo0000@?oonfX4
o`0002Wooo]Z1?l0000<oookJPCo0000:OoonfX5o`0003oooo]Z1?l0000YoookJPCo00008_oonfX0
01oooo]Z1?l0000ZoookJPCo0000?ooonfX4o`0002Wooo]Z1Ol00004oookJPGo00000ooonfX4o`00
02Wooo]Z1?l00010oookJPCo0000:OoonfX4o`0000cooo]Z1?l0000YoookJPCo0000@?oonfX5o`00
02Sooo]Z1?l0000RoookJP007ooonfX4o`0002[ooo]Z1?l0000ooookJPGo0000:?oonfX5o`0000Co
oo]Z1Ol00003oookJPGo0000:?oonfX4o`00043ooo]Z1?l0000YoookJPCo00003?oonfX4o`0002Wo
oo]Z1?l00010oookJPGo0000:?oonfX4o`0002;ooo]Z000OoookJPGo0000:?oonfX5o`0003oooo]Z
1Ol0000XoookJPCo00001OoonfX5o`0000?ooo]Z1Ol0000XoookJPCo0000@?oonfX4o`0002Sooo]Z
1Ol0000<oookJPGo0000:?oonfX4o`00043ooo]Z1Ol0000XoookJPCo00008_oonfX001oooo]Z1Ol0
000XoookJPGo0000?ooonfX5o`0002Sooo]Z1?l00005oookJPGo00000ooonfX5o`0002Sooo]Z1?l0
0010oookJPCo0000:?oonfX5o`0000cooo]Z1Ol0000XoookJPCo0000@OoonfX4o`0002Sooo]Z1?l0
000RoookJP007ooonfX5o`0002Sooo]Z1Ol00010oookJPCo0000:?oonfX4o`0000Gooo]Z1Ol00004
oookJPCo00009ooonfX5o`00043ooo]Z1?l0000XoookJPGo00003?oonfX5o`0002Sooo]Z1?l00011
oookJPCo0000:?oonfX4o`0002;ooo]Z000PoookJPCo0000:?oonfX4o`00047ooo]Z1?l0000Xoook
JPCo00001OoonfX5o`0000Cooo]Z1?l0000WoookJPGo0000@?oonfX5o`0002Oooo]Z1?l0000>oook
JPCo0000:?oonfX4o`00047ooo]Z1?l0000XoookJPCo00008_oonfX0023ooo]Z1?l0000XoookJPCo
0000@OoonfX4o`0002Sooo]Z1?l00005oookJPGo00001?oonfX4o`0002Oooo]Z1Ol00010oookJPGo
00009ooonfX4o`0000kooo]Z1?l0000WoookJPGo0000@OoonfX4o`0002Sooo]Z1?l0000RoookJP00
8?oonfX4o`0002Sooo]Z1?l00011oookJPCo0000:?oonfX4o`0000Gooo]Z1Ol00004oookJPCo0000
9ooonfX4o`00047ooo]Z1Ol0000WoookJPCo00003_oonfX4o`0002Oooo]Z1Ol00011oookJPCo0000
:?oonfX4o`0002;ooo]Z000PoookJPCo0000:?oonfX4o`00047ooo]Z1?l0000XoookJPCo00001Ooo
nfX5o`0000Cooo]Z1?l0000WoookJPCo0000@_oonfX4o`0002Oooo]Z1?l0000>oookJPCo00009ooo
nfX5o`00047ooo]Z1?l0000WoookJPGo00008_oonfX0023ooo]Z1?l0000XoookJPCo0000@OoonfX5
o`0002Oooo]Z1?l00005oookJPGo00001?oonfX4o`0002Oooo]Z1?l00012oookJPCo00009ooonfX4
o`0000kooo]Z1?l0000WoookJPCo0000@_oonfX5o`0002Kooo]Z1Ol0000RoookJP008?oonfX4o`00
02Sooo]Z1?l00011oookJPGo00009ooonfX4o`0000Gooo]Z1Ol00004oookJPCo00009ooonfX4o`00
04;ooo]Z1?l0000WoookJPCo00003_oonfX4o`0002Oooo]Z1?l00012oookJPGo00009_oonfX5o`00
02;ooo]Z000PoookJPCo00009ooonfX5o`00047ooo]Z1Ol0000WoookJPCo00001OoonfX5o`0000Co
oo]Z1?l0000WoookJPCo0000@_oonfX4o`0002Oooo]Z1?l0000>oookJPCo00009ooonfX4o`0004;o
oo]Z1Ol0000VoookJPCo00008ooonfX0023ooo]Z1?l0000WoookJPGo0000@_oonfX4o`0002Oooo]Z
1?l00005oookJPGo00001?oonfX4o`0002Kooo]Z1Ol00012oookJPCo00009ooonfX4o`0000kooo]Z
1?l0000WoookJPCo0000@ooonfX4o`0002Kooo]Z1?l0000SoookJP008?oonfX4o`0002Oooo]Z1Ol0
0012oookJPCo00009ooonfX4o`0000Gooo]Z1Ol00004oookJPCo00009_oonfX5o`0004;ooo]Z1?l0
000WoookJPCo00003_oonfX4o`0002Oooo]Z1?l00013oookJPCo00009_oonfX4o`0002?ooo]Z000P
oookJPGo00009_oonfX4o`0004?ooo]Z1?l0000VoookJPGo00001OoonfX5o`0000Cooo]Z1?l0000V
oookJPGo0000@_oonfX5o`0002Kooo]Z1?l0000>oookJPCo00009ooonfX4o`0004?ooo]Z1?l0000V
oookJPCo00008ooonfX0023ooo]Z1Ol0000VoookJPCo0000@ooonfX4o`0002Kooo]Z1Ol00005oook
JPGo00001?oonfX4o`0002Kooo]Z1?l00013oookJPGo00009_oonfX4o`0000kooo]Z1?l0000Voook
JPGo0000@ooonfX4o`0002Kooo]Z1?l0000SoookJP008?oonfX5o`0002Kooo]Z1?l00013oookJPCo
00009_oonfX5o`0000Gooo]Z1Ol00004oookJPCo00009_oonfX4o`0004?ooo]Z1Ol0000VoookJPCo
00003_oonfX4o`0002Kooo]Z1Ol00013oookJPCo00009_oonfX4o`0002?ooo]Z000QoookJPCo0000
9_oonfX4o`0004?ooo]Z1?l0000VoookJPCo00001_oonfX5o`0000Cooo]Z1?l0000VoookJPCo0000
A?oonfX4o`0002Gooo]Z1Ol0000>oookJPCo00009_oonfX5o`0004?ooo]Z1?l0000VoookJPCo0000
8ooonfX0027ooo]Z1?l0000VoookJPCo0000@ooonfX5o`0002Gooo]Z1?l00006oookJPGo00001?oo
nfX4o`0002Kooo]Z1?l00014oookJPCo00009OoonfX5o`0000kooo]Z1Ol0000UoookJPCo0000A?oo
nfX5o`0002Gooo]Z1?l0000SoookJP008OoonfX4o`0002Kooo]Z1?l00013oookJPGo00009OoonfX4
o`0000Kooo]Z1Ol00004oookJPCo00009_oonfX4o`0004Cooo]Z1?l0000UoookJPGo00003_oonfX5
o`0002Gooo]Z1?l00014oookJPGo00009OoonfX4o`0002?ooo]Z000QoookJPCo00009OoonfX5o`00
04?ooo]Z1Ol0000UoookJPCo00001_oonfX5o`0000Cooo]Z1?l0000VoookJPCo0000A?oonfX4o`00
02Gooo]Z1?l0000?oookJPGo00009OoonfX4o`0004Cooo]Z1Ol0000UoookJPCo00008ooonfX0027o
oo]Z1?l0000UoookJPGo0000A?oonfX4o`0000Oooo]Z1Ol007l4oookJP?o001o1OoonfX3o`00O`Go
oo]Z1Ol007l4o`0000Kooo]Z1Ol00004oookJPGo00009?oonfX5o`0004Cooo]Z1?l0000UoookJPCo
00004?oonfX4o`0002Gooo]Z1?l00015oookJPCo00009OoonfX4o`0002?ooo]Z000QoookJPCo0000
9OoonfX5o`0004Cooo]Z1?l00006oookJPOo001o0ooonfX3o`00O`Gooo]Z0ol007l4oookJPKo001o
1?l00006oookJPGo00001?oonfX5o`0002Cooo]Z1Ol00014oookJPCo00009OoonfX4o`00013ooo]Z
1?l0000UoookJPCo0000AOoonfX4o`0002Gooo]Z1?l0000SoookJP008OoonfX4o`0002Gooo]Z1?l0
0015oookJPCo00001_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP?o001o
0ooonfX4o`00O`03oookJ_l007oo001o00Co00001_oonfX5o`0000Cooo]Z1Ol0000ToookJPGo0000
A?oonfX4o`0002Gooo]Z1?l0000@oookJPCo00009OoonfX4o`0004Gooo]Z1?l0000UoookJPCo0000
8ooonfX0027ooo]Z1?l0000UoookJPCo0000AOoonfX4o`0000Gooo]Z0ol007l3oookJP?o001o2_oo
nfX3o`00O`?ooo]Z0ol007l3oookJP03o`00Ool0003o000000;o00001_oonfX5o`0000Gooo]Z1?l0
000ToookJPCo0000AOoonfX5o`0002Cooo]Z1?l0000@oookJPCo00009?oonfX5o`0004Gooo]Z1?l0
000UoookJPCo00008ooonfX0027ooo]Z1Ol0000ToookJPCo0000AOoonfX4o`0000Gooo]Z0ol007l3
oookJP?o001o2_oonfX3o`00O`Wooo]Z00?o001oo`000?l000000_l00006oookJPKo00001?oonfX4
o`0002Cooo]Z1?l00015oookJPGo00009?oonfX4o`00013ooo]Z1?l0000ToookJPGo0000AOoonfX4
o`0002Cooo]Z1Ol0000SoookJP008OoonfX5o`0002Cooo]Z1?l00015oookJPGo00001?oonfX3o`00
O`?ooo]Z0ol007l:oookJP?o001o2OoonfX00ol007oo0000o`000002o`0000Kooo]Z1Ol00005oook
JPCo00009?oonfX4o`0004Gooo]Z1Ol0000ToookJPCo00004?oonfX4o`0002Cooo]Z1Ol00015oook
JPGo00008ooonfX5o`0002?ooo]Z000QoookJPGo00009?oonfX4o`0004Gooo]Z1Ol00004oookJP?o
001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJP;o001o0_oonfX2o`00O`Co00001_oonfX5o`0000Go
oo]Z1?l0000ToookJPCo0000A_oonfX4o`0002Cooo]Z1?l0000@oookJPCo00009?oonfX4o`0004Ko
oo]Z1Ol0000SoookJPGo00008ooonfX002;ooo]Z1?l0000ToookJPCo0000AOoonfX5o`0000Cooo]Z
0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1_l007l4o`0000Kooo]Z1Ol00005oookJPCo0000
9?oonfX4o`0004Kooo]Z1?l0000ToookJPCo00004?oonfX4o`0002Cooo]Z1?l00016oookJPGo0000
8ooonfX4o`0002Cooo]Z000RoookJPCo00008ooonfX5o`0004Kooo]Z1?l00004oookJP?o001o0ooo
nfX3o`00O`[ooo]Z0ol007l4oookJPKo001o1?l00006oookJPGo00001OoonfX4o`0002Cooo]Z1?l0
0016oookJPCo00009?oonfX4o`00013ooo]Z1?l0000ToookJPCo0000AooonfX4o`0002?ooo]Z1?l0
000ToookJP008_oonfX4o`0002?ooo]Z1Ol00016oookJPCo00001?oonfX3o`00O`?ooo]Z0ol007l7
oookJPKo001o1?oonfX2o`00O`Cooo]Z1?l00006oookJPGo00001OoonfX4o`0002?ooo]Z1Ol00016
oookJPCo00009?oonfX4o`00013ooo]Z1?l0000ToookJPCo0000AooonfX4o`0002?ooo]Z1?l0000T
oookJP008_oonfX4o`0002?ooo]Z1Ol00016oookJPCo00001OoonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z1_l007l4oookJP;o001o1?oonfX4o`0000Kooo]Z1Ol00005oookJPCo00008ooonfX5
o`0004Kooo]Z1?l0000ToookJPCo00004?oonfX4o`0002Cooo]Z1?l00017oookJPCo00008ooonfX4
o`0002Cooo]Z000RoookJPCo00008ooonfX4o`0004Oooo]Z1?l00005oookJPOo001o2_oonfX4o`00
O`Gooo]Z1?l007l5o`0000Kooo]Z1Ol00005oookJPCo00008ooonfX5o`0004Kooo]Z1?l0000Toook
JPCo00004?oonfX4o`0002Cooo]Z1?l00017oookJPCo00008ooonfX4o`0002Cooo]Z000RoookJPCo
00008ooonfX4o`0004Oooo]Z1?l00006oookJPGo001o3?oonfX3o`00O`Gooo]Z1?l007l5o`0000Ko
oo]Z1Ol00005oookJPCo00008ooonfX4o`0004Oooo]Z1?l0000SoookJPGo00004?oonfX4o`0002?o
oo]Z1Ol00017oookJPCo00008ooonfX4o`0002Cooo]Z000RoookJPCo00008ooonfX4o`0004Oooo]Z
1Ol0000RoookJPGo00001_oonfX5o`0000Gooo]Z1?l0000SoookJPCo0000AooonfX5o`0002;ooo]Z
1Ol0000@oookJPGo00008_oonfX5o`0004Oooo]Z1?l0000SoookJPCo00009?oonfX002;ooo]Z1?l0
000SoookJPCo0000AooonfX5o`0002;ooo]Z1?l00007oookJPGo00001OoonfX4o`0002?ooo]Z1?l0
0017oookJPGo00008_oonfX5o`00013ooo]Z1Ol0000RoookJPGo0000AooonfX5o`0002;ooo]Z1?l0
000ToookJP008_oonfX4o`0002?ooo]Z1?l00017oookJPGo00008_oonfX4o`0000Oooo]Z1Ol00005
oookJPCo00008ooonfX4o`0004Oooo]Z1Ol0000RoookJPCo00004OoonfX5o`0002;ooo]Z1?l00018
oookJPGo00008_oonfX4o`0002Cooo]Z000RoookJPCo00008_oonfX5o`0004Sooo]Z1?l0000Roook
JPCo00001ooonfX5o`0000Gooo]Z1?l0000SoookJPCo0000B?oonfX4o`0002;ooo]Z1?l0000Boook
JPCo00008_oonfX4o`0004Sooo]Z1Ol0000RoookJPCo00009?oonfX002;ooo]Z1Ol0000QoookJPGo
0000B?oonfX4o`0002;ooo]Z1?l00007oookJPGo00001OoonfX4o`0002?ooo]Z1?l00018oookJPCo
00008_oonfX4o`0001;ooo]Z1?l0000RoookJPCo0000BOoonfX4o`0002;ooo]Z1?l0000ToookJP00
8_oonfX5o`00027ooo]Z1Ol00018oookJPCo00008_oonfX4o`0000Oooo]Z1Ol00005oookJPCo0000
8_oonfX5o`0004Sooo]Z1?l0000RoookJPCo00004_oonfX4o`0002;ooo]Z1?l00019oookJPCo0000
8OoonfX5o`0002Cooo]Z000RoookJPGo00008OoonfX4o`0004Wooo]Z1?l0000RoookJPCo00001ooo
nfX5o`0000Gooo]Z1?l0000RoookJPGo0000B?oonfX4o`0002;ooo]Z1?l0000BoookJPCo00008_oo
nfX4o`0004Wooo]Z1?l0000QoookJPGo00009?oonfX002?ooo]Z1?l0000QoookJPCo0000BOoonfX4
o`0002;ooo]Z1?l00007oookJPGo00001OoonfX4o`0002;ooo]Z1Ol00018oookJPCo00008_oonfX4
o`0001;ooo]Z1?l0000QoookJPGo0000BOoonfX4o`00027ooo]Z1Ol0000ToookJP008ooonfX4o`00
027ooo]Z1?l00019oookJPCo00008_oonfX4o`0000Oooo]Z1Ol00005oookJPGo00008OoonfX4o`00
04Wooo]Z1?l0000RoookJPCo00004_oonfX4o`00027ooo]Z1Ol00019oookJPCo00008OoonfX4o`00
02Gooo]Z000SoookJPCo00008OoonfX4o`0004Wooo]Z1Ol0000QoookJPCo00001ooonfX5o`0000Go
oo]Z1Ol0000QoookJPCo0000BOoonfX5o`00027ooo]Z1?l0000BoookJPCo00008OoonfX5o`0004Wo
oo]Z1?l0000QoookJPCo00009OoonfX002?ooo]Z1?l0000PoookJPGo0000BOoonfX5o`00027ooo]Z
1?l00007oookJPGo00001OoonfX5o`00027ooo]Z1?l00019oookJPGo00008OoonfX4o`0001;ooo]Z
1?l0000QoookJPCo0000B_oonfX5o`00023ooo]Z1?l0000UoookJP008ooonfX4o`00023ooo]Z1Ol0
0019oookJPGo00008OoonfX4o`0000Oooo]Z1Ol00006oookJPCo00008OoonfX4o`0004Wooo]Z1Ol0
000QoookJPCo00004_oonfX4o`00027ooo]Z1?l0001:oookJPGo00008?oonfX4o`0002Gooo]Z000S
oookJPCo00008?oonfX5o`0004[ooo]Z1?l0000QoookJPCo00001ooonfX5o`0000Kooo]Z1?l0000Q
oookJPCo0000B_oonfX4o`00027ooo]Z1?l0000BoookJPCo00008OoonfX4o`0004[ooo]Z1Ol0000P
oookJPCo00009OoonfX002?ooo]Z1?l0000PoookJPCo0000BooonfX4o`00027ooo]Z1?l00007oook
JPGo00001_oonfX4o`00027ooo]Z1?l0001:oookJPCo00008OoonfX4o`0001;ooo]Z1?l0000Qoook
JPCo0000BooonfX4o`00023ooo]Z1?l0000UoookJP008ooonfX4o`00023ooo]Z1?l0001;oookJPCo
00008OoonfX4o`0000Oooo]Z1Ol00006oookJPCo00008OoonfX4o`0004[ooo]Z1?l0000QoookJPCo
00004_oonfX4o`00027ooo]Z1?l0001;oookJPCo00008?oonfX4o`0002Gooo]Z000SoookJPCo0000
8?oonfX4o`0004_ooo]Z1?l0000QoookJPCo00001ooonfX5o`0000Kooo]Z1?l0000QoookJPCo0000
B_oonfX4o`00023ooo]Z1Ol0000BoookJPGo00007ooonfX5o`0004_ooo]Z1?l0000PoookJPCo0000
9OoonfX002?ooo]Z1?l0000PoookJPCo0000BooonfX5o`0001oooo]Z1Ol00007oookJPGo00001_oo
nfX4o`00023ooo]Z1Ol0001:oookJPCo00008?oonfX5o`0001;ooo]Z1Ol0000OoookJPGo0000Booo
nfX4o`00023ooo]Z1?l0000UoookJP008ooonfX4o`00023ooo]Z1?l0001;oookJPGo00007ooonfX5
o`0000Oooo]Z1Ol00006oookJPCo00008?oonfX5o`0004[ooo]Z1Ol0000OoookJPGo00004_oonfX5
o`0001oooo]Z1Ol0001;oookJPGo00007ooonfX4o`0002Gooo]Z000SoookJPCo00007ooonfX5o`00
04_ooo]Z1Ol0000OoookJPGo00001ooonfX5o`0000Kooo]Z1?l0000PoookJPGo0000B_oonfX5o`00
01oooo]Z1?l0000DoookJPCo00007ooonfX4o`0004cooo]Z1Ol0000OoookJPCo00009OoonfX002?o
oo]Z1Ol0000NoookJPGo0000C?oonfX4o`0001oooo]Z1?l00008oookJPGo00001_oonfX4o`00023o
oo]Z1?l0001;oookJPGo00007ooonfX4o`0001Cooo]Z1?l0000OoookJPCo0000C?oonfX5o`0001ko
oo]Z1Ol0000UoookJP008ooonfX5o`0001kooo]Z1Ol0001<oookJPCo00007ooonfX4o`0000Sooo]Z
1Ol00006oookJPCo00008?oonfX4o`0004cooo]Z1?l0000OoookJPCo00005?oonfX4o`0001oooo]Z
1?l0001=oookJPCo00007_oonfX5o`0002Gooo]Z000SoookJPGo00007_oonfX4o`0004gooo]Z1?l0
000OoookJPCo00002?oonfX5o`0000Kooo]Z1?l0000PoookJPCo0000C?oonfX4o`0001oooo]Z1?l0
000DoookJPCo00007ooonfX4o`0004gooo]Z1?l0000NoookJPGo00009OoonfX002Cooo]Z1?l0000N
oookJPCo0000COoonfX4o`0001oooo]Z1?l00008oookJPGo00001_oonfX4o`00023ooo]Z1?l0001<
oookJPCo00007ooonfX4o`0001Cooo]Z1?l0000NoookJPGo0000COoonfX4o`0001kooo]Z1?l0000V
oookJP009?oonfX4o`0001kooo]Z1?l0001=oookJPGo00007_oonfX4o`0000Sooo]Z1Ol00006oook
JPCo00008?oonfX4o`0004cooo]Z1?l0000OoookJPCo00005?oonfX4o`0001kooo]Z1Ol0001=oook
JPCo00007_oonfX4o`0002Kooo]Z000ToookJPCo00007_oonfX4o`0004gooo]Z1Ol0000NoookJPCo
00002?oonfX5o`0000Kooo]Z1?l0000PoookJPCo0000C?oonfX5o`0001kooo]Z1?l0000DoookJPCo
00007_oonfX5o`0004gooo]Z1Ol0000MoookJPCo00009_oonfX002Cooo]Z1?l0000NoookJPCo0000
COoonfX5o`0001kooo]Z1?l00008oookJPGo00001_oonfX5o`0001kooo]Z1Ol0001<oookJPGo0000
7_oonfX4o`0001Cooo]Z1?l0000NoookJPCo0000C_oonfX5o`0001gooo]Z1?l0000VoookJP009?oo
nfX4o`0001gooo]Z1Ol0001>oookJPCo00007_oonfX4o`0000Sooo]Z1Ol00006oookJPGo00007_oo
nfX5o`0004cooo]Z1Ol0000NoookJPCo00005?oonfX4o`0001kooo]Z1?l0001>oookJPGo00007Ooo
nfX4o`0002Kooo]Z000ToookJPCo00007OoonfX5o`0004kooo]Z1?l0000NoookJPCo00002?oonfX5
o`0000Kooo]Z1Ol0000NoookJPGo0000COoonfX4o`0001kooo]Z1?l0000DoookJPCo00007_oonfX4
o`0004oooo]Z1?l0000MoookJPCo00009_oonfX002Cooo]Z1?l0000MoookJPGo0000C_oonfX4o`00
01kooo]Z1?l00008oookJPGo00001ooonfX4o`0001kooo]Z1?l0001>oookJPCo00007_oonfX4o`00
01Cooo]Z1?l0000MoookJPGo0000CooonfX4o`0001gooo]Z1?l0000VoookJP009?oonfX4o`0001go
oo]Z1?l0001?oookJPCo00007_oonfX4o`0000Sooo]Z1Ol00007oookJPCo00007_oonfX4o`0004ko
oo]Z1?l0000NoookJPCo00005?oonfX4o`0001gooo]Z1Ol0001?oookJPCo00007OoonfX4o`0002Ko
oo]Z000ToookJPCo00007OoonfX4o`0004oooo]Z1Ol0000MoookJPCo00002?oonfX5o`0000Oooo]Z
1?l0000MoookJPGo0000C_oonfX4o`0001gooo]Z1Ol0000DoookJPCo00007OoonfX5o`0004oooo]Z
1?l0000MoookJPCo00009_oonfX002Cooo]Z1?l0000MoookJPCo0000CooonfX5o`0001gooo]Z1?l0
0008oookJPGo00001ooonfX4o`0001gooo]Z1Ol0001>oookJPGo00007?oonfX5o`0001Cooo]Z1Ol0
000LoookJPCo0000D?oonfX5o`0001cooo]Z1?l0000VoookJP009?oonfX4o`0001gooo]Z1?l0001?
oookJPGo00007OoonfX4o`0000Sooo]Z1Ol00007oookJPCo00007OoonfX5o`0004kooo]Z1Ol0000L
oookJPGo00005?oonfX5o`0001cooo]Z1?l0001@oookJPGo00007?oonfX4o`0002Kooo]Z000Toook
JPCo00007?oonfX5o`00053ooo]Z1?l0000MoookJPCo00002?oonfX5o`0000Oooo]Z1?l0000Moook
JPCo0000CooonfX5o`0001cooo]Z1?l0000EoookJPGo00007?oonfX4o`00053ooo]Z1Ol0000Loook
JPCo00009_oonfX002Cooo]Z1Ol0000KoookJPGo0000D?oonfX4o`0001gooo]Z1?l00008oookJPGo
00001ooonfX4o`0001gooo]Z1?l0001@oookJPCo00007?oonfX4o`0001Kooo]Z1?l0000KoookJPGo
0000DOoonfX4o`0001_ooo]Z1Ol0000VoookJP009?oonfX5o`0001_ooo]Z1Ol0001@oookJPCo0000
7?oonfX5o`0000Sooo]Z1Ol00007oookJPCo00007?oonfX5o`00053ooo]Z1?l0000LoookJPCo0000
5_oonfX4o`0001_ooo]Z1Ol0001AoookJPCo00006ooonfX5o`0002Kooo]Z000ToookJPGo00006ooo
nfX4o`00057ooo]Z1?l0000LoookJPGo00002?oonfX5o`0000Oooo]Z1?l0000LoookJPGo0000D?oo
nfX4o`0001cooo]Z1?l0000FoookJPCo00006ooonfX5o`00057ooo]Z1?l0000KoookJPGo00009_oo
nfX002Gooo]Z1?l0000KoookJPCo0000DOoonfX5o`0001_ooo]Z1Ol00008oookJPGo00001ooonfX4
o`0001cooo]Z1Ol0001@oookJPGo00006ooonfX4o`0001Kooo]Z1?l0000KoookJPCo0000D_oonfX4
o`0001_ooo]Z1?l0000WoookJP009OoonfX4o`0001_ooo]Z1?l0001AoookJPGo00006ooonfX4o`00
00Wooo]Z1Ol00007oookJPCo00007?oonfX4o`00057ooo]Z1Ol0000KoookJPCo00005_oonfX4o`00
01_ooo]Z1?l0001BoookJPGo00006_oonfX4o`0002Oooo]Z000UoookJPCo00006ooonfX4o`00057o
oo]Z1Ol0000KoookJPCo00002OoonfX5o`0000Oooo]Z1?l0000LoookJPCo0000DOoonfX5o`0001_o
oo]Z1?l0000FoookJPCo00006ooonfX4o`0005;ooo]Z1Ol0000JoookJPCo00009ooonfX002Gooo]Z
1?l0000JoookJPGo0000D_oonfX4o`0001_ooo]Z1?l00009oookJPGo00001ooonfX5o`0001[ooo]Z
1Ol0001BoookJPCo00006ooonfX4o`0001Kooo]Z1?l0000JoookJPGo0000D_oonfX5o`0001[ooo]Z
1?l0000WoookJP009OoonfX4o`0001[ooo]Z1Ol0001BoookJPCo00006ooonfX4o`0000Wooo]Z1Ol0
0007oookJPGo00006_oonfX5o`0005;ooo]Z1?l0000KoookJPCo00005_oonfX4o`0001[ooo]Z1Ol0
001CoookJPCo00006_oonfX4o`0002Oooo]Z000UoookJPCo00006_oonfX5o`0005;ooo]Z1?l0000K
oookJPCo00002OoonfX5o`0000Oooo]Z1Ol0000JoookJPGo0000D_oonfX5o`0001[ooo]Z1?l0000F
oookJPCo00006_oonfX5o`0005?ooo]Z1?l0000JoookJPCo00009ooonfX002Gooo]Z1?l0000Joook
JPCo0000DooonfX4o`0001_ooo]Z1?l00009oookJPGo00002?oonfX4o`0001[ooo]Z1?l0001Coook
JPGo00006_oonfX4o`0001Kooo]Z1?l0000JoookJPCo0000E?oonfX4o`0001[ooo]Z1?l0000Woook
JP009OoonfX4o`0001[ooo]Z1?l0001CoookJPGo00006_oonfX4o`0000Wooo]Z1Ol00008oookJPCo
00006_oonfX4o`0005?ooo]Z1Ol0000JoookJPCo00005_oonfX4o`0001[ooo]Z1?l0001DoookJPCo
00006_oonfX4o`0002Oooo]Z000UoookJPCo00006OoonfX5o`0005?ooo]Z1Ol0000JoookJPCo0000
2OoonfX5o`0000Sooo]Z1?l0000IoookJPGo0000E?oonfX4o`0001[ooo]Z1?l0000FoookJPCo0000
6_oonfX4o`0005Cooo]Z1Ol0000IoookJPCo00009ooonfX002Gooo]Z1?l0000IoookJPGo0000Dooo
nfX5o`0001[ooo]Z1?l00009oookJPGo00002?oonfX4o`0001Wooo]Z1Ol0001DoookJPCo00006Ooo
nfX5o`0001Kooo]Z1?l0000IoookJPGo0000E?oonfX5o`0001Wooo]Z1?l0000WoookJP009OoonfX4
o`0001Wooo]Z1Ol0001DoookJPCo00006_oonfX4o`0000Wooo]Z1Ol00008oookJPCo00006OoonfX5
o`0005Cooo]Z1?l0000IoookJPGo00005_oonfX4o`0001Wooo]Z1Ol0001DoookJPGo00006OoonfX4
o`0002Oooo]Z000UoookJPCo00006OoonfX4o`0005Gooo]Z1?l00009oookJPGo001o1?oonfX3o`00
O`03oookJ_l007oo001o00;o001o1?l000000ol007oooo]ZoookJP06oookJPGo00002?oonfX4o`00
01Wooo]Z1?l0001EoookJPGo00006?oonfX5o`0001Kooo]Z1Ol0000HoookJPGo0000EOoonfX4o`00
01Sooo]Z1Ol0000WoookJP009OoonfX4o`0001Wooo]Z1?l0001EoookJPCo00002?oonfX7o`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`Co000000?o001ooookJ_oonfX01_oonfX5o`0000So
oo]Z1?l0000IoookJPCo0000EOoonfX5o`0001Sooo]Z1?l0000GoookJPGo00006?oonfX4o`0005Ko
oo]Z1?l0000HoookJPGo00009ooonfX002Gooo]Z1?l0000HoookJPGo0000EOoonfX5o`0000Oooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l4o`0000Wo
oo]Z1Ol00008oookJPCo00006?oonfX5o`0005Gooo]Z1Ol0000HoookJPCo00005ooonfX5o`0001So
oo]Z1?l0001FoookJPCo00006?oonfX5o`0002Oooo]Z000UoookJPGo00005ooonfX5o`0005Gooo]Z
1Ol00006oookJP?o001o0ooonfX3o`00O`Oooo]Z0ol007l4o`0000Wooo]Z1Ol00008oookJPCo0000
6?oonfX5o`0005Kooo]Z1?l0000HoookJPCo00006?oonfX4o`0001Sooo]Z1?l0001FoookJPGo0000
5ooonfX4o`0002Sooo]Z000UoookJPGo00005ooonfX5o`0005Gooo]Z1Ol00006oookJP?o001o0ooo
nfX3o`00O`Sooo]Z0_l007l4o`0000Wooo]Z1_l00007oookJPCo00006?oonfX5o`0005Kooo]Z1?l0
000HoookJPCo00006?oonfX4o`0001Oooo]Z1Ol0001FoookJPGo00005ooonfX4o`0002Sooo]Z000U
oookJPGo00005ooonfX4o`0005Oooo]Z1?l00006oookJP?o001o0ooonfX3o`00O`Wooo]Z1Ol00009
oookJPGo00002?oonfX4o`0001Sooo]Z1?l0001GoookJPGo00005ooonfX4o`0001Sooo]Z1?l0000G
oookJPGo0000E_oonfX5o`0001Oooo]Z1?l0000XoookJP009_oonfX4o`0001Oooo]Z1?l0001Goook
JPGo00001OoonfX3o`00O`?ooo]Z0ol007l9oookJPGo00002OoonfX5o`0000Sooo]Z1?l0000Hoook
JPCo0000EooonfX5o`0001Oooo]Z1?l0000HoookJPCo00005ooonfX5o`0005Oooo]Z1?l0000Goook
JPCo0000:?oonfX002Kooo]Z1?l0000FoookJPGo0000EooonfX5o`0000Gooo]Z0ol007l3oookJP?o
001o2OoonfX5o`000003o`00Oooonf[ooo]Z00Kooo]Z1Ol00008oookJPGo00005_oonfX5o`0005Oo
oo]Z1Ol0000GoookJPCo00006?oonfX4o`0001Oooo]Z1?l0001HoookJPGo00005_oonfX4o`0002So
oo]Z000VoookJPCo00005_oonfX5o`0005Oooo]Z1Ol00005oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l4o`0000;o001o2?oonfX5o`0000Sooo]Z1Ol0000FoookJPGo0000F?oonfX4o`0001Oooo]Z
1?l0000HoookJPCo00005ooonfX4o`0005Sooo]Z1Ol0000FoookJPCo0000:?oonfX002Kooo]Z1?l0
000FoookJPGo0000F?oonfX4o`0000Gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`Co00000_l0
07l8oookJPGo00002?oonfX5o`0001Kooo]Z1Ol0001HoookJPGo00005_oonfX4o`0001Sooo]Z1?l0
000GoookJPCo0000F?oonfX5o`0001Kooo]Z1?l0000XoookJP009_oonfX4o`0001Kooo]Z1?l0001I
oookJPGo00001OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z0ol007l4o`0000;o001o2?oo
nfX5o`0000Wooo]Z1?l0000FoookJPCo0000FOoonfX5o`0001Kooo]Z1?l0000HoookJPCo00005_oo
nfX5o`0005Wooo]Z1?l0000FoookJPCo0000:?oonfX002Kooo]Z1?l0000FoookJPCo0000FOoonfX5
o`0000Gooo]Z1ol007l8oookJP;o001o1?l000000ol007oooo]ZoookJP07oookJPGo00002OoonfX4
o`0001Kooo]Z1?l0001IoookJPGo00005_oonfX4o`0001Sooo]Z1?l0000FoookJPGo0000FOoonfX5
o`0001Gooo]Z1?l0000XoookJP009_oonfX4o`0001Gooo]Z1Ol0001IoookJPGo00001_oonfX5o`00
O`[ooo]Z00?o001oo`000?l000000_l0000:oookJPGo00002OoonfX4o`0001Gooo]Z1Ol0001Joook
JPCo00005OoonfX5o`0001Sooo]Z1?l0000FoookJPGo0000FOoonfX5o`0001Gooo]Z1?l0000Xoook
JP009_oonfX4o`0001Gooo]Z1Ol0001JoookJPCo00005_oonfX4o`0000[ooo]Z1Ol00009oookJPCo
00005OoonfX5o`0005[ooo]Z1Ol0000DoookJPGo00006?oonfX4o`0001Kooo]Z1?l0001JoookJPGo
00005OoonfX4o`0002Sooo]Z000VoookJPCo00005OoonfX5o`0005[ooo]Z1Ol0000EoookJPCo0000
2_oonfX5o`0000Wooo]Z1?l0000EoookJPGo0000F_oonfX5o`0001Cooo]Z1Ol0000HoookJPCo0000
5_oonfX4o`0005_ooo]Z1?l0000DoookJPGo0000:?oonfX002Kooo]Z1?l0000EoookJPCo0000Fooo
nfX5o`0001Gooo]Z1?l0000:oookJPGo00002OoonfX4o`0001Gooo]Z1?l0001KoookJPGo00005?oo
nfX4o`0001Wooo]Z1?l0000EoookJPGo0000FooonfX5o`0001?ooo]Z1Ol0000XoookJP009_oonfX4
o`0001Gooo]Z1?l0001KoookJPGo00005OoonfX4o`0000[ooo]Z1Ol00009oookJPCo00005?oonfX5
o`0005cooo]Z1?l0000DoookJPCo00006OoonfX4o`0001Gooo]Z1Ol0001KoookJPGo00004ooonfX5
o`0002Sooo]Z000VoookJPCo00005?oonfX5o`0005cooo]Z1?l0000EoookJPCo00002_oonfX5o`00
00Wooo]Z1?l0000DoookJPGo0000G?oonfX4o`0001Cooo]Z1?l0000IoookJPCo00005OoonfX5o`00
05_ooo]Z1Ol0000CoookJPCo0000:OoonfX002Kooo]Z1?l0000DoookJPGo0000G?oonfX5o`0001Co
oo]Z1?l0000:oookJPGo00002OoonfX4o`0001Cooo]Z1Ol0001LoookJPGo00004ooonfX4o`0001Wo
oo]Z1?l0000DoookJPGo0000GOoonfX4o`0001?ooo]Z1?l0000YoookJP009_oonfX4o`0001Cooo]Z
1Ol0001LoookJPGo00004ooonfX5o`0000[ooo]Z1Ol00009oookJPGo00004ooonfX4o`0005gooo]Z
1Ol0000CoookJPCo00006OoonfX5o`0001?ooo]Z1Ol0001MoookJPGo00004_oonfX4o`0002Wooo]Z
000VoookJPCo00005?oonfX4o`0005gooo]Z1Ol0000CoookJPGo00002_oonfX5o`0000Wooo]Z1Ol0
000CoookJPCo0000GOoonfX5o`0001?ooo]Z1?l0000IoookJPGo00004ooonfX5o`0005gooo]Z1Ol0
000BoookJPCo0000:OoonfX002Kooo]Z1Ol0000BoookJPGo0000G_oonfX4o`0001?ooo]Z1Ol0000:
oookJPGo00002OoonfX5o`0001;ooo]Z1Ol0001NoookJPCo00004ooonfX4o`0001Wooo]Z1Ol0000C
oookJPCo0000G_oonfX5o`0001;ooo]Z1?l0000YoookJP009_oonfX5o`0001;ooo]Z1Ol0001Noook
JPGo00004_oonfX4o`0000_ooo]Z1Ol0000:oookJPCo00004_oonfX5o`0005kooo]Z1Ol0000Boook
JPCo00006_oonfX4o`0001;ooo]Z1Ol0001OoookJPCo00004_oonfX4o`0002Wooo]Z000VoookJPGo
00004_oonfX5o`0005kooo]Z1Ol0000BoookJPCo00002ooonfX5o`0000[ooo]Z1?l0000BoookJPGo
0000G_oonfX5o`0001;ooo]Z1?l0000JoookJPCo00004_oonfX5o`0005oooo]Z1Ol0000AoookJPCo
0000:OoonfX002Oooo]Z1?l0000BoookJPCo0000GooonfX5o`0001;ooo]Z1?l0000;oookJPGo0000
2_oonfX4o`0001;ooo]Z1?l0001OoookJPGo00004OoonfX5o`0001[ooo]Z1?l0000BoookJPGo0000
GooonfX5o`00017ooo]Z1?l0000YoookJP009ooonfX4o`00017ooo]Z1Ol0001PoookJPCo00004_oo
nfX4o`0000_ooo]Z1Ol0000:oookJPCo00004OoonfX5o`00063ooo]Z1?l0000AoookJPGo00006_oo
nfX4o`0001;ooo]Z1?l0001PoookJPGo00004OoonfX4o`0002Wooo]Z000WoookJPCo00004OoonfX5
o`00063ooo]Z1Ol0000AoookJPCo00002ooonfX5o`0000[ooo]Z1?l0000AoookJPGo0000H?oonfX5
o`00013ooo]Z1Ol0000JoookJPCo00004OoonfX5o`00067ooo]Z1?l0000AoookJPCo0000:OoonfX0
02Oooo]Z1?l0000AoookJPGo0000H?oonfX5o`00017ooo]Z1?l0000;oookJPGo00002_oonfX4o`00
017ooo]Z1Ol0001PoookJPGo00004?oonfX4o`0001_ooo]Z1?l0000AoookJPGo0000HOoonfX5o`00
013ooo]Z1?l0000YoookJP009ooonfX4o`00017ooo]Z1?l0001QoookJPGo00004OoonfX4o`0000_o
oo]Z1Ol0000:oookJPCo00004OoonfX4o`00067ooo]Z1Ol0000@oookJPCo00006ooonfX4o`00017o
oo]Z1Ol0001QoookJPGo00004?oonfX4o`0002Wooo]Z000WoookJPCo00004?oonfX5o`0006;ooo]Z
1?l0000@oookJPGo00002ooonfX5o`0000[ooo]Z1?l0000@oookJPGo0000H_oonfX4o`00013ooo]Z
1?l0000KoookJPCo00004?oonfX5o`0006;ooo]Z1Ol0000?oookJPGo0000:OoonfX002Oooo]Z1?l0
000@oookJPGo0000H_oonfX4o`00013ooo]Z1Ol0000;oookJPGo00002_oonfX5o`0000oooo]Z1Ol0
001RoookJPGo00003ooonfX4o`0001_ooo]Z1?l0000@oookJPGo0000HooonfX4o`0000oooo]Z1Ol0
000YoookJP009ooonfX4o`00013ooo]Z1Ol0001RoookJPGo00003ooonfX5o`0000_ooo]Z1Ol0000:
oookJPGo00003ooonfX5o`0006;ooo]Z1Ol0000?oookJPCo00006ooonfX4o`00013ooo]Z1Ol0001S
oookJPCo00003ooonfX5o`0002Wooo]Z000WoookJPCo00004?oonfX4o`0006?ooo]Z1Ol0000?oook
JPCo00003?oonfX5o`0000[ooo]Z1Ol0000?oookJPCo0000HooonfX5o`0000oooo]Z1?l0000Koook
JPGo00003ooonfX4o`0006Cooo]Z1Ol0000>oookJPCo0000:_oonfX002Oooo]Z1?l0000@oookJPCo
0000HooonfX5o`0000oooo]Z1?l0000<oookJPGo00002ooonfX4o`0000oooo]Z1?l0001ToookJPCo
00003ooonfX4o`0001_ooo]Z1Ol0000>oookJPGo0000I?oonfX5o`0000kooo]Z1?l0000ZoookJP00
9ooonfX5o`0000kooo]Z1Ol0001ToookJPCo00003ooonfX4o`0000cooo]Z1Ol0000;oookJPCo0000
3_oonfX5o`0006Cooo]Z1?l0000?oookJPCo00006ooonfX5o`0000kooo]Z1Ol0001ToookJPGo0000
3_oonfX4o`0002[ooo]Z000WoookJPGo00003_oonfX5o`0006Cooo]Z1Ol0000>oookJPCo00003?oo
nfX5o`0000_ooo]Z1?l0000>oookJPGo0000I?oonfX5o`0000kooo]Z1?l0000LoookJPCo00003_oo
nfX5o`0006Gooo]Z1?l0000>oookJPCo0000:_oonfX002Oooo]Z1Ol0000>oookJPGo0000I?oonfX5
o`0000kooo]Z1?l0000<oookJPGo00002ooonfX4o`0000kooo]Z1Ol0001ToookJPGo00003OoonfX5
o`0001cooo]Z1?l0000>oookJPCo0000I_oonfX5o`0000gooo]Z1?l0000ZoookJP00:?oonfX4o`00
00kooo]Z1?l0001UoookJPGo00003_oonfX4o`0000cooo]Z1Ol0000;oookJPCo00003_oonfX4o`00
06Gooo]Z1Ol0000=oookJPGo00007?oonfX4o`0000gooo]Z1Ol0001VoookJPGo00003OoonfX4o`00
02[ooo]Z000XoookJPCo00003OoonfX5o`0006Kooo]Z1?l0000>oookJPCo00003?oonfX5o`0000_o
oo]Z1?l0000=oookJPGo0000I_oonfX4o`0000gooo]Z1Ol0000LoookJPCo00003OoonfX5o`0006Ko
oo]Z1Ol0000=oookJPCo0000:_oonfX002Sooo]Z1?l0000=oookJPGo0000I_oonfX4o`0000kooo]Z
1?l0000<oookJPGo00002ooonfX4o`0000gooo]Z1Ol0001VoookJPGo00003?oonfX4o`0001gooo]Z
1?l0000=oookJPGo0000IooonfX4o`0000gooo]Z1?l0000ZoookJP00:?oonfX4o`0000gooo]Z1Ol0
001VoookJPGo00003?oonfX5o`0000cooo]Z1Ol0000;oookJPCo00003OoonfX5o`0006Kooo]Z1Ol0
000<oookJPCo00007OoonfX5o`0000cooo]Z1?l0001XoookJPCo00003OoonfX4o`0002[ooo]Z000X
oookJPCo00003OoonfX4o`0006Oooo]Z1Ol0000<oookJPGo00003?oonfX5o`0000_ooo]Z1?l0000=
oookJPCo0000IooonfX5o`0000cooo]Z1?l0000MoookJPGo00003?oonfX4o`0006Sooo]Z1Ol0000<
oookJPCo0000:_oonfX002Sooo]Z1Ol0000;oookJPGo0000IooonfX5o`0000cooo]Z1Ol0000<oook
JPGo00002ooonfX5o`0000_ooo]Z1Ol0001XoookJPCo00003?oonfX4o`0001gooo]Z1Ol0000;oook
JPGo0000J?oonfX5o`0000cooo]Z1?l0000ZoookJP00:?oonfX5o`0000_ooo]Z1Ol0001XoookJPCo
00003?oonfX4o`0000gooo]Z1Ol0000;oookJPGo00002ooonfX5o`0006Sooo]Z1?l0000<oookJPCo
00007_oonfX4o`0000_ooo]Z1Ol0001XoookJPGo00003?oonfX4o`0002[ooo]Z000XoookJPGo0000
2ooonfX5o`0006Sooo]Z1Ol0000;oookJPCo00003OoonfX5o`0000_ooo]Z1Ol0000;oookJPGo0000
J?oonfX5o`0000_ooo]Z1?l0000NoookJPCo00002ooonfX5o`0006Wooo]Z1?l0000;oookJPGo0000
:_oonfX002Wooo]Z1?l0000;oookJPCo0000JOoonfX5o`0000_ooo]Z1?l0000=oookJPGo00003?oo
nfX4o`0000_ooo]Z1?l0001YoookJPGo00002ooonfX4o`0001kooo]Z1?l0000;oookJPCo0000J_oo
nfX4o`0000_ooo]Z1Ol0000ZoookJP00:OoonfX4o`0000[ooo]Z1Ol0001YoookJPGo00002ooonfX4
o`0000gooo]Z1Ol0000<oookJPCo00002_oonfX5o`0006Wooo]Z1Ol0000;oookJPCo00007_oonfX4
o`0000_ooo]Z1?l0001ZoookJPGo00002_oonfX5o`0002[ooo]Z000YoookJPCo00002_oonfX5o`00
06[ooo]Z1?l0000;oookJPCo00003OoonfX5o`0000cooo]Z1?l0000:oookJPGo0000J_oonfX4o`00
00_ooo]Z1?l0000NoookJPCo00002_oonfX5o`0006[ooo]Z1Ol0000:oookJPCo0000:ooonfX002Wo
oo]Z1?l0000:oookJPGo0000J_oonfX4o`0000_ooo]Z1?l0000=oookJPGo00003?oonfX4o`0000[o
oo]Z1Ol0001ZoookJPCo00002_oonfX5o`0001kooo]Z1?l0000:oookJPGo0000J_oonfX5o`0000[o
oo]Z1?l0000[oookJP00:OoonfX5o`0000Wooo]Z1?l0001[oookJPGo00002_oonfX4o`0000gooo]Z
1Ol0000<oookJPCo00002_oonfX4o`0006_ooo]Z1Ol00009oookJPGo00007_oonfX4o`0000[ooo]Z
1Ol0001[oookJPCo00002_oonfX4o`0002_ooo]Z000YoookJPGo00002OoonfX4o`0006_ooo]Z1Ol0
000:oookJPCo00003OoonfX5o`0000cooo]Z1?l0000:oookJPCo0000JooonfX5o`0000Wooo]Z1Ol0
000NoookJPGo00002OoonfX4o`0006cooo]Z1Ol00009oookJPCo0000:ooonfX002Wooo]Z1Ol00008
oookJPGo0000JooonfX5o`0000Wooo]Z1Ol0000=oookJPGo00003?oonfX4o`0000Wooo]Z1Ol0001[
oookJPGo00002OoonfX4o`0001oooo]Z1Ol00009oookJPCo0000K?oonfX5o`0000Wooo]Z1?l0000[
oookJP00:_oonfX4o`0000Sooo]Z1Ol0001/oookJPCo00002OoonfX5o`0000gooo]Z1Ol0000<oook
JPCo00002OoonfX5o`0006cooo]Z1?l00009oookJPCo00007ooonfX5o`0000Sooo]Z1Ol0001/oook
JPGo00002OoonfX4o`0002_ooo]Z000ZoookJPCo00002?oonfX5o`0006cooo]Z1Ol00008oookJPGo
00003OoonfX5o`0000cooo]Z1Ol00008oookJPGo0000K?oonfX5o`0000Sooo]Z1?l0000PoookJPCo
00002?oonfX5o`0006gooo]Z1?l00009oookJPCo0000:ooonfX002[ooo]Z1?l00008oookJPCo0000
KOoonfX5o`0000Sooo]Z1?l0000>oookJPGo00003?oonfX5o`0000Sooo]Z1?l0001]oookJPGo0000
2?oonfX4o`00023ooo]Z1?l00008oookJPGo0000KOoonfX5o`0000Sooo]Z1?l0000[oookJP00:_oo
nfX4o`0000Sooo]Z1?l0001]oookJPGo00002?oonfX4o`0000kooo]Z1Ol0000<oookJPGo00001ooo
nfX5o`0006gooo]Z1Ol00008oookJPCo00008?oonfX4o`0000Sooo]Z1?l0001^oookJPGo00002?oo
nfX4o`0002_ooo]Z000ZoookJPCo00001ooonfX5o`0006kooo]Z1?l00008oookJPCo00003_oonfX5
o`0000gooo]Z1?l00007oookJPGo0000K_oonfX5o`0000Oooo]Z1?l0000PoookJPCo00002?oonfX4
o`0006kooo]Z1Ol00007oookJPGo0000:ooonfX002[ooo]Z1?l00007oookJPGo0000K_oonfX5o`00
00Oooo]Z1?l0000>oookJPGo00003OoonfX4o`0000Oooo]Z1Ol0001^oookJPGo00001ooonfX4o`00
023ooo]Z1?l00007oookJPGo0000KooonfX4o`0000Oooo]Z1Ol0000[oookJP00:_oonfX4o`0000Oo
oo]Z1Ol0001^oookJPGo00001ooonfX4o`0000kooo]Z1Ol0000=oookJPGo00001_oonfX4o`0006oo
oo]Z1Ol00007oookJPCo00008?oonfX4o`0000Oooo]Z1Ol0001_oookJPCo00001ooonfX5o`0002_o
oo]Z000ZoookJPCo00001ooonfX4o`0006oooo]Z1Ol00006oookJPGo00003_oonfX5o`0000gooo]Z
1Ol00005oookJPGo0000L?oonfX4o`0000Kooo]Z1Ol0000PoookJPCo00001ooonfX5o`0006oooo]Z
1Ol00006oookJPCo0000;?oonfX002[ooo]Z1?l00007oookJPCo0000L?oonfX4o`0000Kooo]Z1Ol0
000>oookJPGo00003OoonfX5o`0000Gooo]Z1Ol0001`oookJPCo00001_oonfX5o`00023ooo]Z1Ol0
0006oookJPCo0000L?oonfX5o`0000Kooo]Z1?l0000/oookJP00:_oonfX4o`0000Kooo]Z1Ol0001`
oookJPGo00001OoonfX5o`0000kooo]Z1Ol0000>oookJPCo00001OoonfX5o`00073ooo]Z1Ol00005
oookJPGo00008?oonfX5o`0000Kooo]Z1?l0001`oookJPGo00001_oonfX4o`0002cooo]Z000Zoook
JPGo00001OoonfX5o`0006Gooo]Z1Ol007l4oookJP;o001o1Ol00005o`00O`Co00001Ol007l:oook
JPGo00003_oonfX4o`0000Gooo]Z1?l0001aoookJPGo00001OoonfX4o`00027ooo]Z1Ol00005oook
JPGo0000LOoonfX4o`0000Kooo]Z1?l0000/oookJP00:_oonfX5o`0000Gooo]Z1Ol0001ToookJPOo
001o0ooonfX2o`00O`Go00001Ol007l4o`0000Ko001o2OoonfX5o`0000kooo]Z1?l00005oookJPCo
0000LOoonfX5o`0000Gooo]Z1?l0000RoookJPCo00001OoonfX5o`00077ooo]Z1?l00005oookJPGo
0000;?oonfX002[ooo]Z1Ol00005oookJPCo0000IOoonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l4o`000004o`00Oooonf[ooo]ZoookJPGo00000_l007l01?oonf[o001oo`00Ool007l9
oookJPGo00003_oonfX4o`0000Cooo]Z1Ol0001boookJPCo00001OoonfX4o`0002;ooo]Z1?l00005
oookJPGo0000LOoonfX5o`0000Cooo]Z1Ol0000/oookJP00:ooonfX4o`0000Gooo]Z1?l0001Toook
JP?o001o0ooonfX3o`00O`Gooo]Z1Ol000000ol007oooo]ZoookJP05o`000004o`00Oooonf[ooo]Z
oookJP?o001o2?oonfX5o`0000kooo]Z1?l00004oookJPGo0000L_oonfX4o`0000Gooo]Z1?l0000R
oookJPGo00000ooonfX5o`0007;ooo]Z1Ol00004oookJPGo0000;?oonfX002_ooo]Z1Ol00003oook
JPGo0000I?oonfX3o`00O`?ooo]Z0ol007l5oookJPGo00000ol007l5o`0000Cooo]Z0ol007l8oook
JPKo00003OoonfX4o`0000Cooo]Z1Ol0001boookJPGo00000ooonfX5o`0002;ooo]Z1Ol00003oook
JPGo0000L_oonfX5o`0000?ooo]Z1Ol0000]oookJP00:ooonfX5o`0000?ooo]Z1Ol0001ToookJP?o
001o0ooonfX3o`00O`Gooo]Z1Ol00003o`00O`Co00001OoonfX3o`00O`Sooo]Z1Ol0000>oookJPCo
00001?oonfX4o`0007?ooo]Z1Ol00003oookJPGo00008_oonfX5o`0000?ooo]Z1Ol0001coookJPCo
00000ooonfX5o`0002gooo]Z000[oookJPGo00000ooonfX5o`0006Cooo]Z0ol007l3oookJP?o001o
1_oonfX4o`000003oookJ_l007oo001o00Co00000_l007l2oookJPCo001o2?oonfX5o`0000kooo]Z
1Ol00002oookJPGo0000LooonfX5o`0000?ooo]Z1Ol0000SoookJPCo00000ooonfX4o`0007Cooo]Z
1?l00003oookJPGo0000;OoonfX002cooo]Z1?l00002oookJPGo0000IOoonfX3o`00O`?ooo]Z0ol0
07l6oookJPGo000000?ooo]Zo`00Ool000000ol00007o`00O`Wooo]Z1Ol0000>oookJPGo00000_oo
nfX5o`0007Cooo]Z1Ol00002oookJPCo00009?oonfX4o`0000;ooo]Z1Ol0001doookJPGo00000_oo
nfX4o`0002kooo]Z000/oookJPCo00000_oonfX5o`0006Gooo]Z0ol007l3oookJP?o001o1_oonfX5
o`000003oookJ_l007oo000000?o00001_l007l:oookJPGo00003_oonfX5o`0000;ooo]Z1Ol0001d
oookJPGo00000_oonfX4o`0002Cooo]Z1?l00002oookJPGo0000M?oonfX5o`0000;ooo]Z1?l0000^
oookJP00;?oonfX4o`0000;ooo]Z1Ol0001UoookJP?o001o0ooonfX3o`00O`Kooo]Z2ol00002o`00
O`kooo]Z1Ol0000?oookJP[o0000MOoonfX6o`000003oookJ_l0003o000000;o00009?oonfX5o`00
0003oookJ_l0003o000000?o0000M?oonfX6o`000003oookJ_l0003o000000;o0000;_oonfX002co
oo]Z2_l0001WoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX00ol007oo0000o`000008o`00
00;o001o3_oonfX5o`0000oooo]Z2_l0001foookJP[o00009?oonfX:o`0007Kooo]Z2_l0000^oook
JP00;?oonfX:o`0006Oooo]Z1ol007l8oookJP[o000000?ooo]Zo`00Ool007l01Ol007l8oookJPGo
00003ooonfX:o`0007Kooo]Z2_l0000ToookJP[o0000M_oonfX:o`0002kooo]Z000/oookJP[o0000
J?oonfX5o`00O`[ooo]Z2?l00002oookJPOo001o2?oonfX5o`00013ooo]Z2?l0001hoookJPWo0000
9OoonfX9o`0007Oooo]Z2Ol0000^oookJP00;OoonfX8o`0007Sooo]Z2?l0000AoookJPGo00004?oo
nfX8o`0007Sooo]Z2?l0000VoookJPSo0000N?oonfX8o`0002oooo]Z000]oookJPOo0000NOoonfX8
o`00017ooo]Z1Ol0000@oookJPSo0000N?oonfX8o`0002Oooo]Z1ol0001hoookJPSo0000;ooonfX0
02kooo]Z1_l0001joookJPKo00004_oonfX5o`00017ooo]Z1_l0001joookJPKo0000:?oonfX6o`00
07[ooo]Z1_l0000`oookJP00;_oonfX5o`0007cooo]Z1?l0000CoookJPGo00004_oonfX4o`0007co
oo]Z1?l0000ZoookJPGo0000NooonfX4o`00037ooo]Z0036oookJPGo0000oooonfYfoookJP00a_oo
nfX5o`000?oooo]ZM_oonfX00<Kooo]Z1Ol0003ooookJWKooo]Z0036oookJPGo0000oooonfYfoook
JP00a_oonfX5o`000?oooo]ZM_oonfX00<Kooo]Z1Ol0003ooookJWKooo]Z0036oookJPGo0000oooo
nfYfoookJP00a_oonfX5o`000?oooo]ZM_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-2.30167, -0.0218422, \
0.0114841, 0.00081322}},
  CellTags->"mmtag:17:Fourier_series__example_plot"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->"mmtag:17:Fourier_series__example_plot"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[OriginalPlot, FourierPlot]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.15873 0.0249899 2.24154 [
[.02381 .01249 -13.4688 -20 ]
[.02381 .01249 13.4688 0 ]
[.18254 .01249 -13.4688 -20 ]
[.18254 .01249 13.4688 0 ]
[.5 .01249 -7 -20 ]
[.5 .01249 7 0 ]
[.65873 .01249 -7 -20 ]
[.65873 .01249 7 0 ]
[.81746 .01249 -7 -20 ]
[.81746 .01249 7 0 ]
[.97619 .01249 -7 -20 ]
[.97619 .01249 7 0 ]
[.32877 .13707 -39 -10 ]
[.32877 .13707 0 10 ]
[.32877 .24914 -29 -10 ]
[.32877 .24914 0 10 ]
[.32877 .36122 -39 -10 ]
[.32877 .36122 0 10 ]
[.32877 .4733 -29 -10 ]
[.32877 .4733 0 10 ]
[.32877 .58538 -39 -10 ]
[.32877 .58538 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .02499 m
.02381 .03124 L
s
gsave
.02381 .01249 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.18254 .02499 m
.18254 .03124 L
s
gsave
.18254 .01249 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .02499 m
.5 .03124 L
s
gsave
.5 .01249 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.65873 .02499 m
.65873 .03124 L
s
gsave
.65873 .01249 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 .02499 m
.81746 .03124 L
s
gsave
.81746 .01249 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 .02499 m
.97619 .03124 L
s
gsave
.97619 .01249 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .02499 m
.05556 .02874 L
s
.0873 .02499 m
.0873 .02874 L
s
.11905 .02499 m
.11905 .02874 L
s
.15079 .02499 m
.15079 .02874 L
s
.21429 .02499 m
.21429 .02874 L
s
.24603 .02499 m
.24603 .02874 L
s
.27778 .02499 m
.27778 .02874 L
s
.30952 .02499 m
.30952 .02874 L
s
.37302 .02499 m
.37302 .02874 L
s
.40476 .02499 m
.40476 .02874 L
s
.43651 .02499 m
.43651 .02874 L
s
.46825 .02499 m
.46825 .02874 L
s
.53175 .02499 m
.53175 .02874 L
s
.56349 .02499 m
.56349 .02874 L
s
.59524 .02499 m
.59524 .02874 L
s
.62698 .02499 m
.62698 .02874 L
s
.69048 .02499 m
.69048 .02874 L
s
.72222 .02499 m
.72222 .02874 L
s
.75397 .02499 m
.75397 .02874 L
s
.78571 .02499 m
.78571 .02874 L
s
.84921 .02499 m
.84921 .02874 L
s
.88095 .02499 m
.88095 .02874 L
s
.9127 .02499 m
.9127 .02874 L
s
.94444 .02499 m
.94444 .02874 L
s
.01 w
0 .02499 m
1 .02499 L
s
.25 Mabswid
.34127 .13707 m
.34752 .13707 L
s
gsave
.32877 .13707 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.34127 .24914 m
.34752 .24914 L
s
gsave
.32877 .24914 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.34127 .36122 m
.34752 .36122 L
s
gsave
.32877 .36122 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.34127 .4733 m
.34752 .4733 L
s
gsave
.32877 .4733 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.34127 .58538 m
.34752 .58538 L
s
gsave
.32877 .58538 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.34127 .04741 m
.34502 .04741 L
s
.34127 .06982 m
.34502 .06982 L
s
.34127 .09224 m
.34502 .09224 L
s
.34127 .11465 m
.34502 .11465 L
s
.34127 .15948 m
.34502 .15948 L
s
.34127 .1819 m
.34502 .1819 L
s
.34127 .20431 m
.34502 .20431 L
s
.34127 .22673 m
.34502 .22673 L
s
.34127 .27156 m
.34502 .27156 L
s
.34127 .29398 m
.34502 .29398 L
s
.34127 .31639 m
.34502 .31639 L
s
.34127 .33881 m
.34502 .33881 L
s
.34127 .38364 m
.34502 .38364 L
s
.34127 .40605 m
.34502 .40605 L
s
.34127 .42847 m
.34502 .42847 L
s
.34127 .45088 m
.34502 .45088 L
s
.34127 .49571 m
.34502 .49571 L
s
.34127 .51813 m
.34502 .51813 L
s
.34127 .54054 m
.34502 .54054 L
s
.34127 .56296 m
.34502 .56296 L
s
.34127 .00257 m
.34502 .00257 L
s
.34127 .60779 m
.34502 .60779 L
s
.01 w
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.015 w
.34127 .02499 m
.34754 .18512 L
.35415 .31963 L
.36085 .42379 L
.3647 .47026 L
.36819 .50485 L
.37132 .52999 L
.37472 .55148 L
.37658 .56087 L
.3783 .5681 L
.37994 .57372 L
.3817 .57847 L
.38256 .58034 L
.38338 .58183 L
.38418 .58302 L
.38492 .5839 L
.38562 .58454 L
.38601 .58482 L
.38636 .58502 L
.38675 .58519 L
.38717 .58531 L
.38757 .58537 L
.38794 .58537 L
.38834 .58532 L
.38876 .5852 L
.38916 .58503 L
.38953 .58483 L
.39043 .58414 L
.39128 .58324 L
.39297 .58076 L
.39481 .57707 L
.39795 .56855 L
.4014 .55616 L
.40841 .52284 L
.42181 .43694 L
.4347 .34012 L
.44842 .23671 L
.46163 .14835 L
.47433 .08209 L
.48087 .05709 L
.4845 .04616 L
.48785 .03805 L
.49126 .03176 L
.49306 .02927 L
.49496 .02724 L
.49576 .02659 L
.49662 .02601 L
.49742 .02558 L
.49816 .02529 L
.49861 .02516 L
Mistroke
.49903 .02507 L
.49927 .02504 L
.49948 .02501 L
.49973 .025 L
.49997 .02499 L
.5004 .025 L
.50079 .02505 L
.50122 .02512 L
.50144 .02517 L
.50168 .02524 L
.50252 .02556 L
.50343 .02604 L
.5043 .02663 L
.50509 .02729 L
.5082 .03095 L
.50981 .03351 L
.51158 .03686 L
.51517 .04529 L
.52164 .06586 L
.52859 .09536 L
.54232 .17302 L
.55555 .26588 L
.56827 .36293 L
.58181 .46223 L
.58806 .50257 L
.59484 .53953 L
.59855 .55597 L
.60197 .56828 L
.60523 .57718 L
.60688 .58051 L
.60775 .58193 L
.60869 .5832 L
.60959 .58416 L
.60999 .58449 L
.61043 .5848 L
.61084 .58503 L
.61123 .5852 L
.61164 .58531 L
.61187 .58535 L
.61208 .58537 L
.61246 .58537 L
.6128 .58532 L
.61319 .58521 L
.61359 .58505 L
.61402 .5848 L
.61443 .58451 L
.61518 .58379 L
.61603 .58274 L
.61692 .58131 L
.61853 .57794 L
Mistroke
.62025 .57312 L
.62215 .56631 L
.62553 .55009 L
.62863 .53036 L
.6322 .50134 L
.63559 .46714 L
.64219 .38025 L
.64833 .27318 L
.65873 .02499 L
Mfstroke
0 g
.0075 w
.02381 .16315 m
.04262 .37259 L
.04754 .45464 L
.0522 .52073 L
.05477 .54975 L
.05613 .56255 L
.05756 .57417 L
.05877 .58237 L
.0601 .58977 L
.06131 .59503 L
.06244 .59875 L
.06309 .60034 L
.06379 .60168 L
.06506 .60309 L
.06631 .60326 L
.06746 .60244 L
.06817 .60152 L
.06883 .60038 L
.07007 .5976 L
.07286 .58885 L
.08255 .54574 L
.09326 .50012 L
.09912 .47479 L
.10458 .44567 L
.11415 .37519 L
.12466 .27965 L
.13351 .20699 L
.14313 .15017 L
.15358 .10578 L
.16348 .06508 L
.16816 .04631 L
.17072 .03702 L
.17312 .02936 L
.17533 .0235 L
.17736 .01933 L
.17846 .0176 L
.17961 .01621 L
.18077 .01526 L
.18204 .01476 L
.18336 .01483 L
.18458 .01544 L
.18521 .01596 L
.18591 .01669 L
.18732 .01867 L
.18857 .02093 L
.1899 .02387 L
.19231 .03041 L
.20165 .0653 L
.21252 .10989 L
.2226 .15334 L
Mistroke
.22751 .18014 L
.23273 .21544 L
.24377 .31045 L
.25425 .40244 L
.26388 .4645 L
.26889 .48794 L
.27419 .50977 L
.28533 .55881 L
.28998 .57991 L
.29254 .58998 L
.29496 .59747 L
.29633 .60053 L
.2971 .60179 L
.29782 .60264 L
.29908 .60332 L
.29972 .60323 L
.30042 .60278 L
.30168 .60098 L
.3024 .59938 L
.30305 .59753 L
.30425 .59311 L
.30551 .58701 L
.30809 .56974 L
.31053 .54751 L
.31508 .49145 L
.32529 .32424 L
.32958 .25626 L
.33193 .22459 L
.33412 .20001 L
.33649 .17994 L
.33774 .17234 L
.33845 .16905 L
.33909 .16668 L
.34022 .16398 L
.34144 .16318 L
.3426 .16447 L
.34367 .16744 L
.34485 .1726 L
.34608 .18015 L
.34829 .19875 L
.35068 .22537 L
.35328 .26101 L
.36231 .41071 L
.36747 .49156 L
.3703 .52853 L
.37298 .55701 L
.37547 .57737 L
.37688 .58618 L
.37818 .59262 L
.37927 .59681 L
Mistroke
.38047 .60017 L
.38173 .60236 L
.38291 .60326 L
.38415 .60308 L
.38485 .60252 L
.38548 .60173 L
.38671 .59952 L
.38787 .5967 L
.39048 .58824 L
.3933 .57674 L
.40317 .53154 L
.41275 .49173 L
.4217 .44771 L
.42629 .41747 L
.43121 .3786 L
.44165 .28389 L
.44696 .23774 L
.4526 .19568 L
.46272 .14029 L
.4729 .09827 L
.48398 .05271 L
.48858 .03564 L
.491 .02815 L
.49354 .02182 L
.4949 .01919 L
.49562 .01803 L
.49639 .01698 L
.49709 .01619 L
.49774 .01561 L
.49899 .01489 L
.50025 .01473 L
.50096 .01488 L
.50162 .01517 L
.50283 .01611 L
.5041 .01763 L
.50531 .01957 L
.50664 .02221 L
.50904 .02827 L
.51355 .04317 L
.52369 .08435 L
.53313 .12262 L
.54201 .16333 L
.54699 .19292 L
.55236 .23227 L
.56174 .31509 L
.57175 .40276 L
.57705 .44009 L
.58273 .47145 L
.59308 .51561 L
.60272 .55848 L
Mistroke
.60544 .57109 L
.60839 .58386 L
.611 .59336 L
.61242 .59748 L
.61312 .59916 L
.61376 .60047 L
.61495 .6023 L
.61624 .60326 L
.61691 .6033 L
.61764 .60297 L
.61834 .60228 L
.61898 .60129 L
.6202 .59844 L
.62131 .59471 L
.62259 .58899 L
.6238 .58217 L
.62621 .56435 L
.62845 .54263 L
.63356 .47667 L
.64387 .30563 L
.64845 .23669 L
.6507 .20923 L
.65278 .1889 L
.65394 .17997 L
.65518 .17248 L
.65641 .16714 L
.65712 .16508 L
.65778 .16383 L
.65893 .16318 L
.65997 .16431 L
.66113 .16742 L
.66234 .17278 L
.66357 .18036 L
.66491 .19091 L
.66734 .21574 L
.67188 .27824 L
.68207 .44847 L
.68671 .51563 L
.68925 .54521 L
.69163 .56747 L
.69365 .5821 L
.69469 .58807 L
.69582 .5934 L
.69706 .59785 L
.69823 .60082 L
.69938 .60258 L
.70044 .60328 L
.70173 .60301 L
.70238 .60245 L
.70309 .60152 L
Mistroke
.70435 .59914 L
.70553 .59618 L
.70818 .58734 L
.71102 .57556 L
.72099 .52997 L
.73066 .48983 L
.73961 .44503 L
.74455 .41159 L
.7498 .3689 L
.76088 .26802 L
.77057 .19228 L
.77602 .16035 L
.78101 .13663 L
.79051 .09768 L
.80051 .05644 L
.80474 .04018 L
.80925 .02601 L
.81058 .02275 L
.81184 .02013 L
.81307 .01805 L
.8142 .01657 L
.81527 .01555 L
.81641 .01491 L
.81755 .01472 L
.8188 .01503 L
.8201 .01593 L
.8213 .01727 L
.82262 .0193 L
.82402 .02205 L
.82638 .02792 L
.82898 .03599 L
.83827 .07239 L
.84917 .11685 L
.85395 .13678 L
.85918 .16178 L
.86858 .22249 L
.87849 .30856 L
.88941 .40427 L
.89934 .46724 L
.90416 .48943 L
.9094 .51096 L
.91891 .55255 L
.9242 .5769 L
.92709 .58865 L
.92851 .59352 L
.9298 .59728 L
.93098 .60001 L
.93211 .60191 L
.93329 .60307 L
.93458 .60325 L
Mistroke
.93591 .60214 L
.93665 .6009 L
.93732 .59938 L
.93862 .59528 L
.93985 .59 L
.94212 .57645 L
.94424 .55926 L
.94906 .50451 L
.95878 .3486 L
.9631 .2774 L
.96718 .22048 L
.96944 .1961 L
.97063 .18572 L
.9719 .17673 L
.97296 .1709 L
.97413 .16632 L
.97519 .1639 L
.97619 .16315 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP006ooonfX9o`00Oe;ooo]Z0ol007nUoook
JP?o001oD?oonfX9o`00Oe3ooo]Z1Ol007mEoookJP?o001o6OoonfX001_ooo]Z2Ol007mBoookJP?o
001oYOoonfX3o`00Oe3ooo]Z2Ol007m?oookJPOo001oE?oonfX3o`00OaWooo]Z000KoookJPCo001o
EooonfX3o`00OjGooo]Z0ol007m@oookJPCo001oDooonfX3o`00O`?ooo]Z0ol007mCoookJP?o001o
6OoonfX000oooo]Z2_l007l3oookJPCo001oA_oonfX:o`00O`Kooo]Z0ol007nUoookJP?o001oDOoo
nfX4o`00Oe;ooo]Z0ol007l3oookJP?o001oC_oonfX9o`00OaSooo]Z000?oookJP[o001o1?oonfX5
o`00OdCooo]Z2_l007l6oookJP?o001oYOoonfX3o`00Oe;ooo]Z1Ol007mFoookJP?o001oC_oonfX9
o`00OaSooo]Z000OoookJPCo001oDooonfX3o`00Odgooo]Z1Ol0001CoookJP?o001oE?oonfX4o`00
OeGooo]Z0ol007m>oookJP;o001o0ooonfX3o`00OaWooo]Z000PoookJP?o001oDooonfX3o`00Odgo
oo]Z1Ol0001CoookJP?o001oEOoonfX3o`00Oe?ooo]Z1?l007m@oookJP;o001o0_oonfX3o`00OaWo
oo]Z000QoookJP?o001oD_oonfX3o`00Odgooo]Z1Ol0001CoookJP?o001oE_oonfX3o`00Oe;ooo]Z
0ol007mAoookJP?o001o00Cooo]Zo`00Ool007oo001o6OoonfX001_ooo]Z0ol007l3oookJP?o001o
D_oonfX3o`00Odgooo]Z1Ol0001CoookJP?o001oD?oonfX3o`00O`?ooo]Z0ol007mDoookJP;o001o
DOoonfX2o`00O`04oookJ_l007oo001oo`00OaWooo]Z000KoookJP?o001o0ooonfX3o`00Odoooo]Z
1_l007m=oookJPGo0000D?oonfX6o`00Oe3ooo]Z0ol007l3oookJP?o001oC_oonfX3o`00O`?ooo]Z
0ol007mAoookJPGo001o6OoonfX001_ooo]Z1?l007l2oookJP?o001oCooonfX6o`00Odgooo]Z1Ol0
001@oookJPKo001oD?oonfX4o`00O`;ooo]Z0ol007m>oookJP?o001o0ooonfX3o`00Oe7ooo]Z1Ol0
07lIoookJP007?oonfX7o`00Oe;ooo]Z1?l007m=oookJPGo0000D_oonfX4o`00Oe7ooo]Z1ol007m@
oookJPOo001oDooonfX4o`00OaWooo]Z000MoookJPGo001oE?oonfX3o`00Odgooo]Z1Ol0001Coook
JP?o001oD_oonfX5o`00Oe;ooo]Z1Ol007mEoookJP?o001o6OoonfX00<Kooo]Z1Ol0003ooookJWKo
oo]Z001^oookJPKo0000D_oonfX5o`00057ooo]Z1_l0002XoookJPOo0000KooonfX006gooo]Z2?l0
001AoookJPGo0000D?oonfX8o`000:Kooo]Z2?l0001_oookJP00K?oonfX9o`00057ooo]Z1Ol0001?
oookJP[o0000YOoonfX9o`0006kooo]Z001/oookJP[o0000C_oonfX8ool004kooo]Z2_l0001>oook
JPSoo`00C_oonfX:o`0006kooo]Z000;oookJ[Wo00002?oo002Vo`0000Soo`00^_l0000<oookJP00
2ooonfZio`0000Soo`00C?l000000ooo003o0000o`000004o`000003ool00?l0003o000000?o0000
00?oo`00o`000?l00000B_l00008ool00;[o00003?oonfX000_ooo]Z^Ol00008ool004_o000000?o
o`00o`000?l000001?l00002ool000Ko000000?oo`00o`000?l00000BOl00008ool00;[o00003?oo
nfX000_ooo]Z^Ol00008ool004[o00000_oo0005o`0000Coo`001Ol00002ool004[o00002?oo002j
o`0000cooo]Z000;oookJ[Wo00002?oo001:o`0000;oo`001Ol00004ool000Go00000_oo001:o`00
00Soo`00^_l0000<oookJP006_oonfX00ol0003ooo]ZoookJP1=oookJPGo00000_oonfX00ol0003o
oo]Zo`000004o`0004cooo]Z2?oo0019oookJP?oo`001?l00006ool000Co00000_oo001:oookJPSo
o`00C?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX01?l0001@oookJP03o`000?oonf[ooo]Z01Wo
oo]Z000JoookJP03o`000?oonf[ooo]Z04cooo]Z1Ol00003oookJP03o`000?oonf[ooo]Z00Co0000
C?oonfX8ool004Wooo]Z0_oo0005o`0000Koo`001Ol00002ool004Wooo]Z2?oo001<oookJPGo0000
0_oonfX00ol0003ooo]ZoookJP05o`0004oooo]Z00?o0000oookJ_oonfX06OoonfX006Wooo]Z1Ol0
0006oookJPGo0000BooonfX8ool004Sooo]Z0ooo0005o`0000Koo`001Ol00002ool004Wooo]Z2?oo
001;oookJPGo00001_oonfX5o`0006_ooo]Z001XoookJPKo00001_oonfX5o`0004_ooo]Z2?oo0018
oookJP?oo`001Ol00006ool000Go00000ooo0018oookJPSoo`00BooonfX5o`0000Kooo]Z1Ol0001[
oookJP00J?oonfX5o`0000Oooo]Z1Ol0001;oookJPSoo`00AooonfX4ool000Co00002?oo0004o`00
00?oo`00B?oonfX8ool004_ooo]Z1Ol00007oookJPCo0000JooonfX006Sooo]Z1Ol00008oookJPCo
0000BooonfX8ool004Oooo]Z0ooo0005o`0000?oo`000_oonfX3ool000Go00000_oo0018oookJPSo
o`00B_oonfX5o`0000Sooo]Z1Ol0001ZoookJP00IooonfX5o`0000Wooo]Z1Ol0001:oookJPSoo`00
A_oonfX4ool000Go00000ooo0002oookJP?oo`001Ol00003ool004Kooo]Z2Ooo001:oookJPGo0000
2?oonfX5o`0006[ooo]Z001WoookJPGo00002OoonfX5o`0004[ooo]Z2?oo0016oookJPCoo`001Ol0
0002ool000?ooo]Z0ooo0005o`0000?oo`00A_oonfX9ool004[ooo]Z1Ol00008oookJPGo0000J_oo
nfX006Oooo]Z1Ol00009oookJPGo0000B_oonfX8ool004Kooo]Z0ooo0005o`0000?oo`001?oonfX3
ool000Co00001?oo0015oookJPWoo`00BOoonfX5o`0000[ooo]Z1Ol0001YoookJP00IooonfX4o`00
00_ooo]Z1?l0001:oookJPSoo`00A_oonfX3ool000Go00000_oo0005oookJP?oo`001Ol00003ool0
04Gooo]Z2Ooo0019oookJPGo00002_oonfX5o`0006Wooo]Z001WoookJPCo00002ooonfX5o`0004Wo
oo]Z2Ooo0014oookJPCoo`001Ol00002ool000Kooo]Z0_oo0005o`0000?oo`00AOoonfX9ool004Wo
oo]Z1Ol0000:oookJPGo0000JOoonfX006Kooo]Z1Ol0000;oookJPGo0000BOoonfX9ool004Cooo]Z
0ooo0005o`0000;oo`001ooonfX2ool000Go00001?oo0014oookJPWoo`00BOoonfX4o`0000cooo]Z
1Ol0001XoookJP00I_oonfX5o`0000_ooo]Z1Ol00019oookJPWoo`00A?oonfX3ool000Go00000_oo
0007oookJP?oo`001?l00004ool004Cooo]Z2Ooo0019oookJPCo00003?oonfX5o`0006Sooo]Z001V
oookJPGo00003?oonfX4o`0004Wooo]Z2Ooo0014oookJP?oo`001Ol000000ooo003ooo]ZoookJP07
oookJP;oo`001Ol00003ool004Cooo]Z2?oo0019oookJPGo00003?oonfX5o`0006Sooo]Z001Uoook
JPGo00003OoonfX5o`0004Sooo]Z2Ooo0014oookJP?oo`001?l00002ool000Wooo]Z0_oo0005o`00
00Coo`00@ooonfX8ool004Wooo]Z1Ol0000=oookJPCo0000J?oonfX006Gooo]Z1Ol0000=oookJPGo
0000B?oonfX9ool004?ooo]Z0ooo0005o`0000;oo`002_oonfX00ooo003o0000o`000003o`0000Co
o`00@ooonfX8ool004Wooo]Z1Ol0000=oookJPGo0000IooonfX006Gooo]Z1Ol0000=oookJPGo0000
B?oonfX9ool004?ooo]Z0ooo0005o`0000;oo`002_oonfX2ool000Co00001?oo0013oookJPSoo`00
BOoonfX4o`0000kooo]Z1Ol0001WoookJP00I?oonfX5o`0000oooo]Z1?l00019oookJPSoo`00@ooo
nfX3ool000Go000000?oo`00oookJ_oonfX02OoonfX2ool000Go00001?oo0012oookJPSoo`00B?oo
nfX5o`0000kooo]Z1Ol0001WoookJP00I?oonfX5o`0000oooo]Z1Ol00018oookJPSoo`00@_oonfX4
ool000Co00000_oo000<oookJP03ool00?l0003o000000?o00001?oo0012oookJPSoo`00B?oonfX5
o`0000oooo]Z1Ol0001VoookJP00I?oonfX5o`0000oooo]Z1Ol00018oookJPSoo`00@_oonfX3ool0
00Go00000_oo000<oookJP03ool00?l0003o000000?o00001?oo0012oookJPSoo`00B?oonfX5o`00
00oooo]Z1Ol0001VoookJP00I?oonfX4o`00013ooo]Z1Ol00018oookJPSoo`00@_oonfX3ool000Go
00000_oo000<oookJP;oo`001Ol00004ool0047ooo]Z2?oo0017oookJPGo00004?oonfX5o`0006Ko
oo]Z001SoookJPGo00004OoonfX4o`0004Sooo]Z2?oo0012oookJP?oo`001Ol00002ool000gooo]Z
00?oo`00o`000?l000000ol00004ool0047ooo]Z2?oo0017oookJPGo00004OoonfX5o`0006Gooo]Z
001SoookJPGo00004OoonfX5o`0004Oooo]Z2?oo0011oookJPCoo`001?l00002ool000kooo]Z00?o
o`00o`000?l000000ol00004ool0047ooo]Z2?oo0017oookJPGo00004OoonfX5o`0006Gooo]Z001S
oookJPGo00004OoonfX5o`0004Oooo]Z2?oo0011oookJP?oo`001Ol00002ool000kooo]Z0_oo0004
o`0000Coo`00@OoonfX8ool004Oooo]Z1?l0000BoookJPGo0000IOoonfX006?ooo]Z1?l0000Boook
JPGo0000AooonfX8ool0047ooo]Z0ooo0005o`0000;oo`003ooonfX00ooo003o0000o`000003o`00
00Coo`00@?oonfX8ool004Kooo]Z1Ol0000CoookJPCo0000IOoonfX006?ooo]Z1?l0000CoookJPCo
0000AooonfX8ool0043ooo]Z1?oo0005o`000003ool00?oonf[ooo]Z00kooo]Z00?oo`00o`000?l0
00000ol00004ool0043ooo]Z2?oo0016oookJPGo00004ooonfX5o`0006Cooo]Z001RoookJPGo0000
4ooonfX5o`0004Kooo]Z2?oo0010oookJPCoo`001?l00002ool0013ooo]Z00?oo`00o`000?l00000
0ol00004ool0043ooo]Z2?oo0016oookJPGo00004ooonfX5o`0006Cooo]Z001RoookJPGo00004ooo
nfX5o`0004Kooo]Z2?oo0010oookJPCoo`001?l00002ool0017ooo]Z00?oo`00o`000?l000000_l0
0004ool0043ooo]Z2?oo0016oookJPCo00005?oonfX5o`0006Cooo]Z001RoookJPGo00004ooonfX5
o`0004Kooo]Z2?oo0010oookJP?oo`001Ol00002ool0017ooo]Z00?oo`00o`000?l000000ol00004
ool003oooo]Z2?oo0015oookJPGo00005OoonfX4o`0006Cooo]Z001RoookJPCo00005OoonfX4o`00
04Kooo]Z2?oo0010oookJP?oo`001Ol000000ooo003ooo]ZoookJP0@oookJP03ool00?l0003o0000
00?o00001?oo000noookJPWoo`00AOoonfX5o`0001Gooo]Z1Ol0001SoookJP00HOoonfX5o`0001Go
oo]Z1Ol00015oookJPSoo`00?ooonfX4ool000Go000000?oo`00oookJ_oonfX04?oonfX00ooo003o
0000o`000003o`0000Coo`00?_oonfX9ool004Gooo]Z1Ol0000EoookJPGo0000HooonfX0067ooo]Z
1Ol0000EoookJPGo0000AOoonfX8ool003oooo]Z1?oo0004o`0000;oo`004ooonfX00ooo003o0000
o`000002o`0000Coo`00?_oonfX9ool004Cooo]Z1Ol0000FoookJPGo0000HooonfX0067ooo]Z1Ol0
000EoookJPGo0000AOoonfX8ool003oooo]Z0ooo0005o`000003ool00?oonf[ooo]Z01;ooo]Z00?o
o`00o`000?l000000ol00004ool003gooo]Z2Ooo0014oookJPGo00005ooonfX4o`0006?ooo]Z001Q
oookJPCo00005ooonfX4o`0004Gooo]Z2?oo000ooookJP?oo`001Ol000000ooo003ooo]ZoookJP0B
oookJP03ool00?l0003o000000?o00001?oo000moookJPWoo`00A?oonfX5o`0001Oooo]Z1Ol0001R
oookJP00HOoonfX4o`0001Oooo]Z1Ol00014oookJPSoo`00?ooonfX3ool000Go000000?oo`00oook
J_oonfX04_oonfX00ooo003o0000o`000003o`0000Coo`00?OoonfX9ool004Cooo]Z1?l0000Hoook
JPGo0000H_oonfX0063ooo]Z1Ol0000GoookJPGo0000A?oonfX8ool003kooo]Z1?oo0004o`0000;o
o`005OoonfX00ooo003o0000o`000002o`0000Coo`00?OoonfX9ool004?ooo]Z1Ol0000HoookJPGo
0000H_oonfX0063ooo]Z1Ol0000GoookJPGo0000A?oonfX8ool003kooo]Z0ooo0005o`0000;oo`00
5OoonfX00ooo003o0000o`000003o`0000?oo`00?OoonfX8ool004Cooo]Z1Ol0000IoookJPCo0000
H_oonfX0063ooo]Z1Ol0000HoookJPCo0000A?oonfX8ool003kooo]Z0ooo0005o`000003ool00?oo
nf[ooo]Z01Cooo]Z00?oo`00o`000?l000000ol00004ool003cooo]Z2?oo0014oookJPGo00006Ooo
nfX4o`0006;ooo]Z001PoookJPCo00006OoonfX5o`0004?ooo]Z2?oo000noookJP?oo`001Ol00000
0ooo003ooo]ZoookJP0DoookJP03ool00?l0003o000000?o00001?oo000loookJPSoo`00A?oonfX4
o`0001[ooo]Z1Ol0001QoookJP00H?oonfX4o`0001Wooo]Z1Ol00013oookJPWoo`00?OoonfX3ool0
00Co00000_oo000GoookJP03ool00?l0003o000000;o00001?oo000loookJPSoo`00@ooonfX5o`00
01[ooo]Z1Ol0001QoookJP00GooonfX5o`0001Wooo]Z1Ol00013oookJPWoo`00??oonfX3ool000Go
00000_oo000GoookJP03ool00?l0003o000000?o00000ooo000loookJPSoo`00@ooonfX5o`0001[o
oo]Z1Ol0001QoookJP00GooonfX5o`0001[ooo]Z1?l00013oookJPWoo`00??oonfX3ool000Go0000
0_oo000GoookJP03ool00?l0003o000000?o00000ooo000loookJPSoo`00@ooonfX5o`0001_ooo]Z
1?l0001QoookJP00GooonfX5o`0001[ooo]Z1Ol00012oookJPWoo`00??oonfX3ool000Go000000?o
o`00oookJ_oonfX05_oonfX00ooo003o0000o`000003o`0000?oo`00??oonfX8ool004?ooo]Z1?l0
000LoookJPGo0000H?oonfX005oooo]Z1?l0000KoookJPGo0000@_oonfX9ool003cooo]Z0ooo0004
o`0000;oo`006?oonfX2ool000Co00001?oo000koookJPSoo`00@ooonfX4o`0001cooo]Z1Ol0001P
oookJP00G_oonfX5o`0001_ooo]Z1Ol00012oookJPWoo`00??oonfX3ool000Co00000_oo000Ioook
JP03ool00?l0003o000000;o00001?oo000koookJPSoo`00@_oonfX5o`0001cooo]Z1Ol0001Poook
JP00G_oonfX5o`0001cooo]Z1?l00012oookJPWoo`00>ooonfX3ool000Go00000_oo000IoookJP03
ool00?l0003o000000?o00000ooo000koookJPSoo`00@_oonfX5o`0001gooo]Z1?l0001PoookJP00
G_oonfX5o`0001cooo]Z1Ol00012oookJPSoo`00>ooonfX3ool000Go00000_oo000IoookJP03ool0
0?l0003o000000?o00000ooo000koookJPSoo`00@_oonfX5o`0001gooo]Z1Ol0001OoookJP00G_oo
nfX4o`0001gooo]Z1Ol00012oookJPSoo`00>ooonfX3ool000Go000000?oo`00oookJ_oonfX06?oo
nfX00ooo003o0000o`000003o`0000?oo`00>ooonfX8ool004;ooo]Z1?l0000NoookJPGo0000Gooo
nfX005gooo]Z1Ol0000MoookJPGo0000@_oonfX8ool003_ooo]Z0ooo0004o`0000;oo`006_oonfX2
ool000Co00000ooo000koookJPSoo`00@OoonfX5o`0001kooo]Z1Ol0001OoookJP00GOoonfX5o`00
01kooo]Z1?l00012oookJPSoo`00>ooonfX2ool000Go00000_oo000JoookJP;oo`001Ol00003ool0
03[ooo]Z2?oo0011oookJPGo00007ooonfX4o`0005oooo]Z001MoookJPGo00007_oonfX5o`00047o
oo]Z2?oo000joookJP?oo`001Ol00002ool001_ooo]Z00?oo`00o`000?l000000ol00003ool003[o
oo]Z2?oo0011oookJPGo00007ooonfX4o`0005oooo]Z001MoookJPCo00007ooonfX5o`00047ooo]Z
2?oo000joookJP?oo`001Ol00002ool001_ooo]Z00?oo`00o`000?l000000ol00003ool003[ooo]Z
2?oo0011oookJPCo00008?oonfX5o`0005kooo]Z001LoookJPGo00007ooonfX5o`00047ooo]Z2?oo
000joookJP?oo`001?l00002ool001cooo]Z0_oo0004o`0000?oo`00>OoonfX9ool0043ooo]Z1Ol0
000PoookJPGo0000G_oonfX005cooo]Z1Ol0000PoookJPCo0000@OoonfX8ool003[ooo]Z0ooo0004
o`0000;oo`007?oonfX2ool000Go00000_oo000ioookJPWoo`00@?oonfX5o`00023ooo]Z1Ol0001N
oookJP00G?oonfX5o`00023ooo]Z1Ol00010oookJPSoo`00>_oonfX2ool000Go00000_oo000Loook
JP;oo`001Ol00002ool003Wooo]Z2Ooo0010oookJPGo00008OoonfX4o`0005kooo]Z001LoookJPCo
00008OoonfX5o`0001Sooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Gooo]Z1Ol007l:oookJPSo
o`00>OoonfX3ool000Go00000_oo000LoookJP;oo`001Ol00003ool003Sooo]Z2Ooo0010oookJPCo
00008_oonfX4o`0005kooo]Z001KoookJPGo00008OoonfX5o`0001Oooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`?ooo]Z1ol007l9oookJPSoo`00>OoonfX3ool000Go00000_oo000MoookJP;oo`00
1?l00003ool003Sooo]Z2Ooo0010oookJPCo00008_oonfX5o`0005gooo]Z001KoookJPGo00008_oo
nfX4o`0001Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l007l01?oonf[o001oo`00Ool007l9oookJPSoo`00>OoonfX3ool0
00Co00000_oo000NoookJP;oo`001?l00003ool003Sooo]Z2Ooo000ooookJPGo00008_oonfX5o`00
05gooo]Z001KoookJPGo00008_oonfX5o`0001Gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o2?oonfX8ool003Wooo]Z0ooo0004o`00
00;oo`007_oonfX2ool000Go00000_oo000hoookJPWoo`00?ooonfX5o`0002;ooo]Z1Ol0001Moook
JP00FooonfX4o`0002?ooo]Z1Ol0000EoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o1ooonfX3o`00O`Sooo]Z2?oo000ioookJP;oo`001Ol00002ool001kooo]Z0_oo0005o`0000;o
o`00>?oonfX8ool0043ooo]Z1Ol0000SoookJPCo0000GOoonfX005[ooo]Z1Ol0000SoookJPGo0000
5OoonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z0ol007l8oookJPSoo`00
>?oonfX3ool000Go00000_oo000NoookJP;oo`001Ol00002ool003Sooo]Z2?oo0010oookJPCo0000
9?oonfX4o`0005gooo]Z001JoookJPGo00009?oonfX4o`0001Gooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l2oookJP;o001o0_oonfX4o`00O`Sooo]Z2?oo000hoookJP?oo`001Ol0
0002ool001kooo]Z0ooo0004o`0000;oo`00>?oonfX8ool003oooo]Z1Ol0000ToookJPGo0000G?oo
nfX005[ooo]Z1Ol0000ToookJPGo00005?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00O`;ooo]Z1ol007l9oookJPSoo`00>?oonfX3ool000Co00000_oo000PoookJP;oo`001Ol00002
ool003Oooo]Z2?oo000ooookJPGo00009?oonfX5o`0005cooo]Z001JoookJPCo00009OoonfX5o`00
01Cooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJPKo001o2_oonfX8ool0
03Sooo]Z0_oo0005o`0000;oo`008?oonfX2ool000Go00000_oo000goookJPSoo`00?ooonfX5o`00
02Cooo]Z1Ol0001LoookJP00FOoonfX5o`0002Gooo]Z1Ol0000DoookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o0_oonfX2o`00O`kooo]Z2?oo000hoookJP;oo`001Ol00002ool0023o
oo]Z0_oo0005o`0000;oo`00=ooonfX8ool003oooo]Z1?l0000VoookJPCo0000G?oonfX005Wooo]Z
1Ol0000VoookJPCo00005OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP;o001o3_oonfX8ool003Sooo]Z0_oo0005o`0000;oo`008?oonfX3ool0
00Co00000_oo000goookJPSoo`00?_oonfX5o`0002Kooo]Z1Ol0001KoookJP00FOoonfX5o`0002Ko
oo]Z1Ol0000DoookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007l8oookJPSoo`00=ooonfX3ool000Co
00000ooo000PoookJP?oo`001Ol000000ooo003ooo]ZoookJP0eoookJPSoo`00?_oonfX5o`0002Ko
oo]Z1Ol0001KoookJP00FOoonfX4o`0002Oooo]Z1Ol0000EoookJPGo001o2_oonfX5o`00O`Gooo]Z
1ol007l8oookJPSoo`00=ooonfX3ool000Co00000_oo000QoookJP?oo`001Ol000000ooo003ooo]Z
oookJP0eoookJPSoo`00?_oonfX5o`0002Kooo]Z1Ol0001KoookJP00FOoonfX4o`0002Oooo]Z1Ol0
000moookJPWoo`00=_oonfX2ool000Go00000_oo000QoookJP?oo`001Ol00002ool003Kooo]Z2?oo
000noookJPCo0000:?oonfX4o`0005_ooo]Z001HoookJPGo0000:?oonfX4o`0003gooo]Z2Ooo000f
oookJP;oo`001Ol00002ool002;ooo]Z0ooo0004o`0000;oo`00=_oonfX8ool003kooo]Z1?l0000X
oookJPCo0000FooonfX005Sooo]Z1Ol0000XoookJPGo0000??oonfX9ool003Kooo]Z0_oo0005o`00
00;oo`008_oonfX3ool000Co00000_oo000foookJPSoo`00?OoonfX5o`0002Sooo]Z1Ol0001Joook
JP00F?oonfX5o`0002Sooo]Z1Ol0000loookJPWoo`00=_oonfX2ool000Co00000ooo000RoookJP?o
o`001Ol000000ooo003ooo]ZoookJP0doookJPSoo`00?OoonfX5o`0002Sooo]Z1Ol0001JoookJP00
6?oonfX4o`0003cooo]Z1?l0000YoookJPGo0000??oonfX4o`0000Goo`00=_oonfX2ool000Co0000
0ooo000RoookJP?oo`001Ol000000ooo003ooo]ZoookJP0doookJPGoo`001?l0000loookJPGo0000
:?oonfX5o`0003cooo]Z1?l0000JoookJP006?oonfX4o`0003cooo]Z1?l0000ZoookJPCo0000>ooo
nfX6o`0000Coo`00=OoonfX2ool000Go00000_oo000SoookJP?oo`001Ol000000ooo003ooo]Zoook
JP0doookJPCoo`001_l0000koookJPCo0000:_oonfX4o`0003cooo]Z1?l0000JoookJP006?oonfX4
o`0003cooo]Z1?l0000ZoookJPCo0000>ooonfX6o`0000Coo`00=OoonfX2ool000Go00000_oo000S
oookJPCoo`001?l00002ool003Gooo]Z1?oo0006o`0003_ooo]Z1?l0000ZoookJPCo0000>ooonfX5
o`0001[ooo]Z000HoookJPCo0000>ooonfX5o`0002[ooo]Z1Ol0000ioookJPOo00001?oo000eoook
JP;oo`001Ol00002ool002Cooo]Z0ooo0004o`0000;oo`00=?oonfX5ool000Ko0000>_oonfX5o`00
02[ooo]Z1Ol0000joookJPGo00006_oonfX001Sooo]Z1?l0000koookJPGo0000:_oonfX5o`0003Wo
oo]Z1ol00004ool003Gooo]Z0_oo0004o`0000?oo`009?oonfX3ool000Go000000?oo`00oookJ_oo
nfX0<_oonfX4ool000Oo0000>_oonfX5o`0002[ooo]Z1Ol0000ioookJPKo00006_oonfX001Sooo]Z
1?l0000koookJPGo0000:_oonfX5o`0003Wooo]Z2?l00003ool003Gooo]Z0_oo0004o`0000?oo`00
9?oonfX3ool000Go000000?oo`00oookJ_oonfX0<_oonfX4ool000So0000>OoonfX5o`0002[ooo]Z
1Ol0000ioookJPGo00006ooonfX001Sooo]Z1?l0000koookJPCo0000;?oonfX4o`0003Wooo]Z2?l0
0003ool003Gooo]Z00?oo`00o`000?l000000ol00003ool002Cooo]Z0ooo0005o`000003ool00?oo
nf[ooo]Z03;ooo]Z1?oo0008o`0003Wooo]Z1?l0000/oookJPCo0000>OoonfX5o`0001_ooo]Z000H
oookJPGo0000>_oonfX4o`0002cooo]Z1?l0000ioookJPSo00000ooo000eoookJP03ool00?l0003o
000000?o00000ooo000ToookJPCoo`001?l000000ooo003ooo]ZoookJP0boookJPCoo`002?l0000i
oookJPCo0000;?oonfX4o`0003Wooo]Z1?l0000LoookJP006?oonfX5o`0003[ooo]Z1?l0000/oook
JPGo0000=ooonfX:o`0000;oo`00=?oonfX2ool000Go00000_oo000UoookJPCoo`001?l000000ooo
003ooo]ZoookJP0boookJP?oo`002_l0000goookJPGo0000;?oonfX4o`0003Wooo]Z1?l0000Loook
JP006?oonfX5o`0003Wooo]Z1Ol0000/oookJPGo0000=ooonfX:o`0000;oo`00=?oonfX2ool000Co
00000ooo000VoookJP?oo`001Ol000000ooo003ooo]ZoookJP0aoookJP?oo`002_l0000goookJPGo
0000;?oonfX4o`0003Wooo]Z1?l0000LoookJP006OoonfX4o`0003Wooo]Z1Ol0000/oookJPGo0000
=ooonfX:o`0000;oo`00=?oonfX2ool000Co00000ooo000VoookJP?oo`001Ol000000ooo003ooo]Z
oookJP0aoookJP?oo`002_l0000goookJPGo0000;?oonfX5o`0003Sooo]Z1?l0000LoookJP006Ooo
nfX4o`0003Wooo]Z1Ol0000]oookJPCo0000=ooonfX4o`0000;oo`001?l00002ool003Cooo]Z00?o
o`00o`000?l000000ol00003ool002Kooo]Z0ooo0005o`000003ool00?oonf[ooo]Z037ooo]Z0ooo
0004o`000003ool00?oonf[o000000?o0000=ooonfX4o`0002gooo]Z1Ol0000goookJPGo00007?oo
nfX001Wooo]Z1?l0000ioookJPCo0000;_oonfX4o`0003Oooo]Z1?l00002ool000Co00000_oo000d
oookJP03ool00?l0003o000000?o00000ooo000VoookJPCoo`001?l000000ooo003ooo]ZoookJP0a
oookJP?oo`001?l000000ooo003ooo]Zo`000003o`0003Oooo]Z1?l0000]oookJPGo0000=ooonfX5
o`0001cooo]Z000IoookJPCo0000>OoonfX4o`0002kooo]Z1?l0000goookJPCo00000_oo0004o`00
00;oo`00=?oonfX00ooo003o0000o`000003o`0000?oo`009_oonfX4ool000Co000000?oo`00oook
J_oonfX0<OoonfX3ool000Co000000?oo`00oookJ_l000000ol0000goookJPCo0000;_oonfX4o`00
03Oooo]Z1Ol0000LoookJP006OoonfX4o`0003Wooo]Z1?l0000^oookJPCo0000=ooonfX4o`0000;o
o`001?l00002ool003Cooo]Z00?oo`00o`000?l000000_l00004ool002Kooo]Z1?oo0004o`000003
ool00?oonf[ooo]Z037ooo]Z0ooo0004o`000003ool00?oonf[o000000?o0000=_oonfX5o`0002ko
oo]Z1?l0000goookJPCo00007OoonfX001Wooo]Z1?l0000ioookJPCo0000;_oonfX4o`0003Kooo]Z
1Ol00002ool000Co00000_oo000coookJP;oo`001?l00003ool002Oooo]Z1?oo0005o`0003?ooo]Z
0ooo0004o`000003ool00?oonf[o000000?o0000=_oonfX5o`0002kooo]Z1?l0000goookJPCo0000
7OoonfX001Wooo]Z1?l0000hoookJPGo0000;_oonfX5o`0003Gooo]Z1Ol00002ool000Go000000?o
o`00oookJ_oonfX0<OoonfX00ooo003o0000o`000003o`0000?oo`00:?oonfX3ool000Go000000?o
o`00oookJ_oonfX0<?oonfX3ool000Co000000?oo`00oookJ_l000000ol0000foookJPGo0000;_oo
nfX4o`0003Oooo]Z1?l0000MoookJP006OoonfX4o`0003Sooo]Z1Ol0000^oookJPGo0000=OoonfX5
o`0000;oo`001Ol000000ooo003ooo]ZoookJP0aoookJP03ool00?l0003o000000?o00000ooo000X
oookJP?oo`001Ol000000ooo003ooo]ZoookJP0`oookJP?oo`001?l000000ooo003ooo]Zo`000003
o`0003Kooo]Z1?l0000_oookJPGo0000=_oonfX4o`0001gooo]Z000IoookJPGo0000=ooonfX5o`00
02kooo]Z1Ol0000eoookJPGo00000_oo0005o`000003ool00?oonf[ooo]Z037ooo]Z00?oo`00o`00
0?l000000ol00003ool002Sooo]Z1?oo0004o`000003ool00?oonf[ooo]Z033ooo]Z0ooo0004o`00
0003ool00?oonf[o000000?o0000=_oonfX4o`0002oooo]Z1Ol0000foookJPCo00007OoonfX001Wo
oo]Z1Ol0000goookJPCo0000<?oonfX4o`0003Gooo]Z1Ol00003ool000Co000000?oo`00oookJ_oo
nfX0<OoonfX00ooo003o0000o`000002o`0000Coo`00:?oonfX4ool000Co000000?oo`00oookJ_oo
nfX0<?oonfX3ool000Co000000?oo`00oookJ_l000001?l0000eoookJPCo0000;ooonfX5o`0003Ko
oo]Z1?l0000MoookJP006OoonfX5o`0003Oooo]Z1?l0000`oookJPCo0000=OoonfX5o`0000?oo`00
1?l00002ool003;ooo]Z00?oo`00o`000?l000000_l00004ool002Sooo]Z1?oo0004o`000003ool0
0?oonf[ooo]Z033ooo]Z0_oo0005o`000003ool00?oonf[o000000Co0000=OoonfX4o`00033ooo]Z
1?l0000foookJPCo00007OoonfX001[ooo]Z1?l0000goookJPCo0000<?oonfX4o`0003Gooo]Z1Ol0
0003ool000Co00000_oo000boookJP03ool00?l0003o000000;o00001?oo000XoookJPCoo`001Ol0
000boookJP;oo`001Ol000000ooo003ooo]Zo`000004o`0003Cooo]Z1Ol0000`oookJPCo0000=_oo
nfX4o`0001gooo]Z000JoookJPCo0000=_oonfX5o`00033ooo]Z1?l0000eoookJPGo00000ooo0004
o`0000;oo`00<OoonfX2ool000Co00000ooo000YoookJPCoo`001Ol0000boookJP;oo`001Ol00000
0ooo003ooo]ZoookJP04o`0003Cooo]Z1Ol0000`oookJPCo0000=OoonfX5o`0001gooo]Z000Joook
JPCo0000=_oonfX5o`00033ooo]Z1?l0000eoookJPGo00000ooo0004o`0000;oo`00<OoonfX00ooo
003o0000o`000003o`0000?oo`00:_oonfX3ool000Go000000?oo`00oookJ_oonfX0;ooonfX2ool0
00Co00000_oo0002oookJPCo0000=?oonfX5o`00033ooo]Z1?l0000eoookJPGo00007OoonfX001[o
oo]Z1?l0000foookJPGo0000<?oonfX4o`0003Gooo]Z1Ol00003ool000Co00000_oo000aoookJP03
ool00?l0003o000000?o00000ooo000ZoookJPCoo`001?l000000ooo003ooo]ZoookJP0_oookJP;o
o`001?l00002ool000;ooo]Z1?l0000doookJPCo0000<OoonfX5o`0003Cooo]Z1Ol0000MoookJP00
6_oonfX4o`0003Kooo]Z1?l0000aoookJPGo0000=?oonfX5o`0000?oo`001?l00002ool0037ooo]Z
00?oo`00o`000?l000000ol00003ool002[ooo]Z1?oo0004o`000003ool00?oonf[ooo]Z02oooo]Z
0_oo0004o`0000;oo`000_oonfX4o`0003Cooo]Z1?l0000aoookJPGo0000=?oonfX4o`0001kooo]Z
000JoookJPCo0000=_oonfX4o`00037ooo]Z1Ol0000doookJPGo00000ooo0004o`0000;oo`00<Ooo
nfX00ooo003o0000o`000002o`0000Coo`00:_oonfX4ool000Co000000?oo`00oookJ_oonfX0;_oo
nfX3ool000Co00000_oo0002oookJPGo0000<ooonfX4o`00037ooo]Z1Ol0000doookJPCo00007_oo
nfX001[ooo]Z1?l0000foookJPCo0000<OoonfX5o`0003Cooo]Z1_l00002ool000Co00000_oo000a
oookJP03ool00?l0003o000000;o00001?oo000ZoookJPCoo`001?l000000ooo003ooo]ZoookJP0^
oookJP?oo`001?l00002ool000;ooo]Z1Ol0000coookJPCo0000<_oonfX4o`0003Cooo]Z1?l0000N
oookJP006_oonfX4o`0003Kooo]Z1?l0000boookJPCo0000<ooonfX7o`0000;oo`001Ol000000ooo
003ooo]ZoookJP0_oookJP03ool00?l0003o000000;o00001?oo000ZoookJPCoo`001Ol0000`oook
JP?oo`001?l00002ool000;ooo]Z1Ol0000coookJPCo0000<_oonfX4o`0003Cooo]Z1?l0000Noook
JP006_oonfX4o`0003Gooo]Z1Ol0000boookJPCo0000<ooonfX7o`0000;oo`001Ol000000ooo003o
oo]ZoookJP0^oookJP;oo`001?l00003ool002_ooo]Z1?oo0005o`00033ooo]Z0ooo0004o`0000;o
o`000ooonfX4o`0003?ooo]Z1?l0000boookJPCo0000<ooonfX5o`0001kooo]Z000JoookJPGo0000
=?oonfX5o`0003;ooo]Z1?l0000coookJPOo00000_oo0005o`000003ool00?oonf[ooo]Z02kooo]Z
00?oo`00o`000?l000000ol00003ool002cooo]Z0ooo0005o`000003ool00?oonf[ooo]Z02gooo]Z
0_oo0005o`0000;oo`000ooonfX4o`0003;ooo]Z1Ol0000boookJPCo0000<ooonfX5o`0001kooo]Z
000JoookJPGo0000=?oonfX5o`0003;ooo]Z1?l0000coookJPCo000000?ooo]Zo`000?l000000ooo
0004o`000003ool00?oonf[ooo]Z02kooo]Z00?oo`00o`000?l000000ol00003ool002cooo]Z1?oo
0004o`000003ool00?oonf[ooo]Z02gooo]Z0_oo0005o`0000;oo`000ooonfX4o`0003;ooo]Z1Ol0
000boookJPGo0000<_oonfX5o`0001kooo]Z000JoookJPGo0000=?oonfX4o`0003?ooo]Z1?l0000c
oookJPCo000000?ooo]Zo`000?l000000ooo0004o`000003ool00?oonf[ooo]Z02kooo]Z00?oo`00
o`000?l000000ol00003ool002cooo]Z1?oo0004o`000003ool00?oonf[ooo]Z02gooo]Z0_oo0005
o`0000;oo`000ooonfX4o`0003;ooo]Z1Ol0000boookJPGo0000<_oonfX4o`0001oooo]Z000Koook
JPCo0000=?oonfX4o`0003?ooo]Z1?l0000coookJPCo000000?ooo]Zo`000?l000000ooo0004o`00
0003ool00?oonf[ooo]Z02kooo]Z00?oo`00o`000?l000000_l00004ool002cooo]Z1?oo0004o`00
0003ool00?oonf[ooo]Z02gooo]Z0_oo0004o`0000;oo`001?oonfX4o`0003;ooo]Z1?l0000coook
JPGo0000<_oonfX4o`0001oooo]Z000KoookJPCo0000=?oonfX4o`0003?ooo]Z1Ol0000boookJPCo
000000?ooo]Zo`000?l000000ooo0004o`000003ool00?oonf[ooo]Z02kooo]Z00?oo`00o`000?l0
00000_l00004ool002cooo]Z1?oo0004o`000003ool00?oonf[ooo]Z02gooo]Z0_oo0004o`0000;o
o`001?oonfX4o`0003;ooo]Z1?l0000doookJPCo0000<_oonfX4o`0001oooo]Z000KoookJPCo0000
=?oonfX4o`0003?ooo]Z1Ol0000boookJPCo000000?ooo]Zo`000?l000000ooo0004o`000003ool0
0?oonf[ooo]Z02kooo]Z00?oo`00o`000?l000000_l00004ool002cooo]Z1?oo0005o`0002oooo]Z
0_oo0004o`0000;oo`001?oonfX4o`0003;ooo]Z1?l0000doookJPCo0000<_oonfX4o`0001oooo]Z
000KoookJPCo0000=?oonfX4o`0003?ooo]Z1Ol0000boookJPCo000000?ooo]Zo`000?l000000ooo
0004o`000003ool00?oonf[ooo]Z02gooo]Z0_oo0004o`0000?oo`00;OoonfX4ool000Go0000;ooo
nfX2ool000Co00000_oo0004oookJPCo0000<_oonfX4o`0003Cooo]Z1?l0000boookJPCo00007ooo
nfX001_ooo]Z1?l0000coookJPGo0000=?oonfX4o`0003;ooo]Z1?l000000ooonf[o0000o`000003
ool000Co000000?oo`00oookJ_oonfX0;OoonfX2ool000Co00000ooo000^oookJP?oo`001Ol0000_
oookJP;oo`001?l00002ool000Cooo]Z1?l0000boookJPCo0000=?oonfX4o`0003;ooo]Z1?l0000O
oookJP006ooonfX4o`0003?ooo]Z1Ol0000doookJPCo0000<_oonfX4o`000003oookJ_l0003o0000
00?oo`001?l000000ooo003ooo]ZoookJP0]oookJP03ool00?l0003o000000?o00000ooo000^oook
JPCoo`001?l000000ooo003ooo]ZoookJP0/oookJP03ool00?l0003o000000?o00000_oo0004oook
JPGo0000<?oonfX5o`0003Cooo]Z1Ol0000aoookJPCo00007ooonfX001_ooo]Z1?l0000coookJPGo
0000=?oonfX4o`0003;ooo]Z1?l000000ooonf[o0000o`000003ool000Co00000_oo000^oookJP03
ool00?l0003o000000?o00000ooo000^oookJPCoo`001?l000000ooo003ooo]ZoookJP0/oookJP03
ool00?l0003o000000?o00000_oo0004oookJPGo0000<?oonfX5o`0003Cooo]Z1Ol0000aoookJPCo
00007ooonfX001_ooo]Z1?l0000coookJPCo0000=OoonfX4o`0003;ooo]Z1?l000000ooonf[o0000
o`000003ool000Go000000?oo`00oookJ_oonfX0;?oonfX00ooo003o0000o`000003o`0000?oo`00
;_oonfX4ool000Co000000?oo`00oookJ_oonfX0;?oonfX00ooo003o0000o`000003o`0000;oo`00
1?oonfX5o`00033ooo]Z1Ol0000doookJPGo0000<OoonfX4o`0001oooo]Z000KoookJPGo0000<_oo
nfX4o`0003Gooo]Z1?l0000boookJPCo000000?ooo]Zo`000?l000000ooo0005o`000003ool00?oo
nf[ooo]Z02cooo]Z00?oo`00o`000?l000000_l00004ool002kooo]Z1?oo0004o`000003ool00?oo
nf[ooo]Z02cooo]Z00?oo`00o`000?l000000_l00003ool000Gooo]Z1?l0000`oookJPCo0000=_oo
nfX4o`00033ooo]Z1Ol0000OoookJP006ooonfX5o`0003;ooo]Z1?l0000eoookJPCo0000<_oonfX4
o`000003oookJ_l0003o000000?oo`001Ol000000ooo003ooo]ZoookJP0/oookJP03ool00?l0003o
000000;o00001?oo000^oookJPCoo`001?l000000ooo003ooo]ZoookJP0/oookJP03ool00?l0003o
000000;o00000ooo0005oookJPCo0000<?oonfX4o`0003Kooo]Z1?l0000`oookJPGo00007ooonfX0
01_ooo]Z1Ol0000boookJPCo0000=OoonfX5o`00033ooo]Z1Ol000000ooonf[o0000o`000004ool0
00Co000000?oo`00oookJ_oonfX0:ooonfX2ool000Co00000ooo000_oookJPCoo`001?l000000ooo
003ooo]ZoookJP0/oookJP03ool00?l0003o000000;o00000ooo0005oookJPCo0000<?oonfX4o`00
03Kooo]Z1?l0000`oookJPGo00007ooonfX001cooo]Z1?l0000boookJPCo0000=OoonfX5o`0001So
oo]Z1Ol007l4oookJP?o001o1OoonfX3o`00O`Cooo]Z1Ol000000ooonf[o0000o`000004ool000Co
000000?oo`00oookJ_oonfX0:ooonfX2ool000Co00000ooo000_oookJPCoo`001Ol0000^oookJP03
ool00?l0003o000000;o00000ooo0005oookJPCo0000<?oonfX4o`0003Kooo]Z1?l0000`oookJPCo
00008?oonfX001cooo]Z1?l0000aoookJPGo0000=OoonfX5o`0001Oooo]Z1ol007l3oookJP?o001o
1OoonfX3o`00O`Cooo]Z1Ol000000ooonf[o0000o`000004ool000Co000000?oo`00oookJ_oonfX0
:ooonfX2ool000Co00000ooo000`oookJP?oo`001Ol000000ooo003ooo]ZoookJP0[oookJP03ool0
0?l0003o000000;o00000ooo0005oookJPCo0000<?oonfX4o`0003Kooo]Z1?l0000`oookJPCo0000
8?oonfX001cooo]Z1?l0000aoookJPGo0000=_oonfX4o`0001Oooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o1OoonfX3o`00O`Cooo]Z1?l00002oookJP?o00000ooo0004o`000003ool0
0?oonf[ooo]Z02_ooo]Z00?oo`00o`000?l000000ol00003ool0033ooo]Z0ooo0005o`000003ool0
0?oonf[ooo]Z02_ooo]Z00?oo`00o`000?l000000_l00003ool000Gooo]Z1?l0000_oookJPGo0000
=_oonfX5o`0002oooo]Z1?l0000PoookJP007?oonfX4o`00037ooo]Z1Ol0000foookJPCo00005_oo
nfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX4o`0000;ooo]Z0ol00003ool000Co000000?o
o`00oookJ_oonfX0:ooonfX00ooo003o0000o`000003o`0000?oo`00<?oonfX4ool000Co000000?o
o`00oookJ_oonfX0:ooonfX00ooo003o0000o`000002o`0000?oo`001OoonfX4o`0002oooo]Z1Ol0
000foookJPGo0000;ooonfX4o`00023ooo]Z000LoookJPCo0000<OoonfX4o`0003Oooo]Z1?l0000F
oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJPCo00000_oonfX3o`0000?oo`001?l00000
0ooo003ooo]ZoookJP0[oookJP03ool00?l0003o000000?o00000ooo000`oookJPCoo`001?l00000
0ooo003ooo]ZoookJP0[oookJP03ool00?l0003o000000;o00000ooo0005oookJPCo0000;ooonfX5
o`0003Kooo]Z1Ol0000_oookJPCo00008?oonfX001cooo]Z1?l0000aoookJPCo0000=ooonfX4o`00
01Kooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1?l00002oookJP?o00000ooo0004o`00
0003ool00?oonf[ooo]Z02_ooo]Z00?oo`00o`000?l000000_l00004ool0033ooo]Z1?oo0004o`00
0003ool00?oonf[ooo]Z02[ooo]Z0_oo0004o`0000?oo`001OoonfX4o`0002oooo]Z1?l0000hoook
JPCo0000;ooonfX4o`00023ooo]Z000LoookJPCo0000<OoonfX4o`0003Oooo]Z1?l0000FoookJP?o
001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJPCo00000_oonfX3o`0000?oo`001Ol0000/oookJP;o
o`001?l00003ool0037ooo]Z1?oo0004o`000003ool00?oonf[ooo]Z02[ooo]Z0_oo0004o`0000?o
o`001OoonfX4o`0002oooo]Z1?l0000hoookJPCo0000;ooonfX4o`00023ooo]Z000LoookJPCo0000
<OoonfX4o`0003Oooo]Z1?l0000FoookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJPCo0000
0_oonfX3o`0000?oo`001Ol0000/oookJP;oo`001?l00003ool0037ooo]Z1?oo0004o`000003ool0
0?oonf[ooo]Z02[ooo]Z00?oo`00o`000?l000000ol00003ool000Gooo]Z1?l0000_oookJPCo0000
>?oonfX4o`0002oooo]Z1?l0000PoookJP007?oonfX4o`00037ooo]Z1?l0000goookJPGo00005Ooo
nfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX4o`0000;ooo]Z0ol00003ool000Go0000;?oo
nfX2ool000Co00000ooo000boookJP?oo`001?l00002ool002_ooo]Z00?oo`00o`000?l000000ol0
0003ool000Gooo]Z1?l0000_oookJPCo0000>?oonfX4o`0002oooo]Z1?l0000PoookJP007?oonfX5
o`0002oooo]Z1Ol0000goookJPGo00005OoonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o1?oonfX4
o`0000;ooo]Z0ol00004ool000Co0000;?oonfX2ool000Co00000ooo000boookJP?oo`001Ol00000
0ooo003ooo]ZoookJP0YoookJP03ool00?l0003o000000?o00000ooo0005oookJPCo0000;ooonfX4
o`0003Sooo]Z1?l0000_oookJPCo00008?oonfX001cooo]Z1Ol0000_oookJPGo0000=ooonfX5o`00
01Kooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPKo001o1?oonfX4o`0000;ooo]Z0ol00004
ool000Co0000;?oonfX00ooo003o0000o`000003o`0000?oo`00<_oonfX3ool000Go000000?oo`00
oookJ_oonfX0:OoonfX00ooo003o0000o`000002o`0000Coo`001OoonfX4o`0002oooo]Z1?l0000h
oookJPGo0000;_oonfX4o`00023ooo]Z000LoookJPGo0000;ooonfX5o`0003Sooo]Z1?l0000Foook
JPOo001o2_oonfX4o`00O`Cooo]Z1?l00002oookJP?o00001?oo0004o`0002cooo]Z00?oo`00o`00
0?l000000ol00003ool003;ooo]Z0ooo0005o`000003ool00?oonf[ooo]Z02Wooo]Z00?oo`00o`00
0?l000000_l00004ool000Gooo]Z1Ol0000]oookJPGo0000>?oonfX5o`0002kooo]Z1?l0000Poook
JP007OoonfX4o`0002oooo]Z1?l0000ioookJPCo00005ooonfX5o`00O`cooo]Z0ol007l4oookJPCo
00000_oonfX3o`0000Coo`001?l0000/oookJP03ool00?l0003o000000?o00000ooo000boookJPCo
o`001?l000000ooo003ooo]ZoookJP0YoookJP03ool00?l0003o000000;o00000ooo0006oookJPGo
0000;OoonfX5o`0003Sooo]Z1Ol0000]oookJPGo00008?oonfX001gooo]Z1?l0000_oookJPCo0000
>OoonfX4o`0002oooo]Z1?l00002oookJP?o00001?oo0004o`000003ool00?oonf[ooo]Z02Sooo]Z
0_oo0004o`0000?oo`00<ooonfX4ool000Co000000?oo`00oookJ_oonfX0:OoonfX00ooo003o0000
o`000002o`0000?oo`001_oonfX5o`0002gooo]Z1Ol0000ioookJPCo0000;OoonfX5o`00023ooo]Z
000MoookJPCo0000;ooonfX4o`0003Wooo]Z1?l0000^oookJPGo00000_oonfX3o`0000Coo`001?l0
00000ooo003ooo]ZoookJP0XoookJP;oo`001?l00003ool003?ooo]Z1?oo0004o`000003ool00?oo
nf[ooo]Z02Wooo]Z00?oo`00o`000?l000000_l00003ool000Oooo]Z1?l0000]oookJPCo0000>_oo
nfX4o`0002gooo]Z1Ol0000PoookJP007OoonfX4o`0002oooo]Z1?l0000ioookJPCo0000;_oonfX5
o`0000;ooo]Z0ol00004ool000Co000000?oo`00oookJ_oonfX0:?oonfX2ool000Co00000ooo000d
oookJP?oo`001?l000000ooo003ooo]ZoookJP0YoookJP03ool00?l0003o000000;o00000ooo0007
oookJPCo0000;OoonfX4o`0003[ooo]Z1?l0000]oookJPCo00008OoonfX001gooo]Z1?l0000_oook
JPCo0000>OoonfX5o`0002gooo]Z1Ol00002oookJP?o00001?oo0004o`000003ool00?oonf[ooo]Z
02Sooo]Z0_oo0004o`0000?oo`00=?oonfX3ool000Co00000_oo000ZoookJP03ool00?l0003o0000
00;o00000ooo0007oookJPCo0000;OoonfX4o`0003[ooo]Z1?l0000]oookJPCo00008OoonfX001go
oo]Z1?l0000^oookJPGo0000>OoonfX5o`0002gooo]Z1?l00003oookJP?o00001?oo0004o`000003
ool00?oonf[ooo]Z02Sooo]Z0_oo0004o`0000?oo`00=?oonfX3ool000Co00000_oo000ZoookJP03
ool00?l0003o000000;o00000ooo0007oookJPCo0000;OoonfX4o`0003[ooo]Z1Ol0000/oookJPCo
00008OoonfX001gooo]Z1?l0000^oookJPGo0000>OoonfX5o`0002gooo]Z1?l00003oookJP?o0000
1?oo0004o`000003ool00?oonf[ooo]Z02Sooo]Z0_oo0004o`0000?oo`00=?oonfX3ool000Go0000
00?oo`00oookJ_oonfX0:?oonfX00ooo003o0000o`000002o`0000?oo`001ooonfX4o`0002gooo]Z
1?l0000joookJPGo0000;?oonfX4o`00027ooo]Z000MoookJPCo0000;_oonfX5o`0003[ooo]Z1?l0
000]oookJPCo00000ooonfX3o`0000Coo`001?l000000ooo003ooo]ZoookJP0XoookJP03ool00?l0
003o000000?o00000ooo000doookJP?oo`001Ol000000ooo003ooo]ZoookJP0XoookJP03ool00?l0
003o000000;o00000ooo0007oookJPCo0000;OoonfX4o`0003[ooo]Z1Ol0000/oookJPCo00008Ooo
nfX001gooo]Z1Ol0000]oookJPCo0000>ooonfX4o`0002gooo]Z1?l00003oookJPCo00000ooo0004
o`000003ool00?oonf[ooo]Z02Oooo]Z0_oo0005o`0000;oo`00=OoonfX3ool000Go000000?oo`00
oookJ_oonfX0:?oonfX00ooo003o0000o`000002o`0000?oo`001ooonfX4o`0002cooo]Z1Ol0000k
oookJPCo0000;?oonfX4o`00027ooo]Z000MoookJPGo0000;OoonfX4o`0003_ooo]Z1?l0000]oook
JPCo00000ooonfX4o`0000?oo`001Ol0000YoookJP;oo`001Ol00002ool003Gooo]Z1?oo0004o`00
0003ool00?oonf[ooo]Z02Sooo]Z00?oo`00o`000?l000000_l00003ool000Oooo]Z1?l0000/oook
JPGo0000>ooonfX4o`0002cooo]Z1?l0000QoookJP007OoonfX5o`0002gooo]Z1?l0000koookJPCo
0000;OoonfX4o`0000?ooo]Z1?l00003ool000Go0000:OoonfX2ool000Co00000ooo000eoookJPCo
o`001?l000000ooo003ooo]ZoookJP0XoookJP03ool00?l0003o000000;o00000ooo0007oookJPCo
0000;?oonfX5o`0003_ooo]Z1?l0000/oookJPCo00008OoonfX001kooo]Z1?l0000]oookJPCo0000
>ooonfX4o`0002gooo]Z1?l00003oookJPCo00000ooo0005o`0002Wooo]Z0_oo0004o`0000?oo`00
=_oonfX3ool000Co00000_oo000YoookJP03ool00?l0003o000000;o00000ooo0007oookJPCo0000
;?oonfX4o`0003cooo]Z1?l0000/oookJPCo00008OoonfX001kooo]Z1?l0000]oookJPCo0000>ooo
nfX4o`0002gooo]Z1?l00003oookJPCo00001?oo0004o`0002Wooo]Z0_oo0004o`0000?oo`00=_oo
nfX3ool000Co00000_oo000YoookJP03ool00?l0003o000000;o00000ooo0007oookJPCo0000;?oo
nfX4o`0003cooo]Z1?l0000/oookJPCo00008OoonfX001kooo]Z1?l0000/oookJPGo0000>ooonfX5
o`0002cooo]Z1?l00003oookJPCo00001?oo0004o`0002Wooo]Z0_oo0004o`0000?oo`00=_oonfX3
ool000Co00000_oo000YoookJP03ool00?l0003o000000;o00000ooo0007oookJPCo0000;?oonfX4
o`0003cooo]Z1Ol0000[oookJPCo00008OoonfX001kooo]Z1?l0000/oookJPGo0000>ooonfX5o`00
02cooo]Z1?l00003oookJPCo00001?oo0004o`0002Wooo]Z0_oo0004o`0000?oo`00=_oonfX3ool0
00Co00000_oo000XoookJP03ool00?l0003o000000?o00000ooo0007oookJPCo0000;?oonfX4o`00
03cooo]Z1Ol0000[oookJPCo00008OoonfX001kooo]Z1?l0000/oookJPGo0000>ooonfX5o`0002_o
oo]Z1Ol00003oookJPCo00001?oo0004o`0002Sooo]Z0_oo0005o`0000;oo`00=ooonfX3ool000Go
000000?oo`00oookJ_oonfX09_oonfX00ooo003o0000o`000003o`0000?oo`001ooonfX4o`0002co
oo]Z1?l0000loookJPGo0000:ooonfX4o`00027ooo]Z000NoookJPCo0000;?oonfX4o`0003gooo]Z
1?l0000[oookJPGo00000ooonfX4o`0000Coo`001?l0000XoookJP;oo`001Ol00002ool003Oooo]Z
0ooo0005o`000003ool00?oonf[ooo]Z02Kooo]Z00?oo`00o`000?l000000ol00003ool000Oooo]Z
1Ol0000[oookJPCo0000?OoonfX4o`0002_ooo]Z1?l0000QoookJP007_oonfX4o`0002cooo]Z1?l0
000moookJPCo0000:ooonfX5o`0000?ooo]Z1?l00004ool000Co0000:?oonfX2ool000Go00000_oo
000goookJP?oo`001Ol000000ooo003ooo]ZoookJP0VoookJP03ool00?l0003o000000;o00001?oo
0007oookJPGo0000:_oonfX5o`0003gooo]Z1?l0000[oookJPCo00008OoonfX001kooo]Z1?l0000/
oookJPCo0000?OoonfX4o`0002_ooo]Z1?l00004oookJPCo00001?oo0004o`0002Sooo]Z0_oo0004
o`0000?oo`00>?oonfX3ool000Co000000?oo`00oookJ_oonfX09_oonfX00ooo003o0000o`000002
o`0000Coo`001ooonfX5o`0002[ooo]Z1Ol0000moookJPCo0000:_oonfX5o`00027ooo]Z000Noook
JPCo0000;?oonfX4o`0003gooo]Z1?l0000[oookJPCo00001?oonfX4o`0000Coo`001?l0000Xoook
JP;oo`001?l00003ool003Sooo]Z0ooo0004o`0000;oo`009ooonfX00ooo003o0000o`000002o`00
00Coo`002?oonfX4o`0002[ooo]Z1Ol0000moookJPCo0000:_oonfX5o`00027ooo]Z000NoookJPGo
0000:ooonfX4o`0003gooo]Z1?l0000[oookJPCo00001?oonfX4o`0000Coo`001?l000000ooo003o
oo]ZoookJP0UoookJP;oo`001?l00003ool003Sooo]Z0ooo0004o`0000;oo`009ooonfX00ooo003o
0000o`000002o`0000Coo`002?oonfX4o`0002[ooo]Z1?l0000noookJPCo0000:_oonfX5o`00027o
oo]Z000NoookJPGo0000:ooonfX4o`0003gooo]Z1?l0000[oookJPCo00001?oonfX4o`0000Coo`00
1?l000000ooo003ooo]ZoookJP0UoookJP;oo`001?l00003ool003Sooo]Z0ooo0004o`0000;oo`00
9ooonfX00ooo003o0000o`000002o`0000?oo`002OoonfX4o`0002[ooo]Z1?l0000noookJPGo0000
:OoonfX4o`0002;ooo]Z000NoookJPGo0000:_oonfX5o`0003gooo]Z1Ol0000ZoookJPCo00001?oo
nfX4o`0000Coo`001?l000000ooo003ooo]ZoookJP0ToookJP?oo`001?l00002ool003Wooo]Z0ooo
0004o`0000;oo`009ooonfX00ooo003o0000o`000002o`0000?oo`002OoonfX4o`0002[ooo]Z1?l0
000noookJPGo0000:OoonfX4o`0002;ooo]Z000OoookJPCo0000:_oonfX5o`0003gooo]Z1Ol0000Z
oookJPCo00001?oonfX4o`0000Coo`001?l000000ooo003ooo]ZoookJP0ToookJP?oo`001?l00002
ool003Wooo]Z0ooo0004o`0000;oo`009ooonfX00ooo003o0000o`000002o`0000?oo`002OoonfX4
o`0002[ooo]Z1?l0000noookJPGo0000:OoonfX4o`0002;ooo]Z000OoookJPCo0000:_oonfX5o`00
03gooo]Z1Ol0000ZoookJPCo00001?oonfX4o`0000Coo`001?l000000ooo003ooo]ZoookJP0Toook
JP;oo`001Ol00002ool003Wooo]Z0ooo0005o`000003ool00?oonf[ooo]Z02Gooo]Z00?oo`00o`00
0?l000000_l00003ool000Wooo]Z1?l0000ZoookJPCo0000?ooonfX4o`0002Wooo]Z1?l0000Roook
JP007ooonfX4o`0002[ooo]Z1?l0000ooookJPCo0000:_oonfX4o`0000Cooo]Z1?l00004ool000Co
000000?oo`00oookJ_oonfX09?oonfX2ool000Go00000_oo000ioookJP?oo`001Ol000000ooo003o
oo]ZoookJP0UoookJP03ool00?l0003o000000;o00000ooo0009oookJPCo0000:_oonfX4o`0003oo
oo]Z1?l0000YoookJPCo00008_oonfX001oooo]Z1?l0000ZoookJPCo0000?ooonfX4o`0002[ooo]Z
1?l00004oookJPCo00001?oo0004o`000003ool00?oonf[ooo]Z02Cooo]Z0_oo0005o`0000;oo`00
>_oonfX2ool000Go00000_oo000VoookJP03ool00?l0003o000000;o00000ooo0009oookJPCo0000
:OoonfX5o`0003oooo]Z1?l0000YoookJPCo00008_oonfX001oooo]Z1?l0000ZoookJPCo0000?ooo
nfX4o`0002[ooo]Z1?l00004oookJPGo00000ooo0004o`000003ool00?oonf[ooo]Z02Cooo]Z0_oo
0004o`0000?oo`00>_oonfX3ool000Co00000_oo000VoookJP03ool00?l0003o000000;o00000ooo
0009oookJPCo0000:OoonfX5o`0003oooo]Z1?l0000YoookJPCo00008_oonfX001oooo]Z1?l0000Z
oookJPCo0000?ooonfX4o`0002Wooo]Z1Ol00004oookJPGo00000ooo0004o`000003ool00?oonf[o
oo]Z02Cooo]Z0_oo0004o`0000?oo`00>_oonfX3ool000Co00000_oo000VoookJP03ool00?l0003o
000000;o00000ooo0009oookJPCo0000:OoonfX5o`0003oooo]Z1?l0000YoookJPCo00008_oonfX0
01oooo]Z1?l0000ZoookJPCo0000?ooonfX4o`0002Wooo]Z1Ol00004oookJPGo00000ooo0004o`00
0003ool00?oonf[ooo]Z02?ooo]Z0ooo0004o`0000;oo`00>ooonfX3ool000Co00000_oo000Voook
JP03ool00?l0003o000000;o00000ooo0009oookJPCo0000:OoonfX4o`00043ooo]Z1Ol0000Xoook
JPCo00008_oonfX001oooo]Z1?l0000ZoookJPCo0000?ooonfX5o`0002Sooo]Z1Ol00004oookJPGo
00000ooo0005o`0002Gooo]Z0ooo0004o`0000;oo`00>ooonfX3ool000Co00000_oo000VoookJP03
ool00?l0003o000000;o00000ooo0009oookJPCo0000:OoonfX4o`00043ooo]Z1Ol0000XoookJPCo
00008_oonfX001oooo]Z1Ol0000XoookJPGo0000?ooonfX5o`0002Sooo]Z1?l00005oookJPGo0000
0ooo0005o`0002Gooo]Z0ooo0004o`0000;oo`00>ooonfX3ool000Co00000_oo000VoookJPGo0000
0ooo0009oookJPGo0000:?oonfX4o`00043ooo]Z1Ol0000XoookJPCo00008_oonfX001oooo]Z1Ol0
000XoookJPGo0000?ooonfX5o`0002Sooo]Z1?l00005oookJPGo00000ooo0005o`0002Gooo]Z0ooo
0004o`0000;oo`00>ooonfX3ool000Co00000_oo000VoookJPGo00000ooo0009oookJPGo0000:?oo
nfX4o`00047ooo]Z1?l0000XoookJPCo00008_oonfX001oooo]Z1Ol0000XoookJPGo0000@?oonfX4
o`0002Sooo]Z1?l00005oookJPGo00001?oo0004o`0002Gooo]Z0_oo0005o`0000;oo`00??oonfX2
ool000Co00000_oo000UoookJP03ool00?l0003o000000?o00000ooo0009oookJPGo0000:?oonfX4
o`00047ooo]Z1?l0000XoookJPCo00008_oonfX0023ooo]Z1?l0000XoookJPCo0000@OoonfX4o`00
02Sooo]Z1?l00005oookJPGo00001?oo0004o`0002Gooo]Z0_oo0005o`0000;oo`00??oonfX2ool0
00Go00000_oo000ToookJP03ool00?l0003o000000;o00001?oo000:oookJPCo0000:?oonfX4o`00
047ooo]Z1?l0000XoookJPCo00008_oonfX0023ooo]Z1?l0000XoookJPCo0000@OoonfX4o`0002So
oo]Z1?l00005oookJPGo00001?oo0004o`0002Gooo]Z0_oo0005o`0000;oo`00??oonfX2ool000Go
00000_oo000ToookJP03ool00?l0003o000000;o00001?oo000:oookJPCo00009ooonfX5o`00047o
oo]Z1?l0000XoookJPCo00008_oonfX0023ooo]Z1?l0000XoookJPCo0000@OoonfX4o`0002Sooo]Z
1?l00005oookJPGo00001?oo0004o`000003ool00?oonf[ooo]Z027ooo]Z0ooo0004o`0000;oo`00
?OoonfX2ool000Go00000_oo000ToookJP03ool00?l0003o000000;o00001?oo000:oookJPCo0000
9ooonfX5o`00047ooo]Z1?l0000XoookJPCo00008_oonfX0023ooo]Z1?l0000XoookJPCo0000@Ooo
nfX4o`0002Sooo]Z1?l00005oookJPGo00001?oo0004o`000003ool00?oonf[ooo]Z027ooo]Z0ooo
0004o`0000;oo`00?OoonfX3ool000Co00000_oo000ToookJP03ool00?l0003o000000;o00001?oo
000:oookJPCo00009ooonfX5o`00047ooo]Z1?l0000WoookJPGo00008_oonfX0023ooo]Z1?l0000X
oookJPCo0000@OoonfX5o`0002Oooo]Z1?l00005oookJPGo00001?oo0004o`000003ool00?oonf[o
oo]Z027ooo]Z0ooo0004o`0000;oo`00?OoonfX3ool000Co00000_oo000ToookJP03ool00?l0003o
000000;o00001?oo000:oookJPCo00009ooonfX4o`0004;ooo]Z1Ol0000VoookJPGo00008_oonfX0
023ooo]Z1?l0000XoookJPCo0000@OoonfX5o`0002Oooo]Z1?l00005oookJPGo00001?oo0004o`00
0003ool00?oonf[ooo]Z027ooo]Z0ooo0004o`0000;oo`00?OoonfX3ool000Co00000_oo000Toook
JP03ool00?l0003o000000;o00001?oo000:oookJPCo00009ooonfX4o`0004;ooo]Z1Ol0000Voook
JPGo00008_oonfX0023ooo]Z1?l0000WoookJPGo0000@OoonfX5o`0002Oooo]Z1?l00005oookJPGo
00001?oo0004o`000003ool00?oonf[ooo]Z027ooo]Z0ooo0004o`0000;oo`00?OoonfX3ool000Co
00000_oo000ToookJP03ool00?l0003o000000;o00000ooo000;oookJPCo00009ooonfX4o`0004;o
oo]Z1Ol0000VoookJPCo00008ooonfX0023ooo]Z1?l0000WoookJPGo0000@_oonfX4o`0002Oooo]Z
1?l00005oookJPGo00001?oo0004o`000003ool00?oonf[ooo]Z027ooo]Z0_oo0005o`0000;oo`00
?_oonfX2ool000Co00000_oo000ToookJP03ool00?l0003o000000;o00000ooo000;oookJPCo0000
9ooonfX4o`0004?ooo]Z1?l0000VoookJPCo00008ooonfX0023ooo]Z1?l0000WoookJPGo0000@_oo
nfX4o`0002Oooo]Z1?l00005oookJPGo00001?oo0004o`000003ool00?oonf[ooo]Z027ooo]Z0_oo
0005o`0000;oo`00?_oonfX2ool000Co00000ooo000SoookJP03ool00?l0003o000000;o00000ooo
000;oookJPCo00009ooonfX4o`0004?ooo]Z1?l0000VoookJPCo00008ooonfX0023ooo]Z1Ol0000V
oookJPCo0000@ooonfX4o`0002Kooo]Z1Ol00005oookJPGo000000Cooo]Zool00?oo003oo`001?l0
00000ooo003ooo]ZoookJP0QoookJP;oo`001Ol000000ooo003ooo]ZoookJP0moookJP;oo`001Ol0
0002ool002?ooo]Z00?oo`00o`000?l000000_l00003ool000_ooo]Z1?l0000WoookJPCo0000@ooo
nfX4o`0002Kooo]Z1?l0000SoookJP008?oonfX5o`0002Kooo]Z1?l00013oookJPCo00009_oonfX5
o`0000Gooo]Z1Ol000001?oonf[oo`00ool00?oo0004o`000003ool00?oonf[ooo]Z023ooo]Z0ooo
0004o`0000;oo`00?ooonfX2ool000Go00000_oo000SoookJP03ool00?l0003o000000;o00000ooo
000;oookJPCo00009_oonfX5o`0004?ooo]Z1?l0000VoookJPCo00008ooonfX0023ooo]Z1Ol0000V
oookJPCo0000@ooonfX4o`0002Kooo]Z1Ol00005oookJPGo000000Cooo]Zool00?oo003oo`001?l0
00000ooo003ooo]ZoookJP0PoookJP?oo`001?l00002ool003oooo]Z0_oo0005o`0000;oo`008ooo
nfX00ooo003o0000o`000002o`0000?oo`002ooonfX4o`0002Kooo]Z1Ol00013oookJPCo00009_oo
nfX4o`0002?ooo]Z000QoookJPCo00009_oonfX4o`0004?ooo]Z1?l0000VoookJPCo00001_oonfX5
o`000004oookJ_oo003oo`00ool000Co000000?oo`00oookJ_oonfX08?oonfX3ool000Co00000_oo
000ooookJP?oo`001?l00002ool002?ooo]Z1Ol00003ool000_ooo]Z1?l0000VoookJPGo0000@ooo
nfX4o`0002Kooo]Z1?l0000SoookJP008OoonfX4o`0002Kooo]Z1?l00013oookJPGo00009OoonfX4
o`0000Kooo]Z1Ol000001?oonf[oo`00ool00?oo0004o`000003ool00?oonf[ooo]Z023ooo]Z0ooo
0004o`0000;oo`00?ooonfX3ool000Co00000_oo000SoookJPGo00000ooo000;oookJPGo00009Ooo
nfX4o`0004Cooo]Z1Ol0000UoookJPCo00008ooonfX0027ooo]Z1?l0000VoookJPCo0000@ooonfX5
o`0002Gooo]Z1?l00006oookJPGo000000Cooo]Zool00?oo003oo`001?l000000ooo003ooo]Zoook
JP0PoookJP?oo`001?l00002ool003oooo]Z0ooo0004o`0000;oo`008ooonfX5o`0000?oo`002ooo
nfX5o`0002Gooo]Z1?l00014oookJPGo00009OoonfX4o`0002?ooo]Z000QoookJPCo00009OoonfX5
o`0004?ooo]Z1Ol0000UoookJPCo00001_oonfX5o`000004oookJ_oo003oo`00ool000Co000000?o
o`00oookJ_oonfX08?oonfX3ool000Co00000_oo0010oookJP;oo`001?l00003ool002;ooo]Z1?l0
0004ool000_ooo]Z1Ol0000UoookJPCo0000A?oonfX5o`0002Gooo]Z1?l0000SoookJP008OoonfX4
o`0002Gooo]Z1Ol00014oookJPCo00001ooonfX5o`00O`Cooo]Z0ol007l5oookJP?o001o1OoonfX5
o`00O`Co00001_oonfX5o`000004oookJ_oo003oo`00ool000Go000000?oo`00oookJ_oonfX07ooo
nfX2ool000Go00000_oo0010oookJP;oo`001?l00003ool002;ooo]Z1?l00004ool000cooo]Z1?l0
000UoookJPCo0000AOoonfX4o`0002Gooo]Z1?l0000SoookJP008OoonfX4o`0002Gooo]Z1Ol00014
oookJPCo00001_oonfX7o`00O`?ooo]Z0ol007l5oookJP?o001o1?oonfX6o`00O`Co00001_oonfX5
o`000004oookJ_oo003oo`00ool000Go000000?oo`00oookJ_oonfX07_oonfX3ool000Go000000?o
o`00oookJ_oonfX0?ooonfX2ool000Co00000ooo000RoookJPCo00001?oo000<oookJPCo00009Ooo
nfX4o`0004Gooo]Z1?l0000UoookJPCo00008ooonfX0027ooo]Z1?l0000UoookJPCo0000AOoonfX4
o`0000Kooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX3o`00O`?ooo]Z1?l0
07l00ooonf[o001oo`00O`04o`0000Kooo]Z1Ol000001?oonf[oo`00ool00?oo0005o`000003ool0
0?oonf[ooo]Z01kooo]Z0ooo0005o`000003ool00?oonf[ooo]Z03oooo]Z0_oo0004o`0000?oo`00
8OoonfX00ooo003o0000o`000002o`0000Coo`003?oonfX4o`0002Gooo]Z1?l00015oookJPCo0000
9OoonfX4o`0002?ooo]Z000QoookJPCo00009OoonfX4o`0004Gooo]Z1?l00005oookJP?o001o0ooo
nfX3o`00O`[ooo]Z0ol007l3oookJP?o001o0ooonfX00ol007oo0000o`000002o`0000Kooo]Z1Ol0
00000ooonf[oo`00ool00002ool000Co000000?oo`00oookJ_oonfX07_oonfX3ool000Co00000_oo
0011oookJP;oo`001Ol00002ool0027ooo]Z00?oo`00o`000?l000000_l00004ool000cooo]Z1?l0
000ToookJPGo0000AOoonfX4o`0002Gooo]Z1?l0000SoookJP008OoonfX5o`0002Cooo]Z1?l00015
oookJPCo00001OoonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2OoonfX00ol007oo0000o`000002
o`0000Kooo]Z1_l00004ool000Co000000?oo`00oookJ_oonfX07_oonfX3ool000Co00000_oo0011
oookJP;oo`001Ol00002ool0027ooo]Z00?oo`00o`000?l000000_l00004ool000cooo]Z1?l0000T
oookJPGo0000AOoonfX4o`0002Cooo]Z1Ol0000SoookJP008OoonfX5o`0002Cooo]Z1?l00015oook
JPGo00001?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2OoonfX00ol007oo0000o`000002o`00
00Kooo]Z1Ol000000ooonf[oo`00ool00002ool000Co000000?oo`00oookJ_oonfX07_oonfX3ool0
00Co00000_oo0011oookJP;oo`001Ol00002ool0027ooo]Z00?oo`00o`000?l000000_l00004ool0
00cooo]Z1?l0000ToookJPGo0000AOoonfX5o`0002?ooo]Z1Ol0000SoookJP008OoonfX5o`0002Co
oo]Z1?l00015oookJPGo00001?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX2o`00O`;o
oo]Z0_l007l4o`0000Kooo]Z1Ol000000ooonf[oo`00ool00002ool000Co000000?oo`00oookJ_oo
nfX07_oonfX3ool000Co00000_oo0012oookJP;oo`001?l00003ool0023ooo]Z00?oo`00o`000?l0
00000_l00004ool000cooo]Z1?l0000ToookJPCo0000A_oonfX5o`0002?ooo]Z1Ol0000SoookJP00
8_oonfX4o`0002Cooo]Z1?l00015oookJPGo00001?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o
1?oonfX6o`00O`Co00001_oonfX5o`0000;ooo]Z0ooo0004o`000003ool00?oonf[ooo]Z01kooo]Z
0ooo0004o`0000;oo`00@_oonfX2ool000Co00000ooo000PoookJP03ool00?l0003o000000;o0000
1?oo000<oookJPCo00009?oonfX4o`0004Kooo]Z1Ol0000SoookJPCo00009?oonfX002;ooo]Z1?l0
000SoookJPGo0000A_oonfX4o`0000Cooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1_l0
07l4o`0000Kooo]Z1Ol00002oookJP?oo`001?l000000ooo003ooo]ZoookJP0NoookJP?oo`001?l0
00000ooo003ooo]ZoookJP11oookJP;oo`001?l00003ool0023ooo]Z00?oo`00o`000?l000000_l0
0004ool000cooo]Z1?l0000ToookJPCo0000AooonfX4o`0002?ooo]Z1?l0000ToookJP008_oonfX4
o`0002?ooo]Z1Ol00016oookJPCo00001?oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o1?oonfX2
o`00O`Cooo]Z1?l00006oookJPGo00000_oonfX3ool000Co000000?oo`00oookJ_oonfX07OoonfX3
ool000Go000000?oo`00oookJ_oonfX0@OoonfX2ool000Co00000ooo000PoookJP03ool00?l0003o
000000;o00000ooo000=oookJPCo00009?oonfX4o`0004Oooo]Z1?l0000SoookJPCo00009?oonfX0
02;ooo]Z1?l0000SoookJPGo0000A_oonfX4o`0000Gooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJPKo001o1?oonfX2o`00O`Cooo]Z1?l00006oookJPGo00000_oonfX3ool000Co000000?oo`00
oookJ_oonfX07OoonfX3ool000Go000000?oo`00oookJ_oonfX0@OoonfX2ool000Co00000ooo000P
oookJP03ool00?l0003o000000;o00000ooo000=oookJPCo00009?oonfX4o`0004Oooo]Z1?l0000S
oookJPCo00009?oonfX002;ooo]Z1?l0000SoookJPCo0000AooonfX4o`0000Gooo]Z1ol007l:oook
JPCo001o1OoonfX4o`00O`Go00001_oonfX5o`0000;ooo]Z0ooo0004o`000003ool00?oonf[ooo]Z
01gooo]Z0ooo0005o`000003ool00?oonf[ooo]Z047ooo]Z0_oo0004o`0000?oo`008?oonfX00ooo
003o0000o`000002o`0000?oo`003OoonfX4o`0002Cooo]Z1?l00017oookJPCo00008ooonfX4o`00
02Cooo]Z000RoookJPCo00008ooonfX4o`0004Oooo]Z1?l00006oookJPGo001o3?oonfX3o`00O`Go
oo]Z1?l007l5o`0000Kooo]Z1Ol00002oookJP?oo`001?l000000ooo003ooo]ZoookJP0MoookJP?o
o`001?l00002ool004?ooo]Z0_oo0004o`0000?oo`008?oonfX5o`0000?oo`003OoonfX4o`0002?o
oo]Z1Ol00017oookJPCo00008ooonfX4o`0002Cooo]Z000RoookJPCo00008ooonfX4o`0004Oooo]Z
1Ol0000RoookJPGo00001_oonfX5o`0000;ooo]Z0ooo0004o`000003ool00?oonf[ooo]Z01gooo]Z
0ooo0004o`0000;oo`00A?oonfX00ooo003o0000o`000003o`0000?oo`007ooonfX5o`0000?oo`00
3OoonfX5o`0002;ooo]Z1Ol00017oookJPCo00008ooonfX4o`0002Cooo]Z000RoookJPCo00008ooo
nfX4o`0004Oooo]Z1Ol0000RoookJPCo00001ooonfX5o`0000;ooo]Z0ooo0004o`000003ool00?oo
nf[ooo]Z01gooo]Z0ooo0004o`0000;oo`00A?oonfX00ooo003o0000o`000003o`0000?oo`007ooo
nfX5o`0000?oo`003OoonfX5o`0002;ooo]Z1Ol00017oookJPGo00008_oonfX4o`0002Cooo]Z000R
oookJPCo00008ooonfX4o`0004Oooo]Z1Ol0000RoookJPCo00001ooonfX5o`0000;ooo]Z0ooo0004
o`0000;oo`007_oonfX3ool000Co00000_oo0014oookJP03ool00?l0003o000000?o00000ooo000O
oookJPCo00001?oo000=oookJPGo00008_oonfX4o`0004Sooo]Z1Ol0000RoookJPCo00009?oonfX0
02;ooo]Z1?l0000RoookJPGo0000B?oonfX4o`0002;ooo]Z1?l00007oookJPGo00000_oonfX3ool0
00Co00000_oo000MoookJPCoo`001?l000000ooo003ooo]ZoookJP13oookJP;oo`001?l00003ool0
01oooo]Z1?l00004ool000kooo]Z1?l0000RoookJPCo0000B?oonfX5o`0002;ooo]Z1?l0000Toook
JP008_oonfX5o`00027ooo]Z1Ol00018oookJPCo00008_oonfX4o`0000Oooo]Z1Ol00002oookJP?o
o`001?l00002ool001gooo]Z1?oo0004o`000003ool00?oonf[ooo]Z04?ooo]Z0_oo0004o`0000?o
o`007ooonfX4o`0000Coo`003_oonfX4o`0002;ooo]Z1?l00019oookJPCo00008_oonfX4o`0002Co
oo]Z000RoookJPGo00008OoonfX5o`0004Sooo]Z1?l0000RoookJPCo00001ooonfX5o`0000;ooo]Z
0ooo0004o`0000;oo`007OoonfX3ool000Go000000?oo`00oookJ_oonfX0@ooonfX2ool000Co0000
0ooo000NoookJP03ool00?l0003o000000;o00001?oo000>oookJPCo00008_oonfX4o`0004Wooo]Z
1?l0000QoookJPGo00009?oonfX002;ooo]Z1Ol0000QoookJPCo0000BOoonfX4o`0002;ooo]Z1?l0
0007oookJPGo00000_oonfX3ool000Co00000_oo000MoookJP?oo`001Ol000000ooo003ooo]Zoook
JP13oookJP;oo`001?l00003ool001kooo]Z00?oo`00o`000?l000000_l00004ool000kooo]Z1?l0
000RoookJPCo0000BOoonfX4o`00027ooo]Z1Ol0000ToookJP008ooonfX4o`00027ooo]Z1?l00019
oookJPCo00008_oonfX4o`0000Oooo]Z1Ol00002oookJP?oo`001?l00002ool001gooo]Z0ooo0005
o`000003ool00?oonf[ooo]Z04Cooo]Z00?oo`00o`000?l000000_l00004ool001gooo]Z00?oo`00
o`000?l000000_l00004ool000kooo]Z1?l0000QoookJPGo0000BOoonfX4o`00027ooo]Z1Ol0000T
oookJP008ooonfX4o`00027ooo]Z1?l00019oookJPCo00008_oonfX4o`0000Oooo]Z1Ol00002oook
JP?oo`001Ol000000ooo003ooo]ZoookJP0KoookJP?oo`001?l00002ool004Kooo]Z00?oo`00o`00
0?l000000_l00004ool001gooo]Z00?oo`00o`000?l000000_l00004ool000kooo]Z1?l0000Qoook
JPGo0000BOoonfX4o`00027ooo]Z1?l0000UoookJP008ooonfX4o`00027ooo]Z1?l00019oookJPGo
00008OoonfX4o`0000Oooo]Z1Ol00003oookJP;oo`001Ol000000ooo003ooo]ZoookJP0KoookJP?o
o`001?l00002ool004Kooo]Z00?oo`00o`000?l000000ol00003ool001gooo]Z00?oo`00o`000?l0
00000_l00004ool000kooo]Z1?l0000QoookJPGo0000BOoonfX4o`00027ooo]Z1?l0000UoookJP00
8ooonfX4o`00023ooo]Z1Ol00019oookJPGo00008OoonfX4o`0000Oooo]Z1Ol00003oookJP;oo`00
1Ol000000ooo003ooo]ZoookJP0KoookJP?oo`001?l000000ooo003ooo]ZoookJP15oookJP03ool0
0?l0003o000000?o00000ooo000MoookJP03ool00?l0003o000000;o00001?oo000>oookJPCo0000
8OoonfX4o`0004[ooo]Z1Ol0000PoookJPCo00009OoonfX002?ooo]Z1?l0000PoookJPGo0000BOoo
nfX5o`00027ooo]Z1?l00007oookJPGo00000ooonfX3ool000Co000000?oo`00oookJ_oonfX06_oo
nfX4ool000Co000000?oo`00oookJ_oonfX0AOoonfX00ooo003o0000o`000003o`0000?oo`007Ooo
nfX00ooo003o0000o`000002o`0000Coo`003_oonfX4o`00027ooo]Z1?l0001:oookJPGo00008?oo
nfX4o`0002Gooo]Z000SoookJPCo00008?oonfX5o`0004[ooo]Z1?l0000QoookJPCo00001ooonfX5
o`0000?ooo]Z0ooo0004o`000003ool00?oonf[ooo]Z01[ooo]Z1?oo0004o`000003ool00?oonf[o
oo]Z04Gooo]Z0_oo0004o`0000?oo`007OoonfX00ooo003o0000o`000002o`0000?oo`003ooonfX4
o`00027ooo]Z1?l0001:oookJPGo00008?oonfX4o`0002Gooo]Z000SoookJPCo00008?oonfX4o`00
04_ooo]Z1?l0000QoookJPCo00001ooonfX5o`0000?ooo]Z0ooo0004o`000003ool00?oonf[ooo]Z
01[ooo]Z1?oo0004o`000003ool00?oonf[ooo]Z04Gooo]Z0_oo0004o`0000?oo`007OoonfX00ooo
003o0000o`000002o`0000?oo`003ooonfX4o`00027ooo]Z1?l0001;oookJPCo00008?oonfX4o`00
02Gooo]Z000SoookJPCo00008?oonfX4o`0004_ooo]Z1?l0000QoookJPCo00001ooonfX5o`0000?o
oo]Z0ooo0004o`000003ool00?oonf[ooo]Z01[ooo]Z1?oo0004o`000003ool00?oonf[ooo]Z04Ko
oo]Z00?oo`00o`000?l000000_l00004ool001cooo]Z00?oo`00o`000?l000000_l00003ool000oo
oo]Z1?l0000QoookJPCo0000BooonfX4o`00023ooo]Z1?l0000UoookJP008ooonfX4o`00023ooo]Z
1?l0001;oookJPCo00008OoonfX4o`0000Oooo]Z1Ol00003oookJP?oo`001?l000000ooo003ooo]Z
oookJP0JoookJPCoo`001?l000000ooo003ooo]ZoookJP16oookJP03ool00?l0003o000000;o0000
1?oo000LoookJPGo00000ooo000?oookJPGo00007ooonfX5o`0004_ooo]Z1?l0000PoookJPCo0000
9OoonfX002?ooo]Z1?l0000PoookJPCo0000BooonfX5o`0001oooo]Z1Ol00007oookJPGo00000ooo
nfX3ool000Co00000_oo000KoookJP?oo`001Ol000000ooo003ooo]ZoookJP16oookJP03ool00?l0
003o000000;o00001?oo000LoookJPGo00000ooo000?oookJPGo00007ooonfX5o`0004_ooo]Z1?l0
000PoookJPCo00009OoonfX002?ooo]Z1?l0000PoookJPCo0000BooonfX5o`0001oooo]Z1Ol00007
oookJPGo00000ooonfX3ool000Co00000_oo000KoookJP?oo`001Ol000000ooo003ooo]ZoookJP16
oookJP03ool00?l0003o000000?o00000ooo000KoookJP03ool00?l0003o000000?o00000ooo000?
oookJPGo00007ooonfX5o`0004_ooo]Z1Ol0000OoookJPCo00009OoonfX002?ooo]Z1?l0000Ooook
JPGo0000BooonfX5o`0001oooo]Z1Ol00007oookJPGo00000ooonfX3ool000Co00000_oo000Koook
JP?oo`001Ol00019oookJP03ool00?l0003o000000?o00000ooo000KoookJP03ool00?l0003o0000
00;o00001?oo000@oookJPCo00007ooonfX4o`0004cooo]Z1Ol0000OoookJPCo00009OoonfX002?o
oo]Z1Ol0000NoookJPGo0000C?oonfX4o`0001oooo]Z1?l00008oookJPGo00000ooonfX3ool000Co
00000_oo000JoookJPCoo`001?l000000ooo003ooo]ZoookJP17oookJP03ool00?l0003o000000?o
00000ooo000KoookJP03ool00?l0003o000000;o00001?oo000@oookJPCo00007ooonfX4o`0004co
oo]Z1Ol0000NoookJPGo00009OoonfX002?ooo]Z1Ol0000NoookJPGo0000C?oonfX4o`0001oooo]Z
1?l00008oookJPGo00000ooonfX3ool000Co00000_oo000JoookJPCoo`001?l000000ooo003ooo]Z
oookJP17oookJP;oo`001?l00004ool001[ooo]Z00?oo`00o`000?l000000_l00004ool0013ooo]Z
1?l0000OoookJPCo0000COoonfX4o`0001kooo]Z1Ol0000UoookJP008ooonfX5o`0001kooo]Z1?l0
001=oookJPCo00007ooonfX4o`0000Sooo]Z1Ol00003oookJP?oo`001?l00002ool001[ooo]Z1?oo
0004o`000003ool00?oonf[ooo]Z04Sooo]Z00?oo`00o`000?l000000_l00004ool001[ooo]Z00?o
o`00o`000?l000000_l00004ool0013ooo]Z1?l0000OoookJPCo0000COoonfX4o`0001kooo]Z1Ol0
000UoookJP009?oonfX4o`0001kooo]Z1?l0001=oookJPCo00007ooonfX4o`0000Sooo]Z1Ol00003
oookJP?oo`001?l00002ool001[ooo]Z1?oo0004o`000003ool00?oonf[ooo]Z04Sooo]Z00?oo`00
o`000?l000000_l00004ool001[ooo]Z00?oo`00o`000?l000000_l00004ool0013ooo]Z1?l0000N
oookJPGo0000COoonfX4o`0001kooo]Z1?l0000VoookJP009?oonfX4o`0001kooo]Z1?l0001=oook
JPGo00007_oonfX4o`0000Sooo]Z1Ol00004oookJP;oo`001?l00002ool001[ooo]Z1?oo0004o`00
0003ool00?oonf[ooo]Z04Sooo]Z00?oo`00o`000?l000000_l00004ool001[ooo]Z00?oo`00o`00
0?l000000_l00004ool0013ooo]Z1?l0000NoookJPGo0000COoonfX4o`0001kooo]Z1?l0000Voook
JP009?oonfX4o`0001kooo]Z1?l0001=oookJPGo00007_oonfX4o`0000Sooo]Z1Ol00004oookJP;o
o`001?l00002ool001[ooo]Z1?oo0004o`000003ool00?oonf[ooo]Z04Sooo]Z00?oo`00o`000?l0
00000ol00003ool001[ooo]Z00?oo`00o`000?l000000_l00003ool0017ooo]Z1?l0000NoookJPGo
0000COoonfX5o`0001gooo]Z1?l0000VoookJP009?oonfX4o`0001kooo]Z1?l0001=oookJPGo0000
7_oonfX4o`0000Sooo]Z1Ol00004oookJP;oo`001Ol000000ooo003ooo]ZoookJP0HoookJP?oo`00
1Ol000000ooo003ooo]ZoookJP18oookJP03ool00?l0003o000000?o00000ooo000JoookJP03ool0
0?l0003o000000;o00000ooo000AoookJPCo00007_oonfX4o`0004kooo]Z1Ol0000MoookJPCo0000
9_oonfX002Cooo]Z1?l0000MoookJPGo0000C_oonfX4o`0001kooo]Z1?l00008oookJPGo00001?oo
nfX2ool000Go000000?oo`00oookJ_oonfX05ooonfX4ool000Go0000BooonfX00ooo003o0000o`00
0003o`0000?oo`006_oonfX00ooo003o0000o`000002o`0000?oo`004OoonfX4o`0001kooo]Z1?l0
001>oookJPGo00007OoonfX4o`0002Kooo]Z000ToookJPCo00007OoonfX5o`0004kooo]Z1?l0000N
oookJPCo00002?oonfX5o`0000Cooo]Z0_oo0005o`000003ool00?oonf[ooo]Z01Oooo]Z1?oo0005
o`0004cooo]Z00?oo`00o`000?l000000_l00004ool001Wooo]Z00?oo`00o`000?l000000_l00003
ool0017ooo]Z1?l0000NoookJPCo0000CooonfX4o`0001gooo]Z1?l0000VoookJP009?oonfX4o`00
01gooo]Z1Ol0001>oookJPCo00007_oonfX4o`0000Sooo]Z1Ol00004oookJP?oo`001?l000000ooo
003ooo]ZoookJP0GoookJPCoo`001?l000000ooo003ooo]ZoookJP1:oookJP03ool00?l0003o0000
00;o00001?oo000IoookJP03ool00?l0003o000000;o00000ooo000AoookJPCo00007OoonfX5o`00
04oooo]Z1?l0000MoookJPCo00009_oonfX002Cooo]Z1?l0000MoookJPCo0000CooonfX4o`0001ko
oo]Z1?l00008oookJPGo00001?oonfX3ool000Co00000_oo000HoookJPCoo`001?l000000ooo003o
oo]ZoookJP1:oookJP03ool00?l0003o000000;o00001?oo000HoookJP;oo`001?l00003ool0017o
oo]Z1?l0000MoookJPGo0000CooonfX4o`0001gooo]Z1?l0000VoookJP009?oonfX4o`0001gooo]Z
1?l0001?oookJPGo00007OoonfX4o`0000Sooo]Z1Ol00004oookJP?oo`001?l00002ool001Sooo]Z
0ooo0005o`000003ool00?oonf[ooo]Z04[ooo]Z00?oo`00o`000?l000000_l00004ool001Sooo]Z
00?oo`00o`000?l000000ol00003ool0017ooo]Z1?l0000MoookJPGo0000CooonfX4o`0001gooo]Z
1?l0000VoookJP009?oonfX4o`0001gooo]Z1?l0001?oookJPGo00007OoonfX4o`0000Sooo]Z1Ol0
0004oookJP?oo`001?l00002ool001Sooo]Z0ooo0005o`000003ool00?oonf[ooo]Z04[ooo]Z00?o
o`00o`000?l000000ol00003ool001Sooo]Z00?oo`00o`000?l000000ol00003ool0017ooo]Z1Ol0
000LoookJPCo0000D?oonfX5o`0001cooo]Z1?l0000VoookJP009?oonfX4o`0001gooo]Z1?l0001?
oookJPGo00007OoonfX4o`0000Sooo]Z1Ol00004oookJP?oo`001?l00002ool001Sooo]Z0ooo0005
o`000003ool00?oonf[ooo]Z04[ooo]Z00?oo`00o`000?l000000ol00003ool001Sooo]Z00?oo`00
o`000?l000000ol00003ool0017ooo]Z1Ol0000LoookJPCo0000D?oonfX5o`0001cooo]Z1?l0000V
oookJP009?oonfX4o`0001cooo]Z1Ol0001@oookJPCo00007OoonfX4o`0000Sooo]Z1Ol00004oook
JP?oo`001?l00002ool001Oooo]Z1?oo0004o`000003ool00?oonf[ooo]Z04_ooo]Z00?oo`00o`00
0?l000000ol00003ool001Sooo]Z00?oo`00o`000?l000000_l00004ool0017ooo]Z1Ol0000Loook
JPCo0000D?oonfX5o`0001cooo]Z1?l0000VoookJP009?oonfX5o`0001_ooo]Z1Ol0001@oookJPCo
00007OoonfX4o`0000Sooo]Z1Ol00004oookJP?oo`001?l00002ool001Oooo]Z1?oo0004o`000003
ool00?oonf[ooo]Z04cooo]Z00?oo`00o`000?l000000_l00004ool001Oooo]Z00?oo`00o`000?l0
00000_l00004ool001;ooo]Z1?l0000KoookJPGo0000DOoonfX4o`0001_ooo]Z1Ol0000VoookJP00
9?oonfX5o`0001_ooo]Z1Ol0001@oookJPCo00007?oonfX5o`0000Sooo]Z1Ol00004oookJP?oo`00
1?l00002ool001Oooo]Z0ooo0005o`000003ool00?oonf[ooo]Z04cooo]Z00?oo`00o`000?l00000
0_l00004ool001Oooo]Z00?oo`00o`000?l000000_l00004ool001;ooo]Z1?l0000KoookJPGo0000
DOoonfX4o`0001_ooo]Z1Ol0000VoookJP009?oonfX5o`0001_ooo]Z1?l0001AoookJPCo00007?oo
nfX5o`0000Sooo]Z1Ol00005oookJP;oo`001?l00002ool001Oooo]Z0ooo0005o`000003ool00?oo
nf[ooo]Z04cooo]Z00?oo`00o`000?l000000_l00004ool001Oooo]Z00?oo`00o`000?l000000_l0
0003ool001?ooo]Z1?l0000KoookJPGo0000DOoonfX4o`0001_ooo]Z1Ol0000VoookJP009OoonfX4
o`0001_ooo]Z1?l0001AoookJPGo00006ooonfX5o`0000Sooo]Z1Ol00005oookJP;oo`001?l00002
ool001Oooo]Z0ooo0005o`000003ool00?oonf[ooo]Z04cooo]Z00?oo`00o`000?l000000ol00003
ool001Oooo]Z00?oo`00o`000?l000000_l00003ool001?ooo]Z1?l0000KoookJPCo0000D_oonfX4
o`0001_ooo]Z1?l0000WoookJP009OoonfX4o`0001_ooo]Z1?l0001AoookJPGo00006ooonfX4o`00
00Wooo]Z1Ol00005oookJP;oo`001?l00002ool001Oooo]Z0ooo0004o`0000;oo`00C_oonfX00ooo
003o0000o`000003o`0000?oo`005ooonfX00ooo003o0000o`000002o`0000?oo`004ooonfX4o`00
01_ooo]Z1?l0001BoookJPGo00006_oonfX4o`0002Oooo]Z000UoookJPCo00006ooonfX4o`00057o
oo]Z1Ol0000KoookJPCo00002OoonfX5o`0000Gooo]Z0_oo0004o`0000;oo`005ooonfX3ool000Co
00000_oo001>oookJP03ool00?l0003o000000?o00000ooo000GoookJP03ool00?l0003o000000;o
00000ooo000CoookJPCo00006ooonfX4o`0005;ooo]Z1Ol0000JoookJPCo00009ooonfX002Gooo]Z
1?l0000JoookJPGo0000D_oonfX4o`0001_ooo]Z1?l00009oookJPGo00001OoonfX2ool000Go0000
00?oo`00oookJ_oonfX05?oonfX3ool000Go000000?oo`00oookJ_oonfX0COoonfX2ool000Co0000
0ooo000GoookJP03ool00?l0003o000000;o00000ooo000CoookJPCo00006_oonfX5o`0005;ooo]Z
1Ol0000JoookJPCo00009ooonfX002Gooo]Z1?l0000JoookJPGo0000D_oonfX4o`0001_ooo]Z1?l0
0009oookJPGo00001OoonfX2ool000Go000000?oo`00oookJ_oonfX05?oonfX3ool000Go000000?o
o`00oookJ_oonfX0C_oonfX00ooo003o0000o`000002o`0000Coo`005OoonfX2ool000Co00000ooo
000CoookJPCo00006_oonfX5o`0005?ooo]Z1?l0000JoookJPCo00009ooonfX002Gooo]Z1?l0000J
oookJPGo0000D_oonfX4o`0001_ooo]Z1?l00009oookJPGo00001OoonfX2ool000Go00000_oo000E
oookJP?oo`001Ol000000ooo003ooo]ZoookJP1>oookJP03ool00?l0003o000000?o00000ooo000E
oookJP;oo`001?l00003ool001?ooo]Z1?l0000JoookJPGo0000DooonfX4o`0001[ooo]Z1?l0000W
oookJP009OoonfX4o`0001[ooo]Z1?l0001CoookJPCo00006ooonfX4o`0000Wooo]Z1Ol00005oook
JP?oo`001?l00002ool001Gooo]Z0ooo0004o`0000;oo`00D?oonfX00ooo003o0000o`000003o`00
00?oo`005OoonfX2ool000Co00000ooo000CoookJPCo00006_oonfX4o`0005Cooo]Z1?l0000Joook
JPCo00009ooonfX002Gooo]Z1?l0000JoookJPCo0000DooonfX5o`0001[ooo]Z1?l00009oookJPGo
00001OoonfX3ool000Co00000_oo000EoookJP?oo`001?l00002ool0053ooo]Z00?oo`00o`000?l0
00000ol00003ool001Gooo]Z0_oo0004o`0000?oo`004ooonfX4o`0001[ooo]Z1?l0001DoookJPCo
00006_oonfX4o`0002Oooo]Z000UoookJPCo00006OoonfX5o`0005?ooo]Z1Ol0000JoookJPCo0000
2OoonfX5o`0000Gooo]Z0ooo0004o`0000;oo`005OoonfX2ool000Go00000_oo001@oookJP;oo`00
1?l00003ool001Gooo]Z0_oo0004o`0000?oo`004ooonfX4o`0001[ooo]Z1?l0001DoookJPGo0000
6OoonfX4o`0002Oooo]Z000UoookJPCo00006OoonfX5o`0005?ooo]Z1Ol0000JoookJPCo00002Ooo
nfX5o`0000Gooo]Z0ooo0004o`0000;oo`005OoonfX2ool000Go00000_oo001@oookJP;oo`001?l0
0003ool001Gooo]Z00?oo`00o`000?l000000ol00003ool001?ooo]Z1?l0000IoookJPGo0000E?oo
nfX5o`0001Wooo]Z1?l0000WoookJP009OoonfX4o`0001Wooo]Z1Ol0001DoookJPCo00006_oonfX4
o`0000Wooo]Z1Ol00005oookJP?oo`001?l00002ool001Cooo]Z0ooo0005o`000003ool00?oonf[o
oo]Z04oooo]Z0_oo0004o`0000?oo`005OoonfX00ooo003o0000o`000003o`0000?oo`004ooonfX4
o`0001Wooo]Z1Ol0001DoookJPGo00006OoonfX4o`0002Oooo]Z000UoookJPCo00006OoonfX4o`00
05Gooo]Z1?l00009oookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o1?l000000ol0
07oooo]ZoookJP06oookJPGo00001OoonfX3ool000Co00000_oo000DoookJP?oo`001?l00002ool0
05;ooo]Z00?oo`00o`000?l000000ol00003ool001Cooo]Z00?oo`00o`000?l000000ol00002ool0
01Cooo]Z1Ol0000HoookJPGo0000EOoonfX4o`0001Sooo]Z1Ol0000WoookJP009OoonfX4o`0001Wo
oo]Z1?l0001EoookJPCo00002?oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`Co
000000?o001ooookJ_oonfX01_oonfX5o`0000Kooo]Z0_oo0004o`0000;oo`005?oonfX3ool000Co
00000_oo001BoookJP03ool00?l0003o000000?o00000ooo000DoookJP03ool00?l0003o000000;o
00000ooo000DoookJPGo00006?oonfX4o`0005Kooo]Z1?l0000HoookJPGo00009ooonfX002Gooo]Z
1?l0000HoookJPGo0000EOoonfX5o`0000Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l4o`0000Wooo]Z1Ol00006oookJP;oo`001?l00002ool001Co
oo]Z0_oo0005o`0000;oo`00D_oonfX00ooo003o0000o`000003o`0000?oo`005?oonfX00ooo003o
0000o`000002o`0000?oo`005?oonfX5o`0001Sooo]Z1?l0001FoookJPCo00006?oonfX5o`0002Oo
oo]Z000UoookJPGo00005ooonfX5o`0005Gooo]Z1Ol00006oookJP?o001o0ooonfX3o`00O`Oooo]Z
0ol007l4o`0000Wooo]Z1Ol00006oookJP;oo`001?l00002ool001Cooo]Z0_oo0005o`0000;oo`00
D_oonfX2ool000Co00000ooo000DoookJP03ool00?l0003o000000;o00000ooo000EoookJPCo0000
6?oonfX4o`0005Kooo]Z1Ol0000GoookJPCo0000:?oonfX002Gooo]Z1Ol0000GoookJPGo0000EOoo
nfX5o`0000Kooo]Z0ol007l3oookJP?o001o2?oonfX2o`00O`Co00002OoonfX6o`0000Gooo]Z0_oo
0004o`0000;oo`005?oonfX2ool000Go00000_oo001BoookJP;oo`001?l00003ool001Cooo]Z00?o
o`00o`000?l000000_l00003ool001Gooo]Z1?l0000GoookJPGo0000E_oonfX5o`0001Oooo]Z1?l0
000XoookJP009OoonfX5o`0001Oooo]Z1?l0001GoookJPCo00001_oonfX3o`00O`?ooo]Z0ol007l9
oookJPGo00002OoonfX5o`0000Kooo]Z0_oo0004o`0000;oo`005?oonfX2ool000Co00000ooo001B
oookJP;oo`001Ol00002ool001Cooo]Z00?oo`00o`000?l000000_l00003ool001Gooo]Z1?l0000G
oookJPGo0000E_oonfX5o`0001Oooo]Z1?l0000XoookJP009_oonfX4o`0001Oooo]Z1?l0001Goook
JPGo00001OoonfX3o`00O`?ooo]Z0ol007l9oookJPGo00002OoonfX5o`0000Kooo]Z0_oo0004o`00
00?oo`004_oonfX3ool000Co00000_oo001CoookJP;oo`001Ol00002ool001Cooo]Z00?oo`00o`00
0?l000000_l00003ool001Gooo]Z1?l0000GoookJPGo0000EooonfX4o`0001Oooo]Z1?l0000Xoook
JP009_oonfX4o`0001Kooo]Z1Ol0001GoookJPGo00001OoonfX3o`00O`?ooo]Z0ol007l9oookJPGo
000000?o001ooookJ_oonfX01_oonfX5o`0000Kooo]Z0_oo0005o`0000;oo`004_oonfX2ool000Go
00000_oo001DoookJP03ool00?l0003o000000?o00000ooo000CoookJP03ool00?l0003o000000;o
00000ooo000EoookJPCo00005ooonfX4o`0005Sooo]Z1Ol0000FoookJPCo0000:?oonfX002Kooo]Z
1?l0000FoookJPGo0000EooonfX5o`0000Gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`Co0000
0_l007l8oookJPGo00001_oonfX2ool000Go00000_oo000BoookJP;oo`001Ol00002ool005Cooo]Z
0_oo0004o`0000?oo`004_oonfX2ool000Co00000ooo000EoookJPCo00005ooonfX4o`0005Sooo]Z
1Ol0000FoookJPCo0000:?oonfX002Kooo]Z1?l0000FoookJPGo0000F?oonfX4o`0000Gooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`Co00000_l007l8oookJPGo00001_oonfX2ool000Go00000_oo
000BoookJP;oo`001Ol00002ool005Cooo]Z0_oo0005o`0000;oo`004_oonfX2ool000Co00000ooo
000EoookJPCo00005ooonfX4o`0005Sooo]Z1Ol0000FoookJPCo0000:?oonfX002Kooo]Z1?l0000F
oookJPCo0000FOoonfX5o`0000Gooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJP?o001o1?l0
0002o`00O`Sooo]Z1Ol00006oookJP?oo`001?l00002ool001;ooo]Z0_oo0004o`0000?oo`00E?oo
nfX2ool000Go00000_oo000BoookJP;oo`001?l00003ool001Gooo]Z1?l0000FoookJPGo0000FOoo
nfX4o`0001Kooo]Z1?l0000XoookJP009_oonfX4o`0001Kooo]Z1?l0001IoookJPGo00001OoonfX7
o`00O`Sooo]Z0_l007l4o`000003o`00Oooonf[ooo]Z00Oooo]Z1Ol00006oookJP?oo`001?l00002
ool001;ooo]Z0_oo0004o`0000?oo`00E?oonfX2ool000Go00000_oo000BoookJP;oo`001?l00003
ool001Gooo]Z1?l0000FoookJPGo0000FOoonfX5o`0001Gooo]Z1?l0000XoookJP009_oonfX4o`00
01Gooo]Z1Ol0001IoookJPGo00001_oonfX5o`00O`[ooo]Z00?o001oo`000?l000000_l0000:oook
JPGo00001_oonfX3ool000Co00000_oo000BoookJP03ool00?l0003o000000?o00000ooo001Doook
JP?oo`001?l00002ool001;ooo]Z00?oo`00o`000?l000000ol00003ool001Gooo]Z1?l0000Foook
JPGo0000FOoonfX5o`0001Gooo]Z1?l0000XoookJP009_oonfX4o`0001Gooo]Z1Ol0001JoookJPCo
00005_oonfX4o`0000[ooo]Z1Ol00007oookJP;oo`001?l00002ool0017ooo]Z0_oo0005o`0000;o
o`00EOoonfX3ool000Go000000?oo`00oookJ_oonfX04?oonfX00ooo003o0000o`000003o`0000?o
o`005OoonfX4o`0001Kooo]Z1?l0001JoookJPGo00005OoonfX4o`0002Sooo]Z000VoookJPCo0000
5OoonfX5o`0005[ooo]Z1Ol0000EoookJPCo00002_oonfX5o`0000Oooo]Z0_oo0004o`0000;oo`00
4OoonfX2ool000Go00000_oo001FoookJP;oo`001Ol00002ool0017ooo]Z00?oo`00o`000?l00000
0ol00003ool001Gooo]Z1?l0000FoookJPCo0000FooonfX4o`0001Cooo]Z1Ol0000XoookJP009_oo
nfX4o`0001Gooo]Z1?l0001KoookJPGo00005OoonfX4o`0000[ooo]Z1Ol00007oookJP;oo`001?l0
0003ool0013ooo]Z0_oo0004o`0000?oo`00E_oonfX2ool000Go00000_oo000AoookJP03ool00?l0
003o000000;o00000ooo000FoookJPCo00005OoonfX5o`0005_ooo]Z1Ol0000CoookJPGo0000:?oo
nfX002Kooo]Z1?l0000EoookJPCo0000FooonfX5o`0001Gooo]Z1?l0000:oookJPGo00001ooonfX2
ool000Co00000ooo000@oookJP03ool00?l0003o000000?o00000ooo001FoookJP?oo`001?l00002
ool0017ooo]Z00?oo`00o`000?l000000_l00003ool001Kooo]Z1?l0000EoookJPGo0000FooonfX5
o`0001?ooo]Z1Ol0000XoookJP009_oonfX4o`0001Cooo]Z1Ol0001LoookJPCo00005OoonfX4o`00
00[ooo]Z1Ol00007oookJP;oo`001?l00003ool0013ooo]Z00?oo`00o`000?l000000ol00003ool0
05Kooo]Z0ooo0004o`0000;oo`004OoonfX00ooo003o0000o`000002o`0000?oo`005_oonfX4o`00
01Gooo]Z1Ol0001KoookJPGo00004ooonfX4o`0002Wooo]Z000VoookJPCo00005?oonfX5o`0005co
oo]Z1Ol0000DoookJPCo00002_oonfX5o`0000Oooo]Z0_oo0004o`0000?oo`004?oonfX00ooo003o
0000o`000003o`0000?oo`00E_oonfX3ool000Go000000?oo`00oookJ_oonfX03ooonfX00ooo003o
0000o`000002o`0000?oo`005_oonfX4o`0001Cooo]Z1Ol0001MoookJPCo00004ooonfX4o`0002Wo
oo]Z000VoookJPCo00005?oonfX5o`0005cooo]Z1Ol0000CoookJPGo00002_oonfX5o`0000Oooo]Z
0_oo0005o`0000;oo`004?oonfX00ooo003o0000o`000002o`0000Coo`00E_oonfX3ool000Go0000
00?oo`00oookJ_oonfX03ooonfX00ooo003o0000o`000002o`0000?oo`005_oonfX5o`0001?ooo]Z
1Ol0001MoookJPGo00004_oonfX4o`0002Wooo]Z000VoookJPCo00005?oonfX4o`0005gooo]Z1Ol0
000CoookJPGo00002_oonfX5o`0000Oooo]Z0_oo0005o`0000;oo`003ooonfX2ool000Co00000ooo
001GoookJP?oo`001Ol000000ooo003ooo]ZoookJP0?oookJP03ool00?l0003o000000;o00000ooo
000FoookJPGo00004ooonfX5o`0005gooo]Z1Ol0000BoookJPCo0000:OoonfX002Kooo]Z1Ol0000B
oookJPGo0000G_oonfX4o`0001?ooo]Z1Ol0000:oookJPGo00001ooonfX2ool000Go00000_oo000?
oookJP03ool00?l0003o000000?o00000ooo001HoookJP?oo`001?l00002ool0013ooo]Z00?oo`00
o`000?l000000_l00003ool001Kooo]Z1Ol0000CoookJPCo0000G_oonfX5o`0001;ooo]Z1?l0000Y
oookJP009_oonfX5o`0001;ooo]Z1Ol0001NoookJPGo00004_oonfX4o`0000_ooo]Z1Ol00008oook
JP;oo`001?l00002ool000oooo]Z00?oo`00o`000?l000000ol00003ool005Sooo]Z0ooo0005o`00
0003ool00?oonf[ooo]Z00gooo]Z0_oo0004o`0000?oo`005ooonfX4o`0001;ooo]Z1Ol0001Ooook
JPCo00004_oonfX4o`0002Wooo]Z000VoookJPGo00004_oonfX5o`0005kooo]Z1Ol0000BoookJPCo
00002ooonfX5o`0000Sooo]Z0_oo0004o`0000;oo`003ooonfX00ooo003o0000o`000003o`0000?o
o`00F?oonfX3ool000Go000000?oo`00oookJ_oonfX03OoonfX2ool000Co00000ooo000GoookJPCo
00004_oonfX5o`0005oooo]Z1Ol0000AoookJPCo0000:OoonfX002Oooo]Z1?l0000BoookJPCo0000
GooonfX5o`0001;ooo]Z1?l0000;oookJPGo00002?oonfX2ool000Co00000_oo000?oookJP03ool0
0?l0003o000000;o00001?oo001HoookJP?oo`001Ol000000ooo003ooo]ZoookJP0=oookJP03ool0
0?l0003o000000?o00000ooo000GoookJPCo00004_oonfX5o`0005oooo]Z1Ol0000AoookJPCo0000
:OoonfX002Oooo]Z1?l0000AoookJPGo0000H?oonfX4o`0001;ooo]Z1?l0000;oookJPGo00002?oo
nfX2ool000Co00000_oo000?oookJPGo00001?oo001HoookJPCoo`001?l000000ooo003ooo]Zoook
JP0=oookJP03ool00?l0003o000000?o00000ooo000GoookJPCo00004_oonfX4o`00063ooo]Z1Ol0
000AoookJPCo0000:OoonfX002Oooo]Z1?l0000AoookJPGo0000H?oonfX5o`00017ooo]Z1?l0000;
oookJPGo00002?oonfX2ool000Co00000ooo000>oookJPGo00001?oo001HoookJPCoo`001Ol00000
0ooo003ooo]ZoookJP0<oookJP03ool00?l0003o000000?o00000ooo000GoookJPCo00004OoonfX5
o`00067ooo]Z1?l0000AoookJPCo0000:OoonfX002Oooo]Z1?l0000AoookJPGo0000H?oonfX5o`00
017ooo]Z1?l0000;oookJPGo00002?oonfX2ool000Co00000ooo000=oookJP03ool00?l0003o0000
00?o00000ooo001IoookJPCoo`001Ol000000ooo003ooo]ZoookJP0<oookJP03ool00?l0003o0000
00;o00001?oo000GoookJPCo00004OoonfX5o`00067ooo]Z1Ol0000@oookJPCo0000:OoonfX002Oo
oo]Z1?l0000AoookJPCo0000HOoonfX5o`00017ooo]Z1?l0000;oookJPGo00002?oonfX2ool000Co
00000ooo000=oookJP03ool00?l0003o000000;o00001?oo001JoookJP?oo`001Ol000000ooo003o
oo]ZoookJP0<oookJP03ool00?l0003o000000;o00001?oo000GoookJPCo00004OoonfX5o`00067o
oo]Z1Ol0000@oookJPCo0000:OoonfX002Oooo]Z1?l0000@oookJPGo0000H_oonfX4o`00013ooo]Z
1Ol0000;oookJPGo00002?oonfX2ool000Co00000ooo000=oookJPGo00001?oo001JoookJPCoo`00
1?l000000ooo003ooo]ZoookJP0<oookJP03ool00?l0003o000000;o00000ooo000HoookJPCo0000
4?oonfX5o`0006;ooo]Z1Ol0000?oookJPGo0000:OoonfX002Oooo]Z1?l0000@oookJPGo0000H_oo
nfX4o`00013ooo]Z1Ol0000;oookJPGo00002?oonfX2ool000Go00000_oo000=oookJPGo00001?oo
001JoookJPCoo`001Ol0000=oookJP;oo`001?l00003ool001Sooo]Z1?l0000@oookJPGo0000Hooo
nfX4o`0000oooo]Z1Ol0000YoookJP009ooonfX4o`00013ooo]Z1Ol0001RoookJPGo00003ooonfX5
o`0000_ooo]Z1Ol00008oookJP;oo`001Ol00002ool000gooo]Z1Ol00004ool005[ooo]Z1?oo0005
o`000003ool00?oonf[ooo]Z00[ooo]Z0_oo0004o`0000?oo`006?oonfX4o`00013ooo]Z1Ol0001S
oookJPCo00003ooonfX5o`0002Wooo]Z000WoookJPCo00004?oonfX4o`0006?ooo]Z1Ol0000?oook
JPCo00003?oonfX5o`0000Sooo]Z0_oo0005o`0000;oo`003?oonfX00ooo003o0000o`000002o`00
00Goo`00F_oonfX4ool000Go000000?oo`00oookJ_oonfX02_oonfX2ool000Co00000ooo000Hoook
JPGo00003ooonfX4o`0006Cooo]Z1Ol0000>oookJPCo0000:_oonfX002Oooo]Z1?l0000@oookJPCo
0000HooonfX5o`0000oooo]Z1?l0000<oookJPGo00002OoonfX2ool000Co00000_oo000<oookJP03
ool00?l0003o000000;o00001Ooo001KoookJPCoo`001?l000000ooo003ooo]ZoookJP0:oookJP;o
o`001?l00003ool001Sooo]Z1Ol0000>oookJPGo0000I?oonfX5o`0000kooo]Z1?l0000ZoookJP00
9ooonfX5o`0000kooo]Z1Ol0001ToookJPCo00003ooonfX4o`0000cooo]Z1Ol00009oookJP;oo`00
1?l00002ool000cooo]Z1Ol00004ool005cooo]Z1?oo0004o`000003ool00?oonf[ooo]Z00[ooo]Z
0_oo0004o`0000?oo`006?oonfX5o`0000kooo]Z1Ol0001ToookJPGo00003_oonfX4o`0002[ooo]Z
000WoookJPGo00003_oonfX5o`0006Cooo]Z1Ol0000>oookJPCo00003?oonfX5o`0000Wooo]Z0_oo
0004o`0000;oo`003?oonfX5o`0000Coo`00G?oonfX4ool000Go00003?oonfX2ool000Co00000ooo
000IoookJPCo00003_oonfX5o`0006Gooo]Z1?l0000>oookJPCo0000:_oonfX002Oooo]Z1Ol0000>
oookJPGo0000I?oonfX5o`0000kooo]Z1?l0000<oookJPGo00002OoonfX2ool000Co00000ooo000;
oookJPGo00001?oo001LoookJPCoo`001Ol000000ooo003ooo]ZoookJP08oookJP;oo`001Ol00003
ool001Wooo]Z1?l0000>oookJPCo0000I_oonfX5o`0000gooo]Z1?l0000ZoookJP00:?oonfX4o`00
00kooo]Z1?l0001UoookJPGo00003_oonfX4o`0000cooo]Z1Ol00009oookJP;oo`001?l00003ool0
00[ooo]Z00?oo`00o`000?l000000_l00005ool005cooo]Z1?oo0005o`000003ool00?oonf[ooo]Z
00Sooo]Z0_oo0005o`0000;oo`006_oonfX4o`0000gooo]Z1Ol0001VoookJPGo00003OoonfX4o`00
02[ooo]Z000XoookJPCo00003OoonfX5o`0006Kooo]Z1?l0000>oookJPCo00003?oonfX5o`0000Wo
oo]Z0_oo0004o`0000?oo`002_oonfX5o`0000Goo`00GOoonfX4ool000Co000000?oo`00oookJ_oo
nfX02?oonfX2ool000Go00000_oo000JoookJPCo00003OoonfX5o`0006Kooo]Z1Ol0000=oookJPCo
0000:_oonfX002Sooo]Z1?l0000=oookJPGo0000I_oonfX4o`0000kooo]Z1?l0000<oookJPGo0000
2OoonfX2ool000Co00000ooo000:oookJPGo00001?oo001NoookJPCoo`001Ol0000:oookJP;oo`00
1?l00003ool001[ooo]Z1?l0000=oookJPGo0000IooonfX4o`0000gooo]Z1?l0000ZoookJP00:?oo
nfX4o`0000gooo]Z1Ol0001VoookJPGo00003?oonfX5o`0000cooo]Z1Ol00009oookJP;oo`001?l0
0003ool000[ooo]Z1Ol00004ool005kooo]Z1?oo0005o`0000[ooo]Z0_oo0004o`0000?oo`006_oo
nfX5o`0000cooo]Z1?l0001XoookJPCo00003OoonfX4o`0002[ooo]Z000XoookJPCo00003OoonfX4
o`0006Oooo]Z1Ol0000<oookJPGo00003?oonfX5o`0000Wooo]Z0_oo0004o`0000?oo`002OoonfX0
0ooo003o0000o`000002o`0000Goo`00G_oonfX4ool000Go000000?oo`00oookJ_oonfX01_oonfX3
ool000Co00000ooo000JoookJPGo00003?oonfX4o`0006Sooo]Z1Ol0000<oookJPCo0000:_oonfX0
02Sooo]Z1Ol0000;oookJPGo0000IooonfX5o`0000cooo]Z1Ol0000<oookJPGo00002OoonfX2ool0
00Go00000ooo0008oookJPGo00001Ooo001NoookJPGoo`001?l000000ooo003ooo]ZoookJP06oook
JP?oo`001?l00003ool001[ooo]Z1Ol0000;oookJPGo0000J?oonfX5o`0000cooo]Z1?l0000Zoook
JP00:?oonfX5o`0000_ooo]Z1Ol0001XoookJPCo00003?oonfX4o`0000gooo]Z1Ol0000:oookJP03
ool00?l0003o000000?o00000ooo0008oookJPGo00001Ooo001OoookJPCoo`001?l000000ooo003o
oo]ZoookJP06oookJP?oo`001?l00002ool001cooo]Z1?l0000;oookJPGo0000J?oonfX5o`0000co
oo]Z1?l0000ZoookJP00:?oonfX5o`0000_ooo]Z1Ol0001XoookJPGo00002ooonfX4o`0000gooo]Z
1Ol0000:oookJP03ool00?l0003o000000?o00000ooo0008oookJPGo00001?oo001PoookJPCoo`00
1Ol00008oookJP?oo`001?l00002ool001cooo]Z1?l0000;oookJPGo0000JOoonfX4o`0000_ooo]Z
1Ol0000ZoookJP00:OoonfX4o`0000_ooo]Z1?l0001YoookJPGo00002ooonfX4o`0000gooo]Z1Ol0
000:oookJP;oo`001?l00003ool000Sooo]Z1?l00005ool0063ooo]Z1?oo0005o`0000Sooo]Z0ooo
0004o`0000;oo`007?oonfX4o`0000_ooo]Z1?l0001ZoookJPCo00002ooonfX5o`0002[ooo]Z000Y
oookJPCo00002_oonfX5o`0006Wooo]Z1Ol0000;oookJPCo00003OoonfX5o`0000[ooo]Z0_oo0004
o`0000?oo`001ooonfX5o`0000Goo`00H?oonfX4ool000Go000000?oo`00oookJ_oonfX01?oonfX4
ool000Co00000_oo000LoookJPCo00002ooonfX4o`0006[ooo]Z1Ol0000:oookJPGo0000:_oonfX0
02Wooo]Z1?l0000:oookJPGo0000J_oonfX4o`0000_ooo]Z1?l0000=oookJPGo00002_oonfX2ool0
00Co00001?oo0006oookJPGo00001Ooo001PoookJPGoo`001?l000000ooo003ooo]ZoookJP04oook
JPCoo`001?l00002ool001cooo]Z1?l0000:oookJPGo0000J_oonfX5o`0000[ooo]Z1?l0000[oook
JP00:OoonfX4o`0000[ooo]Z1Ol0001ZoookJPCo00002ooonfX4o`0000gooo]Z1Ol0000:oookJP;o
o`001?l00004ool000Kooo]Z1Ol00004ool006;ooo]Z1?oo0004o`000003ool00?oonf[ooo]Z00Co
oo]Z0ooo0005o`000003ool00?oonf[ooo]Z01_ooo]Z1?l0000:oookJPGo0000J_oonfX5o`0000[o
oo]Z1?l0000[oookJP00:OoonfX5o`0000Wooo]Z1?l0001[oookJPGo00002_oonfX4o`0000gooo]Z
1Ol0000;oookJP03ool00?l0003o000000;o00001?oo0006oookJPCo00001Ooo001RoookJPCoo`00
1Ol000000ooo003ooo]ZoookJP03oookJP?oo`001Ol000000ooo003ooo]ZoookJP0KoookJPCo0000
2_oonfX5o`0006_ooo]Z1?l0000:oookJPCo0000:ooonfX002Wooo]Z1Ol00009oookJPCo0000Jooo
nfX5o`0000[ooo]Z1?l0000=oookJPGo00002ooonfX00ooo003o0000o`000002o`0000Coo`001Ooo
nfX00ooo003o0000o`000002o`0000Goo`00H_oonfX4ool000Go000000?oo`00oookJ_oonfX00ooo
nfX3ool000Go000000?oo`00oookJ_oonfX06ooonfX5o`0000Wooo]Z1?l0001/oookJPGo00002Ooo
nfX4o`0002_ooo]Z000YoookJPGo00002?oonfX5o`0006_ooo]Z1Ol00009oookJPGo00003OoonfX5
o`0000_ooo]Z00?oo`00o`000?l000000_l00004ool000Gooo]Z1Ol00005ool006;ooo]Z1?oo0005
o`000003ool00?oonf[ooo]Z00;ooo]Z1?oo0004o`0000;oo`007OoonfX5o`0000Wooo]Z1?l0001/
oookJPGo00002OoonfX4o`0002_ooo]Z000ZoookJPCo00002?oonfX5o`0006cooo]Z1?l00009oook
JPGo00003OoonfX5o`0000_ooo]Z00?oo`00o`000?l000000_l00005ool000Cooo]Z1Ol00005ool0
06;ooo]Z1Ooo0004o`0000;oo`000ooonfX4ool000Co00000_oo000MoookJPGo00002?oonfX5o`00
06cooo]Z1Ol00009oookJPCo0000:ooonfX002[ooo]Z1?l00008oookJPGo0000K?oonfX5o`0000So
oo]Z1Ol0000=oookJPGo00002ooonfX00ooo003o0000o`000003o`0000Coo`000ooonfX00ooo003o
0000o`000003o`0000Coo`00I?oonfX4ool000Go000000Coo`00oookJ_oonf[ooo]Z1?oo0004o`00
0003ool00?oonf[ooo]Z01gooo]Z1?l00008oookJPGo0000KOoonfX4o`0000Wooo]Z1?l0000[oook
JP00:_oonfX4o`0000Sooo]Z1?l0001]oookJPGo00002?oonfX4o`0000kooo]Z1Ol0000<oookJPGo
00001?oo0003oookJP03ool00?l0003o000000;o00001Ooo001ToookJPCoo`001Ol000001?oo003o
oo]ZoookJ_oonfX4ool000Co000000?oo`00oookJ_oonfX07OoonfX4o`0000Sooo]Z1Ol0001]oook
JPGo00002?oonfX4o`0002_ooo]Z000ZoookJPCo00002?oonfX4o`0006gooo]Z1Ol00008oookJPCo
00003_oonfX5o`0000cooo]Z1Ol00005ool000;ooo]Z1Ol00005ool006Cooo]Z1?oo0005o`0000;o
o`0000?ooo]Zool00?oo00000ooo0004o`000003ool00?oonf[ooo]Z01gooo]Z1?l00008oookJPCo
0000K_oonfX5o`0000Sooo]Z1?l0000[oookJP00:_oonfX4o`0000Oooo]Z1Ol0001^oookJPCo0000
2?oonfX4o`0000kooo]Z1Ol0000<oookJP03ool00?l0003o000000;o00001Ooo00000ooonf[oo`00
o`000004o`0000Goo`00IOoonfX4ool000Go000000?oo`00oookJ_oo00001?oo0004o`000003ool0
0?oonf[ooo]Z01gooo]Z1?l00008oookJPCo0000K_oonfX5o`0000Oooo]Z1Ol0000[oookJP00:_oo
nfX4o`0000Oooo]Z1Ol0001^oookJPGo00001ooonfX4o`0000kooo]Z1Ol0000<oookJP03ool00?l0
003o000000;o00001Ooo00000ooonf[oo`00o`000004o`0000Coo`00I_oonfX4ool000Go000000?o
o`00oookJ_oo00001?oo0004o`000003ool00?oonf[ooo]Z01gooo]Z1?l00007oookJPGo0000Kooo
nfX4o`0000Oooo]Z1Ol0000[oookJP00:_oonfX4o`0000Oooo]Z1Ol0001^oookJPGo00001ooonfX4
o`0000kooo]Z1Ol0000<oookJP03ool00?l0003o000000?o00001_oo0004o`0000Goo`00I_oonfX4
ool000Go00001ooo0004o`00023ooo]Z1?l00007oookJPGo0000KooonfX4o`0000Oooo]Z1Ol0000[
oookJP00:_oonfX4o`0000Oooo]Z1?l0001_oookJPGo00001_oonfX5o`0000kooo]Z1Ol0000=oook
JPGo00001Ooo0005o`0000Goo`00IooonfX4ool000Co00001_oo0005o`00023ooo]Z1?l00007oook
JPGo0000KooonfX5o`0000Kooo]Z1?l0000/oookJP00:_oonfX4o`0000Oooo]Z1?l0001`oookJPCo
00001_oonfX5o`0000kooo]Z1Ol0000=oookJPGo00001Ooo0005o`0000Coo`00J?oonfX4ool000Co
00001_oo0005o`00023ooo]Z1Ol00006oookJPCo0000L?oonfX5o`0000Kooo]Z1?l0000/oookJP00
:_oonfX4o`0000Kooo]Z1Ol0001`oookJPGo00001OoonfX5o`0000kooo]Z1Ol0000=oookJP03ool0
0?l0003o000000;o00001Ooo0005o`0000Coo`00J?oonfX4ool000Go00001Ooo0005o`00023ooo]Z
1Ol00006oookJPCo0000L?oonfX5o`0000Kooo]Z1?l0000/oookJP00:_oonfX5o`0000Gooo]Z1Ol0
001UoookJPGo001o1?oonfX2o`00O`Go00001Ol007l4o`0000Go001o2_oonfX5o`0000kooo]Z1?l0
0005ool000Co00001Ooo001YoookJP?oo`001Ol00005ool000Co00008OoonfX5o`0000Gooo]Z1Ol0
001aoookJPCo00001_oonfX4o`0002cooo]Z000ZoookJPGo00001OoonfX5o`0006Cooo]Z1ol007l3
oookJP;o001o1Ol00005o`00O`Co00001_l007l9oookJPGo00003_oonfX4o`0000Goo`001?l00004
ool006[ooo]Z0ooo0005o`0000Goo`001?l0000RoookJPCo00001OoonfX5o`00077ooo]Z1?l00005
oookJPGo0000;?oonfX002[ooo]Z1Ol00005oookJPCo0000IOoonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l4o`000004o`00Oooonf[ooo]ZoookJPGo00000_l007l01?oonf[o001oo`00
Ool007l9oookJPGo00003_oonfX4o`0000Coo`001Ol00004ool006[ooo]Z1?oo0004o`0000Goo`00
1?l0000RoookJPCo00001OoonfX5o`00077ooo]Z1Ol00004oookJPGo0000;?oonfX002_ooo]Z1?l0
0005oookJPCo0000I?oonfX3o`00O`?ooo]Z0ol007l5oookJPGo000000?o001ooookJ_oonfX01Ol0
00001?l007oooo]ZoookJ_oonfX3o`00O`Sooo]Z1Ol0000>oookJPCo00001?oo0005o`0000?oo`00
K?oonfX3ool000Co00001Ooo0004o`0002;ooo]Z1Ol00003oookJPGo0000L_oonfX5o`0000Cooo]Z
1Ol0000/oookJP00:ooonfX5o`0000?ooo]Z1Ol0001ToookJP?o001o0ooonfX3o`00O`Gooo]Z1Ol0
0003o`00O`Go00001?oonfX3o`00O`Sooo]Z1_l0000=oookJPCo00001?oo0005o`0000?oo`00K?oo
nfX3ool000Go00000ooo0005o`0002;ooo]Z1Ol00003oookJPGo0000L_oonfX5o`0000?ooo]Z1Ol0
000]oookJP00:ooonfX5o`0000?ooo]Z1Ol0001ToookJP?o001o0ooonfX3o`00O`Gooo]Z1Ol00003
o`00O`Co00001OoonfX3o`00O`Sooo]Z1Ol0000>oookJPCo00001?oo0004o`0000?oo`00K_oonfX2
ool000Go00000ooo0005o`0002;ooo]Z1Ol00003oookJPGo0000LooonfX4o`0000?ooo]Z1Ol0000]
oookJP00:ooonfX5o`0000?ooo]Z1Ol0001ToookJP?o001o0ooonfX3o`00O`Kooo]Z1?l000000ooo
nf[o001oo`00O`04o`0000;o001o0_oonfX4o`00O`Sooo]Z1Ol0000>oookJPGo00000_oo0005o`00
00?oo`00K_oonfX2ool000Go00000ooo0005o`0002?ooo]Z1?l00003oookJPCo0000M?oonfX4o`00
00?ooo]Z1Ol0000]oookJP00;?oonfX4o`0000;ooo]Z1Ol0001UoookJP?o001o0ooonfX3o`00O`Ko
oo]Z1Ol000000ooonf[o001oo`000003o`0000Oo001o2OoonfX5o`0000kooo]Z1Ol00002ool000Go
00000_oo001`oookJP;oo`001Ol00002ool000Co00009?oonfX4o`0000;ooo]Z1Ol0001doookJPGo
00000_oonfX4o`0002kooo]Z000/oookJPCo00000_oonfX5o`0006Gooo]Z0ol007l3oookJP?o001o
1_oonfX5o`000003oookJ_l007oo000000?o00001_l007l:oookJPGo00003_oonfX5o`0000;oo`00
1Ol000000ooo003ooo]ZoookJP1`oookJP03ool00?l0003o000000?o00000_oo0004o`0002Cooo]Z
1?l00002oookJPGo0000M?oonfX5o`0000;ooo]Z1?l0000^oookJP00;?oonfX4o`0000;ooo]Z1Ol0
001UoookJP?o001o0ooonfX3o`00O`Kooo]Z2ol00002o`00O`kooo]Z1Ol0000?oookJP[o0000MOoo
nfX6o`000003oookJ_l0003o000000;o00009?oonfX5o`000003oookJ_l0003o000000?o0000M?oo
nfX6o`000003oookJ_l0003o000000;o0000;_oonfX002cooo]Z2_l0001WoookJP?o001o00Cooo]Z
o`00Ool007oo001o1ooonfX00ol007oo0000o`000008o`0000;o001o3_oonfX5o`0000oooo]Z2_l0
001foookJP[o00009?oonfX:o`0007Kooo]Z2_l0000^oookJP00;?oonfX:o`0006Oooo]Z1ol007l8
oookJP[o000000?ooo]Zo`00Ool007l01Ol007l8oookJPGo00003ooonfX:o`0007Kooo]Z2_l0000T
oookJP[o0000M_oonfX:o`0002kooo]Z000/oookJP[o0000J?oonfX5o`00O`[ooo]Z2?l00002oook
JPOo001o2?oonfX5o`00013ooo]Z2?l0001hoookJPWo00009OoonfX9o`0007Oooo]Z2Ol0000^oook
JP00;OoonfX8o`0007Sooo]Z2?l0000AoookJPGo00004?oonfX8o`0007Sooo]Z2?l0000VoookJPSo
0000N?oonfX8o`0002oooo]Z000]oookJPOo0000NOoonfX8o`00017ooo]Z1Ol0000@oookJPSo0000
N?oonfX8o`0002Oooo]Z1ol0001hoookJPSo0000;ooonfX002kooo]Z1_l0001joookJPKo00004_oo
nfX5o`00017ooo]Z1_l0001joookJPKo0000:?oonfX6o`0007[ooo]Z1_l0000`oookJP00;_oonfX5
o`0007cooo]Z1?l0000CoookJPGo00004_oonfX4o`0007cooo]Z1?l0000ZoookJPGo0000NooonfX4
o`00037ooo]Z0036oookJPGo0000oooonfYfoookJP00a_oonfX5o`000?oooo]ZM_oonfX00<Kooo]Z
1Ol0003ooookJWKooo]Z0036oookJPGo0000oooonfYfoookJP00a_oonfX5o`000?oooo]ZM_oonfX0
0<Kooo]Z1Ol0003ooookJWKooo]Z0036oookJPGo0000oooonfYfoookJP00a_oonfX5o`000?oooo]Z
M_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-2.30167, -0.0218422, \
0.0114841, 0.00081322}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Fourier Series Coefficients using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s package:"
}], "Text"],

Cell[BoxData[
    \(<< Calculus`FourierTransform`\)], "Input",
  CellTags->{
  "mmtag:17:FourierTransform_Package", "mmtag:17:Package__FourierTransform"}],

Cell[BoxData[
    \(AFunction[x_]\  := \ \((x - 3)\)^3\/27\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[AFunction[x], {x, 0, 6}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.311414 13.0168 [
[.18254 .29891 -7 -20 ]
[.18254 .29891 7 0 ]
[.34127 .29891 -7 -20 ]
[.34127 .29891 7 0 ]
[.5 .29891 -7 -20 ]
[.5 .29891 7 0 ]
[.65873 .29891 -7 -20 ]
[.65873 .29891 7 0 ]
[.81746 .29891 -7 -20 ]
[.81746 .29891 7 0 ]
[.97619 .29891 -7 -20 ]
[.97619 .29891 7 0 ]
[.01131 .05108 -51.9375 -10 ]
[.01131 .05108 0 10 ]
[.01131 .18125 -51.9375 -10 ]
[.01131 .18125 0 10 ]
[.01131 .44158 -39 -10 ]
[.01131 .44158 0 10 ]
[.01131 .57175 -39 -10 ]
[.01131 .57175 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .31141 m
.18254 .31766 L
s
gsave
.18254 .29891 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34127 .31141 m
.34127 .31766 L
s
gsave
.34127 .29891 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .31141 m
.5 .31766 L
s
gsave
.5 .29891 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.65873 .31141 m
.65873 .31766 L
s
gsave
.65873 .29891 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.81746 .31141 m
.81746 .31766 L
s
gsave
.81746 .29891 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.97619 .31141 m
.97619 .31766 L
s
gsave
.97619 .29891 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .31141 m
.05556 .31516 L
s
.0873 .31141 m
.0873 .31516 L
s
.11905 .31141 m
.11905 .31516 L
s
.15079 .31141 m
.15079 .31516 L
s
.21429 .31141 m
.21429 .31516 L
s
.24603 .31141 m
.24603 .31516 L
s
.27778 .31141 m
.27778 .31516 L
s
.30952 .31141 m
.30952 .31516 L
s
.37302 .31141 m
.37302 .31516 L
s
.40476 .31141 m
.40476 .31516 L
s
.43651 .31141 m
.43651 .31516 L
s
.46825 .31141 m
.46825 .31516 L
s
.53175 .31141 m
.53175 .31516 L
s
.56349 .31141 m
.56349 .31516 L
s
.59524 .31141 m
.59524 .31516 L
s
.62698 .31141 m
.62698 .31516 L
s
.69048 .31141 m
.69048 .31516 L
s
.72222 .31141 m
.72222 .31516 L
s
.75397 .31141 m
.75397 .31516 L
s
.78571 .31141 m
.78571 .31516 L
s
.84921 .31141 m
.84921 .31516 L
s
.88095 .31141 m
.88095 .31516 L
s
.9127 .31141 m
.9127 .31516 L
s
.94444 .31141 m
.94444 .31516 L
s
.01 w
0 .31141 m
1 .31141 L
s
.25 Mabswid
.02381 .05108 m
.03006 .05108 L
s
gsave
.01131 .05108 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
.02381 .18125 m
.03006 .18125 L
s
gsave
.01131 .18125 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.01) show
1.000 setlinewidth
grestore
.02381 .44158 m
.03006 .44158 L
s
gsave
.01131 .44158 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.01) show
1.000 setlinewidth
grestore
.02381 .57175 m
.03006 .57175 L
s
gsave
.01131 .57175 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .07711 m
.02756 .07711 L
s
.02381 .10315 m
.02756 .10315 L
s
.02381 .12918 m
.02756 .12918 L
s
.02381 .15521 m
.02756 .15521 L
s
.02381 .20728 m
.02756 .20728 L
s
.02381 .23331 m
.02756 .23331 L
s
.02381 .25935 m
.02756 .25935 L
s
.02381 .28538 m
.02756 .28538 L
s
.02381 .33745 m
.02756 .33745 L
s
.02381 .36348 m
.02756 .36348 L
s
.02381 .38951 m
.02756 .38951 L
s
.02381 .41555 m
.02756 .41555 L
s
.02381 .46761 m
.02756 .46761 L
s
.02381 .49365 m
.02756 .49365 L
s
.02381 .51968 m
.02756 .51968 L
s
.02381 .54572 m
.02756 .54572 L
s
.02381 .02504 m
.02756 .02504 L
s
.02381 .59778 m
.02756 .59778 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.36281 0 m
.36292 .00091 L
.38395 .12301 L
.40336 .20262 L
.41426 .23544 L
.42424 .25899 L
.43408 .27689 L
.44322 .28935 L
.45326 .2991 L
.45886 .30302 L
.46395 .30576 L
.46882 .30776 L
.47149 .30862 L
.47397 .30929 L
.47837 .31019 L
.4807 .31055 L
.48319 .31084 L
.48587 .31107 L
.48739 .31117 L
.48879 .31124 L
.49001 .31129 L
.49136 .31134 L
.49203 .31135 L
.49276 .31137 L
.49408 .31139 L
.49529 .3114 L
.49661 .31141 L
.49727 .31141 L
.49798 .31141 L
.49926 .31141 L
.50054 .31141 L
.50175 .31141 L
.50284 .31142 L
.50401 .31142 L
.50525 .31143 L
.50637 .31144 L
.50767 .31147 L
.5089 .3115 L
.51004 .31154 L
.51109 .31158 L
.51348 .31171 L
.51484 .31181 L
.51613 .31192 L
.51852 .31218 L
.5211 .31255 L
.52389 .31306 L
.52923 .31442 L
.53191 .31533 L
.53486 .31652 L
.54007 .31917 L
Mistroke
.54493 .32235 L
.54996 .32644 L
.55541 .33192 L
.56533 .34502 L
.57498 .36222 L
.58389 .38259 L
.6026 .4416 L
.61324 .48645 L
.62321 .5369 L
Mfstroke
.62321 .5369 m
.63581 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00>?oonfX5o`000?oooo]ZoooonfX5oookJP00>?oonfX5o`000?oooo]Z
oooonfX5oookJP00>?oonfX5o`000:kooo]Z1?l0003ooookJU;ooo]Z000hoookJPGo0000[_oonfX4
o`000?oooo]ZD_oonfX003Sooo]Z1Ol0002_oookJP?o0000oooonfYBoookJP00>?oonfX5o`000:oo
oo]Z0ol0003ooookJU;ooo]Z000hoookJPGo0000[ooonfX4o`000?oooo]ZDOoonfX003Sooo]Z1Ol0
002_oookJPCo0000oooonfYAoookJP00>?oonfX5o`000;3ooo]Z0ol0003ooookJU7ooo]Z000hoook
JPGo0000/?oonfX3o`000?oooo]ZDOoonfX003Sooo]Z1Ol0002`oookJP?o0000oooonfYAoookJP00
>?oonfX5o`000;3ooo]Z0ol0003ooookJU7ooo]Z000hoookJPGo0000/?oonfX4o`000?oooo]ZD?oo
nfX003Sooo]Z1Ol0002`oookJPCo0000oooonfY@oookJP00>?oonfX5o`000;7ooo]Z0ol0003ooook
JU3ooo]Z000hoookJPGo0000/OoonfX3o`000?oooo]ZD?oonfX003Sooo]Z1Ol0002aoookJP?o0000
oooonfY@oookJP00>?oonfX5o`000;7ooo]Z0ol0003ooookJU3ooo]Z000hoookJPGo0000/OoonfX4
o`000?oooo]ZCooonfX003Sooo]Z1Ol0002aoookJPCo0000oooonfY?oookJP00>?oonfX5o`000;;o
oo]Z0ol0003ooookJToooo]Z000hoookJPGo0000/_oonfX3o`000?oooo]ZCooonfX003Sooo]Z1Ol0
002boookJP?o0000oooonfY?oookJP00>?oonfX5o`000;;ooo]Z1?l0003ooookJTkooo]Z000hoook
JPGo0000/_oonfX4o`000?oooo]ZC_oonfX0017ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`?o
oo]Z2Ol007l7oookJPGo0000/ooonfX3o`000?oooo]ZC_oonfX0013ooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`;ooo]Z2Ol007l7oookJPGo0000/ooonfX3o`000?oooo]ZC_oonfX0013ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`;o
oo]Z1?l007l<oookJPGo0000/ooonfX3o`000?oooo]ZC_oonfX000?ooo]Z2_l007l2oookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX4o`00O`_ooo]Z1Ol0002coookJP?o0000
oooonfY>oookJP000ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l3oookJPGo001o2OoonfX6o`000;;ooo]Z1?l0003ooookJTgooo]Z000?oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o1OoonfX4o`00O`Sooo]Z1Ol0002coookJPCo0000oooonfY=
oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l8oook
JPGo0000]?oonfX3o`000?oooo]ZCOoonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l7oookJP?o001o1ooonfX5o`000;Cooo]Z0ol0003ooookJTgooo]Z000?oookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oo
oo]Z1Ol0002doookJP?o0000oooonfY=oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000]?oonfX3o`000?oo
oo]ZCOoonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0_oonfX4o`00O`;ooo]Z0ol007l7oookJPGo0000]?oonfX4o`000?oooo]ZC?oonfX0013o
oo]Z1ol007l8oookJPOo001o0ooonfX7o`00O`Sooo]Z1Ol0002doookJPCo0000oooonfY<oookJP00
4OoonfX5o`00O`[ooo]Z1Ol007l5oookJPGo001o2OoonfX5o`000;Gooo]Z0ol0003ooookJTcooo]Z
000hoookJPGo0000]OoonfX3o`000?oooo]ZC?oonfX003Sooo]Z1Ol0002eoookJP?o0000oooonfY<
oookJP00>?oonfX5o`000;Gooo]Z0ol0003ooookJTcooo]Z000hoookJPGo0000]OoonfX4o`000?oo
oo]ZBooonfX003Sooo]Z1Ol0002eoookJPCo0000oooonfY;oookJP00>?oonfX5o`000;Kooo]Z0ol0
003ooookJT_ooo]Z000hoookJPGo0000]_oonfX3o`000?oooo]ZBooonfX003Sooo]Z1Ol0002foook
JP?o0000oooonfY;oookJP00>?oonfX5o`000;Kooo]Z0ol0003ooookJT_ooo]Z000hoookJPGo0000
]_oonfX4o`000?oooo]ZB_oonfX003Sooo]Z1Ol0002foookJPCo0000oooonfY:oookJP00>?oonfX5
o`000;Oooo]Z0ol0003ooookJT[ooo]Z000hoookJPGo0000]ooonfX3o`000?oooo]ZB_oonfX003So
oo]Z1Ol0002goookJP?o0000oooonfY:oookJP00>?oonfX5o`000;Oooo]Z1?l0003ooookJTWooo]Z
000hoookJPGo0000]ooonfX4o`000?oooo]ZBOoonfX003Sooo]Z1Ol0002hoookJP?o0000oooonfY9
oookJP00>?oonfX5o`000;Sooo]Z0ol0003ooookJTWooo]Z000hoookJPGo0000^?oonfX3o`000?oo
oo]ZBOoonfX003Sooo]Z1Ol0002hoookJP?o0000oooonfY9oookJP00>?oonfX5o`000;Sooo]Z1?l0
003ooookJTSooo]Z000hoookJPGo0000^?oonfX4o`000?oooo]ZB?oonfX003Sooo]Z1Ol0002ioook
JP?o0000oooonfY8oookJP00>?oonfX5o`000;Wooo]Z0ol0003ooookJTSooo]Z000hoookJPGo0000
^OoonfX3o`000?oooo]ZB?oonfX003Sooo]Z1Ol0002ioookJP?o0000oooonfY8oookJP00>?oonfX5
o`000;Wooo]Z1?l0003ooookJTOooo]Z000hoookJPGo0000^OoonfX4o`000?oooo]ZAooonfX003So
oo]Z1Ol0002joookJP?o0000oooonfY7oookJP00>?oonfX5o`000;[ooo]Z0ol0003ooookJTOooo]Z
000hoookJPGo0000^_oonfX3o`000?oooo]ZAooonfX003Sooo]Z1Ol0002joookJPCo0000oooonfY6
oookJP00>?oonfX5o`000;[ooo]Z1?l0003ooookJTKooo]Z000hoookJPGo0000^ooonfX3o`000?oo
oo]ZA_oonfX003Sooo]Z1Ol0002koookJP?o0000oooonfY6oookJP00>?oonfX5o`000;_ooo]Z1?l0
003ooookJTGooo]Z000hoookJPGo0000^ooonfX4o`000?oooo]ZAOoonfX003Sooo]Z1Ol0002loook
JP?o0000oooonfY5oookJP00>?oonfX5o`000;cooo]Z0ol0003ooookJTGooo]Z000hoookJPGo0000
_?oonfX4o`000?oooo]ZA?oonfX003Sooo]Z1Ol0002loookJPCo0000oooonfY4oookJP00>?oonfX5
o`000;gooo]Z0ol0003ooookJTCooo]Z000hoookJPGo0000_OoonfX3o`000?oooo]ZA?oonfX003So
oo]Z1Ol0002moookJP?o0000oooonfY4oookJP00>?oonfX5o`000;gooo]Z1?l0003ooookJT?ooo]Z
000hoookJPGo0000_OoonfX4o`000?oooo]Z@ooonfX003Sooo]Z1Ol0002noookJP?o0000oooonfY3
oookJP00>?oonfX5o`000;kooo]Z0ol0003ooookJT?ooo]Z000hoookJPGo0000__oonfX4o`000?oo
oo]Z@_oonfX003Sooo]Z1Ol0002noookJPCo0000oooonfY2oookJP00>?oonfX5o`000;oooo]Z0ol0
003ooookJT;ooo]Z000hoookJPGo0000_ooonfX3o`000?oooo]Z@_oonfX003Sooo]Z1Ol0002ooook
JPCo0000oooonfY1oookJP00>?oonfX5o`000;oooo]Z1?l0003ooookJT7ooo]Z000hoookJPGo0000
`?oonfX3o`000?oooo]Z@OoonfX003Sooo]Z1Ol00030oookJP?o0000oooonfY1oookJP004OoonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o1ooonfX3o`00O`Wooo]Z1Ol00030oookJPCo0000oooonfY0
oookJP004?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1_oonfX3o`00O`Wooo]Z1Ol00030oook
JPCo0000oooonfY0oookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oook
JP?o001o00Cooo]Zo`00Ool007oo001o1_oonfX3o`00O`Wooo]Z1Ol00031oookJP?o0000oooonfY0
oookJP000ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l5oook
JP?o001o2OoonfX5o`000<7ooo]Z0ol0003ooookJT3ooo]Z0003oookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Gooo]Z0ol007l9oookJPKo0000`?oonfX4o`000?oo
oo]Z?ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l5oookJP?o001o
2OoonfX5o`000<7ooo]Z1?l0003ooookJSoooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o1OoonfX3o`00O`Wooo]Z1Ol00032oookJP?o0000oooonfXooookJP003ooonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Gooo]Z0ol007l9oookJPGo0000`_oonfX3
o`000?oooo]Z?ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l5oook
JP?o001o2OoonfX5o`000<;ooo]Z0ol0003ooookJSoooo]Z000?oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o0_oonfX6o`00O`Wooo]Z1Ol00032oookJPCo0000oooonfXnoookJP00
4?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JPKo001o2OoonfX5o`000<;ooo]Z1?l0003ooookJSkooo]Z000@oookJPOo001o2?oonfX7o`00O`Go
oo]Z1?l007l9oookJPGo0000`ooonfX3o`000?oooo]Z?_oonfX0017ooo]Z1Ol007l:oookJPGo001o
1ooonfX3o`00O`Wooo]Z1Ol00033oookJP?o0000oooonfXnoookJP00>?oonfX5o`000<?ooo]Z1?l0
003ooookJSgooo]Z000hoookJPGo0000`ooonfX4o`000?oooo]Z?OoonfX003Sooo]Z1Ol00034oook
JP?o0000oooonfXmoookJP00>?oonfX5o`000<Cooo]Z1?l0003ooookJScooo]Z000hoookJPGo0000
a?oonfX4o`000?oooo]Z??oonfX003Sooo]Z1Ol00035oookJP?o0000oooonfXloookJP00>?oonfX5
o`000<Gooo]Z1?l0003ooookJS_ooo]Z000hoookJPGo0000aOoonfX4o`000?oooo]Z>ooonfX003So
oo]Z1Ol00036oookJP?o0000oooonfXkoookJP00>?oonfX5o`000<Kooo]Z1?l0003ooookJS[ooo]Z
000hoookJPGo0000a_oonfX4o`000?oooo]Z>_oonfX003Sooo]Z1Ol00037oookJP?o0000oooonfXj
oookJP00>?oonfX5o`000<Oooo]Z1?l0003ooookJSWooo]Z000hoookJPGo0000aooonfX4o`000?oo
oo]Z>OoonfX003Sooo]Z1Ol00038oookJP?o0000oooonfXioookJP00>?oonfX5o`000<Sooo]Z1?l0
003ooookJSSooo]Z000hoookJPGo0000b?oonfX4o`000?oooo]Z>?oonfX003Sooo]Z1Ol00039oook
JP?o0000oooonfXhoookJP00>?oonfX5o`000<Wooo]Z1?l0003ooookJSOooo]Z000hoookJPGo0000
bOoonfX4o`000?oooo]Z=ooonfX003Sooo]Z1Ol0003:oookJPCo0000oooonfXfoookJP00>?oonfX5
o`000<[ooo]Z1?l0003ooookJSKooo]Z000hoookJPGo0000booonfX3o`000?oooo]Z=_oonfX003So
oo]Z1Ol0003;oookJPCo0000oooonfXeoookJP00>?oonfX5o`000<_ooo]Z1?l0003ooookJSGooo]Z
000hoookJPGo0000c?oonfX4o`000?oooo]Z=?oonfX003Sooo]Z1Ol0003<oookJPCo0000oooonfXd
oookJP00>?oonfX5o`000<gooo]Z0ol0003ooookJSCooo]Z000hoookJPGo0000cOoonfX4o`000?oo
oo]Z<ooonfX003Sooo]Z1Ol0003=oookJPCo0000oooonfXcoookJP00>?oonfX5o`000<kooo]Z0ol0
003ooookJS?ooo]Z000hoookJPGo0000c_oonfX4o`000?oooo]Z<_oonfX003Sooo]Z1Ol0003>oook
JPCo0000oooonfXboookJP00>?oonfX5o`000<oooo]Z1?l0003ooookJS7ooo]Z000hoookJPGo0000
cooonfX4o`000?oooo]Z<OoonfX003Sooo]Z1Ol0003@oookJPCo0000oooonfX`oookJP00>?oonfX5
o`000=3ooo]Z1Ol0003ooookJRoooo]Z000hoookJPGo0000dOoonfX4o`000?oooo]Z;ooonfX003So
oo]Z1Ol0003BoookJPCo0000oooonfX^oookJP00>?oonfX5o`00053ooo]Z0ol007m<oookJPWo001o
:_oonfX4o`0001oooo]Z1Ol007mAoookJP?o001oC_oonfX5o`00Odkooo]Z1Ol007l?oookJP00>?oo
nfX5o`00053ooo]Z0ol007m<oookJPWo001o:ooonfX4o`0001gooo]Z1ol007m@oookJP?o001oCOoo
nfX7o`00Odcooo]Z1ol007l>oookJP00>?oonfX5o`00053ooo]Z0ol007m<oookJPCo001o<?oonfX4
o`0001cooo]Z0ol007l3oookJP?o001oCooonfX3o`00Odcooo]Z1?l007l01?oonf[o001oo`00Ool0
07m<oookJP?o001o0_oonfX3o`00O`gooo]Z000hoookJPGo0000D?oonfX3o`00Odgooo]Z1?l007l`
oookJPCo00006ooonfX3o`00O`?ooo]Z0ol007m:oookJPWo001oBooonfX3o`00O`?ooo]Z0ol007m:
oookJP?o001o0ooonfX3o`00O`gooo]Z000hoookJPGo0000D?oonfX3o`00Odkooo]Z1Ol007l^oook
JPGo00008?oonfX3o`00Od[ooo]Z2Ol007mAoookJP?o001oB_oonfX3o`00O`?ooo]Z0ol007l=oook
JP00>?oonfX5o`00053ooo]Z0ol007m@oookJPCo001o;_oonfX5o`0001oooo]Z0ol007m:oookJP;o
001o0ooonfX3o`00Oe;ooo]Z0ol007m:oookJPCo001o0_oonfX3o`00O`gooo]Z000hoookJPGo0000
D?oonfX3o`00Oe7ooo]Z0ol007l_oookJPCo00007OoonfX4o`00Odcooo]Z0_l007l2oookJP?o001o
COoonfX2o`00O`;ooo]Z1?l007m:oookJPSo001o3_oonfX003Sooo]Z1Ol0001@oookJP?o001oD_oo
nfX3o`00Oboooo]Z1?l0000LoookJP?o001oCOoonfX3o`00O`04oookJ_l007oo001oo`00Odgooo]Z
1ol007m;oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX003Sooo]Z1Ol0001@oookJP?o001o
C?oonfX3o`00O`?ooo]Z0ol007l_oookJPGo00007OoonfX2o`00Odgooo]Z0_l007l01?oonf[o001o
o`00Ool007m=oookJPKo001oC?oonfX3o`00Oa?ooo]Z000hoookJPGo0000COoonfX6o`00Odcooo]Z
0ol007l3oookJP?o001o<?oonfX5o`0001Kooo]Z0ol007l3oookJP?o001oCOoonfX5o`00Odgooo]Z
0_l007m@oookJP?o001o4ooonfX003Sooo]Z1Ol0001=oookJPKo001oC?oonfX4o`00O`;ooo]Z0ol0
07laoookJPGo00005OoonfX3o`00O`?ooo]Z0ol007m=oookJPGo001oCOoonfX2o`00Oe7ooo]Z0ol0
07l2oookJP?o001o3OoonfX003Sooo]Z1Ol0001?oookJPCo001oCOoonfX7o`00Oc?ooo]Z1Ol0000E
oookJPOo001oCooonfX4o`00Odkooo]Z1ol007m;oookJPOo001o3_oonfX003Sooo]Z1Ol0001@oook
JP?o001oC_oonfX5o`00OcGooo]Z1Ol0000EoookJPGo001oDOoonfX3o`00Odkooo]Z1ol007m=oook
JPCo001o3ooonfX003Sooo]Z1Ol0003LoookJPKo0000oooonfXRoookJP00>?oonfX5o`000=gooo]Z
1_l0003ooookJR7ooo]Z000hoookJPGo0000g_oonfX8o`000?oooo]Z7_oonfX003Sooo]Z1Ol0003P
oookJPSo0000oooonfXLoookJP00>?oonfX5o`000>7ooo]Z2Ol0003ooookJQ[ooo]Z000[oookJ_oo
0000ool0000Fo`00007ooo]Z000[oookJ_oo0000ool0000Fo`00007ooo]Z000[oookJ_oo0000ool0
000Fo`00007ooo]Z000[oookJ_oo0000ool0000Fo`00007ooo]Z000[oookJ_oo0000ool0000Fo`00
007ooo]Z000hoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z057o
oo]Z00?o0000oookJ_oonfX02ooonfX9o`0003cooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003o
oo]ZoookJP1@oookJP03o`000?oonf[ooo]Z00kooo]Z000hoookJPGo0000DOoonfX00ol0003ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX03_oonfX7o`0003_ooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z00kooo]Z
000hoookJPGo0000oooonfX=oookJPKo0000lOoonfX003Sooo]Z1Ol0003ooookJPkooo]Z1_l0003`
oookJP00>?oonfX5o`000?oooo]Z3ooonfX6o`000>oooo]Z000hoookJPGo0000oooonfXAoookJPGo
0000k_oonfX003Sooo]Z1Ol0003ooookJQ;ooo]Z1Ol0003]oookJP00>?oonfX5o`000?oooo]Z4ooo
nfX5o`000>cooo]Z000hoookJPGo0000oooonfXDoookJPCo0000k?oonfX003Sooo]Z1Ol0003ooook
JQGooo]Z1?l0003[oookJP00>?oonfX5o`000?oooo]Z5OoonfX5o`000>[ooo]Z000hoookJPGo0000
oooonfXFoookJPGo0000jOoonfX003Sooo]Z1Ol0003ooookJQOooo]Z1?l0003YoookJP00>?oonfX5
o`000?oooo]Z6?oonfX4o`000>Sooo]Z000hoookJPGo0000oooonfXHoookJPGo0000iooonfX003So
oo]Z1Ol0003ooookJQWooo]Z1?l0003WoookJP00>?oonfX5o`000?oooo]Z6_oonfX4o`000>Kooo]Z
000hoookJPGo0000oooonfXJoookJPCo0000i_oonfX003Sooo]Z1Ol0003ooookJQ_ooo]Z1?l0003U
oookJP00>?oonfX5o`000?oooo]Z6ooonfX5o`000>Cooo]Z000hoookJPGo0000oooonfXLoookJPCo
0000i?oonfX003Sooo]Z1Ol0003ooookJQgooo]Z1?l0003SoookJP00>?oonfX5o`000?oooo]Z7Ooo
nfX4o`000>?ooo]Z000hoookJPGo0000oooonfXNoookJPCo0000h_oonfX003Sooo]Z1Ol0003ooook
JQkooo]Z1?l0003RoookJP00>?oonfX5o`000?oooo]Z7ooonfX4o`000>7ooo]Z000hoookJPGo0000
oooonfXOoookJPCo0000hOoonfX003Sooo]Z1Ol0003ooookJR3ooo]Z1?l0003PoookJP00>?oonfX5
o`000?oooo]Z8?oonfX4o`000>3ooo]Z000hoookJPGo0000oooonfXQoookJPCo0000gooonfX003So
oo]Z1Ol0003ooookJR7ooo]Z1?l0003OoookJP00>?oonfX5o`000?oooo]Z8_oonfX3o`000=oooo]Z
000hoookJPGo0000oooonfXRoookJPCo0000g_oonfX003Sooo]Z1Ol0003ooookJR;ooo]Z1?l0003N
oookJP00>?oonfX5o`000?oooo]Z8ooonfX4o`000=gooo]Z000hoookJPGo0000oooonfXSoookJPCo
0000gOoonfX003Sooo]Z1Ol0003ooookJRCooo]Z0ol0003MoookJP00>?oonfX5o`000?oooo]Z9?oo
nfX4o`000=cooo]Z000hoookJPGo0000oooonfXToookJPCo0000g?oonfX003Sooo]Z1Ol0003ooook
JRGooo]Z0ol0003LoookJP00>?oonfX5o`000?oooo]Z9OoonfX4o`000=_ooo]Z000hoookJPGo0000
oooonfXUoookJPCo0000fooonfX003Sooo]Z1Ol0003ooookJRKooo]Z0ol0003KoookJP00>?oonfX5
o`000?oooo]Z9_oonfX4o`000=[ooo]Z000hoookJPGo0000oooonfXVoookJPCo0000f_oonfX003So
oo]Z1Ol0003ooookJROooo]Z0ol0003JoookJP00>?oonfX5o`000?oooo]Z9ooonfX4o`000=Wooo]Z
000hoookJPGo0000oooonfXWoookJPCo0000fOoonfX003Sooo]Z1Ol0003ooookJRSooo]Z0ol0003I
oookJP00>?oonfX5o`000?oooo]Z:?oonfX4o`000=Sooo]Z000hoookJPGo0000oooonfXXoookJPCo
0000f?oonfX003Sooo]Z1Ol0003ooookJRWooo]Z0ol0003HoookJP00>?oonfX5o`000?oooo]Z:Ooo
nfX4o`000=Oooo]Z000hoookJPGo0000oooonfXYoookJPCo0000eooonfX003Sooo]Z1Ol0003ooook
JR[ooo]Z0ol0003GoookJP00>?oonfX5o`000?oooo]Z:_oonfX4o`000=Kooo]Z000hoookJPGo0000
oooonfXZoookJPCo0000e_oonfX003Sooo]Z1Ol0003ooookJR_ooo]Z0ol0003FoookJP00>?oonfX5
o`000?oooo]Z:ooonfX4o`000=Gooo]Z000hoookJPGo0000oooonfX[oookJPCo0000eOoonfX003So
oo]Z1Ol0003ooookJRcooo]Z0ol0003EoookJP00>?oonfX5o`000?oooo]Z;?oonfX4o`000=Cooo]Z
000AoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l7oookJP?o001o2OoonfX5o`000?oooo]Z;?oo
nfX4o`000=Cooo]Z000@oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l6oookJP?o001o2OoonfX5
o`000?oooo]Z;OoonfX3o`000=Cooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l6oookJP?o001o2OoonfX5o`000?oooo]Z;Ooo
nfX4o`000=?ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1OoonfX3
o`00O`Wooo]Z1Ol0003ooookJRgooo]Z1?l0003CoookJP003ooonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Gooo]Z0ol007l9oookJPKo0000oooonfX]oookJP?o0000dooonfX000oo
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l5oookJP?o001o2OoonfX5o`000?oo
oo]Z;_oonfX3o`000=?ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1OoonfX3o`00O`Wooo]Z1Ol0003ooookJRkooo]Z1?l0003BoookJP003ooonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`Gooo]Z0ol007l9oookJPGo0000oooonfX^oookJPCo0000d_oo
nfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l5oookJP?o001o2OoonfX5
o`000?oooo]Z;ooonfX3o`000=;ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o0_oonfX6o`00O`Wooo]Z1Ol0003ooookJRoooo]Z0ol0003BoookJP004?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJPKo001o2OoonfX5
o`000?oooo]Z;ooonfX3o`000=;ooo]Z000@oookJPOo001o2?oonfX7o`00O`Gooo]Z1?l007l9oook
JPGo0000oooonfX_oookJPCo0000dOoonfX0017ooo]Z1Ol007l:oookJPGo001o1ooonfX3o`00O`Wo
oo]Z1Ol0003ooookJRoooo]Z1?l0003AoookJP00>?oonfX5o`000?oooo]Z<?oonfX3o`000=7ooo]Z
000hoookJPGo0000oooonfX`oookJP?o0000dOoonfX003Sooo]Z1Ol0003ooookJS3ooo]Z1?l0003@
oookJP00>?oonfX5o`000?oooo]Z<?oonfX4o`000=3ooo]Z000hoookJPGo0000oooonfXaoookJP?o
0000d?oonfX003Sooo]Z1Ol0003ooookJS7ooo]Z0ol0003@oookJP00>?oonfX5o`000?oooo]Z<Ooo
nfX3o`000=3ooo]Z000hoookJPGo0000oooonfXaoookJPCo0000cooonfX003Sooo]Z1Ol0003ooook
JS7ooo]Z1?l0003?oookJP00>?oonfX5o`000?oooo]Z<_oonfX3o`000<oooo]Z000hoookJPGo0000
oooonfXboookJP?o0000cooonfX003Sooo]Z1Ol0003ooookJS;ooo]Z0ol0003?oookJP00>?oonfX5
o`000?oooo]Z<_oonfX4o`000<kooo]Z000hoookJPGo0000oooonfXboookJPCo0000c_oonfX003So
oo]Z1Ol0003ooookJS?ooo]Z0ol0003>oookJP00>?oonfX5o`000?oooo]Z<ooonfX3o`000<kooo]Z
000hoookJPGo0000oooonfXcoookJPCo0000cOoonfX003Sooo]Z1Ol0003ooookJS?ooo]Z1?l0003=
oookJP00>?oonfX5o`000?oooo]Z=?oonfX3o`000<gooo]Z000hoookJPGo0000oooonfXdoookJP?o
0000cOoonfX003Sooo]Z1Ol0003ooookJSCooo]Z0ol0003=oookJP00>?oonfX5o`000?oooo]Z=?oo
nfX4o`000<cooo]Z000hoookJPGo0000oooonfXdoookJPCo0000c?oonfX003Sooo]Z1Ol0003ooook
JSGooo]Z0ol0003<oookJP00>?oonfX5o`000?oooo]Z=OoonfX3o`000<cooo]Z000hoookJPGo0000
oooonfXeoookJPCo0000booonfX003Sooo]Z1Ol0003ooookJSGooo]Z1?l0003;oookJP00>?oonfX5
o`000?oooo]Z=_oonfX3o`000<_ooo]Z000hoookJPGo0000oooonfXfoookJP?o0000booonfX003So
oo]Z1Ol0003ooookJSKooo]Z0ol0003;oookJP00>?oonfX5o`000?oooo]Z=_oonfX4o`000<[ooo]Z
000hoookJPGo0000oooonfXfoookJPCo0000b_oonfX003Sooo]Z1Ol0003ooookJSOooo]Z0ol0003:
oookJP00>?oonfX5o`000?oooo]Z=ooonfX3o`000<[ooo]Z000hoookJPGo0000oooonfXgoookJPCo
0000bOoonfX003Sooo]Z1Ol0003ooookJSOooo]Z1?l00039oookJP00>?oonfX5o`000?oooo]Z>?oo
nfX3o`000<Wooo]Z000hoookJPGo0000oooonfXhoookJP?o0000bOoonfX003Sooo]Z1Ol0003ooook
JSSooo]Z0ol00039oookJP00>?oonfX5o`000?oooo]Z>?oonfX4o`000<Sooo]Z000hoookJPGo0000
oooonfXhoookJPCo0000b?oonfX003Sooo]Z1Ol0003ooookJSWooo]Z0ol00038oookJP00>?oonfX5
o`000?oooo]Z>OoonfX3o`000<Sooo]Z000hoookJPGo0000oooonfXioookJP?o0000b?oonfX003So
oo]Z1Ol0003ooookJSWooo]Z0ol00038oookJP00>?oonfX5o`000?oooo]Z>OoonfX4o`000<Oooo]Z
000hoookJPGo0000oooonfXioookJPCo0000aooonfX003Sooo]Z1Ol0003ooookJS[ooo]Z0ol00037
oookJP00>?oonfX5o`000?oooo]Z>_oonfX3o`000<Oooo]Z000hoookJPGo0000oooonfXjoookJP?o
0000aooonfX003Sooo]Z1Ol0003ooookJS[ooo]Z0ol00037oookJP00>?oonfX5o`000?oooo]Z>_oo
nfX3o`000<Oooo]Z000hoookJPGo0000oooonfXjoookJPCo0000a_oonfX003Sooo]Z1Ol0003ooook
JS[ooo]Z1?l00036oookJP00>?oonfX5o`000?oooo]Z>ooonfX3o`000<Kooo]Z000AoookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l3oookJPWo001o1ooonfX5o`000?oooo]Z>ooonfX3o`000<Kooo]Z
000@oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo001o1ooonfX5o`000?oooo]Z>ooo
nfX3o`000<Kooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l2oookJPCo001o3?oonfX5o`000?oooo]Z>ooonfX3o`000<Kooo]Z
000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX4o`00O`_ooo]Z1Ol0
003ooookJS_ooo]Z0ol00036oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00O`?ooo]Z1Ol007l9oookJPKo0000oooonfXjoookJPCo0000aOoonfX000oooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l5oookJPCo001o2?oonfX5o`000?oooo]Z>ooonfX4o`00
0<Gooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`So
oo]Z1Ol0003ooookJScooo]Z0ol00035oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`Oooo]Z0ol007l7oookJPGo0000oooonfXloookJP?o0000aOoonfX000oooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
1ooonfX5o`000?oooo]Z??oonfX3o`000<Gooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJScooo]Z
0ol00035oookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l01?oonf[o001o
o`00Ool007l2oookJPCo001o0_oonfX3o`00O`Oooo]Z1Ol0003ooookJScooo]Z0ol00035oookJP00
4?oonfX7o`00O`Sooo]Z1ol007l3oookJPOo001o2?oonfX5o`000?oooo]Z??oonfX4o`000<Cooo]Z
000AoookJPGo001o2_oonfX5o`00O`Gooo]Z1Ol007l9oookJPGo0000oooonfXloookJPCo0000a?oo
nfX003Sooo]Z1Ol0003ooookJSgooo]Z0ol00034oookJP00>?oonfX5o`000?oooo]Z?OoonfX3o`00
0<Cooo]Z000hoookJPGo0000oooonfXmoookJP?o0000a?oonfX003Sooo]Z1Ol0003ooookJSgooo]Z
0ol00034oookJP00>?oonfX5o`000?oooo]Z?OoonfX3o`000<Cooo]Z000hoookJPGo0000oooonfXm
oookJPCo0000`ooonfX003Sooo]Z1Ol0003ooookJSgooo]Z1?l00033oookJP00>?oonfX5o`000?oo
oo]Z?_oonfX3o`000<?ooo]Z000hoookJPGo0000oooonfXnoookJP?o0000`ooonfX003Sooo]Z1Ol0
003ooookJSkooo]Z0ol00033oookJP00>?oonfX5o`000?oooo]Z?_oonfX3o`000<?ooo]Z000hoook
JPGo0000oooonfXnoookJP?o0000`ooonfX003Sooo]Z1Ol0003ooookJSkooo]Z1?l00032oookJP00
>?oonfX5o`000?oooo]Z?_oonfX4o`000<;ooo]Z000hoookJPGo0000oooonfXooookJP?o0000`_oo
nfX003Sooo]Z1Ol0003ooookJSoooo]Z0ol00032oookJP00>?oonfX5o`000?oooo]Z?ooonfX3o`00
0<;ooo]Z000hoookJPGo0000oooonf[ooookJPGooo]Z000hoookJPGo0000oooonf[ooookJPGooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.700396, -0.0260855, \
0.0119686, 0.000145948}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Fourier Series functions are defined for function that are periodic in \
the domain x \[Element] (-1/2,1/2).  So we need to map the periodic functions \
to this domain"
}], "Text",
  CellTags->"mmtag:17:Fourier_series__changing_domain_of_periodicity"],

Cell[BoxData[
    \(ReduceHalfHalf[f_\ , \ x_\ , \ \[Lambda]_\ ]\  := \ 
      f[\((x + 1/2)\)*\[Lambda]\ ]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReducedFunction\  = \ 
      ReduceHalfHalf[AFunction, x, 6] // Simplify\)], "Input"],

Cell[BoxData[
    \(8\ x\^3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[ReducedFunction, {x, \(-1\)/2, 1/2}, 
      PlotRange \[Rule] All]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.309017 0.294302 [
[.11905 .29652 -20.9688 -20 ]
[.11905 .29652 20.9688 0 ]
[.30952 .29652 -20.9688 -20 ]
[.30952 .29652 20.9688 0 ]
[.69048 .29652 -14.5 -20 ]
[.69048 .29652 14.5 0 ]
[.88095 .29652 -14.5 -20 ]
[.88095 .29652 14.5 0 ]
[.4875 .01472 -26.9375 -10 ]
[.4875 .01472 0 10 ]
[.4875 .16187 -41.9375 -10 ]
[.4875 .16187 0 10 ]
[.4875 .45617 -29 -10 ]
[.4875 .45617 0 10 ]
[.4875 .60332 -14 -10 ]
[.4875 .60332 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
gsave
.11905 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.30952 .30902 m
.30952 .31527 L
s
gsave
.30952 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.69048 .30902 m
.69048 .31527 L
s
gsave
.69048 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.88095 .30902 m
.88095 .31527 L
s
gsave
.88095 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 .01472 m
.50625 .01472 L
s
gsave
.4875 .01472 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .16187 m
.50625 .16187 L
s
gsave
.4875 .16187 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .45617 m
.50625 .45617 L
s
gsave
.4875 .45617 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .60332 m
.50625 .60332 L
s
gsave
.4875 .60332 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.01 w
.5 0 m
.5 .61803 L
s
.0075 w
.02381 .01472 m
.06244 .08069 L
.10458 .14051 L
.14415 .1862 L
.18221 .22154 L
.22272 .25091 L
.26171 .27214 L
.28158 .28062 L
.30316 .28823 L
.32216 .29369 L
.34309 .29849 L
.36292 .302 L
.38395 .30476 L
.40336 .30656 L
.41426 .3073 L
.42424 .30783 L
.43408 .30824 L
.44322 .30852 L
.45325 .30874 L
.45886 .30883 L
.46395 .30889 L
.46882 .30893 L
.47149 .30895 L
.47397 .30897 L
.47837 .30899 L
.4807 .309 L
.48319 .309 L
.48587 .30901 L
.48739 .30901 L
.48879 .30901 L
.49001 .30901 L
.49136 .30902 L
.49203 .30902 L
.49276 .30902 L
.49408 .30902 L
.49529 .30902 L
.49661 .30902 L
.49727 .30902 L
.49798 .30902 L
.49926 .30902 L
.50054 .30902 L
.50175 .30902 L
.50284 .30902 L
.50401 .30902 L
.50525 .30902 L
.50637 .30902 L
.50767 .30902 L
.5089 .30902 L
.51004 .30902 L
.51109 .30902 L
Mistroke
.51348 .30902 L
.51484 .30903 L
.51613 .30903 L
.51852 .30903 L
.5211 .30904 L
.52389 .30905 L
.52923 .30909 L
.53191 .30911 L
.53486 .30913 L
.54007 .30919 L
.54493 .30926 L
.54996 .30936 L
.55541 .30948 L
.56533 .30978 L
.57498 .31017 L
.58389 .31063 L
.6026 .31196 L
.61324 .31297 L
.62321 .31412 L
.64343 .31706 L
.66195 .32059 L
.68252 .32559 L
.70163 .33136 L
.73979 .3466 L
.77889 .36814 L
.82044 .39869 L
.86047 .43668 L
.89899 .48213 L
.93996 .54113 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP004?oonfX4
o`000>cooo]Z2_l007l6oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1?l0003/oook
JP[o001o1_oonfX3o`00O`[ooo]Z1ol0003ooookJQgooo]Z000@oookJPGo0000nooonfX3o`00O`[o
oo]Z1Ol0003ooookJQoooo]Z000@oookJPGo0000nooonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z
000@oookJPKo0000n_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z000AoookJPKo0000nOoonfX3
o`00O`[ooo]Z1Ol0003ooookJQoooo]Z000AoookJPKo0000m_oonfX6o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z000BoookJPKo0000mOoonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z000CoookJPGo0000
mooonfX4o`00O`[ooo]Z1Ol0003ooookJQoooo]Z000CoookJPKo0000mooonfX3o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z000DoookJPKo0000oooonfX4oookJPGo0000oooonfXOoookJP005?oonfX6o`00
0?oooo]Z1?oonfX5o`000?oooo]Z7ooonfX001Gooo]Z1_l0003ooookJP?ooo]Z1Ol0003ooookJQoo
oo]Z000FoookJPGo0000oooonfX3oookJPGo0000oooonfXOoookJP005_oonfX6o`000?oooo]Z0_oo
nfX5o`000?oooo]Z7ooonfX001Oooo]Z1_l0003ooookJP7ooo]Z1Ol0003ooookJQoooo]Z000Goook
JPKo0000oooonfX1oookJPGo0000oooonfXOoookJP006?oonfX6o`000?oooo]Z1Ol0003ooookJQoo
oo]Z000IoookJPGo0000oooonfX5o`000?oooo]Z7ooonfX001Wooo]Z1_l0003noookJPGo0000oooo
nfXOoookJP006_oonfX6o`000?gooo]Z1Ol0003ooookJQoooo]Z000JoookJPKo0000oOoonfX5o`00
0?oooo]Z7ooonfX001_ooo]Z1_l0003loookJPGo0000oooonfXOoookJP007?oonfX5o`000?cooo]Z
1Ol0003ooookJQoooo]Z000LoookJPKo0000nooonfX5o`000?oooo]Z7ooonfX001gooo]Z1_l0003j
oookJPGo0000oooonfXOoookJP007OoonfX6o`000?[ooo]Z1Ol0003ooookJQoooo]Z000NoookJPKo
0000nOoonfX5o`000?oooo]Z7ooonfX001oooo]Z1Ol0003ioookJPGo0000oooonfXOoookJP007ooo
nfX6o`000?Sooo]Z1Ol0003ooookJQoooo]Z000PoookJPKo0000mooonfX5o`000?oooo]Z7ooonfX0
023ooo]Z1_l0003goookJPGo0000oooonfXOoookJP008OoonfX6o`000?Kooo]Z1Ol0003ooookJQoo
oo]Z000RoookJPGo0000m_oonfX5o`000?oooo]Z7ooonfX002;ooo]Z1_l0003eoookJPGo0000oooo
nfXOoookJP008ooonfX6o`000?Cooo]Z1Ol0003ooookJQoooo]Z000SoookJPKo0000m?oonfX5o`00
0?oooo]Z7ooonfX002Cooo]Z1_l0003coookJPGo0000oooonfXOoookJP009OoonfX5o`000??ooo]Z
1Ol0003ooookJQoooo]Z000UoookJPKo0000l_oonfX5o`000?oooo]Z7ooonfX002Kooo]Z1_l0003a
oookJPGo0000oooonfXOoookJP009_oonfX6o`000?7ooo]Z1Ol0003ooookJQoooo]Z000WoookJPKo
0000l?oonfX5o`000?oooo]Z7ooonfX002Sooo]Z1_l0003_oookJPGo0000oooonfXOoookJP00:?oo
nfX7o`000>kooo]Z1Ol0003ooookJQoooo]Z000YoookJPKo0000k_oonfX5o`000?oooo]Z7ooonfX0
02[ooo]Z1_l0003]oookJPGo0000oooonfXOoookJP00:ooonfX6o`000>cooo]Z1Ol0003ooookJQoo
oo]Z000[oookJPKo0000k?oonfX5o`000?oooo]Z7ooonfX002cooo]Z1_l0003[oookJPGo0000oooo
nfXOoookJP00;OoonfX6o`000>[ooo]Z1Ol0003ooookJQoooo]Z000]oookJPOo0000jOoonfX5o`00
0?oooo]Z7ooonfX002kooo]Z1_l0003YoookJPGo0000oooonfXOoookJP00;ooonfX6o`000>Sooo]Z
1Ol0003ooookJQoooo]Z000`oookJPKo0000iooonfX5o`000?oooo]Z7ooonfX0033ooo]Z1_l0003W
oookJPGo0000oooonfXOoookJP00<OoonfX6o`000>Kooo]Z1Ol0003ooookJQoooo]Z000boookJPKo
0000iOoonfX5o`000?oooo]Z7ooonfX003;ooo]Z1_l0003UoookJPGo0000oooonfXOoookJP00<ooo
nfX6o`000>Cooo]Z1Ol0003ooookJQoooo]Z000doookJPKo0000hooonfX5o`000?oooo]Z7ooonfX0
03Cooo]Z1ol0003RoookJPGo0000oooonfXOoookJP00=OoonfX6o`000>;ooo]Z1Ol0003ooookJQoo
oo]Z000foookJPKo0000hOoonfX5o`000?oooo]Z7ooonfX003Oooo]Z1_l0003PoookJPGo0000oooo
nfXOoookJP00=ooonfX6o`000>3ooo]Z1Ol0003ooookJQoooo]Z000hoookJPKo0000gooonfX5o`00
0?oooo]Z7ooonfX003Wooo]Z1_l0003NoookJPGo0000oooonfXOoookJP00>OoonfX7o`000=gooo]Z
1Ol0003ooookJQoooo]Z000joookJPKo0000gOoonfX5o`000?oooo]Z7ooonfX003_ooo]Z1_l0003L
oookJPGo0000oooonfXOoookJP00??oonfX6o`000=_ooo]Z1Ol0003ooookJQoooo]Z000loookJPKo
0000fooonfX5o`000?oooo]Z7ooonfX003gooo]Z1_l0003JoookJPGo0000oooonfXOoookJP00?_oo
nfX6o`000=Wooo]Z1Ol0003ooookJQoooo]Z000noookJPOo0000f?oonfX5o`000?oooo]Z7ooonfX0
03oooo]Z1ol0003GoookJPGo0000oooonfXOoookJP00@?oonfX7o`000=Kooo]Z1Ol0003ooookJQoo
oo]Z0011oookJPOo0000eOoonfX5o`000?oooo]Z7ooonfX004;ooo]Z1_l0003EoookJPGo0000oooo
nfXOoookJP00@ooonfX6o`000;Kooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003o
oookJQoooo]Z0014oookJPKo0000]?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`00
0?oooo]Z7ooonfX004Cooo]Z1ol0002coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX0
04Gooo]Z1ol0002UoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Sooo]Z1Ol0003ooookJQoooo]Z0016oookJPOo0000Y?oonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Sooo]Z1ol0003ooookJQgooo]Z0017oookJPKo0000/?oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX004Sooo]Z1_l0002_oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX004Wooo]Z1_l0002^
oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00BOoonfX7o`00
0:gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z001:oookJPOo
0000[?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX004_ooo]Z
1ol0002/oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0003ooookJQoo
oo]Z001<oookJPOo0000ZooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00COoo
nfX6o`000:cooo]Z1Ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX004kooo]Z1_l00039
oookJPGo0000oooonfXOoookJP00CooonfX6o`000<Sooo]Z1Ol0003ooookJQoooo]Z001?oookJPOo
0000aooonfX5o`000?oooo]Z7ooonfX0053ooo]Z1ol00036oookJPGo0000oooonfXOoookJP00DOoo
nfX8o`000<Cooo]Z1Ol0003ooookJQoooo]Z001BoookJPSo0000`ooonfX5o`000?oooo]Z7ooonfX0
05?ooo]Z2?l00032oookJPGo0000oooonfXOoookJP00E?oonfX8o`000<7ooo]Z1Ol0003ooookJQoo
oo]Z001FoookJPOo0000`?oonfX5o`000?oooo]Z7ooonfX005Oooo]Z1ol0002ooookJPGo0000oooo
nfXOoookJP00F?oonfX7o`000;kooo]Z1Ol0003ooookJQoooo]Z001IoookJPOo0000_OoonfX5o`00
0?oooo]Z7ooonfX005[ooo]Z1ol0002loookJPGo0000oooonfXOoookJP00FooonfX7o`000;_ooo]Z
1Ol0003ooookJQoooo]Z001LoookJPOo0000^_oonfX5o`000?oooo]Z7ooonfX005gooo]Z1ol0002i
oookJPGo0000oooonfXOoookJP00G_oonfX7o`000;Sooo]Z1Ol0003ooookJQoooo]Z001OoookJPOo
0000]ooonfX5o`000?oooo]Z7ooonfX0063ooo]Z1ol0002foookJPGo0000oooonfXOoookJP00HOoo
nfX7o`000;Gooo]Z1Ol0003ooookJQoooo]Z001RoookJPOo0000]?oonfX5o`000?oooo]Z7ooonfX0
06?ooo]Z1ol0002coookJPGo0000oooonfXOoookJP00I?oonfX7o`000;;ooo]Z1Ol0003ooookJQoo
oo]Z001UoookJPOo0000/OoonfX5o`000?oooo]Z7ooonfX006Kooo]Z2?l0002_oookJPGo0000oooo
nfXOoookJP00IooonfX8o`000:kooo]Z1Ol0003ooookJQoooo]Z001XoookJPWo0000[?oonfX5o`00
0?oooo]Z7ooonfX006Wooo]Z2Ol0002[oookJPGo0000oooonfXOoookJP00JooonfX8o`000:[ooo]Z
1Ol0003ooookJQoooo]Z001/oookJPWo0000Z?oonfX5o`000?oooo]Z7ooonfX006kooo]Z2?l0002W
oookJPGo0000oooonfXOoookJP00KooonfX9o`000:Gooo]Z1Ol0003ooookJQoooo]Z001`oookJPWo
0000Y?oonfX5o`000?oooo]Z7ooonfX007;ooo]Z2Ol0002RoookJPGo0000oooonfXOoookJP00Looo
nfX9o`000:7ooo]Z1Ol0003ooookJQoooo]Z001eoookJPWo0000WooonfX5o`000?oooo]Z7ooonfX0
07Kooo]Z2Ol0002NoookJPGo0000oooonfXOoookJP00N?oonfX8o`0009gooo]Z1Ol0003ooookJQoo
oo]Z001ioookJPWo0000VooonfX5o`000?oooo]Z7ooonfX007_ooo]Z2?l0002JoookJPGo0000oooo
nfXOoookJP00O?oonfX9o`0009Sooo]Z1Ol0003ooookJQoooo]Z001moookJP[o0000U_oonfX5o`00
0?oooo]Z7ooonfX007oooo]Z2_l0002DoookJPGo0000oooonfXOoookJP00P?oonfX:o`0009?ooo]Z
1Ol0003ooookJQoooo]Z0022oookJP[o0000TOoonfX5o`000?oooo]Z7ooonfX008Cooo]Z2_l0002?
oookJPGo0000oooonfXOoookJP00Q_oonfX:o`0008gooo]Z1Ol0003ooookJQoooo]Z0027oookJP_o
0000RooonfX5o`000?oooo]Z7ooonfX008Wooo]Z2ol00029oookJPGo0000oooonfXOoookJP00Rooo
nfX:o`0008Sooo]Z1Ol0003ooookJQoooo]Z002=oookJP[o0000Q_oonfX5o`000?oooo]Z7ooonfX0
08oooo]Z2_l00024oookJPGo0000oooonfXOoookJP00TOoonfX:o`0008;ooo]Z1Ol0003ooookJQoo
oo]Z0014oookJPGo001o1?oonfX3o`00O`Kooo]Z0ol007lioookJPco00004OoonfX5o`00O`Cooo]Z
0ol007l00ooonf[o001oo`00O`07o`00OeSooo]Z1Ol0001NoookJPGo001o1?oonfX3o`00O`03oook
J_l007oo001o00Oo001oE_oonfX5o`00O`Cooo]Z0ol007l6oookJP?o001o?ooonfX004?ooo]Z1ol0
07l3oookJP?o001o1_oonfX3o`00Oc_ooo]Z3?l0000>oookJPOo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00Oo001oF?oonfX5o`0005gooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol0
07mEoookJPOo001o0ooonfX3o`00O`Kooo]Z0ol007looookJP00@ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l6oookJP?o001o?OoonfX<o`0000cooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007mMoookJPGo0000GOoonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00Oe[ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o1_oonfX3o`00Ocoooo]Z000foookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l6oookJPWo001o?_oonfX=o`0000Ko001o0_oonfX3o`00O`?ooo]Z0ol007l7oookJPCo
001oG?oonfX5o`0005cooo]Z0ol007l3oookJP?o001o1ooonfX4o`00OeSooo]Z0ol007l3oookJP?o
001o1_oonfX9o`00Ockooo]Z000foookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPWo001o
@OoonfX=o`0000?o001o0_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo001oF_oonfX5o`0005cooo]Z
0ol007l3oookJP?o001o2?oonfX5o`00OeKooo]Z0ol007l3oookJP?o001o1_oonfX9o`00Ockooo]Z
0012oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001oA?oonfX>o`0000;ooo]Z0ol0
07l3oookJP?o001o2_oonfX4o`00OeWooo]Z1Ol0001LoookJP?o001o0ooonfX3o`00O`[ooo]Z1?l0
07mEoookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o?ooonfX004;ooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`;ooo]Z0ol007m6oookJPoo00000_l007l3oookJP?o001o2ooonfX3
o`00OeWooo]Z1Ol0001LoookJP?o001o0ooonfX3o`00O`_ooo]Z0ol007mEoookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l2oookJP?o001o?ooonfX004;ooo]Z0ol007l3oookJP?o001o1ooonfX3o`00
O`04oookJ_l007oo001oo`00OdWooo]Z3ol00002oookJP?o001o3?oonfX3o`00OeSooo]Z1Ol0001L
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007mDoookJP?o001o0ooonfX3o`00O`Oooo]Z0ol007l0
1?oonf[o001oo`00Ool007looookJP00@_oonfX3o`00O`?ooo]Z0ol007l8oookJP;o001o00Cooo]Z
o`00Ool007oo001oC?oonfX?o`0000;o001o1_oonfX3o`00O`?ooo]Z0ol007mHoookJPGo0000G?oo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00OeCooo]Z0ol007l3oookJP?o001o2?oo
nfX2o`00O`04oookJ_l007oo001oo`00Ocoooo]Z0012oookJP?o001o0ooonfX3o`00O`Wooo]Z1Ol0
07m?oookJPoo00001OoonfX3o`00O`?ooo]Z0ol007mHoookJPGo0000G?oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00OeCooo]Z0ol007l3oookJP?o001o2OoonfX5o`00Ocoooo]Z0013
oookJP?o001o00Cooo]Zo`00Ool007oo001o2_oonfX5o`00Oe;ooo]Z3ol00002oookJPCo001o0_oo
nfX3o`00OeSooo]Z1Ol0001MoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z
0ol007mEoookJP?o001o00Cooo]Zo`00Ool007oo001o2_oonfX5o`00Ocoooo]Z0013oookJPOo001o
2ooonfX4o`00OeGooo]Z4?l00006o`00OeWooo]Z1Ol0001MoookJPOo001o2?oonfX7o`00OeKooo]Z
1ol007l;oookJPCo001o?ooonfX004Cooo]Z1Ol007l=oookJP?o001oE_oonfX2o`00Oa7o000000?o
001ooookJ_oonfX0F?oonfX5o`0005kooo]Z1Ol007l:oookJPGo001oF?oonfX5o`00O`gooo]Z0ol0
07looookJP00]?oonfXBo`0005Oooo]Z1Ol0003ooookJQoooo]Z002goookJQCo0000D_oonfX5o`00
0?oooo]Z7ooonfX00;_ooo]Z5_l0001<oookJPGo0000oooonfXOoookJP00_ooonfXHo`0004Kooo]Z
1Ol0003ooookJQoooo]Z0033oookJQWo0000@OoonfX5o`000?oooo]Z7ooonfX00<Sooo]Z7Ol0000h
oookJPGo0000oooonfXOoookJP000_oonf[oo`000?oo0000?Ol00003oookJP000_oonf[oo`000?oo
0000?Ol00003oookJP000_oonf[oo`000?oo0000?Ol00003oookJP000_oonf[oo`000?oo0000?Ol0
0003oookJP000_oonf[oo`000?oo0000?Ol00003oookJP00B?oonfX00ol0003ooo]ZoookJP1Xoook
JP03o`000?oonf[ooo]Z06Oooo]Z1Ol0000ToookJRWo00007?oonfX00ol0003ooo]ZoookJP1Xoook
JP03o`000?oonf[ooo]Z04Oooo]Z0018oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oo
nfX0IooonfX5o`00037ooo]Z8_l0000FoookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oo
nfX0AooonfX00?oooo]Z7_oonfX5o`0003oooo]Z6Ol00036oookJP00oooonfXNoookJPGo0000AOoo
nfXIo`000<3ooo]Z003ooookJQkooo]Z1Ol0001:oookJQWo0000^ooonfX00?oooo]Z7_oonfX5o`00
053ooo]Z5ol0002goookJP00oooonfXNoookJPGo0000EOoonfXEo`000;Cooo]Z003ooookJQkooo]Z
1Ol0001KoookJQ;o0000/OoonfX00?oooo]Z7_oonfX5o`00063ooo]Z4?l0002^oookJP00oooonfXN
oookJPGo0000I?oonfX>o`000:cooo]Z003ooookJQkooo]Z1Ol0001WoookJPko0000ZOoonfX00?oo
oo]Z7_oonfX5o`0006[ooo]Z3_l0002VoookJP00oooonfXNoookJPGo0000KOoonfX>o`000:?ooo]Z
003ooookJQkooo]Z1Ol0001_oookJPko0000XOoonfX00?oooo]Z7_oonfX5o`0007;ooo]Z3_l0002N
oookJP00oooonfXNoookJPGo0000MOoonfX>o`0009_ooo]Z003ooookJQkooo]Z1Ol0001hoookJPko
0000V?oonfX00?oooo]Z7_oonfX5o`0007[ooo]Z3_l0002FoookJP00oooonfXNoookJPGo0000OOoo
nfX=o`0009Cooo]Z003ooookJQkooo]Z1Ol00020oookJPco0000T_oonfX00?oooo]Z7_oonfX5o`00
08?ooo]Z2_l0002AoookJP00oooonfXNoookJPGo0000QOoonfX:o`0008oooo]Z003ooookJQkooo]Z
1Ol00027oookJP[o0000SOoonfX00?oooo]Z7_oonfX5o`0008Wooo]Z2_l0002;oookJP00oooonfXN
oookJPGo0000R_oonfX;o`0008Wooo]Z003ooookJQkooo]Z1Ol0002<oookJP_o0000QooonfX00?oo
oo]Z7_oonfX5o`0008kooo]Z2_l00026oookJP00oooonfXNoookJPGo0000T?oonfX:o`0008Cooo]Z
003ooookJQkooo]Z1Ol0002BoookJP[o0000P_oonfX00?oooo]Z7_oonfX5o`0009Cooo]Z2_l00020
oookJP00oooonfXNoookJPGo0000UOoonfX:o`0007oooo]Z003ooookJQkooo]Z1Ol0002GoookJPWo
0000O_oonfX00?oooo]Z7_oonfX5o`0009Wooo]Z2?l0001moookJP00oooonfXNoookJPGo0000Vooo
nfX8o`0007_ooo]Z003ooookJQkooo]Z1Ol0002LoookJPSo0000N_oonfX00?oooo]Z7_oonfX5o`00
09gooo]Z2?l0001ioookJP00oooonfXNoookJPGo0000W_oonfX9o`0007Oooo]Z003ooookJQkooo]Z
1Ol0002PoookJPSo0000M_oonfX00?oooo]Z7_oonfX5o`000:7ooo]Z2?l0001eoookJP00oooonfXN
oookJPGo0000X_oonfX8o`0007Cooo]Z003ooookJQkooo]Z1Ol0002ToookJPSo0000L_oonfX00?oo
oo]Z7_oonfX5o`000:Gooo]Z2?l0001aoookJP00oooonfXNoookJPGo0000Y_oonfX8o`00073ooo]Z
003ooookJQkooo]Z1Ol0002WoookJPWo0000K_oonfX00?oooo]Z7_oonfX5o`000:Wooo]Z2?l0001]
oookJP00oooonfXNoookJPGo0000Z_oonfX8o`0006cooo]Z003ooookJQkooo]Z1Ol0002[oookJPSo
0000JooonfX00?oooo]Z7_oonfX5o`000:gooo]Z2?l0001YoookJP00oooonfXNoookJPGo0000[_oo
nfX8o`0006Sooo]Z003ooookJQkooo]Z1Ol0002_oookJPSo0000IooonfX00?oooo]Z7_oonfX5o`00
0;3ooo]Z2?l0001VoookJP00oooonfXNoookJPGo0000/_oonfX7o`0006Gooo]Z003ooookJQkooo]Z
1Ol0002coookJPOo0000I?oonfX00?oooo]Z7_oonfX5o`000;Cooo]Z1ol0001SoookJP00oooonfXN
oookJPGo0000]OoonfX7o`0006;ooo]Z003ooookJQkooo]Z1Ol0002foookJPOo0000HOoonfX00?oo
oo]Z7_oonfX5o`000;Oooo]Z1ol0001PoookJP00oooonfXNoookJPGo0000^?oonfX8o`0005kooo]Z
003ooookJQkooo]Z1Ol0002ioookJPSo0000GOoonfX00?oooo]Z7_oonfX5o`000;[ooo]Z2?l0001L
oookJP00oooonfXNoookJPGo0000^ooonfX8o`0005_ooo]Z003ooookJQkooo]Z1Ol0002moookJPOo
0000F_oonfX00?oooo]Z7_oonfX5o`000;kooo]Z1ol0001IoookJP00oooonfXNoookJPGo0000_ooo
nfX7o`0005Sooo]Z003ooookJQkooo]Z1Ol00030oookJPOo0000EooonfX00?oooo]Z7_oonfX5o`00
0<7ooo]Z1ol0001FoookJP00oooonfXNoookJPGo0000`_oonfX7o`0005Gooo]Z003ooookJQkooo]Z
1Ol00033oookJPOo0000E?oonfX00?oooo]Z7_oonfX5o`000<Cooo]Z1ol0001CoookJP00oooonfXN
oookJPGo0000aOoonfX6o`0005?ooo]Z003ooookJQkooo]Z1Ol00036oookJPKo0000D_oonfX00?oo
oo]Z7_oonfX5o`000<Oooo]Z1_l0001AoookJP00oooonfXNoookJPGo0000aooonfX7o`00053ooo]Z
003ooookJQkooo]Z1Ol00038oookJPOo0000CooonfX00?oooo]Z7_oonfX5o`000<Wooo]Z1_l0001?
oookJP00oooonfXNoookJPGo0000b_oonfX6o`0004kooo]Z003ooookJPGo001o1?oonfX3o`00O`?o
oo]Z1Ol007l:oookJPGo0000booonfX6o`0004gooo]Z003noookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007l9oookJPGo0000booonfX7o`0004cooo]Z003noookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000<co
oo]Z1ol0001;oookJP00oOoonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z
1Ol0003=oookJPKo0000BooonfX00?gooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1ol0
003<oookJPKo0000B_oonfX00?gooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0003?
oookJPKo0000BOoonfX00?gooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oook
JPGo0000cooonfX7o`0004Sooo]Z003moookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo
0000d?oonfX7o`0004Oooo]Z003moookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000
dOoonfX7o`0004Kooo]Z003moookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000d_oo
nfX6o`0004Kooo]Z003noookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0
003CoookJPKo0000AOoonfX00?kooo]Z1ol007l9oookJPOo001o2?oonfX5o`000=Cooo]Z1_l00014
oookJP00oooonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000e?oonfX7o`0004?ooo]Z003ooookJQko
oo]Z1Ol0003EoookJPOo0000@_oonfX00?oooo]Z7_oonfX5o`000=Kooo]Z1_l00012oookJP00oooo
nfXNoookJPGo0000eooonfX6o`00047ooo]Z003ooookJQkooo]Z1Ol0003HoookJPKo0000@?oonfX0
0?oooo]Z7_oonfX5o`000=Sooo]Z1ol0000ooookJP00oooonfXNoookJPGo0000fOoonfX7o`0003ko
oo]Z003ooookJQkooo]Z1Ol0003JoookJPKo0000?_oonfX00?oooo]Z7_oonfX5o`000=_ooo]Z1_l0
000moookJP00oooonfXNoookJPGo0000g?oonfX6o`0003cooo]Z003ooookJQkooo]Z1Ol0003Loook
JPOo0000>ooonfX00?oooo]Z7_oonfX5o`000=gooo]Z1_l0000koookJP00oooonfXNoookJPGo0000
g_oonfX6o`0003[ooo]Z003ooookJQkooo]Z1Ol0003OoookJPKo0000>OoonfX00?oooo]Z7_oonfX5
o`000=oooo]Z1_l0000ioookJP00oooonfXNoookJPGo0000h?oonfX6o`0003Sooo]Z003ooookJQko
oo]Z1Ol0003QoookJPKo0000=ooonfX00?oooo]Z7_oonfX5o`000>7ooo]Z1ol0000foookJP00oooo
nfXNoookJPGo0000h_oonfX6o`0003Kooo]Z003ooookJQkooo]Z1Ol0003SoookJPKo0000=OoonfX0
0?oooo]Z7_oonfX5o`000>Cooo]Z1_l0000doookJP00oooonfXNoookJPGo0000i?oonfX7o`0003?o
oo]Z003ooookJQkooo]Z1Ol0003UoookJPKo0000<ooonfX00?oooo]Z7_oonfX5o`000>Kooo]Z1_l0
000boookJP00oooonfXNoookJPGo0000iooonfX6o`00037ooo]Z003ooookJQkooo]Z1Ol0003Woook
JPKo0000<OoonfX00?oooo]Z7_oonfX5o`000>Sooo]Z1_l0000`oookJP00oooonfXNoookJPGo0000
jOoonfX6o`0002oooo]Z003ooookJQkooo]Z1Ol0003YoookJPOo0000;_oonfX00?oooo]Z7_oonfX5
o`000>[ooo]Z1_l0000^oookJP00oooonfXNoookJPGo0000jooonfX6o`0002gooo]Z003ooookJQko
oo]Z1Ol0003/oookJPKo0000;?oonfX00?oooo]Z7_oonfX5o`000>cooo]Z1ol0000[oookJP00oooo
nfXNoookJPGo0000kOoonfX6o`0002_ooo]Z003ooookJQkooo]Z1Ol0003^oookJPKo0000:_oonfX0
0?oooo]Z7_oonfX5o`000>oooo]Z1_l0000YoookJP00oooonfXNoookJPGo0000kooonfX6o`0002Wo
oo]Z003ooookJQkooo]Z1Ol0003`oookJPKo0000:?oonfX00?oooo]Z7_oonfX5o`000?7ooo]Z1_l0
000WoookJP00oooonfXNoookJPGo0000lOoonfX7o`0002Kooo]Z003ooookJQkooo]Z1Ol0003boook
JPKo00009_oonfX00?oooo]Z7_oonfX5o`000??ooo]Z1_l0000UoookJP00oooonfXNoookJPGo0000
m?oonfX5o`0002Gooo]Z003ooookJQkooo]Z1Ol0003doookJPKo00009?oonfX00?oooo]Z7_oonfX5
o`000?Gooo]Z1_l0000SoookJP00oooonfXNoookJPGo0000mOoonfX6o`0002?ooo]Z003ooookJQko
oo]Z1Ol0003foookJPKo00008_oonfX00?oooo]Z7_oonfX5o`000?Oooo]Z1Ol0000RoookJP00oooo
nfXNoookJPGo0000mooonfX6o`00027ooo]Z003ooookJQkooo]Z1Ol0003hoookJPGo00008OoonfX0
0?oooo]Z7_oonfX5o`000?Sooo]Z1_l0000PoookJP00oooonfXNoookJPGo0000nOoonfX6o`0001oo
oo]Z003ooookJQkooo]Z1Ol0003ioookJPKo00007ooonfX00?oooo]Z7_oonfX5o`000?[ooo]Z1_l0
000NoookJP00oooonfXNoookJPGo0000nooonfX5o`0001kooo]Z003ooookJQkooo]Z1Ol0003koook
JPKo00007OoonfX00?oooo]Z7_oonfX5o`000?cooo]Z1Ol0000MoookJP00oooonfXNoookJPGo0000
o?oonfX6o`0001cooo]Z003ooookJQkooo]Z1Ol0003moookJPKo00006ooonfX00?oooo]Z7_oonfX5
o`000?gooo]Z1_l0000KoookJP00oooonfXNoookJPGo0000o_oonfX6o`0001[ooo]Z003ooookJQko
oo]Z1Ol0003ooookJPGo00006_oonfX00?oooo]Z7_oonfX5o`000?oooo]Z1_l0000IoookJP00oooo
nfXNoookJPGo0000oooonfX1oookJPGo00006OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z0OoonfX6
o`0001Sooo]Z003ooookJQkooo]Z1Ol0003ooookJP;ooo]Z1_l0000GoookJP00oooonfXNoookJPGo
0000oooonfX2oookJPKo00005ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z0ooonfX6o`0001Kooo]Z
003ooookJQkooo]Z1Ol0003ooookJPCooo]Z1Ol0000FoookJP00oooonfXNoookJPGo0000oooonfX4
oookJPKo00005OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z1OoonfX5o`0001Gooo]Z003ooookJQ7o
oo]Z0ol007l:oookJPGo0000oooonfX5oookJPKo00005?oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJPKooo]Z1_l0000CoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z1_oo
nfX6o`0001?ooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfX7oookJPKo00004_oonfX0
0?oooo]Z4OoonfX3o`00O`[ooo]Z1ol0003ooookJPKooo]Z1Ol0000BoookJP00oooonfXAoookJP?o
001o2_oonfX5o`000?oooo]Z2?oonfX5o`0001;ooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000
oooonfX9oookJPCo00004_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o2_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ3ooo]Z
1?l007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.534146, -1.067, \
0.0018579, 0.00601229}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FourierCosCoefficient[ReducedFunction, x, n]\)], "Input",
  CellTags->"mmtag:17:FourierCosCoefficient[]"],

Cell[BoxData[
    \(0\)], "Output",
  CellTags->"mmtag:17:FourierCosCoefficient[]"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FourierSinCoefficient[ReducedFunction, x, n]\)], "Input",
  CellTags->"mmtag:17:FourierSinCoefficient[]"],

Cell[BoxData[
    \(\(2\ \((\(-1\))\)\^n\ \((6 - n\^2\ \[Pi]\^2)\)\)\/\(n\^3\ \
\[Pi]\^3\)\)], "Output",
  CellTags->"mmtag:17:FourierSinCoefficient[]"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FourierTrigSeries[ReducedFunction, x, 5]\)], "Input",
  CellTags->"mmtag:17:FourierTrigSeries[]"],

Cell[BoxData[
    \(\(2\ \((\(-6\) + \[Pi]\^2)\)\ Sin[2\ \[Pi]\ x]\)\/\[Pi]\^3 + \(\((3 - 2\
\ \[Pi]\^2)\)\ Sin[4\ \[Pi]\ x]\)\/\(2\ \[Pi]\^3\) + \(2\ \((\(-2\) + 3\ \
\[Pi]\^2)\)\ Sin[6\ \[Pi]\ x]\)\/\(9\ \[Pi]\^3\) + \(\((3 - 8\ \[Pi]\^2)\)\ \
Sin[8\ \[Pi]\ x]\)\/\(16\ \[Pi]\^3\) + \(2\ \((\(-6\) + 25\ \[Pi]\^2)\)\ \
Sin[10\ \[Pi]\ x]\)\/\(125\ \[Pi]\^3\)\)], "Output",
  CellTags->"mmtag:17:FourierTrigSeries[]"]
}, Open  ]],

Cell[BoxData[
    \(\(AnimateTruncatedFourierSeriesVersionOne[
          function_, \ {truncationstart_, \ truncationend_, \ 
            truncjump_}]\  := \ 
        Table[Plot[
            Evaluate[FourierTrigSeries[function, x, itrunc]], {x, \(-1\), 1}, 
            PlotRange \[Rule] \ {\(-2\), 2}], {itrunc, truncationstart, 
            truncationend, \ truncjump}];\)\)], "Input"],

Cell["\<\
The function above will work, but it is horribly inefficient!  \
Because it asks FourierTrigSeries to calculate one more term each time, it is \
doing some redundant work.  We can fix this up by having
 it calculate one new term and adding to the sum calculated previously. Here \
it is:\
\>", "Text",
  CellTags->
  "mmtag:17:Fourier_series__example_function_for_calculating_and_efficiency"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AnimateTruncatedFourierSeriesVersionTwo[
        function_, \ {truncationstart_, \ truncationend_}]\  := \ 
      Module[{coscof, sincof, \ currentappx\ , n, \ 
          TwoPi = \ 2\ \[Pi]}, \ \[IndentingNewLine]currentappx\  = \ 
          FourierCosCoefficient[function, x, 0]; \[IndentingNewLine]coscof[
            n_]\  = \ 
          Simplify[
            FourierCosCoefficient[function, x, n]]; \[IndentingNewLine]sincof[
            n_]\  = \ 
          Simplify[
            FourierSinCoefficient[function, x, 
              n]]; \[IndentingNewLine]\[IndentingNewLine]Table[
          Plot[Evaluate[
              currentappx\  += \ 
                coscof[itrunc]*Cos[TwoPi\ itrunc\ x]\  + \ \ sincof[itrunc]*
                    Sin[TwoPi\ itrunc\ \ x]], {x, \(-1\), 1}, 
            PlotRange \[Rule] \ {\(-2\), 2}], {itrunc, truncationstart, 
            truncationend}];]\)], "Input",
  CellTags->{
  "mmtag:17:Module[]", "mmtag:17:Fourier_series__example_animation"}],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(coscof\\)\\\" is similar to existing symbol \
\\\"\\!\\(coscos\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message",
  CellTags->{
  "mmtag:17:Module[]", "mmtag:17:Fourier_series__example_animation"}]
}, Open  ]],

Cell["\<\
The following will demonstrate how convergence is difficult where \
the function changes rapidly---this is known as Gibbs' Phenomenon\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AnimateTruncatedFourierSeriesVersionTwo[
      ReducedFunction, {1, 60}]\)], "Input",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.06244 .32784 L
.08255 .33601 L
.0932 .3396 L
.10458 .34277 L
.11009 .34403 L
.11531 .34506 L
.12038 .3459 L
.12507 .34652 L
.12951 .34699 L
.13178 .34717 L
.13422 .34733 L
.13549 .3474 L
.13666 .34745 L
.13784 .3475 L
.13895 .34753 L
.14022 .34756 L
.1409 .34757 L
.14161 .34758 L
.1423 .34758 L
.14295 .34758 L
.14415 .34758 L
.14531 .34756 L
.14656 .34754 L
.14773 .3475 L
.14881 .34746 L
.15143 .34734 L
.15392 .34717 L
.15886 .34673 L
.16423 .34606 L
.17382 .34441 L
.1827 .34237 L
.20137 .33665 L
.22197 .32841 L
.26217 .30888 L
.30086 .29006 L
.32051 .28208 L
.3309 .27856 L
.342 .27543 L
.35275 .27309 L
.35784 .27223 L
.36253 .27159 L
.36724 .27108 L
.36972 .27087 L
.37235 .2707 L
.37463 .27059 L
.37573 .27054 L
.37677 .27051 L
.37799 .27048 L
.37911 .27046 L
Mistroke
.38031 .27045 L
.38162 .27045 L
.38227 .27046 L
.38296 .27046 L
.38419 .27049 L
.38551 .27052 L
.38695 .27057 L
.38955 .2707 L
.39197 .27086 L
.39649 .27126 L
.40134 .27184 L
.40698 .2727 L
.41232 .27371 L
.42232 .27606 L
.44227 .2824 L
.4607 .2899 L
.50002 .30903 L
.53782 .32748 L
.55884 .33604 L
.56803 .33917 L
.57808 .34208 L
.58722 .34423 L
.59696 .34596 L
.60236 .34665 L
.60726 .34712 L
.60962 .34728 L
.61086 .34736 L
.61218 .34742 L
.61333 .34747 L
.61459 .34752 L
.61574 .34755 L
.61682 .34757 L
.61808 .34758 L
.61871 .34758 L
.61941 .34758 L
.62065 .34757 L
.62181 .34756 L
.62248 .34754 L
.62318 .34753 L
.62443 .34749 L
.62578 .34743 L
.62725 .34736 L
.62973 .3472 L
.63238 .34699 L
.63715 .34649 L
.64214 .34581 L
.64686 .34501 L
.6557 .34316 L
.67568 .33731 L
.69413 .33016 L
Mistroke
.7335 .31135 L
.77136 .29263 L
.79241 .28368 L
.81166 .27719 L
.82118 .27471 L
.8262 .27362 L
.83155 .27263 L
.8367 .27185 L
.84136 .27128 L
.84361 .27106 L
.84604 .27086 L
.84835 .27071 L
.85045 .2706 L
.85159 .27055 L
.85283 .27051 L
.85414 .27048 L
.85538 .27046 L
.85653 .27045 L
.85776 .27045 L
.85881 .27046 L
.85997 .27048 L
.86063 .27049 L
.86132 .27051 L
.86256 .27055 L
.86535 .27068 L
.86777 .27083 L
.87041 .27104 L
.87569 .2716 L
.88133 .2724 L
.89148 .27434 L
.90173 .27694 L
.91284 .28041 L
.933 .28821 L
.97393 .30787 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`Wooo]Z1Ol0003ooookJQoooo]Z003noookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX0
0?7ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`00
0?oooo]Z7ooonfX00?7ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo
0000oooonfXNoookJP00oOoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`000?oooo]Z
7ooonfX00?gooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooo
nfXOoookJP00oOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX0
0?gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003moookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00o_oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00o_oonfX7o`00O`Wooo]Z
1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00e?oonfXDo`0003Gooo]Z1Ol0002eoookJQGo0000E?oonfX002;ooo]Z0ol007meoookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007lQoookJR7o0000;OoonfX5o`0007Cooo]Z1Ol007l4oookJP?o
001o0ooonfX5o`00ObKooo]Z8ol0000]oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJPOo001o
0ooonfX3o`00O`;ooo]Z1ol007lKoookJR[o0000:OoonfX5o`0007?ooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00Oaoooo]Z;Ol0000YoookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o5ooonfXbo`0002Gooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o7?oonfXco`0002Kooo]Z0ol007lM
oookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00Oa?ooo]Z5?l0000>oookJQKo00008_oonfX5o`0007;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lHoookJQKo00003ooonfXDo`0002?ooo]Z0ol007lMoook
JP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o3ooonfXCo`0001_ooo]Z4Ol0000OoookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o5?oonfXCo`0001gooo]Z4?l0000PoookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l;oookJQ;o00009?oonfX@o`0001cooo]Z1Ol0001boookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007lAoookJQ3o00009ooonfX>o`0001kooo]Z0ol007lMoookJP008_oo
nfX3o`00Og?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l9oookJQ3o0000;?oo
nfX>o`0001[ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3_oo
nfX@o`0002gooo]Z3_l0000KoookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l7oookJQ3o0000<_oonfX>o`0001Oooo]Z1Ol0001boookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l=oookJPoo0000<ooonfX>o`0001Sooo]Z0ol007lMoookJP008_oonfX3o`00
Og?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Kooo]Z3_l0000ioookJPgo00005OoonfX5o`00
07;ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`_ooo]Z3_l0000joookJPko00005OoonfX3o`00
Oagooo]Z000OoookJPKo001oLooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o2?oonfX<o`00043o
oo]Z3Ol0000BoookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3OoonfX=o`0003oo
oo]Z3_l0000@oookJPKo001o7OoonfX001oooo]Z1_l007mdoookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00O`Kooo]Z3?l00014oookJPgo00004?oonfX5o`0007?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o2ooonfX<o`0004Gooo]Z3Ol0000>oookJPKo001o7OoonfX0027o
oo]Z1?l007mdoookJPOo001o2OoonfX5o`00O`_o0000B_oonfX<o`0000kooo]Z1Ol0001coookJPOo
001o2OoonfX7o`00O`?ooo]Z3?l0001:oookJPgo00003OoonfX4o`00Oagooo]Z000RoookJP?o001o
MOoonfX5o`00O`[ooo]Z0ol007l;o`0004kooo]Z3?l0000<oookJPGo0000M?oonfX5o`00O`[ooo]Z
1ol007l00ooonf[o0000o`000009o`00053ooo]Z3?l0000<oookJP?o001o7OoonfX00:[ooo]Z2ol0
001CoookJP_o00002_oonfX5o`0008Wooo]Z2ol0001DoookJPco0000:_oonfX00:Sooo]Z2ol0001G
oookJP_o00002?oonfX5o`0008Oooo]Z2ol0001HoookJPco0000:?oonfX00:Gooo]Z3?l0001Koook
JPco00001OoonfX5o`0008Gooo]Z2ol0001MoookJP_o00009_oonfX00:?ooo]Z3?l0001OoookJPco
00000ooonfX5o`0008?ooo]Z2ol0001QoookJPco00008ooonfX00:7ooo]Z3?l0001SoookJPco0000
00?ooo]Zo`000?l000000ol00021oookJP_o0000IOoonfX<o`00027ooo]Z002OoookJPco0000Iooo
nfX@o`0007oooo]Z2ol0001YoookJPco00007ooonfX000kooo]Zool0003oo`0002Go00003ooonfX0
00kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Z
ool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX001gooo]Z2ol0001[
oookJPco0000O_oonfX=o`0006[ooo]Z3Ol00020oookJP03o`000?oonf[ooo]Z01cooo]Z000Ooook
JPco0000I_oonfX;o`00087ooo]Z3ol0001VoookJPco0000X_oonfX0027ooo]Z3?l0001RoookJP_o
0000PooonfX5o`000003oookJ_l0003o000000Wo0000H_oonfX<o`000:Cooo]Z000SoookJPco0000
G_oonfX;o`0008Gooo]Z1Ol00003oookJP_o0000G_oonfX;o`000:Oooo]Z000UoookJPco0000F_oo
nfX;o`0008Oooo]Z1Ol00005oookJP_o0000FOoonfX<o`000:Wooo]Z000XoookJP_o0000E_oonfX;
o`0008Wooo]Z1Ol00007oookJP_o0000EOoonfX<o`000:_ooo]Z000ZoookJP_o0000D_oonfX;o`00
08_ooo]Z1Ol00009oookJP_o0000DOoonfX<o`000:gooo]Z000/oookJP_o0000C_oonfX;o`0008go
oo]Z1Ol0000;oookJPco0000C?oonfX<o`000:oooo]Z000^oookJPco0000B?oonfX<o`0008oooo]Z
1Ol0000=oookJPco0000AooonfX<o`000;;ooo]Z000`oookJPco0000@ooonfX=o`00097ooo]Z1Ol0
000?oookJPco0000@ooonfX<o`000;Cooo]Z000boookJPco0000?_oonfX>o`0009?ooo]Z1Ol0000A
oookJPgo0000?OoonfX=o`000;Kooo]Z000doookJPgo0000>?oonfX?o`0009Gooo]Z1Ol0000Doook
JPko0000=ooonfX=o`000;Sooo]Z000goookJPgo0000<_oonfX?o`0009Sooo]Z1Ol0000FoookJPoo
0000<OoonfX=o`000;_ooo]Z000ioookJPoo0000:ooonfX?o`0009_ooo]Z1Ol0000HoookJQ3o0000
:ooonfX>o`000;gooo]Z000koookJQ;o00008_oonfX@o`0009kooo]Z1Ol0000KoookJQ7o00009?oo
nfX>o`000<3ooo]Z000noookJQ;o00006_oonfXBo`000:7ooo]Z1Ol0000OoookJQ;o00007?oonfX?
o`000<;ooo]Z0011oookJQKo00003?oonfXFo`000:Cooo]Z1Ol0000RoookJQKo00003?oonfXEo`00
0<Gooo]Z0015oookJS7o0000YooonfX5o`0002Gooo]Z<Ol00038oookJP00B_oonfXXo`000:_ooo]Z
1Ol0000YoookJR[o0000booonfX004gooo]Z8?l0002`oookJPGo0000;_oonfXRo`000<kooo]Z001D
oookJQ;o0000]ooonfX5o`0003Gooo]Z4_l0003GoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003noookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5
o`000?oooo]Z7ooonfX00?gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000oooonfXOoookJP00oOoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`000?oo
oo]Z7_oonfX00?gooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z
003moookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooo
nfX00?gooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003moook
JP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oOoonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1ol007l9oookJPOo001o
2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z1Ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:
oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPKo0000
oooonfXNoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3
o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoook
JP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX@
oookJPCo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z
0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0
003ooookJQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o
2OoonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooook
JP7ooo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[o
oo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`So
oo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00oooo
nfX>oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003o
oookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoookJP?o
001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3Ooo
nfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooo
oo]Z;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooonf[o
oookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.03279 .30379 L
.04262 .29863 L
.04758 .29644 L
.05288 .2945 L
.05546 .29374 L
.05789 .29313 L
.06024 .29265 L
.06244 .29231 L
.06361 .29217 L
.06487 .29205 L
.06559 .292 L
.06627 .29196 L
.06754 .29192 L
.06819 .29191 L
.06888 .29191 L
.07013 .29195 L
.07089 .29198 L
.07161 .29203 L
.07295 .29216 L
.07413 .2923 L
.07538 .29249 L
.07761 .29292 L
.08001 .29352 L
.08265 .29434 L
.08812 .29658 L
.09399 .29977 L
.10458 .30745 L
.12582 .32849 L
.14594 .35094 L
.15559 .3608 L
.16585 .3696 L
.17461 .37524 L
.177 .37643 L
.17959 .37753 L
.18204 .37838 L
.18427 .379 L
.18667 .37949 L
.18798 .37968 L
.18923 .37981 L
.19038 .37988 L
.19144 .37991 L
.19261 .37989 L
.19384 .37983 L
.19508 .37972 L
.19578 .37963 L
.19642 .37954 L
.19883 .37906 L
.20017 .37871 L
.20164 .37825 L
Mistroke
.20431 .37724 L
.20961 .37451 L
.21526 .3706 L
.22541 .36112 L
.24686 .33275 L
.26704 .30076 L
.28546 .27293 L
.29591 .25969 L
.30565 .24983 L
.31061 .24589 L
.3153 .24288 L
.31789 .24153 L
.3207 .24031 L
.32326 .23944 L
.32563 .23883 L
.32683 .23859 L
.32814 .23839 L
.32936 .23825 L
.33049 .23817 L
.33174 .23813 L
.33245 .23813 L
.3331 .23814 L
.3338 .23817 L
.33443 .23822 L
.33516 .23828 L
.33585 .23836 L
.33717 .23855 L
.33856 .23881 L
.34106 .23944 L
.34375 .24033 L
.3467 .24155 L
.35193 .24434 L
.35689 .24764 L
.36619 .25534 L
.3871 .27731 L
.40529 .29741 L
.41565 .3075 L
.42539 .31534 L
.43489 .32107 L
.44024 .32337 L
.44278 .32422 L
.44514 .32487 L
.4475 .32538 L
.44871 .32559 L
.45002 .32578 L
.45077 .32587 L
.45146 .32594 L
.45211 .32599 L
.45282 .32604 L
.45406 .3261 L
Mistroke
.45537 .32612 L
.45609 .32612 L
.45677 .3261 L
.45805 .32605 L
.45876 .326 L
.45943 .32594 L
.46093 .32578 L
.46345 .3254 L
.46614 .32486 L
.47151 .32334 L
.47644 .32151 L
.48757 .31616 L
.50774 .30449 L
.51684 .29959 L
.52658 .29535 L
.52946 .29438 L
.53218 .29359 L
.53483 .29296 L
.53728 .29251 L
.53959 .29219 L
.54076 .29207 L
.54206 .29198 L
.54335 .29193 L
.54407 .29191 L
.54474 .29191 L
.54596 .29193 L
.54725 .29199 L
.54849 .29209 L
.54983 .29224 L
.55226 .29261 L
.55463 .29311 L
.55681 .29369 L
.56176 .29545 L
.56701 .29795 L
.57576 .30352 L
.58538 .31147 L
.60647 .33347 L
.62574 .35476 L
.63528 .36402 L
.64031 .36827 L
.64567 .37218 L
.65082 .37526 L
.65549 .37741 L
.65774 .37823 L
.66018 .37893 L
.66129 .37919 L
.66247 .37942 L
.66357 .3796 L
.66458 .37973 L
.66581 .37984 L
Mistroke
.66646 .37987 L
.66714 .3799 L
.6683 .37991 L
.66956 .37986 L
.67069 .37978 L
.6719 .37964 L
.67305 .37946 L
.6741 .37926 L
.67659 .37864 L
.67931 .37772 L
.68428 .37539 L
.68888 .37251 L
.69379 .36869 L
.70263 .35999 L
.72403 .33126 L
.7442 .29923 L
.76257 .27168 L
.773 .25867 L
.77809 .25331 L
.78274 .24906 L
.78734 .2455 L
.79235 .2424 L
.7951 .24105 L
.79765 .24003 L
.80008 .23926 L
.80143 .23891 L
.80267 .23866 L
.80388 .23845 L
.80515 .23829 L
.80643 .23818 L
.80715 .23815 L
.80783 .23813 L
.80906 .23814 L
.81017 .23818 L
.81146 .23829 L
.81268 .23844 L
.81401 .23867 L
.81543 .23896 L
.81798 .23966 L
.82071 .24062 L
.82373 .24195 L
.83388 .24823 L
.84317 .25607 L
.86405 .27818 L
.88468 .30068 L
.89471 .30999 L
.9038 .31686 L
.90839 .31965 L
.91334 .32212 L
.91802 .32392 L
Mistroke
.92232 .3251 L
.92469 .32556 L
.92582 .32573 L
.92689 .32586 L
.92816 .32598 L
.92932 .32606 L
.93056 .32611 L
.93126 .32612 L
.93191 .32612 L
.93312 .3261 L
.93425 .32605 L
.93549 .32595 L
.93682 .32582 L
.93815 .32564 L
.93954 .32542 L
.94204 .32492 L
.94652 .32372 L
.9506 .32231 L
.95974 .31826 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`Wooo]Z1Ol0003ooookJQoooo]Z003noookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX0
0?7ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`00
0?oooo]Z7ooonfX00?7ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo
0000oooonfXNoookJP00oOoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`000?oooo]Z
7ooonfX00?gooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooo
nfXOoookJP00_OoonfX>o`0003;ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0002M
oookJPoo0000L_oonfX00;[ooo]Z5Ol0000^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oook
JPGo0000V_oonfXCo`00077ooo]Z002hoookJQSo0000;OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o3_oonfX5o`0009Wooo]Z5_l0001_oookJP00]ooonfXJo`0002gooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001o3_oonfX5o`0009Sooo]Z6Ol0001]oookJP00]_oonfX:o`0000Sooo]Z
2_l0000/oookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0002FoookJP[o00002OoonfX:o`0006_ooo]Z
002eoookJPSo00003ooonfX8o`0002_ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0009Gooo]Z2?l0
000=oookJP_o0000JOoonfX00;?ooo]Z2?l0000BoookJPSo0000B?oonfX5o`0009Cooo]Z2?l0000@
oookJP[o0000J?oonfX00;;ooo]Z2?l0000DoookJPSo0000AooonfX5o`0009?ooo]Z2?l0000Coook
JPWo0000IooonfX00;7ooo]Z2?l0000FoookJPSo0000A_oonfX5o`0009;ooo]Z1ol0000GoookJPSo
0000I_oonfX00;3ooo]Z2?l0000IoookJPOo0000AOoonfX5o`00097ooo]Z1ol0000JoookJPOo0000
IOoonfX00:oooo]Z1ol0000LoookJPOo0000A?oonfX5o`00093ooo]Z1ol0000LoookJPKo0000IOoo
nfX00:kooo]Z1ol0000NoookJPOo0000@ooonfX5o`0008oooo]Z1ol0000NoookJPKo0000I?oonfX0
0:kooo]Z1_l0000PoookJPOo0000@_oonfX5o`0008oooo]Z1_l0000PoookJPKo0000HooonfX00:go
oo]Z1_l0000RoookJPOo0000@OoonfX5o`0008kooo]Z1_l0000QoookJPOo0000H_oonfX00:cooo]Z
1_l0000ToookJPOo0000@?oonfX5o`0008gooo]Z1_l0000SoookJPOo0000HOoonfX00:_ooo]Z1ol0
000UoookJPOo0000?ooonfX5o`0008cooo]Z1ol0000ToookJPOo0000H?oonfX00:_ooo]Z1_l0000W
oookJPOo0000?_oonfX5o`0008_ooo]Z1ol0000VoookJPOo0000GooonfX00:[ooo]Z1_l0000Yoook
JPOo0000?OoonfX5o`0008[ooo]Z1ol0000XoookJPOo0000G_oonfX002;ooo]Z0ol007meoookJPGo
001o1?oonfX3o`00O`?ooo]Z1_l0000[oookJPOo0000??oonfX5o`0007Cooo]Z1Ol007l4oookJP?o
001o0ooonfX5o`00O`03oookJ_l0003o000000Go0000:_oonfX7o`0003gooo]Z0ol007lMoookJP00
8_oonfX3o`00OgCooo]Z1ol007l3oookJP?o001o0_oonfX00ol007oo0000o`000004o`0002cooo]Z
1ol0000koookJPGo0000LooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1_l0000/oookJPOo0000
??oonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l00ooonf[o001oo`000005o`000003o`00Oooonf[ooo]Z02_ooo]Z1ol0000joookJPGo0000
LooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`03
oookJ_l007oo001o00Ko0000;_oonfX7o`0003_ooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z
0ol007mWoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPKo00000ol007l]oookJPOo0000
>OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z1_l0000`oookJPOo0000
>_oonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o0ooo
nfX3o`00O`Kooo]Z1_l00003o`00Obkooo]Z1_l0000ioookJPGo0000L_oonfX3o`00O`?ooo]Z0ol0
07l<oookJPKo0000<OoonfX6o`0003[ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l3
oookJP?o001o1OoonfX6o`000004oookJ_l007oo001oo`00Oboooo]Z1_l0000hoookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l;oookJPKo0000<ooonfX6o`0003Wooo]Z0ol007lMoookJP008_oonfX3
o`00Og?ooo]Z0ol007l3oookJP?o001o1OoonfX5o`000003oookJ_l007oo001o00;o001o<?oonfX6
o`0003Oooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l00ooonf[o0000o`000004
o`0003Gooo]Z1_l0000hoookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0ooonfX3o`00
O`Cooo]Z1_l00004o`00Oc7ooo]Z1ol0000foookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l7oook
JP?o001o1_l0000eoookJPOo0000=ooonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`?o
oo]Z0ol007l3oookJPKo00001?l007lcoookJPOo0000=OoonfX5o`0007;ooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`Ko0000=ooonfX7o`0003Kooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z
0ol007l3oookJP?o001o0ooonfX6o`0003Sooo]Z1ol0000doookJPGo0000L_oonfX3o`00O`?ooo]Z
0ol007l7oookJP03o`00Ool0003o000000Co0000>OoonfX7o`0003;ooo]Z1_l007lMoookJP007ooo
nfX6o`00OgCooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJPKo000000?o001ooookJ_oonfX0
=ooonfX7o`0003?ooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX00ol007oo
0000o`000004o`0003[ooo]Z1ol0000aoookJPKo001o7OoonfX0027ooo]Z1?l007l8oookJPoo0000
GOoonfX7o`00O`;ooo]Z1_l000000ooonf[o001oo`00O`05o`00OcCooo]Z1ol0000boookJPGo0000
3OoonfX@o`0005Kooo]Z1ol007l8oookJPKo00000_l007ljoookJPKo0000<ooonfX4o`00Oagooo]Z
000RoookJP?o001o1OoonfXGo`0005Wooo]Z1Ol007l3oookJPKo000000?ooo]Zo`00Ool007l01Ol0
07leoookJPOo0000<OoonfX5o`0000[ooo]Z5Ol0001EoookJPGo001o2?oonfX6o`0000?o001o>ooo
nfX6o`0003?ooo]Z0ol007lMoookJP009ooonfXLo`0005kooo]Z1_l0000ooookJPOo0000<?oonfX5
o`0000Sooo]Z6_l0001OoookJPKo0000?ooonfX6o`0005;ooo]Z000ToookJR3o0000GOoonfX5o`00
047ooo]Z1ol0000_oookJPGo00001OoonfXOo`0005cooo]Z1_l00010oookJPOo0000DOoonfX002;o
oo]Z3_l00009oookJPgo0000F_oonfX6o`0004;ooo]Z1ol0000^oookJPGo00000ooonfX=o`0000[o
oo]Z3?l0001IoookJPKo0000@_oonfX7o`00053ooo]Z000QoookJPco00004OoonfX9o`0005Sooo]Z
1_l00014oookJPOo0000;OoonfX5o`000003oookJ_l0003o000000[o00003ooonfX;o`0005Sooo]Z
1_l00013oookJPSo0000C_oonfX001oooo]Z2ol0000FoookJPWo0000E_oonfX6o`0004Gooo]Z1ol0
000/oookJQ3o00005?oonfX:o`0005Gooo]Z1_l00015oookJPSo0000COoonfX001gooo]Z2_l0000J
oookJPWo0000E?oonfX6o`0004Oooo]Z1ol0000[oookJPgo00006OoonfX9o`0005?ooo]Z1_l00017
oookJPSo0000C?oonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go
00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooo
nfX000kooo]Zool0003oo`0002Go00003ooonfX001gooo]Z00?o0000oookJ_oonfX0:?oonfX7o`00
04_ooo]Z1_l0001BoookJPWo00006_oonfX=o`0002Wooo]Z1ol00019oookJPKo0000D_oonfX9o`00
01_ooo]Z2ol0000NoookJP00BOoonfX7o`0004Wooo]Z1_l0001EoookJPSo00005ooonfX?o`0002[o
oo]Z1ol00018oookJPKo0000E?oonfX8o`0001Sooo]Z2_l0000QoookJP00B_oonfX7o`0004Sooo]Z
1_l0001FoookJPSo00005?oonfX;o`000003oookJ_l0003o000000?o0000:ooonfX7o`0004Kooo]Z
1_l0001GoookJPWo00004_oonfX;o`0002?ooo]Z001;oookJPOo0000A_oonfX6o`0005Wooo]Z2Ol0
000?oookJP_o00000ooonfX5o`0002cooo]Z1ol00015oookJPGo0000FOoonfX;o`0000gooo]Z3?l0
000ToookJP00C?oonfX7o`0004Gooo]Z1Ol0001KoookJP[o00002ooonfX;o`0000Gooo]Z1Ol0000]
oookJPOo0000@ooonfX6o`0005[ooo]Z3?l00009oookJPco00009_oonfX004gooo]Z1ol00013oook
JPKo0000G?oonfXMo`0000Oooo]Z1Ol0000^oookJPOo0000@OoonfX6o`0005cooo]Z7_l0000Xoook
JP00C_oonfX7o`00047ooo]Z1_l0001NoookJQ[o00002OoonfX5o`0002oooo]Z1ol00010oookJPKo
0000GooonfXHo`0002_ooo]Z001?oookJPOo0000@?oonfX6o`00067ooo]Z5Ol0000;oookJPGo0000
<?oonfX7o`0003kooo]Z1_l0001SoookJQ?o0000;OoonfX0053ooo]Z1_l0000ooookJPKo0000I?oo
nfXAo`0000gooo]Z1Ol0000aoookJPOo0000??oonfX6o`0006Kooo]Z3ol0000_oookJP00DOoonfX6
o`0003gooo]Z1_l00023oookJPGo0000<_oonfX7o`0003_ooo]Z1_l0002ToookJP00D_oonfX6o`00
03cooo]Z1_l00023oookJPGo0000<ooonfX6o`0003[ooo]Z1_l0002UoookJP00D_oonfX7o`0003[o
oo]Z1_l00024oookJPGo0000=?oonfX6o`0003Sooo]Z1_l0002VoookJP00DooonfX7o`0003Sooo]Z
1_l00025oookJPGo0000=OoonfX6o`0003Oooo]Z1_l0002VoookJP00E?oonfX7o`0003Kooo]Z1ol0
0025oookJPGo0000=OoonfX7o`0003Gooo]Z1_l0002WoookJP00EOoonfX7o`0003Cooo]Z1ol00026
oookJPGo0000=_oonfX7o`0003?ooo]Z1_l0002XoookJP00E_oonfX7o`0003?ooo]Z1_l00027oook
JPGo0000=ooonfX7o`0003;ooo]Z1_l0002XoookJP00EooonfX7o`00037ooo]Z1_l00028oookJPGo
0000>?oonfX6o`00037ooo]Z1_l0002YoookJP00F?oonfX7o`0002oooo]Z1_l00029oookJPGo0000
>OoonfX6o`0002oooo]Z1_l0002ZoookJP00FOoonfX7o`0002gooo]Z1ol00029oookJPGo0000>_oo
nfX6o`0002gooo]Z1ol0002ZoookJP00F_oonfX7o`0002_ooo]Z1ol0002:oookJPGo0000>_oonfX7
o`0002cooo]Z1_l0002[oookJP00FooonfX7o`0002[ooo]Z1_l0002;oookJPGo0000>ooonfX7o`00
02[ooo]Z1_l0002/oookJP00G?oonfX7o`0002Sooo]Z1_l0002<oookJPGo0000??oonfX7o`0002So
oo]Z1_l0002]oookJP00GOoonfX7o`0002Kooo]Z1_l0002=oookJPGo0000?OoonfX7o`0002Oooo]Z
1_l0002]oookJP00G_oonfX7o`0002Cooo]Z1ol0002=oookJPGo0000?_oonfX7o`0002Gooo]Z1_l0
002^oookJP00GooonfX8o`00027ooo]Z1ol0002>oookJPGo0000?ooonfX7o`0002;ooo]Z1ol0002_
oookJP00H?oonfX8o`0001oooo]Z1ol0002?oookJPGo0000@?oonfX7o`00023ooo]Z2?l0002_oook
JP00HOoonfX8o`0001gooo]Z1ol0002@oookJPGo0000@OoonfX8o`0001gooo]Z2?l0002`oookJP00
H_oonfX8o`0001_ooo]Z1ol0002AoookJPGo0000@_oonfX8o`0001_ooo]Z2?l0002aoookJP00I?oo
nfX7o`0001Wooo]Z1ol0002BoookJPGo0000@ooonfX9o`0001Oooo]Z2?l0002coookJP00IOoonfX8
o`0001Kooo]Z1ol0002CoookJPGo0000A?oonfX9o`0001Gooo]Z2?l0002doookJP00I_oonfX9o`00
01?ooo]Z1ol0002DoookJPGo0000A_oonfX9o`0001;ooo]Z2?l0002eoookJP00IooonfX9o`00017o
oo]Z1ol0002EoookJPGo0000AooonfX9o`00013ooo]Z2?l0002foookJP00J?oonfX9o`0000kooo]Z
2?l0002FoookJPGo0000BOoonfX9o`0000cooo]Z2?l0002hoookJP00J_oonfX:o`0000Sooo]Z2_l0
002GoookJPGo0000B_oonfX9o`0000Wooo]Z2Ol0002ioookJP00K?oonfXIo`0009Sooo]Z1Ol0001<
oookJQSo0000^_oonfX006gooo]Z5ol0001koookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oook
JPGo0000COoonfXFo`000;_ooo]Z001^oookJQCo0000O?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o2OoonfX5o`0004oooo]Z4_l0002moookJP00LOoonfX>o`0007oooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oook
JPGo0000D?oonfX?o`000;oooo]Z003moookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o2?oonfX5o`000?oooo]Z7ooonfX00?gooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z
1_l0003ooookJQkooo]Z003moookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000oooo
nfXOoookJP00oOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003o
oookJQoooo]Z003moookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000oooonfXOoook
JP00oOoonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?gooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noookJPOo001o2Ooo
nfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoook
JP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oo
nfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooook
JQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1_l0
07l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo
0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol0
07l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8
oookJPKo0000oooonfXNoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooook
JQoooo]Z003ooookJP;ooo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Wooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>
oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoook
JP00oooonfX1oookJPCo001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z
2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z3_oonfX4o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oook
JPKo0000oooonfXNoookJP00oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4_oonfX3o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003o
oookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00
Oooooo]Z;?oonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z
1ol007oooookJRgooo]Z003ooookJPoooo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.03279 .31442 L
.04262 .31935 L
.04758 .32114 L
.05035 .3219 L
.05167 .32219 L
.05288 .32242 L
.054 .32259 L
.05524 .32275 L
.05648 .32287 L
.0578 .32295 L
.05895 .32298 L
.0602 .32297 L
.06137 .32293 L
.06244 .32285 L
.06314 .32279 L
.0638 .32272 L
.06504 .32255 L
.0678 .32204 L
.07019 .32145 L
.07277 .32067 L
.08405 .31584 L
.09383 .31072 L
.09902 .30813 L
.10458 .30575 L
.10735 .30479 L
.10997 .30406 L
.11233 .30358 L
.11366 .30338 L
.11489 .30325 L
.11604 .30318 L
.11711 .30315 L
.11829 .30317 L
.11956 .30325 L
.12082 .30339 L
.12145 .30349 L
.12215 .30361 L
.12452 .30419 L
.12594 .30465 L
.12728 .30516 L
.12979 .30634 L
.13543 .31001 L
.1403 .31433 L
.14558 .32016 L
.16507 .34951 L
.1754 .36713 L
.1865 .38424 L
.19196 .39104 L
.19465 .39386 L
.19714 .39612 L
Mistroke
.19958 .39796 L
.20179 .39931 L
.20424 .40042 L
.20559 .40085 L
.20686 .40114 L
.20797 .40129 L
.20918 .40136 L
.21045 .40131 L
.21163 .40116 L
.21274 .40092 L
.21375 .40062 L
.21491 .40018 L
.21601 .39966 L
.21848 .39816 L
.22075 .39636 L
.2259 .39083 L
.23055 .38415 L
.23556 .37529 L
.24461 .35546 L
.26522 .29968 L
.27475 .27376 L
.28491 .24955 L
.29075 .23811 L
.29606 .22967 L
.29862 .22632 L
.30139 .22324 L
.30399 .22088 L
.30642 .21915 L
.30872 .21793 L
.31002 .21743 L
.3112 .21708 L
.31249 .21682 L
.31322 .21673 L
.3139 .21669 L
.31514 .21669 L
.31646 .21682 L
.31771 .21706 L
.31841 .21724 L
.31906 .21744 L
.3215 .21846 L
.32421 .22006 L
.32707 .22226 L
.33177 .2269 L
.33615 .23225 L
.34609 .24708 L
.3648 .27862 L
.37466 .29332 L
.3851 .30523 L
.39038 .30949 L
.39338 .31135 L
Mistroke
.39619 .31273 L
.39877 .31369 L
.40112 .31431 L
.40242 .31456 L
.40311 .31466 L
.40384 .31474 L
.40455 .31481 L
.40518 .31485 L
.40643 .31489 L
.40769 .31486 L
.40832 .31483 L
.40902 .31478 L
.41026 .31464 L
.41141 .31447 L
.41401 .31393 L
.4168 .31314 L
.42191 .3112 L
.42657 .30904 L
.43662 .30381 L
.44212 .30103 L
.44728 .29875 L
.45167 .29716 L
.45392 .2965 L
.45639 .29591 L
.45894 .29546 L
.46034 .29528 L
.46163 .29516 L
.46285 .29509 L
.46395 .29506 L
.46523 .29506 L
.46644 .29511 L
.46758 .29519 L
.46865 .29529 L
.46983 .29544 L
.47109 .29565 L
.47366 .29619 L
.47601 .29683 L
.48054 .29842 L
.48484 .30033 L
.50479 .31195 L
.51441 .31733 L
.51968 .3197 L
.52227 .32066 L
.52465 .3214 L
.52686 .32197 L
.52929 .32245 L
.53055 .32264 L
.53173 .32278 L
.53298 .32289 L
.53367 .32293 L
Mistroke
.53431 .32296 L
.53543 .32298 L
.53646 .32297 L
.5376 .32292 L
.5388 .32284 L
.53984 .32274 L
.54082 .32261 L
.54305 .32224 L
.54562 .32166 L
.54801 .32098 L
.55342 .319 L
.56329 .31428 L
.57218 .30961 L
.57686 .30737 L
.58181 .30537 L
.58443 .30452 L
.58582 .30415 L
.58731 .3038 L
.58868 .30355 L
.58993 .30337 L
.59118 .30324 L
.59237 .30317 L
.59357 .30315 L
.59485 .30319 L
.59593 .30327 L
.59714 .30341 L
.59842 .30363 L
.59981 .30394 L
.60232 .30472 L
.60458 .30565 L
.60705 .30692 L
.61203 .31033 L
.61664 .31448 L
.62093 .31915 L
.64137 .34971 L
.65996 .38036 L
.6648 .38703 L
.66994 .39296 L
.67432 .39691 L
.67681 .39863 L
.67914 .39988 L
.68042 .40041 L
.6811 .40065 L
.68182 .40086 L
.68252 .40103 L
.68315 .40115 L
.68437 .40131 L
.68556 .40136 L
.68684 .40129 L
.68805 .40112 L
Mistroke
.68916 .40086 L
.69045 .40044 L
.69166 .39993 L
.6944 .39835 L
.69707 .39625 L
.69993 .3934 L
.70523 .3865 L
.71012 .37834 L
.7212 .35448 L
.74133 .29991 L
.7511 .27335 L
.76161 .24846 L
.76645 .23899 L
.77154 .23068 L
.77589 .22505 L
.78064 .22052 L
.78319 .2188 L
.78445 .21815 L
.7856 .21765 L
.78666 .21729 L
.78777 .21699 L
.78888 .21679 L
.79011 .21669 L
.79143 .21669 L
.79263 .21681 L
.7933 .21693 L
.79402 .21708 L
.79534 .21747 L
.79657 .21794 L
.79787 .21855 L
.80022 .21994 L
.80468 .22353 L
.80887 .22794 L
.81843 .24097 L
.83687 .27181 L
.84733 .28839 L
.85243 .2954 L
.85707 .30094 L
.86171 .30561 L
.86674 .3096 L
.8695 .31131 L
.87205 .31259 L
.87449 .31353 L
.87584 .31395 L
.87708 .31426 L
.87836 .31451 L
.87957 .31469 L
.88086 .31482 L
.88159 .31486 L
.88226 .31488 L
Mistroke
.88349 .31488 L
.88461 .31482 L
.8859 .31471 L
.88711 .31455 L
.88846 .31431 L
.88988 .31401 L
.89242 .31331 L
.89817 .31118 L
.90837 .30615 L
.91803 .30117 L
.92224 .29926 L
.92671 .29754 L
.92904 .2968 L
.93161 .29612 L
.93395 .29565 L
.93614 .29532 L
.93727 .2952 L
.93851 .29511 L
.9398 .29506 L
.941 .29506 L
.94213 .29508 L
.94315 .29514 L
.94433 .29524 L
.94545 .29536 L
.94795 .29577 L
.95026 .29629 L
.95547 .29793 L
.96027 .29997 L
.96554 .30267 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00]_oonfX9o`0005kooo]Z1Ol0002FoookJPWo0000OooonfX0
0;Cooo]Z3Ol0001LoookJPGo0000U?oonfX=o`0007gooo]Z002coookJPoo0000FooonfX5o`0009?o
oo]Z3ol0001loookJP00/_oonfXAo`0005[ooo]Z1Ol0002CoookJQ3o0000NooonfX00;7ooo]Z2?l0
0003oookJPSo0000FOoonfX5o`0009;ooo]Z2?l00002oookJPSo0000N_oonfX00;3ooo]Z1ol00007
oookJPOo0000>_oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`00097ooo]Z1_l00007
oookJPOo0000NOoonfX00:oooo]Z1ol00009oookJPOo0000>?oonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o2OoonfX5o`00093ooo]Z1ol00008oookJPOo0000N?oonfX00:kooo]Z1ol0000;oookJPOo
0000=ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0002?oookJPOo00002_oonfX6o`0007Sooo]Z002^oook
JPKo00003OoonfX7o`0002Wooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o2?oonfX5o`0008kooo]Z1ol0000<oookJPKo0000MooonfX00:gooo]Z1_l0000?oookJPKo
0000:OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0002=oookJPKo
00003_oonfX6o`0007Kooo]Z002]oookJPGo00004OoonfX6o`0003Cooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Sooo]Z1Ol0002=oookJPKo00003ooonfX7o`0007Gooo]Z002]oookJPGo00004_oo
nfX6o`0003?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000S?oo
nfX6o`00017ooo]Z1ol0001doookJP00[?oonfX5o`0001?ooo]Z1ol0000boookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l9oookJPGo0000RooonfX7o`0001;ooo]Z1ol0001coookJP00[?oonfX5o`00
01Cooo]Z1_l0000boookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000RooonfX6o`00
01Cooo]Z1ol0001boookJP00ZooonfX6o`0001Gooo]Z1_l0000aoookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l>oookJPGo0000R_oonfX6o`0001Kooo]Z1_l0001boookJP00Z_oonfX6o`0001Oooo]Z
1_l0000aoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0002:oookJPGo
00006?oonfX6o`00077ooo]Z002ZoookJPKo00005ooonfX7o`00033ooo]Z1ol007l9oookJPOo001o
2?oonfX5o`0008[ooo]Z1Ol0000IoookJPGo0000LOoonfX00:Wooo]Z1_l0000IoookJPKo0000<Ooo
nfX5o`00O`[ooo]Z1ol007l8oookJPGo0000ROoonfX5o`0001[ooo]Z1_l0001`oookJP00Z?oonfX6
o`0001_ooo]Z1_l0001>oookJPGo0000ROoonfX5o`0001_ooo]Z1_l0001_oookJP00Z?oonfX6o`00
01cooo]Z1Ol0001>oookJPGo0000R?oonfX6o`0001_ooo]Z1_l0001_oookJP00YooonfX6o`0001go
oo]Z1_l0001=oookJPGo0000R?oonfX5o`0001gooo]Z1_l0001^oookJP00YooonfX5o`0001oooo]Z
1_l0001<oookJPGo0000QooonfX6o`0001kooo]Z1Ol0001^oookJP00YooonfX5o`0001oooo]Z1_l0
001<oookJPGo0000QooonfX5o`0001oooo]Z1_l0001]oookJP00Y_oonfX5o`00027ooo]Z1_l0001;
oookJPGo0000QooonfX5o`00023ooo]Z1_l0001/oookJP00Y_oonfX5o`0002;ooo]Z1Ol0001;oook
JPGo0000Q_oonfX5o`00027ooo]Z1_l0001/oookJP00YOoonfX6o`0002;ooo]Z1_l0001:oookJPGo
0000Q_oonfX5o`0002;ooo]Z1_l0001[oookJP00YOoonfX5o`0002Cooo]Z1Ol0001:oookJPGo0000
QOoonfX6o`0002?ooo]Z1Ol0001[oookJP00YOoonfX5o`0002Cooo]Z1_l00019oookJPGo0000QOoo
nfX5o`0002Cooo]Z1_l0001ZoookJP00Y?oonfX5o`0002Kooo]Z1Ol00019oookJPGo0000Q?oonfX6
o`0002Gooo]Z1_l0001YoookJP00Y?oonfX5o`0002Kooo]Z1_l00018oookJPGo0000Q?oonfX5o`00
02Kooo]Z1_l0001YoookJP008_oonfX3o`00OgGooo]Z1Ol007l4oookJP03o`00Ool0003o000000?o
00001Ol007lRoookJPKo0000AooonfX5o`0007Cooo]Z1Ol007l4oookJP?o001o0ooonfX00ol007oo
0000o`000003o`0002Oooo]Z1_l00018oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJPOo001o
0ooonfX5o`0000Oo001o8OoonfX6o`0004Oooo]Z1Ol0001coookJPOo001o0ooonfX3o`00O`;ooo]Z
00?o001oo`000?l000000ol000000ol007oooo]ZoookJP0VoookJPGo0000B?oonfX3o`00Oagooo]Z
000RoookJP?o001oM?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1Ol00003o`00O`04oook
J_l007oo001oo`00Ob;ooo]Z1_l00016oookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`05o`000003o`00Oooonf[ooo]Z02Kooo]Z1_l00017oook
JP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o00?ooo]Zo`000?l000001?l00002o`00O`?ooo]Z0ol007lRoookJPGo0000A_oonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o1_oonfX00ol007oo0000o`000004o`0000;o001o:?oonfX5o`0004Oo
oo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`?ooo]Z
0ol007l00ooonf[o0000o`000003o`0000Kooo]Z0ol007lRoookJPKo0000AOoonfX5o`0007;ooo]Z
0ol007l3oookJP?o001o1ooonfX5o`0000?o001o:?oonfX6o`0004Kooo]Z0ol007lMoookJP008_oo
nfX3o`00Og?ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000ol00006oookJP?o001o8ooo
nfX5o`0004Gooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00003o`00ObWooo]Z1_l0
0015oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0ooonfX3o`00O`Go00000_oonfX2
o`00O`;ooo]Z1?l007lSoookJPKo0000A?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o1_oonfX5
o`0000Co001o:OoonfX6o`0004Gooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l3oook
JP?o001o1Ol00002oookJPOo001o9OoonfX6o`0004?ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00
O`Kooo]Z1Ol00003o`00Ob_ooo]Z1_l00014oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o
001o0ooonfX3o`00O`Go00000_oonfX6o`00ObKooo]Z1_l00013oookJPGo0000L_oonfX3o`00O`?o
oo]Z0ol007l6oookJPGo00000_l007l]oookJPGo0000A?oonfX3o`00Oagooo]Z000OoookJPKo001o
LooonfX3o`00O`?ooo]Z0_l007l5o`0000?ooo]Z0_l007l[oookJPKo0000@_oonfX5o`0007;ooo]Z
0ol007l3oookJP?o001o1OoonfX5o`00033ooo]Z1_l00010oookJPKo001o7OoonfX001oooo]Z1_l0
07mdoookJP?o001o00Cooo]Zo`00Ool007oo001o1Ol00003oookJP;o001o;?oonfX5o`0004;ooo]Z
1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o1_oonfX5o`00037ooo]Z1Ol00010oookJPKo
001o7OoonfX0027ooo]Z1?l007mdoookJPOo001o1Ol00004oookJPOo001o9_oonfX6o`00047ooo]Z
1Ol0001coookJPOo001o1_oonfX5o`0000Go001o;?oonfX6o`00047ooo]Z1?l007lMoookJP008_oo
nfX3o`00OgGooo]Z1Ol007l5o`0000Gooo]Z1ol007lWoookJPKo0000;?oonfX6o`0000kooo]Z1Ol0
001doookJPGo001o1_oonfX5o`0000Ko001o;OoonfX6o`0002cooo]Z1_l0000?oookJP?o001o7Ooo
nfX009oooo]Z1Ol0000coookJPOo00009_oonfXAo`0000Sooo]Z1Ol0001ooookJPGo0000<ooonfX7
o`0002Gooo]Z4_l0000YoookJP00WooonfX5o`0003Cooo]Z1ol0000QoookJQSo00001OoonfX5o`00
07oooo]Z1Ol0000doookJPOo00008_oonfXFo`0002Oooo]Z002NoookJPGo0000=_oonfX7o`0001oo
oo]Z6ol00003oookJPGo0000O_oonfX5o`0003Kooo]Z1ol0000OoookJQ[o00009OoonfX009kooo]Z
1Ol0000goookJPOo00007?oonfXNo`0000;ooo]Z1Ol0001noookJPGo0000=ooonfX7o`0001cooo]Z
7Ol0000ToookJP00BOoonfX=o`0004Oooo]Z1_l0000hoookJPOo00006?oonfX=o`0000_ooo]Z4?l0
000ZoookJP_o0000B?oonfX6o`0003Sooo]Z1ol0000HoookJPco00003?oonfX:o`0002;ooo]Z0016
oookJQ7o0000A_oonfX5o`0003[ooo]Z2?l0000DoookJP_o00004_oonfX=o`0002Kooo]Z4_l00015
oookJPGo0000>_oonfX8o`0001?ooo]Z3Ol0000@oookJP[o00008?oonfX000kooo]Zool0003oo`00
02Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go0000
3ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX0
01gooo]Z2_l0000CoookJPco00004OoonfX8o`0003cooo]Z1Ol00013oookJQCo00009_oonfX;o`00
01?ooo]Z2ol0000DoookJPOo0000??oonfX5o`0004?ooo]Z5?l0000XoookJP03o`000?oonf[ooo]Z
01cooo]Z000OoookJPWo00003ooonfX<o`0001Kooo]Z1ol0000koookJPGo0000AOoonfX@o`0002So
oo]Z3_l0000>oookJP_o00005ooonfX7o`0003_ooo]Z1Ol00015oookJQ3o0000BOoonfX0023ooo]Z
2ol0000:oookJPco00006OoonfX7o`0003Wooo]Z1Ol00017oookJPco0000:ooonfX@o`0000_ooo]Z
2ol0000IoookJPOo0000>OoonfX5o`0004Sooo]Z2ol0001<oookJP008_oonfXNo`0001_ooo]Z1_l0
000ioookJPGo0000O_oonfX5o`0000;ooo]Z3_l000000ooonf[o0000o`00000<o`0001cooo]Z1_l0
000ioookJPGo0000WooonfX002Cooo]Z6Ol0000OoookJPKo0000=ooonfX6o`0007kooo]Z1Ol00003
oookJQWo00008?oonfX6o`0003Oooo]Z1_l0002OoookJP009OoonfXEo`0002?ooo]Z1_l0000foook
JPGo0000OooonfX5o`0000Kooo]Z5?l0000SoookJPKo0000=_oonfX5o`000:3ooo]Z000XoookJQ3o
00009OoonfX6o`0003Kooo]Z1Ol0001ooookJPGo00002?oonfXAo`0002Cooo]Z1_l0000foookJPGo
0000X?oonfX002gooo]Z1ol0000ZoookJPKo0000=?oonfX5o`00083ooo]Z1Ol0000=oookJPOo0000
:_oonfX6o`0003Cooo]Z1Ol0002QoookJP00GooonfX5o`0003Cooo]Z1Ol00020oookJPGo0000?ooo
nfX6o`0003?ooo]Z1Ol0002QoookJP00GooonfX6o`0003?ooo]Z1Ol00020oookJPGo0000?ooonfX6
o`0003?ooo]Z1Ol0002QoookJP00H?oonfX6o`00037ooo]Z1Ol00021oookJPGo0000@?oonfX6o`00
037ooo]Z1Ol0002RoookJP00H?oonfX6o`00037ooo]Z1Ol00021oookJPGo0000@OoonfX6o`00033o
oo]Z1Ol0002RoookJP00HOoonfX6o`0002oooo]Z1_l00021oookJPGo0000@OoonfX7o`0002kooo]Z
1_l0002RoookJP00H_oonfX6o`0002kooo]Z1Ol00022oookJPGo0000@_oonfX6o`0002kooo]Z1Ol0
002SoookJP00H_oonfX6o`0002kooo]Z1Ol00022oookJPGo0000@ooonfX6o`0002gooo]Z1Ol0002S
oookJP00HooonfX6o`0002cooo]Z1Ol00023oookJPGo0000A?oonfX6o`0002_ooo]Z1Ol0002Toook
JP00I?oonfX5o`0002cooo]Z1Ol00023oookJPGo0000A?oonfX6o`0002_ooo]Z1Ol0002ToookJP00
I?oonfX6o`0002_ooo]Z1Ol00023oookJPGo0000AOoonfX6o`0002[ooo]Z1Ol0002ToookJP00IOoo
nfX6o`0002Wooo]Z1Ol00024oookJPGo0000A_oonfX6o`0002Sooo]Z1Ol0002UoookJP00IOoonfX6
o`0002Wooo]Z1Ol00024oookJPGo0000A_oonfX6o`0002Sooo]Z1Ol0002UoookJP00I_oonfX6o`00
02Sooo]Z1Ol00024oookJPGo0000AooonfX6o`0002Oooo]Z1Ol0002UoookJP00IooonfX6o`0002Ko
oo]Z1Ol00025oookJPGo0000B?oonfX5o`0002Kooo]Z1Ol0002VoookJP00IooonfX6o`0002Kooo]Z
1Ol00025oookJPGo0000B?oonfX6o`0002Gooo]Z1Ol0002VoookJP00J?oonfX6o`0002Cooo]Z1_l0
0025oookJPGo0000BOoonfX6o`0002?ooo]Z1_l0002VoookJP00JOoonfX5o`0002Cooo]Z1Ol00026
oookJPGo0000BOoonfX6o`0002?ooo]Z1Ol0002WoookJP00JOoonfX6o`0002;ooo]Z1_l00026oook
JPGo0000B_oonfX6o`00027ooo]Z1_l0002WoookJP00J_oonfX6o`00027ooo]Z1Ol00027oookJPGo
0000BooonfX5o`00027ooo]Z1Ol0002XoookJP00J_oonfX6o`00023ooo]Z1_l00027oookJPGo0000
BooonfX6o`0001oooo]Z1_l0002XoookJP00JooonfX6o`0001oooo]Z1Ol00028oookJPGo0000C?oo
nfX6o`0001kooo]Z1Ol0002YoookJP00K?oonfX5o`0001oooo]Z1Ol00028oookJPGo0000C?oonfX6
o`0001kooo]Z1Ol0002YoookJP00K?oonfX6o`0001gooo]Z1Ol00029oookJPGo0000COoonfX6o`00
01cooo]Z1Ol0002ZoookJP00KOoonfX6o`0001cooo]Z1Ol00029oookJPGo0000C_oonfX5o`0001co
oo]Z1Ol0002ZoookJP00KOoonfX6o`0001_ooo]Z1_l00029oookJPGo0000C_oonfX6o`0001[ooo]Z
1_l0002ZoookJP00K_oonfX6o`0001[ooo]Z1Ol0002:oookJPGo0000CooonfX6o`0001Wooo]Z1Ol0
002[oookJP00KooonfX6o`0001Sooo]Z1_l0002:oookJPGo0000CooonfX6o`0001Sooo]Z1_l0002[
oookJP00KooonfX6o`0001Oooo]Z1_l0001]oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oook
JPGo0000D?oonfX6o`0001Oooo]Z1Ol0002/oookJP00L?oonfX6o`0001Kooo]Z1_l0001/oookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000DOoonfX5o`0001Kooo]Z1_l0002/oookJP00
LOoonfX6o`0001Cooo]Z1_l0001]oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`00057ooo]Z1_l0000Doook
JPKo0000[OoonfX0077ooo]Z1ol0000BoookJPKo0000KOoonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Sooo]Z1Ol0001BoookJPKo00004_oonfX7o`000:gooo]Z001boookJPOo0000
4?oonfX7o`0006gooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001AoookJPKo0000
4_oonfX6o`000:kooo]Z001coookJPOo00003_oonfX7o`0006kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Sooo]Z1Ol0001CoookJPKo00004?oonfX6o`000:oooo]Z001doookJPOo00003OoonfX6
o`0006oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000E?oonfX6
o`0000kooo]Z1_l0002`oookJP00MOoonfX7o`0000_ooo]Z1_l0001`oookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l9oookJPGo0000E?oonfX7o`0000cooo]Z1ol0002`oookJP00M_oonfX7o`0000So
oo]Z1ol0001aoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000EOoonfX7o`0000Wo
oo]Z2?l0002aoookJP00MooonfX7o`0000Kooo]Z2?l0001aoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l>oookJPGo0000E_oonfX8o`0000Kooo]Z2?l0002boookJP00N?oonfX8o`0000?ooo]Z2?l0
001coookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001GoookJPWo0000
0ooonfX8o`000;?ooo]Z001ioookJQ7o0000M?oonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000F?oo
nfXBo`000;Cooo]Z001joookJPko0000MooonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000FOoonfX?
o`000;Kooo]Z001koookJPco0000U_oonfX5o`0005_ooo]Z3?l0002goookJP00OOoonfX9o`0009Oo
oo]Z1Ol0001MoookJPWo0000^?oonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003o
oookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o
001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z
003ooookJQ7ooo]Z0ol007l:oookJPKo0000oooonfXNoookJP00oooonfXAoookJP?o001o2_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7o
oo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1_l007l:
oookJPGo0000oooonfXOoookJP00oooonfX@oookJPCo001o2_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o
001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o
0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2
oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooookJP;ooo]Z0ol007l>oook
JP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003n
oookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00
O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l0
07l=oookJPGo0000oooonfXOoookJP00oooonfX>oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo
0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooo
nfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooook
JPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJPCo001o0_oonfX3o`00Oooo
oo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oo
nfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02846 .30613 L
.03279 .30363 L
.03793 .30114 L
.04037 .30022 L
.04262 .29953 L
.04498 .299 L
.04622 .29881 L
.04754 .29866 L
.04869 .29859 L
.04976 .29857 L
.05093 .2986 L
.0522 .2987 L
.05351 .29886 L
.05425 .29899 L
.05494 .29912 L
.05755 .2998 L
.05992 .30064 L
.06244 .30174 L
.08414 .3168 L
.08932 .32045 L
.09479 .32368 L
.09945 .32571 L
.10073 .32614 L
.10211 .32653 L
.10331 .32681 L
.10458 .32705 L
.10521 .32715 L
.10591 .32724 L
.10715 .32735 L
.10784 .32739 L
.10859 .32741 L
.1093 .32741 L
.10995 .3274 L
.11113 .32733 L
.11242 .3272 L
.11307 .32712 L
.11377 .32701 L
.11503 .32677 L
.1176 .32614 L
.12002 .32539 L
.12455 .32366 L
.13505 .3192 L
.1376 .31829 L
.14034 .3175 L
.14191 .31717 L
.14335 .31694 L
.14404 .31686 L
.14479 .3168 L
.1455 .31677 L
Mistroke
.14616 .31676 L
.14742 .3168 L
.14813 .31687 L
.14878 .31695 L
.14998 .31716 L
.15125 .31747 L
.15239 .31783 L
.15345 .31824 L
.15586 .31944 L
.15846 .32119 L
.16084 .32318 L
.16618 .3291 L
.17072 .33566 L
.17566 .34421 L
.18463 .36255 L
.19485 .38491 L
.20444 .40306 L
.20926 .40976 L
.21196 .41256 L
.21444 .41443 L
.21577 .41514 L
.21701 .41561 L
.21772 .4158 L
.21837 .41592 L
.21911 .41598 L
.21981 .41598 L
.2205 .41591 L
.22123 .41578 L
.22253 .41536 L
.22325 .41503 L
.22393 .41466 L
.22546 .41358 L
.22806 .41104 L
.23046 .40786 L
.2359 .39782 L
.24069 .38587 L
.24579 .37035 L
.26434 .29913 L
.27369 .26273 L
.27861 .24576 L
.28379 .23034 L
.28833 .2193 L
.29074 .21451 L
.29331 .21023 L
.29569 .20708 L
.29784 .20487 L
.29888 .20404 L
.30001 .2033 L
.30107 .20276 L
.30206 .2024 L
Mistroke
.30331 .20212 L
.30449 .20205 L
.30556 .20214 L
.30672 .2024 L
.30798 .20287 L
.30932 .20358 L
.31174 .20538 L
.31418 .20785 L
.31649 .21072 L
.3208 .21733 L
.34143 .26032 L
.3512 .27927 L
.35654 .28748 L
.36152 .29344 L
.36577 .29717 L
.36816 .29871 L
.37033 .29978 L
.37149 .30023 L
.37271 .30061 L
.37335 .30077 L
.37405 .30092 L
.3753 .30112 L
.37646 .30123 L
.37772 .30127 L
.37891 .30124 L
.38 .30115 L
.38128 .30097 L
.38249 .30075 L
.38474 .30019 L
.38981 .29843 L
.39894 .29451 L
.40377 .29265 L
.40641 .29184 L
.40887 .29124 L
.41016 .29101 L
.41154 .29081 L
.41233 .29073 L
.41308 .29067 L
.41375 .29064 L
.41448 .29062 L
.41578 .29063 L
.4165 .29067 L
.41716 .29072 L
.41844 .29086 L
.41964 .29105 L
.42081 .29129 L
.42206 .2916 L
.42432 .29231 L
.42944 .29458 L
.43485 .29782 L
Mistroke
.43978 .30131 L
.44875 .30818 L
.45827 .31465 L
.463 .31703 L
.46569 .31805 L
.46699 .31845 L
.46821 .31877 L
.46932 .319 L
.47053 .3192 L
.47162 .31934 L
.47264 .31942 L
.47385 .31946 L
.47495 .31945 L
.47621 .31938 L
.4774 .31925 L
.47861 .31907 L
.47993 .31881 L
.4826 .31809 L
.48507 .31721 L
.48738 .31623 L
.49818 .31016 L
.50319 .30702 L
.50863 .30382 L
.51343 .30144 L
.51606 .3004 L
.51853 .29961 L
.52073 .29909 L
.52197 .29887 L
.52311 .29872 L
.52428 .29862 L
.52557 .29857 L
.52622 .29857 L
.52691 .29859 L
.52816 .29868 L
.52931 .29881 L
.53056 .29901 L
.53174 .29926 L
.53283 .29953 L
.53708 .30104 L
.53952 .30218 L
.54175 .30339 L
.54677 .30659 L
.55583 .31337 L
.56102 .31731 L
.56654 .32112 L
.57131 .32385 L
.574 .32508 L
.57647 .32599 L
.57897 .32669 L
.58023 .32696 L
Mistroke
.58095 .32708 L
.58161 .32718 L
.58282 .32731 L
.58411 .3274 L
.58531 .32742 L
.58645 .32739 L
.58754 .32731 L
.5887 .32719 L
.58969 .32705 L
.59078 .32686 L
.59321 .3263 L
.59548 .32563 L
.60559 .32156 L
.6111 .31925 L
.61378 .31829 L
.61622 .31758 L
.61737 .31731 L
.61862 .31708 L
.6198 .31691 L
.62089 .31681 L
.62205 .31676 L
.62331 .31679 L
.62395 .31683 L
.62464 .3169 L
.62588 .3171 L
.62658 .31725 L
.62723 .31741 L
.62871 .31788 L
.63139 .31908 L
.63384 .32059 L
.63643 .32264 L
.64097 .32735 L
.64523 .33307 L
.65495 .35021 L
.67339 .38978 L
.67844 .39939 L
.68122 .40398 L
.68385 .40776 L
.68629 .41071 L
.68895 .41323 L
.69012 .4141 L
.69136 .41485 L
.69242 .41534 L
.69359 .41572 L
.69423 .41586 L
.69492 .41596 L
.69619 .41597 L
.69742 .41578 L
.69857 .41542 L
.69927 .41512 L
Mistroke
.69993 .41477 L
.70116 .41397 L
.70392 .41141 L
.70634 .40831 L
.70857 .40476 L
.7136 .39436 L
.71849 .38128 L
.72385 .36403 L
.73468 .32285 L
.74555 .27913 L
.75583 .24245 L
.76031 .22944 L
.76507 .21815 L
.76755 .21339 L
.77029 .2091 L
.77278 .20608 L
.77399 .20491 L
.77512 .20401 L
.77631 .20324 L
.77739 .20271 L
.77859 .2023 L
.77988 .20208 L
.78111 .20207 L
.78181 .20214 L
.78245 .20227 L
.78364 .20264 L
.78489 .20322 L
.78595 .20385 L
.78709 .20468 L
.78915 .20654 L
.79385 .21236 L
.79926 .22137 L
.80439 .23154 L
.81403 .25256 L
.82365 .27252 L
.82892 .2818 L
.83388 .28901 L
.83853 .29425 L
.84114 .29654 L
.84354 .29823 L
.84557 .29935 L
.8478 .30027 L
.84892 .30061 L
.85012 .3009 L
.85125 .30109 L
.85228 .30121 L
.85347 .30127 L
.85458 .30126 L
.8558 .30119 L
.85711 .30103 L
Mistroke
.85776 .30092 L
.85848 .30079 L
.85978 .3005 L
.86223 .2998 L
.87141 .29611 L
.87662 .29389 L
.87949 .29281 L
.88218 .29195 L
.8847 .29132 L
.88612 .29105 L
.88743 .29085 L
.88853 .29073 L
.88974 .29065 L
.89101 .29062 L
.89219 .29064 L
.89345 .29073 L
.89408 .29079 L
.89479 .29088 L
.89602 .29109 L
.89719 .29133 L
.89981 .29207 L
.90263 .29314 L
.90779 .29578 L
.91252 .29882 L
.93107 .31256 L
.93581 .3154 L
.93841 .31669 L
.94086 .3177 L
.94315 .31844 L
.94436 .31876 L
.94564 .31903 L
.94671 .3192 L
.9479 .31935 L
.94897 .31943 L
.94998 .31946 L
.95126 .31945 L
.95198 .31941 L
.95265 .31936 L
.95388 .31921 L
.95519 .319 L
.95648 .31873 L
.95769 .31842 L
.95995 .3177 L
.9651 .3155 L
.97067 .31243 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00/OoonfX7o`0006Go
oo]Z1Ol0002AoookJPSo0000QOoonfX00;3ooo]Z2_l0001SoookJPGo0000T?oonfX;o`0008?ooo]Z
002_oookJPco0000H_oonfX5o`0008oooo]Z3Ol00022oookJP00[_oonfX>o`00067ooo]Z1Ol0002>
oookJPko0000P_oonfX00:gooo]Z4?l0001PoookJPGo0000SOoonfX@o`00087ooo]Z002]oookJPKo
00001?oonfX7o`0005oooo]Z1Ol0002=oookJPKo00001OoonfX5o`00087ooo]Z002/oookJPKo0000
1_oonfX6o`0005oooo]Z1Ol0002<oookJPKo00001_oonfX6o`00083ooo]Z002/oookJPGo00002?oo
nfX6o`0005kooo]Z1Ol0002<oookJPGo00002?oonfX5o`00083ooo]Z002[oookJPKo00002OoonfX6
o`0005gooo]Z1Ol0002;oookJPKo00002?oonfX6o`0007oooo]Z002ZoookJPKo00002_oonfX6o`00
05gooo]Z1Ol0002;oookJPGo00002_oonfX6o`0007kooo]Z002ZoookJPKo00002ooonfX6o`0005co
oo]Z1Ol0002;oookJPGo00002_oonfX6o`0007kooo]Z002YoookJPKo00003OoonfX5o`0005cooo]Z
1Ol0002:oookJPGo00003?oonfX6o`0007gooo]Z002YoookJPGo00003_oonfX6o`0005_ooo]Z1Ol0
002:oookJPGo00003OoonfX5o`0007gooo]Z002YoookJPGo00003ooonfX5o`0003gooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol00029oookJPKo00003OoonfX6o`0007cooo]Z002Xoook
JPGo00004?oonfX6o`0003_ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol00029oook
JPGo00003ooonfX6o`0007_ooo]Z002XoookJPGo00004OoonfX5o`0003_ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9
oookJPGo0000R?oonfX6o`0000oooo]Z1_l0001koookJP00Z?oonfX5o`00017ooo]Z1Ol0000^oook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol00028oook
JPGo00004OoonfX6o`0007[ooo]Z002WoookJPGo00004ooonfX5o`0002gooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000QooonfX5o`0001;ooo]Z1Ol0001joookJP00
YooonfX5o`0001?ooo]Z1Ol0000ioookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000
QooonfX5o`0001?ooo]Z1_l0001ioookJP00YooonfX5o`0001?ooo]Z1_l0000hoookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0008Oooo]Z1Ol0000DoookJPGo0000NOoo
nfX00:Kooo]Z1Ol0000EoookJPGo0000>?oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5
o`0008Oooo]Z1Ol0000DoookJPKo0000N?oonfX00:Kooo]Z1Ol0000EoookJPKo0000=ooonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0008Kooo]Z1Ol0000FoookJPGo0000N?oonfX00:Ko
oo]Z1Ol0000FoookJPGo0000=ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0008Ko
oo]Z1Ol0000FoookJPKo0000MooonfX00:Gooo]Z1Ol0000GoookJPKo0000=ooonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000Q_oonfX5o`0001Oooo]Z1Ol0001goookJP00
YOoonfX5o`0001Sooo]Z1Ol0000goookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol00026oookJPCo0000
6?oonfX5o`0007Oooo]Z002UoookJPGo00006?oonfX6o`0003Oooo]Z1Ol007l:oookJPOo001o2?oo
nfX5o`0008Gooo]Z1Ol0000IoookJPGo0000M_oonfX00:Cooo]Z1Ol0000JoookJPGo0000EOoonfX5
o`0008Gooo]Z1Ol0000IoookJPGo0000M_oonfX00:Cooo]Z1Ol0000JoookJPGo0000EOoonfX5o`00
08Gooo]Z1Ol0000IoookJPKo0000MOoonfX00:Cooo]Z1Ol0000KoookJPGo0000E?oonfX5o`0008Co
oo]Z1Ol0000KoookJPGo0000MOoonfX00:?ooo]Z1Ol0000LoookJPGo0000E?oonfX5o`0008Cooo]Z
1Ol0000KoookJPKo0000M?oonfX00:?ooo]Z1Ol0000LoookJPKo0000DooonfX5o`0008Cooo]Z1Ol0
000LoookJPGo0000M?oonfX00:?ooo]Z1Ol0000MoookJPGo0000DooonfX5o`0008?ooo]Z1Ol0000M
oookJPKo0000LooonfX00:;ooo]Z1Ol0000NoookJPKo0000D_oonfX5o`0008?ooo]Z1Ol0000Noook
JPGo0000LooonfX00:;ooo]Z1Ol0000OoookJPGo0000D_oonfX5o`0008?ooo]Z1Ol0000NoookJPKo
0000L_oonfX00:;ooo]Z1Ol0000OoookJPKo0000DOoonfX5o`0008?ooo]Z1?l0000PoookJPGo0000
L_oonfX00:;ooo]Z1?l0000QoookJPGo0000DOoonfX5o`0008;ooo]Z1Ol0000PoookJPGo0000L_oo
nfX00:7ooo]Z1Ol0000QoookJPKo0000D?oonfX5o`0008;ooo]Z1Ol0000QoookJPGo0000LOoonfX0
0:7ooo]Z1Ol0000RoookJPGo0000D?oonfX5o`0008;ooo]Z1Ol0000QoookJPGo0000LOoonfX002;o
oo]Z0ol007meoookJPGo001o0_oonfX5o`0000?ooo]Z1Ol007lJoookJPKo0000CooonfX5o`0007Co
oo]Z1Ol007l4oookJP?o001o00?ooo]Zo`000?l000000ol00002o`00Ob3ooo]Z1_l0001@oookJP?o
001o7OoonfX002;ooo]Z0ol007mdoookJPOo001o00?ooo]Zo`000?l000000_l000000ol007oooo]Z
oookJP07o`00Oa[ooo]Z1Ol0001?oookJPGo0000LooonfX7o`00O`?ooo]Z0ol007l00ooonf[o0000
o`000003o`0000?o001o8?oonfX5o`00053ooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol0
07l01?oonf[o001oo`00Ool007l5o`000003o`00Oooonf[o001o00?o001o00Cooo]Zo`00Ool007oo
001o6_oonfX6o`0004kooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l0003o000000?o00000ol007lPoookJPKo0000CooonfX3o`00Oagooo]Z000CoookJP[o
001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o0ooonfX2o`00O`Go00000_oonfX3o`00O`?o
oo]Z0ol007lJoookJPGo0000C_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o1OoonfX5o`0000;o
oo]Z0ol007lPoookJPKo0000C_oonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z
2_l007l2oookJP?o001o0ooonfX2o`00O`Go00002?oonfX3o`00Oa[ooo]Z1_l0001=oookJPGo0000
L_oonfX3o`00O`?ooo]Z0ol007l5oookJPGo00000_oonfX3o`00Ob3ooo]Z1_l0001>oookJP?o001o
7OoonfX002;ooo]Z0ol007mcoookJP?o001o0ooonfX2o`00O`Co00002OoonfX3o`00Oa_ooo]Z1Ol0
001=oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l5oookJPGo00000_oonfX3o`00Ob7ooo]Z1_l0
001=oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0ooonfX00ol007oo0000o`000003
o`0000Cooo]Z0_l007l2oookJPCo001o6ooonfX6o`0004cooo]Z1Ol0001boookJP?o001o0ooonfX3
o`00O`Gooo]Z1?l00002oookJPCo001o8_oonfX5o`0004gooo]Z0ol007lMoookJP008_oonfX3o`00
Og?ooo]Z0ol007l3oookJP03o`00Ool0003o000000?o00001?oonfX7o`00Oagooo]Z1_l0001;oook
JPGo0000L_oonfX3o`00O`?ooo]Z0ol007l4oookJPGo00001Ol007lSoookJPKo0000C?oonfX3o`00
Oagooo]Z000RoookJP?o001oLooonfX3o`00O`?ooo]Z00?o001oo`000?l000000ol00004oookJPKo
001o7_oonfX7o`0004[ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`Cooo]Z1Ol00004o`00ObGo
oo]Z1_l0001;oookJP?o001o7OoonfX001oooo]Z1_l007mcoookJP?o001o0ooonfX00ol007oo0000
o`000002o`0000Gooo]Z0_l007lSoookJPKo0000B_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o
1?oonfX5o`0002Wooo]Z1ol00017oookJPKo001o7OoonfX001oooo]Z1_l007mdoookJP?o001o00?o
oo]Zo`00Ool000001?l00005oookJP;o001o9?oonfX6o`0001Oooo]Z2ol0000WoookJPGo0000Looo
nfX3o`00O`04oookJ_l007oo001oo`00O`Gooo]Z1?l000000ol007oooo]ZoookJP0XoookJPKo0000
5ooonfX<o`0002Cooo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z1Ol007l5o`0000Kooo]Z1ol0
07lOoookJPKo00004ooonfXBo`0002?ooo]Z1Ol0001coookJPOo001o1?oonfX5o`0000Oo001o9Ooo
nfX6o`0001?ooo]Z4_l0000SoookJPCo001o7OoonfX002;ooo]Z0ol007meoookJPCo001o1Ol00006
oookJPOo001o7ooonfX7o`0000oooo]Z5ol0000QoookJPGo0000M?oonfX5o`00O`Gooo]Z1Ol00007
o`00ObKooo]Z1ol0000?oookJQGo00008ooonfX3o`00Oagooo]Z002NoookJPCo0000;_oonfX7o`00
00_ooo]Z6ol0000PoookJPGo0000O_oonfX5o`0002gooo]Z2?l0000;oookJQ[o0000@OoonfX002Oo
oo]Z1ol0001_oookJPGo0000;ooonfX9o`0000Kooo]Z3_l00005oookJP_o00007ooonfX5o`0000So
oo]Z1ol0001_oookJPCo0000;ooonfX8o`0000Oooo]Z3_l00006oookJP[o0000@?oonfX002Cooo]Z
3ol0001ZoookJPGo0000<?oonfX:o`0000;ooo]Z3Ol0000<oookJPSo00007_oonfX5o`0000?ooo]Z
3ol0001[oookJPGo0000<?oonfX:o`0000;ooo]Z3Ol0000<oookJPWo0000?_oonfX002;ooo]Z4ol0
001XoookJPGo0000<OoonfXEo`00017ooo]Z2?l0000LoookJPGo000000?ooo]Zo`000?l000004_l0
001XoookJPGo0000<_oonfXEo`0000oooo]Z2Ol0000moookJP007ooonfXGo`0006Oooo]Z1?l0000c
oookJQ7o00005OoonfX8o`0001_ooo]Z6ol0001WoookJPGo0000<ooonfXAo`0001Cooo]Z2Ol0000k
oookJP007OoonfX=o`000003oookJ_l0003o000000_o0000I?oonfX5o`0003Kooo]Z3?l0000Hoook
JPSo00006_oonfX@o`000003oookJ_l0003o000000Wo0000I_oonfX4o`0003Gooo]Z3Ol0000Hoook
JPWo0000>_oonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go0000
3ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX0
00kooo]Zool0003oo`0002Go00003ooonfX001gooo]Z00?o0000oookJ_oonfX06?oonfX8o`0001_o
oo]Z2?l0000hoookJPGo0000HooonfX:o`0000Sooo]Z3Ol0000HoookJPOo00007?oonfX9o`0003Oo
oo]Z1Ol0001ToookJPWo00002OoonfX:o`0001kooo]Z000ioookJPSo00005ooonfX=o`0003Gooo]Z
1Ol0001VoookJP_o000000?ooo]Zo`000?l000003ol0000IoookJPSo00005ooonfX?o`0003Cooo]Z
1Ol0001UoookJPco000000?ooo]Zo`000?l000002_l0000PoookJP00>ooonfX8o`0001?ooo]Z4Ol0
000coookJPGo0000IooonfXFo`000003oookJ_l0003o000000?o00006_oonfX8o`0001Cooo]Z4_l0
000coookJPCo0000J?oonfXEo`0002;ooo]Z000loookJPSo00003ooonfXEo`0003;ooo]Z1Ol0001Z
oookJQ7o00000ooonfX5o`0001_ooo]Z2_l0000>oookJQKo0000<OoonfX5o`0006[ooo]Z4_l0000S
oookJP00?OoonfX:o`0000[ooo]Z3Ol00002oookJPWo0000<OoonfX4o`0006cooo]Z3_l00005oook
JPGo00007?oonfX:o`0000[ooo]Z3ol000000ooonf[o0000o`000007o`00037ooo]Z1Ol0001[oook
JPoo00009OoonfX003kooo]Z2ol00004oookJPko00001ooonfX8o`0002oooo]Z1Ol0001_oookJPSo
00002?oonfX5o`0001kooo]Z2ol00004oookJPko00002OoonfX6o`00033ooo]Z1Ol0001^oookJPSo
0000:OoonfX0043ooo]Z6Ol0000;oookJPOo0000;_oonfX5o`0007oooo]Z1Ol0000OoookJQ[o0000
3?oonfX6o`0002oooo]Z1?l0002PoookJP00@OoonfXEo`0000oooo]Z1ol0000]oookJPGo0000Oooo
nfX5o`0002;ooo]Z5?l0000?oookJPOo0000;OoonfX5o`000:3ooo]Z0014oookJQ3o00004_oonfX7
o`0002cooo]Z1?l00020oookJPGo00008ooonfX@o`0001?ooo]Z1ol0000/oookJPGo0000X?oonfX0
04Gooo]Z2ol0000GoookJPOo0000:_oonfX5o`00083ooo]Z1Ol0000VoookJP[o00005ooonfX7o`00
02_ooo]Z1Ol0002PoookJP00J?oonfX7o`0002Wooo]Z1Ol00020oookJPGo0000B?oonfX6o`0002[o
oo]Z1Ol0002QoookJP00JOoonfX6o`0002Wooo]Z1Ol00020oookJPGo0000BOoonfX6o`0002Wooo]Z
1Ol0002QoookJP00J_oonfX6o`0002Sooo]Z1?l00021oookJPGo0000B_oonfX5o`0002Wooo]Z1Ol0
002QoookJP00JooonfX5o`0002Oooo]Z1Ol00021oookJPGo0000B_oonfX6o`0002Sooo]Z1?l0002R
oookJP00JooonfX5o`0002Oooo]Z1Ol00021oookJPGo0000BooonfX6o`0002Kooo]Z1Ol0002Roook
JP00K?oonfX5o`0002Kooo]Z1Ol00021oookJPGo0000BooonfX6o`0002Kooo]Z1Ol0002RoookJP00
K?oonfX5o`0002Kooo]Z1?l00022oookJPGo0000C?oonfX6o`0002Gooo]Z1Ol0002RoookJP00K?oo
nfX6o`0002Cooo]Z1Ol00022oookJPGo0000COoonfX5o`0002Gooo]Z1?l0002SoookJP00KOoonfX5
o`0002Cooo]Z1Ol00022oookJPGo0000COoonfX6o`0002?ooo]Z1Ol0002SoookJP00KOoonfX6o`00
02?ooo]Z1Ol00022oookJPGo0000C_oonfX5o`0002?ooo]Z1Ol0002SoookJP00K_oonfX5o`0002;o
oo]Z1Ol00023oookJPGo0000C_oonfX6o`0002;ooo]Z1Ol0002SoookJP00K_oonfX6o`00027ooo]Z
1Ol00023oookJPGo0000CooonfX5o`00027ooo]Z1Ol0002ToookJP00KooonfX5o`00027ooo]Z1Ol0
0023oookJPGo0000CooonfX6o`00023ooo]Z1Ol0002ToookJP00KooonfX6o`00023ooo]Z1?l00024
oookJPGo0000D?oonfX5o`00023ooo]Z1Ol0002ToookJP00L?oonfX5o`0001oooo]Z1Ol00024oook
JPGo0000D?oonfX6o`0001oooo]Z1?l0002UoookJP00L?oonfX6o`0001kooo]Z1Ol00024oookJPGo
0000DOoonfX5o`0001kooo]Z1Ol0002UoookJP00LOoonfX5o`0001kooo]Z1Ol00024oookJPGo0000
DOoonfX5o`0001kooo]Z1Ol0002UoookJP00LOoonfX6o`0001gooo]Z1?l00025oookJPGo0000D_oo
nfX5o`0001gooo]Z1Ol0002UoookJP00L_oonfX5o`0001cooo]Z1Ol00025oookJPGo0000D_oonfX5
o`0001cooo]Z1Ol0002VoookJP00L_oonfX6o`0001_ooo]Z1Ol00025oookJPGo0000D_oonfX6o`00
01_ooo]Z1Ol0002VoookJP00LooonfX5o`0001_ooo]Z1Ol00025oookJPGo0000DooonfX5o`0001_o
oo]Z1Ol0002VoookJP00LooonfX6o`0001Wooo]Z1Ol00026oookJPGo0000DooonfX6o`0001Wooo]Z
1Ol0002WoookJP00M?oonfX5o`0001Wooo]Z1Ol00026oookJPGo0000E?oonfX5o`0001Wooo]Z1Ol0
002WoookJP00M?oonfX6o`0001Sooo]Z1Ol00026oookJPGo0000E?oonfX6o`0001Sooo]Z1Ol0002W
oookJP00MOoonfX5o`0001Oooo]Z1Ol00027oookJPGo0000EOoonfX5o`0001Oooo]Z1Ol0002Xoook
JP00MOoonfX6o`0001Kooo]Z1Ol0001YoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo
0000EOoonfX6o`0001Kooo]Z1Ol0002XoookJP00M_oonfX5o`0001Kooo]Z1Ol0001XoookJPOo001o
0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000E_oonfX5o`0001Kooo]Z1Ol0002XoookJP00M_oo
nfX6o`0001Cooo]Z1Ol0001YoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oook
J_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005Kooo]Z1Ol0000FoookJPCo
0000ZOoonfX007Oooo]Z1Ol0000DoookJPGo0000J?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`Sooo]Z1Ol0001GoookJPGo00005?oonfX5o`000:Wooo]Z001goookJPKo00004ooo
nfX5o`0006Sooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001FoookJPGo00005?oo
nfX5o`000:Wooo]Z001hoookJPGo00004_oonfX5o`0006Wooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Sooo]Z1Ol0001GoookJPKo00004ooonfX5o`000:Wooo]Z001hoookJPKo00004OoonfX5o`00
06Wooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000F?oonfX5o`00
01;ooo]Z1Ol0002ZoookJP00NOoonfX5o`00017ooo]Z1Ol0001YoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1ol007l9oookJPGo0000F?oonfX6o`00017ooo]Z1Ol0002ZoookJP00NOoonfX6o`0000oooo]Z
1Ol0001ZoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000FOoonfX6o`00013ooo]Z
1Ol0002ZoookJP00N_oonfX5o`0000oooo]Z1Ol0001ZoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l>oookJPGo0000FOoonfX6o`0000oooo]Z1Ol0002[oookJP00N_oonfX6o`0000kooo]Z1Ol0001[
oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001JoookJPKo00003_oo
nfX5o`000:_ooo]Z001koookJPGo00003OoonfX5o`0006cooo]Z1ol007l9oookJPOo001o2?oonfX5
o`0005_ooo]Z1Ol0000=oookJPKo0000ZooonfX007_ooo]Z1_l0000<oookJPGo0000KOoonfX5o`00
O`[ooo]Z1ol007l8oookJPGo0000FooonfX6o`0000cooo]Z1Ol0002/oookJP00O?oonfX5o`0000_o
oo]Z1_l0002;oookJPGo0000G?oonfX5o`0000_ooo]Z1_l0002/oookJP00O?oonfX6o`0000[ooo]Z
1Ol0002<oookJPGo0000G?oonfX6o`0000[ooo]Z1Ol0002]oookJP00OOoonfX5o`0000Wooo]Z1_l0
002<oookJPGo0000GOoonfX6o`0000Sooo]Z1_l0002]oookJP00OOoonfX7o`0000Kooo]Z1_l0002=
oookJPGo0000GOoonfX7o`0000Oooo]Z1Ol0002^oookJP00O_oonfX7o`0000Cooo]Z1ol0002=oook
JPGo0000G_oonfX6o`0000Gooo]Z1ol0002^oookJP00O_oonfX8o`000003oookJ_l0003o000000Ko
0000S_oonfX5o`0005oooo]Z4?l0002_oookJP00OooonfX?o`0008oooo]Z1Ol0001PoookJPoo0000
[ooonfX0087ooo]Z3?l0002@oookJPGo0000H?oonfX>o`000;3ooo]Z0022oookJP[o0000TOoonfX5
o`00067ooo]Z2ol0002boookJP00PooonfX8o`0009;ooo]Z1Ol0001SoookJPSo0000/ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPKo0000oooonfXNoookJP00oooonfXAoookJP?o001o2_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z
0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1_l007l:oook
JPGo0000oooonfXOoookJP00oooonfX@oookJPCo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o
0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXOoookJP00oooonfX2
oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oook
JP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o
2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooo
nfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`ko
oo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=
oookJPGo0000oooonfXOoookJP00oooonfX>oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000
oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3
o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgo
oo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z
;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02846 .31192 L
.03279 .31434 L
.03523 .3155 L
.03754 .31641 L
.03881 .31683 L
.0402 .31722 L
.04145 .31749 L
.04262 .31769 L
.04376 .31783 L
.045 .31791 L
.0457 .31792 L
.04637 .31792 L
.04762 .31785 L
.04894 .3177 L
.05016 .3175 L
.0515 .31721 L
.05293 .31681 L
.05792 .31485 L
.06244 .31247 L
.07287 .30641 L
.07572 .30499 L
.07874 .30377 L
.07998 .30337 L
.08131 .30301 L
.08208 .30284 L
.08278 .30271 L
.08342 .30261 L
.08414 .30253 L
.08541 .30244 L
.0861 .30243 L
.08675 .30244 L
.08791 .30251 L
.08917 .30268 L
.08983 .3028 L
.09056 .30297 L
.09202 .30338 L
.09464 .30442 L
.09713 .30574 L
.09979 .30749 L
.10458 .31139 L
.11425 .32095 L
.11954 .32618 L
.12449 .33043 L
.12729 .33242 L
.12984 .33391 L
.13268 .33517 L
.13424 .33569 L
.13502 .33589 L
.13572 .33605 L
Mistroke
.13697 .33626 L
.13765 .33635 L
.13829 .3364 L
.13944 .33645 L
.14068 .33642 L
.14133 .33638 L
.14205 .33631 L
.14279 .33621 L
.14349 .3361 L
.14608 .33552 L
.15083 .33395 L
.156 .33195 L
.15837 .3311 L
.15966 .3307 L
.16088 .33037 L
.162 .33012 L
.16302 .32993 L
.16416 .32979 L
.16539 .32972 L
.16669 .32974 L
.16791 .32987 L
.16861 .32999 L
.16924 .33013 L
.17066 .33056 L
.17203 .33114 L
.17352 .33195 L
.17621 .33394 L
.1787 .33641 L
.18134 .3397 L
.18606 .34729 L
.2059 .3952 L
.2101 .40547 L
.21456 .41486 L
.21689 .41886 L
.21946 .42242 L
.22059 .42365 L
.2218 .42475 L
.22295 .42556 L
.224 .42609 L
.2252 .42645 L
.22632 .42653 L
.22755 .42634 L
.22887 .4258 L
.22953 .42539 L
.23025 .42485 L
.23156 .42358 L
.234 .42026 L
.2364 .41578 L
.23893 .40973 L
.24348 .39569 L
Mistroke
.25344 .35302 L
.26439 .29578 L
.27435 .2463 L
.27926 .22619 L
.28381 .21122 L
.28655 .20416 L
.28903 .1991 L
.29036 .19692 L
.29179 .19499 L
.2933 .19341 L
.29404 .19281 L
.29472 .19236 L
.29593 .1918 L
.29725 .19152 L
.29854 .19157 L
.29926 .19175 L
.29992 .19199 L
.3011 .19262 L
.30237 .19359 L
.3047 .19605 L
.30704 .19936 L
.30955 .20376 L
.31411 .21348 L
.32449 .24007 L
.33453 .26437 L
.34021 .27497 L
.34293 .27896 L
.3455 .28205 L
.34794 .28438 L
.34922 .28538 L
.35058 .28626 L
.35173 .28687 L
.35299 .28741 L
.35413 .28779 L
.3552 .28804 L
.35584 .28816 L
.35654 .28824 L
.35781 .28832 L
.35905 .28829 L
.36019 .28818 L
.3609 .28809 L
.36156 .28797 L
.36279 .2877 L
.36556 .28689 L
.37087 .2849 L
.37583 .28308 L
.37833 .28236 L
.37972 .28204 L
.381 .28182 L
.38172 .28173 L
Mistroke
.38239 .28166 L
.38313 .28161 L
.38391 .28159 L
.38522 .28162 L
.38596 .28167 L
.38666 .28175 L
.3879 .28195 L
.3886 .2821 L
.38926 .28226 L
.39172 .28309 L
.39397 .28412 L
.39636 .28551 L
.40183 .28966 L
.40679 .2943 L
.41578 .30339 L
.4207 .30792 L
.42528 .31141 L
.42778 .31291 L
.43006 .31401 L
.43127 .31448 L
.43259 .31489 L
.43331 .31508 L
.43398 .31523 L
.4353 .31545 L
.4364 .31556 L
.43743 .31561 L
.43855 .31559 L
.43977 .3155 L
.44098 .31533 L
.44225 .31508 L
.44452 .31445 L
.44701 .31351 L
.44967 .31228 L
.45446 .30965 L
.46012 .30629 L
.46534 .30345 L
.46791 .30229 L
.47031 .3014 L
.47282 .30071 L
.47415 .30044 L
.47489 .30033 L
.47557 .30024 L
.47626 .30018 L
.47699 .30013 L
.4783 .30011 L
.4791 .30014 L
.47986 .30019 L
.48053 .30026 L
.48127 .30035 L
.48264 .3006 L
Mistroke
.48408 .30094 L
.48667 .30176 L
.49165 .30401 L
.49628 .30668 L
.50133 .30986 L
.50682 .31319 L
.50946 .31459 L
.51227 .31586 L
.51466 .31673 L
.51603 .31713 L
.5173 .31742 L
.5185 .31764 L
.51976 .31781 L
.52102 .3179 L
.52174 .31792 L
.52241 .31792 L
.52363 .31786 L
.52473 .31776 L
.526 .31757 L
.52721 .31732 L
.52946 .3167 L
.53185 .31584 L
.53612 .31384 L
.54577 .30825 L
.55062 .3056 L
.55301 .30451 L
.55523 .30367 L
.55643 .30329 L
.55777 .30295 L
.55911 .30269 L
.55984 .30258 L
.56053 .30251 L
.56175 .30243 L
.56286 .30243 L
.56409 .30251 L
.56538 .30268 L
.56652 .30291 L
.56756 .30318 L
.5699 .30401 L
.57207 .30504 L
.57412 .30624 L
.5837 .31413 L
.5934 .32393 L
.59871 .32883 L
.60368 .33255 L
.60585 .33381 L
.60791 .33479 L
.60904 .33524 L
.61028 .33564 L
.6114 .33594 L
Mistroke
.61245 .33615 L
.61373 .33633 L
.61488 .33642 L
.61612 .33644 L
.61682 .33642 L
.61747 .33638 L
.61855 .33627 L
.61973 .33609 L
.62097 .33585 L
.62212 .33556 L
.62713 .33391 L
.63258 .3318 L
.63507 .33094 L
.63644 .33053 L
.63772 .33021 L
.63881 .33 L
.63998 .32983 L
.64128 .32973 L
.64248 .32972 L
.64356 .3298 L
.64472 .32997 L
.64581 .33023 L
.6468 .33054 L
.64796 .33102 L
.64923 .33167 L
.65152 .33321 L
.65392 .33538 L
.65647 .3383 L
.66104 .34514 L
.68084 .39199 L
.6895 .41242 L
.69187 .41686 L
.69439 .4208 L
.69562 .42238 L
.69677 .42365 L
.6978 .4246 L
.69893 .42543 L
.70015 .42607 L
.70143 .42646 L
.70262 .42653 L
.70373 .42634 L
.70504 .42581 L
.70623 .42502 L
.70761 .42374 L
.70891 .42216 L
.71127 .41839 L
.71345 .41386 L
.71838 .40007 L
.72321 .3822 L
.72852 .35839 L
Mistroke
.73928 .30271 L
.74922 .25233 L
.75412 .23128 L
.75867 .2152 L
.7614 .20743 L
.76388 .20168 L
.76663 .1968 L
.76814 .19479 L
.76957 .19334 L
.77078 .19244 L
.77206 .19182 L
.77315 .19155 L
.77436 .19152 L
.77565 .19181 L
.77638 .19211 L
.77704 .19247 L
.77832 .19338 L
.77954 .19451 L
.7819 .19739 L
.78412 .20083 L
.78918 .21092 L
.79943 .23679 L
.80822 .25888 L
.81287 .26874 L
.81785 .27718 L
.82051 .28071 L
.82293 .28331 L
.82537 .28534 L
.82767 .28675 L
.82892 .28731 L
.83025 .28777 L
.83138 .28804 L
.83263 .28823 L
.83333 .28829 L
.83397 .28832 L
.83471 .28831 L
.83541 .28828 L
.83665 .28815 L
.83736 .28804 L
.83801 .28792 L
.84043 .28731 L
.84271 .28656 L
.84697 .28493 L
.84935 .28401 L
.8519 .28311 L
.85427 .28242 L
.85543 .28214 L
.85651 .28193 L
.85768 .28176 L
.85895 .28163 L
Mistroke
.86003 .28159 L
.86117 .2816 L
.86243 .2817 L
.8636 .28186 L
.8649 .28212 L
.86629 .28251 L
.86891 .28352 L
.87167 .28497 L
.87661 .28847 L
.89509 .30634 L
.90001 .31039 L
.90465 .31327 L
.90721 .31439 L
.90866 .31486 L
.90999 .31519 L
.91112 .3154 L
.91235 .31554 L
.91364 .31561 L
.91485 .31558 L
.91599 .31549 L
.91723 .31532 L
.9184 .31509 L
.91948 .31482 L
.92153 .31417 L
.92371 .31329 L
.93322 .30812 L
.93825 .30518 L
.94355 .30252 L
.94632 .30146 L
.94779 .30101 L
.94936 .30063 L
.9501 .30048 L
.95081 .30037 L
.95212 .30021 L
.95336 .30013 L
.95405 .30011 L
.9547 .30012 L
.95586 .30017 L
.9571 .3003 L
.95828 .30049 L
.95936 .30071 L
.96199 .30146 L
.9645 .30241 L
.96946 .3049 L
.97489 .30819 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00[ooonfX5o`0006Wooo]Z1Ol0002?oookJPGo0000R_oonfX00:gooo]Z2Ol0001WoookJPGo
0000SOoonfX9o`0008Sooo]Z002/oookJP[o0000IooonfX5o`0008cooo]Z2_l00028oookJP00Zooo
nfX<o`0006Kooo]Z1Ol0002;oookJPco0000QooonfX00:_ooo]Z3?l0001VoookJPGo0000RooonfX=
o`0008Kooo]Z002[oookJPGo00000_oonfX6o`0006Gooo]Z1Ol0002:oookJPKo00000_oonfX7o`00
08Gooo]Z002ZoookJPGo00001?oonfX6o`0006Cooo]Z1Ol0002:oookJPGo00001?oonfX6o`0008Go
oo]Z002YoookJPKo00001?oonfX7o`0006?ooo]Z1Ol0002:oookJPGo00001OoonfX6o`0008Cooo]Z
002YoookJPKo00001OoonfX6o`0006?ooo]Z1Ol00029oookJPGo00001ooonfX5o`0008Cooo]Z002Y
oookJPGo00001ooonfX6o`0006;ooo]Z1Ol00029oookJPGo00001ooonfX6o`0008?ooo]Z002Xoook
JPGo00002OoonfX5o`0006;ooo]Z1Ol00029oookJPGo00002?oonfX5o`0008?ooo]Z002XoookJPGo
00002OoonfX5o`0006;ooo]Z1Ol00028oookJPGo00002OoonfX6o`0008;ooo]Z002XoookJPGo0000
2_oonfX5o`00067ooo]Z1Ol00028oookJPGo00002_oonfX5o`0008;ooo]Z002WoookJPGo00002ooo
nfX5o`00067ooo]Z1Ol00027oookJPKo00002_oonfX6o`00087ooo]Z002WoookJPGo00002ooonfX6
o`00063ooo]Z1Ol00027oookJPGo00003?oonfX5o`00087ooo]Z002WoookJPGo00003?oonfX5o`00
063ooo]Z1Ol00027oookJPGo00003?oonfX5o`00087ooo]Z002VoookJPGo00003OoonfX5o`00063o
oo]Z1Ol00026oookJPGo00003_oonfX5o`00083ooo]Z002VoookJPGo00003_oonfX5o`0005oooo]Z
1Ol00026oookJPGo00003_oonfX5o`00083ooo]Z002VoookJPGo00003_oonfX5o`0005oooo]Z1Ol0
0026oookJPGo00003_oonfX5o`00083ooo]Z002UoookJPGo00003ooonfX6o`00043ooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol00026oookJPCo00004?oonfX5o`0007oooo]Z002Uoook
JPGo00004?oonfX5o`0003oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol00026oook
JPCo00004?oonfX5o`0007oooo]Z002UoookJPGo00004?oonfX5o`0003oooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9
oookJPGo0000QOoonfX5o`00013ooo]Z1Ol0001ooookJP00YOoonfX4o`0001;ooo]Z1Ol0000aoook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol00025oook
JPGo00004OoonfX5o`0007kooo]Z002ToookJPGo00004_oonfX5o`00037ooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000Q?oonfX5o`00017ooo]Z1Ol0001noookJP00
Y?oonfX5o`0001;ooo]Z1_l0000loookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000
QOoonfX4o`0001;ooo]Z1Ol0001noookJP00Y?oonfX5o`0001?ooo]Z1Ol0000loookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0008Cooo]Z1Ol0000CoookJPGo0000OOoo
nfX00:Cooo]Z1?l0000DoookJPGo0000??oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5
o`0008Cooo]Z1Ol0000CoookJPGo0000OOoonfX00:Cooo]Z1?l0000EoookJPGo0000>ooonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0008Cooo]Z1Ol0000CoookJPKo0000O?oonfX00:?o
oo]Z1Ol0000EoookJPGo0000>ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0008?o
oo]Z1Ol0000EoookJPGo0000O?oonfX00:?ooo]Z1Ol0000EoookJPKo0000>ooonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000PooonfX5o`0001Gooo]Z1Ol0001loookJP00
XooonfX5o`0001Kooo]Z1Ol0000koookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol00023oookJPGo0000
5_oonfX5o`0007_ooo]Z002SoookJPCo00005ooonfX5o`0003cooo]Z1Ol007l:oookJPOo001o2?oo
nfX5o`0008?ooo]Z1?l0000GoookJPGo0000NooonfX00:?ooo]Z1?l0000HoookJPGo0000FOoonfX5
o`0008;ooo]Z1Ol0000GoookJPKo0000N_oonfX00:;ooo]Z1Ol0000HoookJPGo0000FOoonfX5o`00
08;ooo]Z1Ol0000HoookJPGo0000N_oonfX00:;ooo]Z1Ol0000HoookJPKo0000F?oonfX5o`0008;o
oo]Z1Ol0000HoookJPKo0000NOoonfX00:;ooo]Z1Ol0000IoookJPGo0000F?oonfX5o`0008;ooo]Z
1?l0000JoookJPGo0000NOoonfX00:;ooo]Z1?l0000JoookJPGo0000F?oonfX5o`0008;ooo]Z1?l0
000JoookJPGo0000NOoonfX00:;ooo]Z1?l0000KoookJPGo0000EooonfX5o`00087ooo]Z1Ol0000K
oookJPGo0000N?oonfX00:7ooo]Z1Ol0000KoookJPGo0000EooonfX5o`00087ooo]Z1Ol0000Koook
JPGo0000N?oonfX00:7ooo]Z1Ol0000KoookJPGo0000EooonfX5o`00087ooo]Z1Ol0000KoookJPKo
0000MooonfX00:7ooo]Z1Ol0000LoookJPGo0000E_oonfX5o`00087ooo]Z1?l0000MoookJPKo0000
M_oonfX00:7ooo]Z1?l0000MoookJPGo0000E_oonfX5o`00087ooo]Z1?l0000MoookJPKo0000M_oo
nfX00:3ooo]Z1Ol0000MoookJPKo0000EOoonfX5o`00083ooo]Z1Ol0000NoookJPKo0000MOoonfX0
0:3ooo]Z1Ol0000NoookJPGo0000EOoonfX5o`00083ooo]Z1Ol0000OoookJPGo0000MOoonfX002;o
oo]Z0ol007meoookJPGo001o00?ooo]Zo`000?l000000ol000001?l007oooo]ZoookJ_oonfX5o`00
OaGooo]Z1_l0001DoookJPGo0000M?oonfX5o`00O`Cooo]Z0ol007l5o`0000?o001o7?oonfX6o`00
05Cooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z1ol007l4o`0000;o001o0_oonfX7o`00OaGo
oo]Z1Ol0001DoookJPGo0000LooonfX7o`00O`?ooo]Z0ol007l4o`0000Go001o7?oonfX5o`0005Co
oo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l01?oonf[o001oo`00Ool007l4o`0000;o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lEoookJPKo0000DooonfX5o`00
07?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1?l000000ol007oooo]Zo`00O`02
o`00Oacooo]Z1Ol0001DoookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00
O`;ooo]Z0ol007l3oookJP03o`00Ool0003o000000?o00000ooonfX3o`00O`?ooo]Z0ol007lEoook
JPKo0000D_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o1OoonfX4o`0000?ooo]Z0ol007lLoook
JPGo0000DooonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o
001o0ooonfX00ol007oo0000o`000003o`0000Wooo]Z0ol007lEoookJPOo0000DOoonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o1?oonfX5o`0000?ooo]Z0ol007lLoookJPKo0000D_oonfX3o`00Oago
oo]Z000RoookJP?o001oLooonfX3o`00O`?ooo]Z00?o001oo`000?l000000ol00009oookJP?o001o
5_oonfX7o`0000oooo]Z2Ol0000hoookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l4oookJPGo0000
0ooonfX3o`00Oacooo]Z1ol0000?oookJPWo0000>OoonfX3o`00Oagooo]Z000RoookJP?o001oLooo
nfX3o`00O`?ooo]Z00?o001oo`000?l000000_l00005oookJP;o001o0_oonfX4o`00OaOooo]Z1ol0
000;oookJPko0000=_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o1?oonfX5o`0000;ooo]Z1?l0
07lMoookJPOo00002_oonfX?o`0003Oooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l3
oookJPGo00001OoonfX7o`00OaWooo]Z1ol00007oookJQ?o0000=?oonfX5o`0007;ooo]Z0ol007l3
oookJP?o001o1?oonfX4o`0000Ko001o7ooonfX8o`0000Kooo]Z4ol0000eoookJP?o001o7OoonfX0
02;ooo]Z0ol007mcoookJP?o001o0ooonfX5o`0000Gooo]Z1_l007lKoookJPSo00000_oonfXGo`00
03?ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`Cooo]Z1?l00005o`00Ob7ooo]Z2?l00002oook
JQOo0000=?oonfX3o`00Oagooo]Z000OoookJPKo001oLooonfX3o`00O`?ooo]Z1Ol00005oookJP;o
001o8?oonfXEo`0000;ooo]Z2_l0000boookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l4oookJPCo
000000?o001ooookJ_oonfX09?oonfXEo`0000?ooo]Z2Ol0000`oookJPKo001o7OoonfX001oooo]Z
1_l007mdoookJP?o001o00?ooo]Zo`00Ool000000ol00006oookJP;o001o8OoonfXAo`0000Sooo]Z
2?l0000aoookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`Cooo]Z1Ol000000ol007oo
oo]ZoookJP0UoookJQ3o00002OoonfX8o`0002oooo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z
1Ol007l4o`0000Oooo]Z1ol007lLoookJPgo00003OoonfX7o`00033ooo]Z1Ol0001coookJPOo001o
1?oonfX5o`0000Oo001o8ooonfX<o`0000gooo]Z1ol0000`oookJPCo001o7OoonfX002;ooo]Z0ol0
07meoookJP?o001o1Ol00007oookJPOo001o7_oonfX8o`00017ooo]Z1ol0000_oookJPGo0000M?oo
nfX5o`00O`Gooo]Z1Ol00007o`00ObCooo]Z2?l0000AoookJPOo0000<?oonfX3o`00Oagooo]Z002M
oookJPGo0000A_oonfX7o`0002kooo]Z1Ol0001noookJPCo0000A_oonfX7o`0004oooo]Z002Moook
JPGo0000AooonfX7o`0002gooo]Z1Ol0001noookJPCo0000AooonfX7o`0004kooo]Z002MoookJPCo
0000BOoonfX7o`0001kooo]Z2Ol00005oookJPGo0000OOoonfX5o`0004Sooo]Z1ol0000NoookJPSo
00009ooonfX003cooo]Z1Ol0001LoookJPCo0000B_oonfX7o`0001Wooo]Z4?l00002oookJPGo0000
7?oonfX5o`0005cooo]Z1Ol00019oookJPOo00006_oonfX?o`0002?ooo]Z000hoookJPco0000F?oo
nfX5o`0004_ooo]Z2?l0000EoookJQWo00006OoonfX<o`0005Sooo]Z1Ol0001:oookJPOo00005ooo
nfXBo`0002;ooo]Z000goookJQ3o0000EOoonfX5o`0004cooo]Z2?l0000CoookJQ[o00005_oonfX@
o`0005Oooo]Z1?l0001<oookJPOo00005?oonfXFo`00023ooo]Z000>oookJ_oo0000ool0000Uo`00
00oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z
000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000Loook
JPco00000_oonfX<o`00017ooo]Z1ol0001=oookJPGo0000EOoonfXBo`0001Kooo]Z3Ol00003oook
JP_o00004?oonfX8o`0004kooo]Z1?l0001DoookJQCo00005ooonfX00ol0003ooo]ZoookJP0Loook
JP007OoonfXGo`0001Cooo]Z1ol0001<oookJPCo0000EooonfX@o`0001Oooo]Z6Ol0000CoookJPSo
0000C?oonfX5o`0005Kooo]Z3ol0000ioookJP008?oonfXBo`0001Oooo]Z1ol0001;oookJPCo0000
F?oonfX<o`0001[ooo]Z6?l0000EoookJPSo0000BooonfX5o`0005Sooo]Z2ol0000koookJP008Ooo
nfX>o`0001_ooo]Z1ol00019oookJPGo0000FooonfX6o`0001gooo]Z1Ol00002oookJPoo00006Ooo
nfX7o`0004[ooo]Z1Ol0001JoookJPKo0000?_oonfX002Cooo]Z2Ol0000NoookJPOo0000B?oonfX5
o`0007kooo]Z1Ol00004oookJP[o00007OoonfX7o`0004Wooo]Z1?l0002OoookJP00C?oonfX7o`00
04Oooo]Z1Ol0001noookJPGo0000;?oonfX6o`0004Wooo]Z1?l0002OoookJP00COoonfX6o`0004Oo
oo]Z1?l0001ooookJPGo0000;OoonfX6o`0004Oooo]Z1Ol0002OoookJP00C_oonfX6o`0001;ooo]Z
2?l0000/oookJPCo0000OooonfX5o`0002kooo]Z1ol0000AoookJPOo0000;OoonfX5o`0009oooo]Z
001?oookJPOo00003?oonfX>o`0002Wooo]Z1Ol0001ooookJPGo0000;_oonfX8o`0000cooo]Z3_l0
000ZoookJPGo0000WooonfX004oooo]Z2?l0000:oookJQ3o0000:?oonfX5o`0007oooo]Z1Ol0000_
oookJPWo00002OoonfX@o`0002Wooo]Z1?l0002PoookJP00D?oonfX;o`0000;ooo]Z5Ol0000Woook
JPGo0000OooonfX5o`00033ooo]Z2ol00002oookJQGo0000:?oonfX4o`000:3ooo]Z001AoookJQSo
00000_oonfX8o`0002Kooo]Z1?l00020oookJPGo0000<_oonfXQo`0002Kooo]Z1Ol0002PoookJP00
DooonfXBo`0000Sooo]Z1_l0000VoookJPCo0000P?oonfX5o`0003?ooo]Z4_l00008oookJPOo0000
9OoonfX5o`000:3ooo]Z001DoookJQ3o00002_oonfX6o`0002Cooo]Z1Ol00020oookJPGo0000=Ooo
nfX?o`0000[ooo]Z1_l0000UoookJPGo0000X?oonfX005Oooo]Z2Ol0000?oookJPGo00009?oonfX5
o`00083ooo]Z1Ol0000goookJP[o00003_oonfX6o`0002Cooo]Z1?l0002QoookJP00KooonfX6o`00
02?ooo]Z1Ol00020oookJPGo0000D?oonfX5o`0002Cooo]Z1?l0002QoookJP00L?oonfX6o`0002;o
oo]Z1?l00021oookJPGo0000D?oonfX6o`0002;ooo]Z1Ol0002QoookJP00L?oonfX7o`00027ooo]Z
1?l00021oookJPGo0000DOoonfX5o`0002;ooo]Z1Ol0002QoookJP00LOoonfX6o`00023ooo]Z1Ol0
0021oookJPGo0000DOoonfX6o`00027ooo]Z1Ol0002QoookJP00L_oonfX6o`0001oooo]Z1Ol00021
oookJPGo0000D_oonfX5o`00027ooo]Z1?l0002RoookJP00LooonfX5o`0001oooo]Z1Ol00021oook
JPGo0000D_oonfX6o`00023ooo]Z1?l0002RoookJP00LooonfX5o`0001oooo]Z1?l00022oookJPGo
0000DooonfX5o`0001oooo]Z1Ol0002RoookJP00M?oonfX5o`0001kooo]Z1?l00022oookJPGo0000
DooonfX5o`0001oooo]Z1Ol0002RoookJP00M?oonfX5o`0001gooo]Z1Ol00022oookJPGo0000E?oo
nfX5o`0001kooo]Z1Ol0002RoookJP00M?oonfX6o`0001cooo]Z1Ol00022oookJPGo0000E?oonfX5
o`0001kooo]Z1?l0002SoookJP00MOoonfX5o`0001cooo]Z1Ol00022oookJPGo0000E?oonfX6o`00
01gooo]Z1?l0002SoookJP00MOoonfX6o`0001_ooo]Z1?l00023oookJPGo0000EOoonfX5o`0001co
oo]Z1Ol0002SoookJP00M_oonfX5o`0001_ooo]Z1?l00023oookJPGo0000EOoonfX6o`0001_ooo]Z
1Ol0002SoookJP00M_oonfX5o`0001[ooo]Z1Ol00023oookJPGo0000E_oonfX5o`0001_ooo]Z1Ol0
002SoookJP00MooonfX5o`0001Wooo]Z1Ol00023oookJPGo0000E_oonfX6o`0001[ooo]Z1?l0002T
oookJP00MooonfX5o`0001Wooo]Z1Ol00023oookJPGo0000EooonfX5o`0001Wooo]Z1Ol0002Toook
JP00MooonfX6o`0001Sooo]Z1?l00024oookJPGo0000EooonfX5o`0001Wooo]Z1Ol0002ToookJP00
N?oonfX5o`0001Oooo]Z1Ol00024oookJPGo0000F?oonfX5o`0001Sooo]Z1Ol0002ToookJP00N?oo
nfX6o`0001Kooo]Z1Ol00024oookJPGo0000F?oonfX5o`0001Sooo]Z1?l0002UoookJP00NOoonfX5
o`0001Kooo]Z1Ol00024oookJPGo0000F?oonfX6o`0001Oooo]Z1?l0002UoookJP00NOoonfX5o`00
01Kooo]Z1?l0001WoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000FOoonfX5o`00
01Kooo]Z1Ol0002UoookJP00N_oonfX5o`0001Gooo]Z1?l0001VoookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l9oookJPGo0000FOoonfX6o`0001Gooo]Z1Ol0002UoookJP00N_oonfX5o`0001Cooo]Z
1Ol0001VoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o
001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005[ooo]Z1Ol0000EoookJPGo0000YOoonfX007[o
oo]Z1_l0000CoookJPGo0000IOoonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`So
oo]Z1Ol0001JoookJPGo00005?oonfX5o`000:Kooo]Z001koookJPGo00004ooonfX5o`0006Gooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001JoookJPGo00004ooonfX5o`000:Kooo]Z
001koookJPKo00004_oonfX4o`0006Kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0
001KoookJPGo00004ooonfX5o`000:Kooo]Z001loookJPGo00004_oonfX4o`0006Kooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000FooonfX6o`00017ooo]Z1Ol0002W
oookJP00O?oonfX5o`00017ooo]Z1Ol0001VoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oook
JPGo0000G?oonfX5o`00017ooo]Z1Ol0002WoookJP00OOoonfX5o`00013ooo]Z1Ol0001VoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000G?oonfX6o`00013ooo]Z1Ol0002WoookJP00
OOoonfX5o`00013ooo]Z1Ol0001VoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000
GOoonfX5o`0000oooo]Z1Ol0002XoookJP00OOoonfX6o`0000oooo]Z1?l0001XoookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001MoookJPKo00003_oonfX5o`000:Sooo]Z
001noookJPGo00003_oonfX5o`0006Sooo]Z1ol007l9oookJPOo001o2?oonfX5o`0005kooo]Z1Ol0
000>oookJPGo0000Z?oonfX007kooo]Z1Ol0000>oookJPGo0000JOoonfX5o`00O`[ooo]Z1ol007l8
oookJPGo0000G_oonfX6o`0000gooo]Z1?l0002YoookJP00OooonfX5o`0000gooo]Z1Ol00027oook
JPGo0000GooonfX5o`0000cooo]Z1Ol0002YoookJP00OooonfX5o`0000gooo]Z1?l00028oookJPGo
0000GooonfX5o`0000cooo]Z1Ol0002YoookJP00OooonfX6o`0000_ooo]Z1Ol00028oookJPGo0000
H?oonfX5o`0000_ooo]Z1Ol0002YoookJP00P?oonfX5o`0000_ooo]Z1Ol00028oookJPGo0000H?oo
nfX5o`0000_ooo]Z1?l0002ZoookJP00P?oonfX5o`0000_ooo]Z1Ol00028oookJPGo0000H?oonfX6
o`0000Wooo]Z1Ol0002ZoookJP00POoonfX5o`0000Wooo]Z1Ol00029oookJPGo0000HOoonfX5o`00
00Wooo]Z1Ol0002ZoookJP00POoonfX5o`0000Sooo]Z1_l00029oookJPGo0000HOoonfX6o`0000Oo
oo]Z1_l0002ZoookJP00POoonfX6o`0000Oooo]Z1_l00029oookJPGo0000H_oonfX5o`0000Kooo]Z
1_l0002[oookJP00P_oonfX6o`0000Gooo]Z1_l0002:oookJPGo0000H_oonfX6o`0000Gooo]Z1_l0
002[oookJP00P_oonfX7o`0000Cooo]Z1Ol0002;oookJPGo0000HooonfX6o`0000?ooo]Z1_l0002/
oookJP00PooonfX7o`0000;ooo]Z1_l0002;oookJPGo0000HooonfX7o`0000;ooo]Z1Ol0002]oook
JP00Q?oonfX=o`0008cooo]Z1Ol0001ToookJPgo0000[OoonfX008Gooo]Z3?l0002<oookJPGo0000
I?oonfX<o`000:kooo]Z0026oookJP[o0000SOoonfX5o`0006Kooo]Z2_l0002^oookJP00Q_oonfX9
o`0008kooo]Z1Ol0001VoookJPWo0000[ooonfX008Sooo]Z1Ol0002@oookJPGo0000J?oonfX5o`00
0;7ooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z
0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX6o`000?oooo]Z7_oo
nfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oook
JPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooo
nfXOoookJP00oooonfX>oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00
O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXN
oookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;o
oo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l0
07l:oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXO
oookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00oooonfX1oookJPCo
001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o
2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000
oooonfXOoookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4
o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oookJPKo0000oooonfXNoook
JP00oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3
oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oo
oo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z
003ooookJPoooo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02846 .30612 L
.03279 .30383 L
.03527 .30282 L
.03645 .30244 L
.03754 .30215 L
.03879 .30189 L
.03945 .30179 L
.04015 .3017 L
.04132 .30163 L
.04262 .30163 L
.04394 .30173 L
.04519 .30192 L
.04632 .30216 L
.04755 .3025 L
.0503 .30354 L
.05285 .30481 L
.06244 .31113 L
.06795 .31478 L
.07065 .31629 L
.07314 .31741 L
.07541 .31818 L
.07655 .31847 L
.0778 .31871 L
.07906 .31887 L
.07976 .31891 L
.08041 .31893 L
.08166 .31891 L
.08284 .31881 L
.08409 .31862 L
.0848 .31848 L
.08546 .31833 L
.08825 .31746 L
.09066 .31647 L
.09325 .31522 L
.09912 .31211 L
.10198 .31069 L
.10458 .3096 L
.10572 .30921 L
.10696 .30885 L
.10813 .30858 L
.10921 .3084 L
.11035 .30829 L
.11161 .30826 L
.11292 .30835 L
.11415 .30854 L
.1148 .30868 L
.1155 .30887 L
.11679 .30931 L
.1192 .31046 L
Mistroke
.12201 .31234 L
.12462 .31454 L
.13549 .32713 L
.14082 .33383 L
.14572 .33924 L
.14821 .34151 L
.15053 .34326 L
.15295 .34468 L
.15423 .34526 L
.1556 .34574 L
.15627 .34592 L
.15698 .34608 L
.15776 .34621 L
.15848 .34629 L
.15977 .34635 L
.1605 .34634 L
.16119 .3463 L
.16247 .34614 L
.16364 .34592 L
.16493 .3456 L
.16628 .3452 L
.17059 .34361 L
.17295 .34271 L
.17518 .34197 L
.17645 .34163 L
.17712 .34148 L
.17782 .34135 L
.17907 .3412 L
.18022 .34116 L
.18137 .34123 L
.18245 .34141 L
.18363 .34173 L
.1849 .34224 L
.18612 .34289 L
.18746 .34383 L
.19018 .34641 L
.19269 .34968 L
.19506 .35354 L
.20038 .36483 L
.20612 .38035 L
.21572 .40899 L
.2208 .42205 L
.22364 .42774 L
.22499 .42991 L
.22623 .43156 L
.22747 .43287 L
.22879 .43385 L
.23011 .43438 L
.23086 .43449 L
.23156 .43444 L
Mistroke
.23283 .43401 L
.23399 .43321 L
.23463 .43261 L
.23532 .43181 L
.2366 .42998 L
.23902 .42516 L
.2416 .41809 L
.24625 .40056 L
.25195 .37167 L
.25731 .33907 L
.26734 .27362 L
.27239 .24338 L
.27711 .21949 L
.28203 .2005 L
.28464 .19324 L
.28609 .19007 L
.28743 .18771 L
.28859 .1861 L
.28981 .18483 L
.29104 .18399 L
.29174 .18371 L
.2924 .18357 L
.29358 .18362 L
.29466 .18399 L
.29585 .18475 L
.2971 .18592 L
.29928 .18882 L
.30131 .1924 L
.30591 .20307 L
.31502 .22972 L
.32466 .25611 L
.32969 .26613 L
.33256 .27033 L
.33393 .27195 L
.33523 .27326 L
.33641 .27425 L
.33769 .27514 L
.33885 .27577 L
.33993 .27622 L
.34121 .2766 L
.34237 .27679 L
.34302 .27685 L
.34371 .27687 L
.34497 .27681 L
.34562 .27674 L
.34631 .27663 L
.34756 .27636 L
.35039 .27549 L
.35611 .27332 L
.35743 .27287 L
Mistroke
.35886 .27244 L
.36012 .27213 L
.36081 .27199 L
.36146 .27188 L
.36267 .27173 L
.36331 .27169 L
.364 .27168 L
.36522 .27173 L
.36634 .27187 L
.36757 .27212 L
.3689 .27252 L
.37014 .27301 L
.37127 .27356 L
.37405 .27531 L
.37667 .27745 L
.38649 .28857 L
.39625 .30053 L
.40116 .3052 L
.40395 .30718 L
.4052 .30789 L
.40656 .30853 L
.4078 .309 L
.40895 .30934 L
.41005 .30957 L
.41122 .30972 L
.41226 .30977 L
.41324 .30975 L
.41432 .30967 L
.41547 .30949 L
.41663 .30924 L
.4179 .30889 L
.42046 .30795 L
.42503 .30575 L
.43031 .30294 L
.43291 .30167 L
.4353 .30067 L
.43747 .29994 L
.43857 .29965 L
.43978 .2994 L
.44098 .29922 L
.44228 .29912 L
.44351 .2991 L
.44463 .29916 L
.44592 .29931 L
.44664 .29943 L
.4473 .29957 L
.44977 .30029 L
.45116 .30082 L
.45266 .3015 L
.45538 .30296 L
Mistroke
.46558 .30986 L
.47018 .31279 L
.47271 .31413 L
.4751 .31514 L
.47646 .31559 L
.47793 .31598 L
.47858 .31611 L
.47927 .31623 L
.48051 .31637 L
.48174 .31642 L
.4829 .31639 L
.48418 .31627 L
.48489 .31617 L
.48555 .31605 L
.48678 .31576 L
.48809 .31537 L
.49046 .31446 L
.49582 .31163 L
.50144 .3081 L
.50662 .30501 L
.5092 .30373 L
.51161 .30277 L
.51292 .30236 L
.51412 .30206 L
.51476 .30193 L
.51545 .30181 L
.51619 .30172 L
.51688 .30166 L
.51757 .30162 L
.51821 .30162 L
.51892 .30163 L
.51968 .30168 L
.52044 .30177 L
.52123 .30189 L
.52265 .30219 L
.52397 .30257 L
.52521 .30301 L
.528 .30426 L
.53767 .31045 L
.54276 .31393 L
.54816 .31691 L
.55076 .31793 L
.55224 .31835 L
.55294 .31852 L
.55362 .31865 L
.55489 .31883 L
.55605 .31892 L
.5573 .31893 L
.558 .3189 L
.55866 .31885 L
Mistroke
.55996 .31868 L
.56118 .31844 L
.56228 .31816 L
.56346 .3178 L
.56858 .31565 L
.57322 .31322 L
.57819 .31068 L
.5806 .30967 L
.58179 .30925 L
.58288 .30892 L
.58386 .30868 L
.58493 .30847 L
.58601 .30833 L
.58716 .30827 L
.58839 .30829 L
.58952 .3084 L
.59076 .30863 L
.59206 .30899 L
.5932 .3094 L
.59426 .30987 L
.59667 .31125 L
.59931 .31322 L
.60171 .31541 L
.6071 .32137 L
.61807 .33508 L
.62288 .34017 L
.62543 .34234 L
.62817 .34417 L
.62946 .34484 L
.63069 .34536 L
.63179 .34574 L
.63299 .34604 L
.63412 .34623 L
.63533 .34634 L
.63646 .34635 L
.63749 .34629 L
.63877 .34612 L
.63994 .34589 L
.64122 .34557 L
.64258 .34516 L
.64736 .34338 L
.64984 .34246 L
.65121 .34202 L
.6525 .34166 L
.6537 .3414 L
.655 .34122 L
.65619 .34116 L
.65728 .3412 L
.65858 .34139 L
.6598 .34172 L
Mistroke
.66049 .34197 L
.66113 .34225 L
.66256 .34305 L
.66393 .34405 L
.66543 .34541 L
.66816 .34866 L
.67071 .35259 L
.67347 .35782 L
.67847 .36964 L
.68782 .39691 L
.69312 .41237 L
.69602 .41981 L
.69873 .42571 L
.70104 .4297 L
.70223 .43133 L
.70352 .43274 L
.70425 .43336 L
.70493 .43382 L
.70558 .43415 L
.70627 .43438 L
.70746 .43447 L
.70878 .43412 L
.70999 .43337 L
.71112 .43227 L
.71236 .43064 L
.71369 .42839 L
.7164 .42215 L
.71886 .41459 L
.72362 .39519 L
.72811 .37182 L
.73823 .3081 L
.74377 .27208 L
.74896 .24131 L
.75393 .21669 L
.75848 .1997 L
.76107 .19267 L
.76353 .18786 L
.76487 .18598 L
.76612 .18473 L
.76684 .18421 L
.76749 .18387 L
.76825 .18363 L
.76895 .18355 L
.77003 .18368 L
.7712 .18418 L
.77243 .18508 L
.77357 .18624 L
.77562 .18907 L
.77782 .19304 L
.78283 .20502 L
Mistroke
.7874 .21819 L
.79667 .24556 L
.80174 .25812 L
.80651 .26713 L
.80898 .27062 L
.81164 .27345 L
.81308 .27461 L
.81459 .27554 L
.81588 .27613 L
.81662 .27639 L
.8173 .27657 L
.8186 .2768 L
.81983 .27687 L
.82093 .27683 L
.82212 .27669 L
.82343 .27644 L
.8248 .27607 L
.82727 .27524 L
.83212 .27339 L
.83451 .27259 L
.83567 .27228 L
.83672 .27204 L
.83795 .27183 L
.83926 .27171 L
.83995 .27168 L
.84069 .27169 L
.84139 .27173 L
.84203 .27179 L
.84315 .27198 L
.84438 .27229 L
.84567 .27274 L
.84687 .27326 L
.84925 .27462 L
.8515 .27629 L
.85572 .28027 L
.86519 .29178 L
.87019 .29799 L
.87488 .30302 L
.87744 .30527 L
.87977 .30695 L
.88237 .30837 L
.8838 .30894 L
.8845 .30916 L
.88516 .30934 L
.88632 .30958 L
.88737 .30971 L
.8885 .30977 L
.88973 .30974 L
.89081 .30963 L
.89194 .30944 L
Mistroke
.89291 .30922 L
.89397 .30892 L
.89638 .30806 L
.89895 .3069 L
.9036 .30448 L
.90853 .30193 L
.91123 .30077 L
.91377 .29991 L
.91508 .29958 L
.91576 .29944 L
.9165 .29932 L
.91727 .29921 L
.91807 .29914 L
.91882 .29911 L
.91952 .2991 L
.92021 .29912 L
.92086 .29916 L
.92209 .2993 L
.92341 .29955 L
.92483 .29992 L
.92726 .30078 L
.92992 .30204 L
.9353 .30534 L
.94025 .3088 L
.94495 .31195 L
.94872 .31404 L
.95085 .31497 L
.95282 .31565 L
.95376 .3159 L
.95465 .31609 L
.95545 .31622 L
.9563 .31633 L
.95724 .3164 L
.95824 .31642 L
.95908 .31639 L
.96001 .31631 L
.9611 .31616 L
.96213 .31596 L
.96406 .31544 L
.96613 .31468 L
.96838 .31364 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00[?oonfX6o`0006_ooo]Z1Ol0002<oookJPKo0000S?oonfX00:[ooo]Z
2Ol0001ZoookJPGo0000RooonfX8o`0008_ooo]Z002ZoookJPWo0000J_oonfX5o`0008[ooo]Z2Ol0
002;oookJP00Z_oonfX:o`0006Wooo]Z1Ol0002:oookJP[o0000R_oonfX00:Wooo]Z2ol0001Yoook
JPGo0000ROoonfX<o`0008Wooo]Z002XoookJPKo000000?ooo]Zo`000?l000001?l0001XoookJPGo
0000R?oonfX6o`000003oookJ_l0003o000000Go0000R?oonfX00:Sooo]Z1_l00002oookJPGo0000
J?oonfX5o`0008Sooo]Z1_l00002oookJPKo0000R?oonfX00:Sooo]Z1Ol00003oookJPKo0000Iooo
nfX5o`0008Sooo]Z1Ol00004oookJPGo0000R?oonfX00:Oooo]Z1Ol00005oookJPGo0000IooonfX5
o`0008Oooo]Z1Ol00006oookJPGo0000QooonfX00:Oooo]Z1Ol00005oookJPKo0000I_oonfX5o`00
08Oooo]Z1Ol00006oookJPGo0000QooonfX00:Oooo]Z1Ol00006oookJPGo0000I_oonfX5o`0008Oo
oo]Z1Ol00006oookJPGo0000QooonfX00:Oooo]Z1?l00007oookJPKo0000IOoonfX5o`0008Oooo]Z
1?l00008oookJPGo0000Q_oonfX00:Kooo]Z1Ol00008oookJPGo0000IOoonfX5o`0008Kooo]Z1Ol0
0008oookJPGo0000Q_oonfX00:Kooo]Z1Ol00008oookJPKo0000I?oonfX5o`0008Kooo]Z1Ol00008
oookJPGo0000Q_oonfX00:Kooo]Z1Ol00009oookJPGo0000I?oonfX5o`0008Kooo]Z1Ol00009oook
JPGo0000QOoonfX00:Gooo]Z1Ol0000:oookJPGo0000I?oonfX5o`0008Kooo]Z1?l0000:oookJPGo
0000QOoonfX00:Gooo]Z1Ol0000;oookJPGo0000HooonfX5o`0008Kooo]Z1?l0000:oookJPKo0000
Q?oonfX00:Gooo]Z1Ol0000;oookJPGo0000HooonfX5o`0008Gooo]Z1Ol0000;oookJPGo0000Q?oo
nfX00:Gooo]Z1?l0000<oookJPGo0000HooonfX5o`0008Gooo]Z1Ol0000;oookJPGo0000Q?oonfX0
0:Cooo]Z1Ol0000=oookJPGo0000H_oonfX5o`0008Gooo]Z1Ol0000<oookJPGo0000PooonfX00:Co
oo]Z1Ol0000=oookJPGo0000H_oonfX5o`0008Gooo]Z1?l0000=oookJPGo0000PooonfX00:Cooo]Z
1Ol0000=oookJPGo0000H_oonfX5o`0008Cooo]Z1Ol0000=oookJPKo0000P_oonfX00:Cooo]Z1?l0
000?oookJPGo0000HOoonfX5o`0008Cooo]Z1Ol0000>oookJPGo0000P_oonfX00:Cooo]Z1?l0000?
oookJPGo0000@ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0008Cooo]Z1Ol0000>
oookJPGo0000P_oonfX00:?ooo]Z1Ol0000?oookJPGo0000@_oonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o2OoonfX5o`0008Cooo]Z1?l0000@oookJPGo0000POoonfX00:?ooo]Z1Ol0000@oookJPGo
0000@OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol00023oookJPGo00004?oonfX5o`00087ooo]Z002Soook
JPGo00004?oonfX5o`0003Cooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o2?oonfX5o`0008?ooo]Z1Ol0000@oookJPGo0000POoonfX00:?ooo]Z1?l0000AoookJPKo
0000<ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l00022oookJPGo
00004OoonfX5o`00083ooo]Z002SoookJPCo00004_oonfX5o`0003oooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Sooo]Z1Ol00023oookJPCo00004_oonfX5o`00083ooo]Z002SoookJPCo00004_oo
nfX5o`0003oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000Pooo
nfX4o`0001;ooo]Z1Ol00020oookJP00X_oonfX5o`0001?ooo]Z1Ol0000noookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l9oookJPGo0000P_oonfX5o`0001?ooo]Z1Ol0001ooookJP00X_oonfX5o`00
01?ooo]Z1Ol0000noookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000P_oonfX5o`00
01?ooo]Z1Ol0001ooookJP00X_oonfX5o`0001?ooo]Z1Ol0000noookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l>oookJPGo0000P_oonfX5o`0001?ooo]Z1Ol0001ooookJP00X_oonfX4o`0001Gooo]Z
1Ol0000noookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol00022oookJPCo
00005OoonfX5o`0007kooo]Z002RoookJPCo00005OoonfX5o`0003kooo]Z1ol007l9oookJPOo001o
2?oonfX5o`0008;ooo]Z1?l0000EoookJPGo0000O_oonfX00:;ooo]Z1?l0000EoookJPGo0000?ooo
nfX5o`00O`[ooo]Z1ol007l8oookJPGo0000POoonfX5o`0001Gooo]Z1Ol0001noookJP00XOoonfX5
o`0001Kooo]Z1Ol0001LoookJPGo0000POoonfX5o`0001Kooo]Z1Ol0001moookJP00XOoonfX5o`00
01Kooo]Z1Ol0001LoookJPGo0000POoonfX5o`0001Kooo]Z1Ol0001moookJP00XOoonfX5o`0001Ko
oo]Z1Ol0001LoookJPGo0000POoonfX4o`0001Oooo]Z1_l0001loookJP00XOoonfX4o`0001Sooo]Z
1Ol0001KoookJPGo0000POoonfX4o`0001Sooo]Z1Ol0001loookJP00XOoonfX4o`0001Sooo]Z1Ol0
001KoookJPGo0000P?oonfX5o`0001Sooo]Z1_l0001koookJP00X?oonfX5o`0001Sooo]Z1_l0001J
oookJPGo0000P?oonfX5o`0001Wooo]Z1Ol0001koookJP00X?oonfX5o`0001Wooo]Z1Ol0001Joook
JPGo0000P?oonfX5o`0001Wooo]Z1_l0001joookJP00X?oonfX5o`0001Wooo]Z1_l0001IoookJPGo
0000P?oonfX4o`0001_ooo]Z1Ol0001joookJP00X?oonfX4o`0001_ooo]Z1Ol0001IoookJPGo0000
P?oonfX4o`0001_ooo]Z1Ol0001joookJP00X?oonfX4o`0001_ooo]Z1_l0001HoookJPGo0000P?oo
nfX4o`0001cooo]Z1Ol0001ioookJP00X?oonfX4o`0001cooo]Z1Ol0001HoookJPGo0000OooonfX5
o`0001cooo]Z1Ol0001ioookJP00WooonfX5o`0001cooo]Z1_l0001GoookJPGo0000OooonfX5o`00
01cooo]Z1_l0001hoookJP008_oonfX3o`00OgGooo]Z1Ol007l5o`0000;o001o0ooonfX5o`00Oa?o
oo]Z1_l00009oookJP[o0000@ooonfX5o`0007Cooo]Z1Ol007l4oookJP;o001o1Ol00004o`00OaWo
oo]Z1_l00009oookJP[o0000A?oonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX6o`00O`Go0000
0_l007l2oookJPOo001o4_oonfX7o`0000Kooo]Z3_l00011oookJPGo0000LooonfX7o`00O`?ooo]Z
0_l007l4o`0000Ko001o6?oonfX8o`0000Gooo]Z3_l00012oookJP?o001o7OoonfX002;ooo]Z0ol0
07mdoookJP?o001o00?ooo]Zo`00Ool007l01?l00003o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o4ooonfXKo`00043ooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX2o`00O`Co00000_l007l01?oonf[o001oo`00Ool007lIoookJQco0000@?oonfX3o`00
Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o0ooonfX00ol007oo
0000o`000002o`0000Cooo]Z0ol007l3oookJP?o001o4ooonfXKo`0003oooo]Z1Ol0001boookJP?o
001o0ooonfX3o`00O`Cooo]Z1?l000001?l007oooo]ZoookJ_oonfX3o`00OaWooo]Z7?l0000ooook
JP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l3oookJP03
o`00Ool0003o000000;o00002_oonfX3o`00OaCooo]Z3ol00004oookJPOo0000?ooonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o0ooonfX5o`0000Cooo]Z0ol007lJoookJPoo00001?oonfX9o`0003ko
oo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l3oookJPGo00002_oonfX3o`00OaGooo]Z
3?l00008oookJPKo0000?_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0ooonfX5o`0000Cooo]Z
0ol007lKoookJPco00002?oonfX7o`0003kooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol0
07l3oookJPGo00001OoonfX2o`00O`;ooo]Z1?l007lHoookJPGo00003OoonfX6o`0003gooo]Z1Ol0
001boookJP?o001o0ooonfX3o`00O`?ooo]Z1Ol000000ol007oooo]ZoookJP04o`00Oakooo]Z1_l0
000=oookJPKo0000?OoonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`?ooo]Z1Ol00005
oookJPOo001o:ooonfX7o`0003cooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`?ooo]Z1?l00007
o`00Oc?ooo]Z1_l0000loookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0ooonfX4o`00
00Kooo]Z1_l007l]oookJPOo0000>ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0ooonfX4o`00
00Ko001o=?oonfX7o`0003_ooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l3oookJPCo
00001_oonfX2o`00Oc;ooo]Z1ol0000joookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l3oookJPCo
00000_l007lioookJPKo0000>?oonfX6o`00Oagooo]Z000OoookJPKo001oM?oonfX3o`00O`03oook
J_l007oo000000?o00001_oonfX2o`00Oc?ooo]Z1ol0000ioookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`Cooo]Z1?l00002o`00Oc[ooo]Z1_l0000goookJPKo001o7OoonfX0027ooo]Z
1?l007mdoookJPCo001o1Ol00007oookJPOo001o;_oonfX7o`0003Sooo]Z1Ol0001coookJPOo001o
0ooonfX5o`000003oookJ_l007oo001o00Go001o=OoonfX6o`0003Sooo]Z1?l007lMoookJP008_oo
nfX3o`00OgGooo]Z0ol007l5o`0000Oooo]Z1ol007l_oookJPOo0000=ooonfX5o`0007Cooo]Z1Ol0
07l4oookJPGo000000?ooo]Zo`00Ool007l01Ol007leoookJPOo0000>?oonfX3o`00Oagooo]Z002M
oookJPGo0000?_oonfX7o`0003Kooo]Z1Ol0001moookJPGo0000?_oonfX7o`0005Oooo]Z002Moook
JPCo0000@?oonfX7o`0003Gooo]Z1Ol0001moookJPCo0000@?oonfX7o`0005Kooo]Z002MoookJPCo
0000@OoonfX7o`0001;ooo]Z2ol0000GoookJPGo0000OOoonfX4o`00047ooo]Z1_l0000CoookJP_o
0000>?oonfX002;ooo]Z2_l0001aoookJPCo0000@_oonfX6o`0000oooo]Z4?l0000EoookJPGo0000
0_oonfX9o`0007;ooo]Z1?l00012oookJPKo00003ooonfXAo`0003Gooo]Z000OoookJPoo0000K_oo
nfX5o`0004?ooo]Z1_l0000<oookJQCo00004ooonfXDo`0006kooo]Z1?l00013oookJPOo00003?oo
nfXCo`0003Cooo]Z000MoookJQ?o0000K?oonfX5o`0004Cooo]Z1ol00007oookJQWo00004OoonfXE
o`0006cooo]Z1Ol00013oookJPSo00002OoonfXGo`0003;ooo]Z000>oookJ_oo0000ool0000Uo`00
00oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z
000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000Moook
JP03o`000?oonf[ooo]Z013ooo]Z2Ol00006oookJP[o00001_oonfX7o`0004Gooo]Z1Ol0001/oook
JQKo00003ooonfX;o`0000Gooo]Z2_l00006oookJPOo0000AOoonfX5o`0006_ooo]Z5Ol0000Noook
JP00<_oonfXFo`0000Sooo]Z1ol00014oookJPCo0000K_oonfXEo`00017ooo]Z5_l0000:oookJPKo
0000A?oonfX5o`0006cooo]Z4_l0000PoookJP00<ooonfXCo`0000cooo]Z1_l00013oookJPCo0000
KooonfX>o`000003oookJ_l0003o000000?o00004_oonfXCo`0000gooo]Z1_l00013oookJPGo0000
K_oonfX?o`00027ooo]Z000doookJPoo00003ooonfX7o`0004;ooo]Z1?l0001aoookJP[o00000ooo
nfX5o`0001Gooo]Z3ol0000>oookJPOo0000@_oonfX4o`00077ooo]Z2_l0000ToookJP00=_oonfX<
o`00017ooo]Z1_l00011oookJPGo0000O_oonfX5o`0001Oooo]Z2ol0000AoookJPKo0000@_oonfX4
o`0009oooo]Z001DoookJPKo0000@?oonfX5o`0007kooo]Z1Ol0000doookJPKo0000@OoonfX4o`00
09oooo]Z001EoookJPKo0000?ooonfX5o`0007kooo]Z1Ol0000eoookJPKo0000@?oonfX4o`0009oo
oo]Z001EoookJPOo0000?_oonfX4o`0007oooo]Z1Ol0000eoookJPOo0000?_oonfX5o`0009oooo]Z
001FoookJPOo0000?OoonfX4o`0007oooo]Z1Ol0000foookJPOo0000?OoonfX5o`0009oooo]Z001G
oookJPOo0000??oonfX4o`0007oooo]Z1Ol0000goookJPOo0000??oonfX5o`0009oooo]Z001Hoook
JPOo0000>_oonfX5o`0007oooo]Z1Ol0000hoookJPOo0000>ooonfX4o`000:3ooo]Z001IoookJPOo
0000>OoonfX5o`0007oooo]Z1Ol0000ioookJPOo0000>_oonfX4o`000:3ooo]Z001JoookJPOo0000
>?oonfX5o`0007oooo]Z1Ol0000joookJPOo0000>OoonfX4o`000:3ooo]Z001KoookJPKo00003_oo
nfX5o`0002Gooo]Z1?l00020oookJPGo0000>ooonfX7o`0000gooo]Z1Ol0000VoookJPCo0000X?oo
nfX005cooo]Z1ol00008oookJPco00008_oonfX4o`00083ooo]Z1Ol0000loookJPOo00002OoonfX;
o`0002;ooo]Z1Ol0002PoookJP00GOoonfX8o`0000Cooo]Z3ol0000QoookJPCo0000P?oonfX5o`00
03gooo]Z2?l00005oookJPko00008OoonfX5o`000:3ooo]Z001MoookJQco00008?oonfX4o`00083o
oo]Z1Ol0000noookJQ_o00008?oonfX5o`000:3ooo]Z001NoookJQ_o00007ooonfX5o`00083ooo]Z
1Ol0000ooookJQ[o00008?oonfX4o`000:7ooo]Z001PoookJPko00001_oonfX6o`0001kooo]Z1Ol0
0020oookJPGo0000@?oonfX?o`0000Gooo]Z1_l0000OoookJPCo0000XOoonfX006;ooo]Z2_l00009
oookJPKo00007OoonfX5o`00083ooo]Z1Ol00012oookJP_o00002?oonfX6o`0001kooo]Z1?l0002Q
oookJP00MOoonfX7o`0001cooo]Z1?l00021oookJPGo0000EOoonfX7o`0001gooo]Z1?l0002Qoook
JP00M_oonfX6o`0001cooo]Z1?l00021oookJPGo0000E_oonfX6o`0001cooo]Z1Ol0002QoookJP00
MooonfX6o`0001_ooo]Z1?l00021oookJPGo0000EooonfX6o`0001_ooo]Z1Ol0002QoookJP00N?oo
nfX5o`0001_ooo]Z1?l00021oookJPGo0000F?oonfX5o`0001_ooo]Z1Ol0002QoookJP00N?oonfX6
o`0001[ooo]Z1?l00021oookJPGo0000F?oonfX6o`0001[ooo]Z1?l0002RoookJP00NOoonfX5o`00
01[ooo]Z1?l00021oookJPGo0000FOoonfX5o`0001[ooo]Z1?l0002RoookJP00NOoonfX6o`0001So
oo]Z1Ol00021oookJPGo0000FOoonfX6o`0001Wooo]Z1?l0002RoookJP00N_oonfX5o`0001Sooo]Z
1Ol00021oookJPGo0000F_oonfX5o`0001Wooo]Z1?l0002RoookJP00N_oonfX6o`0001Oooo]Z1Ol0
0021oookJPGo0000F_oonfX5o`0001Sooo]Z1Ol0002RoookJP00NooonfX5o`0001Oooo]Z1?l00022
oookJPGo0000FooonfX5o`0001Oooo]Z1Ol0002RoookJP00NooonfX5o`0001Oooo]Z1?l00022oook
JPGo0000FooonfX5o`0001Oooo]Z1Ol0002RoookJP00O?oonfX5o`0001Kooo]Z1?l00022oookJPGo
0000FooonfX6o`0001Kooo]Z1?l0002SoookJP00O?oonfX5o`0001Kooo]Z1?l00022oookJPGo0000
G?oonfX5o`0001Kooo]Z1?l0002SoookJP00O?oonfX5o`0001Gooo]Z1Ol00022oookJPGo0000G?oo
nfX5o`0001Gooo]Z1Ol0002SoookJP00OOoonfX5o`0001Cooo]Z1Ol00022oookJPGo0000GOoonfX5
o`0001Cooo]Z1Ol0002SoookJP00OOoonfX5o`0001Cooo]Z1Ol0001ToookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPGo0000GOoonfX5o`0001Cooo]Z1Ol0002SoookJP00OOoonfX5o`0001Co
oo]Z1?l0001ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000GOoonfX5o`0001Co
oo]Z1?l0002ToookJP00O_oonfX5o`0001;ooo]Z1Ol0001ToookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`00
05kooo]Z1Ol0000BoookJPGo0000Y?oonfX007kooo]Z1Ol0000BoookJPGo0000HooonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001NoookJPGo00004_oonfX5o`000:Co
oo]Z001noookJPGo00004_oonfX5o`0006?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z
1_l0001MoookJPGo00004_oonfX5o`000:Cooo]Z001ooookJPGo00004OoonfX4o`0006Cooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001OoookJPGo00004OoonfX4o`000:Gooo]Z001o
oookJPGo00004?oonfX5o`0006Cooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8
oookJPGo0000GooonfX5o`00017ooo]Z1?l0002UoookJP00OooonfX5o`00013ooo]Z1Ol0001Toook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000GooonfX5o`00013ooo]Z1Ol0002Uoook
JP00P?oonfX5o`0000oooo]Z1Ol0001ToookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo
0000H?oonfX5o`0000oooo]Z1Ol0002UoookJP00P?oonfX5o`0000oooo]Z1?l0001UoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000H?oonfX5o`0000oooo]Z1Ol0002UoookJP00P?oo
nfX5o`0000kooo]Z1Ol0001VoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z
1Ol0001PoookJPGo00003ooonfX4o`000:Kooo]Z0021oookJPGo00003OoonfX5o`0006Kooo]Z1ol0
07l9oookJPOo001o2?oonfX5o`00067ooo]Z1Ol0000=oookJPGo0000Y_oonfX0087ooo]Z1Ol0000=
oookJPGo0000IooonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000HOoonfX5o`0000gooo]Z1Ol0002V
oookJP00POoonfX5o`0000gooo]Z1?l00026oookJPGo0000HOoonfX5o`0000gooo]Z1Ol0002Voook
JP00P_oonfX5o`0000_ooo]Z1Ol00026oookJPGo0000H_oonfX5o`0000cooo]Z1?l0002WoookJP00
P_oonfX5o`0000_ooo]Z1Ol00026oookJPGo0000H_oonfX5o`0000cooo]Z1?l0002WoookJP00P_oo
nfX5o`0000_ooo]Z1Ol00026oookJPGo0000H_oonfX5o`0000_ooo]Z1Ol0002WoookJP00PooonfX5
o`0000[ooo]Z1?l00027oookJPGo0000HooonfX5o`0000[ooo]Z1Ol0002WoookJP00PooonfX5o`00
00[ooo]Z1?l00027oookJPGo0000HooonfX5o`0000[ooo]Z1Ol0002WoookJP00PooonfX6o`0000So
oo]Z1Ol00027oookJPGo0000HooonfX5o`0000[ooo]Z1?l0002XoookJP00Q?oonfX5o`0000Sooo]Z
1Ol00027oookJPGo0000I?oonfX5o`0000Sooo]Z1Ol0002XoookJP00Q?oonfX5o`0000Sooo]Z1Ol0
0027oookJPGo0000I?oonfX5o`0000Sooo]Z1Ol0002XoookJP00QOoonfX5o`0000Oooo]Z1?l00028
oookJPGo0000I?oonfX5o`0000Oooo]Z1_l0002XoookJP00QOoonfX5o`0000Kooo]Z1Ol00028oook
JPGo0000IOoonfX5o`0000Kooo]Z1Ol0002YoookJP00QOoonfX6o`0000Gooo]Z1Ol00028oookJPGo
0000IOoonfX6o`0000Gooo]Z1Ol0002YoookJP00Q_oonfX5o`0000Gooo]Z1Ol00028oookJPGo0000
IOoonfX6o`0000Cooo]Z1Ol0002ZoookJP00Q_oonfX5o`0000Cooo]Z1Ol00029oookJPGo0000I_oo
nfX6o`0000?ooo]Z1Ol0002ZoookJP00QooonfX6o`000003oookJ_l0003o000000Co0000ROoonfX5
o`0006Oooo]Z1_l000000ooonf[o0000o`000004o`000:[ooo]Z0027oookJPgo0000ROoonfX5o`00
06Oooo]Z3?l0002[oookJP00QooonfX<o`0008[ooo]Z1Ol0001XoookJP_o0000ZooonfX008Sooo]Z
2_l0002;oookJPGo0000JOoonfX9o`000:cooo]Z0029oookJPWo0000RooonfX5o`0006Wooo]Z2?l0
002]oookJP00R_oonfX6o`0008gooo]Z1Ol0001ZoookJPKo0000[_oonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3
o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoook
JP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPKo0000oooonfXNoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX@oookJPCo001o2_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJP;o
oo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooo
nfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z
003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00oooonfX>oookJPCo001o3?oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7o
oo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oo
oookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJPCo
001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooo
nfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02846 .3119 L
.03068 .3131 L
.03279 .31406 L
.03398 .31451 L
.03527 .31492 L
.03645 .3152 L
.03754 .31539 L
.03871 .31552 L
.04 .31556 L
.04065 .31554 L
.04135 .31548 L
.04262 .31531 L
.04393 .31504 L
.04516 .31469 L
.04793 .31361 L
.05297 .31089 L
.05752 .30808 L
.06244 .30539 L
.06384 .30478 L
.06531 .30425 L
.06657 .30389 L
.06729 .30373 L
.06795 .30361 L
.06925 .30346 L
.06996 .30343 L
.07064 .30343 L
.07184 .3035 L
.07314 .3037 L
.0743 .30398 L
.07558 .30439 L
.07818 .30555 L
.08058 .30697 L
.08284 .30856 L
.09343 .31717 L
.096 .31898 L
.09875 .32058 L
.10034 .32129 L
.10177 .32181 L
.10247 .32201 L
.10322 .32219 L
.10393 .32232 L
.10458 .32242 L
.10574 .32251 L
.10699 .32251 L
.10817 .32242 L
.10925 .32227 L
.11051 .322 L
.11188 .32161 L
.11438 .32069 L
Mistroke
.11941 .31836 L
.12217 .31709 L
.12476 .31607 L
.12594 .3157 L
.12718 .3154 L
.12784 .31528 L
.12855 .31518 L
.1298 .31509 L
.13094 .31512 L
.13216 .31526 L
.13332 .31552 L
.13436 .31586 L
.1355 .31634 L
.13656 .3169 L
.13894 .31854 L
.14104 .32041 L
.14327 .3228 L
.15289 .33632 L
.15813 .34404 L
.16068 .34738 L
.163 .35001 L
.16501 .35193 L
.16718 .35357 L
.16837 .35428 L
.16947 .35481 L
.17052 .3552 L
.17164 .35549 L
.17276 .35567 L
.17396 .35573 L
.1751 .35568 L
.17613 .35555 L
.17735 .3553 L
.17867 .35492 L
.18107 .35405 L
.18595 .35207 L
.18713 .35168 L
.18841 .35134 L
.18914 .35119 L
.18982 .3511 L
.19114 .35104 L
.19226 .35112 L
.1933 .35134 L
.19445 .35174 L
.19567 .35237 L
.19696 .35327 L
.19818 .35437 L
.20046 .3571 L
.20298 .36119 L
.20566 .36673 L
.21047 .37952 L
Mistroke
.22133 .4153 L
.22364 .42241 L
.22616 .42926 L
.22838 .43421 L
.2296 .43641 L
.23075 .4381 L
.23144 .43892 L
.23219 .43965 L
.23349 .44046 L
.23414 .44065 L
.23482 .44069 L
.23604 .44033 L
.23723 .43943 L
.23834 .43809 L
.23957 .43605 L
.24088 .4332 L
.24323 .42633 L
.24579 .41635 L
.25045 .39201 L
.25918 .33042 L
.26939 .25205 L
.27439 .21999 L
.27897 .19766 L
.28131 .18932 L
.28378 .18291 L
.28506 .18055 L
.28625 .17895 L
.28756 .17782 L
.2883 .17748 L
.28896 .17735 L
.28965 .17738 L
.29038 .17759 L
.29168 .17844 L
.29241 .17915 L
.29309 .17997 L
.29463 .18233 L
.29721 .1877 L
.29998 .19506 L
.31012 .22836 L
.31548 .2446 L
.31841 .2519 L
.32117 .25747 L
.32381 .26155 L
.32529 .26331 L
.32665 .2646 L
.3278 .26546 L
.32906 .26616 L
.33038 .26666 L
.33161 .26692 L
.33287 .267 L
Mistroke
.33405 .26693 L
.33512 .26676 L
.33628 .26647 L
.33888 .26558 L
.34128 .26459 L
.34366 .26362 L
.34593 .26287 L
.34718 .26258 L
.34789 .26245 L
.34855 .26237 L
.34971 .2623 L
.35094 .26235 L
.35212 .26253 L
.35339 .26287 L
.35459 .26334 L
.35569 .26389 L
.35778 .26528 L
.36 .2672 L
.36508 .27317 L
.36982 .28005 L
.37499 .28786 L
.37772 .2917 L
.38062 .29533 L
.3832 .29804 L
.38457 .29925 L
.38604 .30037 L
.38739 .30121 L
.38863 .30184 L
.38982 .3023 L
.39106 .30265 L
.39225 .30286 L
.39351 .30295 L
.3947 .30291 L
.39579 .30279 L
.39706 .30254 L
.39845 .30216 L
.40096 .30124 L
.40558 .2991 L
.40813 .29791 L
.41054 .29691 L
.41279 .29617 L
.41405 .29587 L
.41523 .29566 L
.41632 .29555 L
.4173 .29551 L
.41844 .29554 L
.41951 .29565 L
.42067 .29586 L
.42188 .29618 L
.42292 .29653 L
Mistroke
.42406 .29699 L
.4266 .2983 L
.42897 .29984 L
.43938 .30825 L
.44188 .31014 L
.4446 .31191 L
.44585 .3126 L
.44717 .31322 L
.44831 .31367 L
.44954 .31406 L
.45027 .31425 L
.45094 .31438 L
.45225 .31456 L
.45294 .3146 L
.4537 .31461 L
.4545 .31458 L
.45523 .31451 L
.45655 .31429 L
.45774 .31401 L
.45912 .31357 L
.46042 .31307 L
.47016 .30756 L
.47273 .30604 L
.47549 .30461 L
.47682 .30402 L
.47809 .30353 L
.47924 .30317 L
.48046 .30286 L
.4815 .30267 L
.48265 .30253 L
.48369 .30248 L
.48467 .30249 L
.48582 .30258 L
.48688 .30274 L
.48804 .30298 L
.48926 .30333 L
.49165 .30424 L
.49387 .30532 L
.49893 .30833 L
.50396 .3115 L
.50661 .31297 L
.50943 .31424 L
.51061 .31466 L
.51188 .31503 L
.51261 .3152 L
.51328 .31532 L
.51459 .31549 L
.51575 .31556 L
.51703 .31553 L
.51823 .3154 L
Mistroke
.51935 .31521 L
.52052 .31493 L
.52178 .31454 L
.52407 .31363 L
.52834 .31137 L
.5333 .30833 L
.53572 .3069 L
.53793 .30573 L
.54013 .30475 L
.54128 .30432 L
.54252 .30396 L
.54383 .30367 L
.54504 .3035 L
.54618 .30343 L
.54744 .30345 L
.54809 .30351 L
.54879 .3036 L
.55003 .30386 L
.55072 .30404 L
.55136 .30424 L
.55282 .30481 L
.55526 .30604 L
.55787 .30772 L
.5632 .3119 L
.56883 .31656 L
.57365 .31987 L
.57496 .32058 L
.57638 .32123 L
.57771 .32173 L
.57894 .32208 L
.58025 .32234 L
.58095 .32244 L
.58168 .3225 L
.58239 .32252 L
.58305 .32252 L
.58429 .32243 L
.58552 .32225 L
.58664 .32201 L
.58788 .32167 L
.58918 .32123 L
.59493 .31869 L
.59774 .31736 L
.60029 .3163 L
.60143 .31591 L
.60268 .31556 L
.60385 .31531 L
.60493 .31516 L
.60608 .31509 L
.60735 .31513 L
.60867 .31532 L
Mistroke
.6099 .31564 L
.61055 .31586 L
.61126 .31615 L
.61255 .31679 L
.61498 .31842 L
.61781 .32099 L
.62044 .32397 L
.631 .33923 L
.63618 .34651 L
.63845 .34922 L
.64095 .35171 L
.64319 .35346 L
.64529 .35464 L
.64645 .35511 L
.6475 .35542 L
.64872 .35564 L
.64988 .35573 L
.65104 .3557 L
.65228 .35556 L
.65334 .35534 L
.65451 .35503 L
.65711 .35411 L
.65955 .3531 L
.66181 .35219 L
.66306 .35176 L
.66424 .35142 L
.6649 .35127 L
.66563 .35115 L
.66689 .35104 L
.66818 .35109 L
.66937 .35131 L
.6706 .35172 L
.67176 .3523 L
.67303 .35317 L
.67439 .35439 L
.67717 .35785 L
.67971 .3622 L
.68425 .3727 L
.6892 .38746 L
.69821 .41751 L
.70077 .4251 L
.70353 .43205 L
.7048 .43466 L
.70614 .43697 L
.70729 .43853 L
.70854 .43978 L
.70977 .4405 L
.71088 .44069 L
.71217 .44036 L
.71339 .43946 L
Mistroke
.71451 .43812 L
.71555 .43644 L
.7179 .43102 L
.71911 .42738 L
.7204 .42283 L
.72274 .41292 L
.72808 .38307 L
.73888 .3028 L
.74391 .26411 L
.74928 .22764 L
.75189 .21286 L
.75435 .20107 L
.75658 .19235 L
.75894 .18527 L
.76015 .18255 L
.76146 .18022 L
.76266 .17871 L
.76379 .17781 L
.76511 .17735 L
.76631 .1775 L
.76698 .1778 L
.76771 .1783 L
.76903 .17965 L
.77048 .18176 L
.7718 .18418 L
.77475 .1911 L
.78005 .20723 L
.78945 .23826 L
.79418 .25093 L
.79686 .25655 L
.79936 .26067 L
.80077 .26251 L
.8021 .26394 L
.80332 .26498 L
.80461 .26583 L
.80527 .26617 L
.80601 .26648 L
.8073 .26683 L
.80803 .26695 L
.80881 .267 L
.80955 .26699 L
.81022 .26693 L
.81149 .26672 L
.81267 .26642 L
.81534 .26547 L
.8202 .2635 L
.82148 .26306 L
.82284 .26269 L
.824 .26246 L
.82527 .26232 L
Mistroke
.82599 .2623 L
.82664 .26232 L
.8274 .26238 L
.82811 .26249 L
.82938 .26281 L
.8301 .26306 L
.83076 .26333 L
.83306 .26462 L
.83436 .26558 L
.83559 .26664 L
.84072 .27243 L
.8496 .2855 L
.8543 .29222 L
.85932 .29798 L
.86199 .3002 L
.86441 .30165 L
.86558 .30215 L
.86685 .30256 L
.86805 .3028 L
.86915 .30292 L
.87039 .30294 L
.87155 .30285 L
.87281 .30264 L
.87353 .30247 L
.87418 .3023 L
.87691 .30134 L
.8795 .30019 L
.88379 .29815 L
.88614 .29713 L
.88835 .29635 L
.88962 .29601 L
.89028 .29586 L
.89098 .29573 L
.89222 .29557 L
.89336 .29551 L
.89451 .29553 L
.89558 .29564 L
.89675 .29584 L
.89801 .29616 L
.89923 .29657 L
.90058 .29714 L
.90331 .29861 L
.9082 .30214 L
.91354 .30659 L
.91634 .30885 L
.91928 .31097 L
.92187 .31251 L
.92324 .31317 L
.92471 .31375 L
.92605 .31415 L
Mistroke
.92728 .31441 L
.92851 .31456 L
.92967 .31461 L
.93086 .31456 L
.93211 .31441 L
.93318 .3142 L
.93435 .31389 L
.93697 .31291 L
.93941 .31172 L
.94414 .30893 L
.94928 .30584 L
.95164 .30462 L
.95414 .30358 L
.95517 .30325 L
.95628 .30295 L
.9575 .3027 L
.95864 .30255 L
.95974 .30248 L
.96077 .30249 L
.96189 .30257 L
.9631 .30274 L
.96436 .30302 L
.96556 .30336 L
.96779 .30422 L
.97182 .3063 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00Z_oo
nfX6o`0006gooo]Z1Ol00029oookJPOo0000S_oonfX00:Wooo]Z2?l0001/oookJPGo0000ROoonfX8
o`0008gooo]Z002YoookJPWo0000JooonfX5o`0008Sooo]Z2_l0002<oookJP00Z?oonfX:o`0006_o
oo]Z1Ol00028oookJP[o0000S?oonfX00:Sooo]Z2ol0001ZoookJPGo0000QooonfX;o`0008cooo]Z
002WoookJPKo000000?ooo]Zo`000?l000000ol0001ZoookJPGo0000QooonfX5o`0000;ooo]Z1Ol0
002;oookJP00Y_oonfX6o`0000;ooo]Z1Ol0001ZoookJPGo0000QooonfX5o`0000;ooo]Z1Ol0002;
oookJP00Y_oonfX6o`0000?ooo]Z1Ol0001YoookJPGo0000Q_oonfX5o`0000?ooo]Z1_l0002:oook
JP00Y_oonfX5o`0000Cooo]Z1Ol0001YoookJPGo0000Q_oonfX5o`0000Cooo]Z1Ol0002:oookJP00
YOoonfX5o`0000Gooo]Z1_l0001XoookJPGo0000Q_oonfX5o`0000Cooo]Z1_l00029oookJP00YOoo
nfX5o`0000Kooo]Z1Ol0001XoookJPGo0000Q_oonfX4o`0000Kooo]Z1Ol00029oookJP00YOoonfX5
o`0000Kooo]Z1Ol0001XoookJPGo0000QOoonfX5o`0000Kooo]Z1Ol00029oookJP00YOoonfX4o`00
00Sooo]Z1Ol0001WoookJPGo0000QOoonfX5o`0000Oooo]Z1Ol00028oookJP00YOoonfX4o`0000So
oo]Z1Ol0001WoookJPGo0000QOoonfX5o`0000Oooo]Z1Ol00028oookJP00YOoonfX4o`0000Sooo]Z
1Ol0001WoookJPGo0000QOoonfX4o`0000Sooo]Z1Ol00028oookJP00Y?oonfX5o`0000Wooo]Z1Ol0
001VoookJPGo0000QOoonfX4o`0000Wooo]Z1Ol00027oookJP00Y?oonfX5o`0000Wooo]Z1Ol0001V
oookJPGo0000QOoonfX4o`0000Wooo]Z1Ol00027oookJP00Y?oonfX5o`0000Wooo]Z1Ol0001Voook
JPGo0000Q?oonfX5o`0000Wooo]Z1Ol00027oookJP00Y?oonfX4o`0000_ooo]Z1?l0001VoookJPGo
0000Q?oonfX5o`0000[ooo]Z1?l00027oookJP00Y?oonfX4o`0000_ooo]Z1Ol0001UoookJPGo0000
Q?oonfX5o`0000[ooo]Z1Ol00026oookJP00Y?oonfX4o`0000_ooo]Z1Ol0001UoookJPGo0000Q?oo
nfX4o`0000_ooo]Z1Ol00026oookJP00XooonfX5o`0000_ooo]Z1Ol0001UoookJPGo0000Q?oonfX4
o`0000_ooo]Z1Ol00026oookJP00XooonfX5o`0000cooo]Z1?l0001UoookJPGo0000PooonfX5o`00
00cooo]Z1Ol00025oookJP00XooonfX5o`0000cooo]Z1Ol0001ToookJPGo0000PooonfX5o`0000co
oo]Z1Ol00025oookJP00XooonfX4o`0000gooo]Z1Ol0001ToookJPGo0000PooonfX5o`0000cooo]Z
1Ol00025oookJP00XooonfX4o`0000gooo]Z1Ol0001ToookJPGo0000PooonfX4o`0000kooo]Z1Ol0
0024oookJP00XooonfX4o`0000kooo]Z1Ol00015oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:
oookJPGo0000P_oonfX5o`0000kooo]Z1Ol00024oookJP00X_oonfX5o`0000kooo]Z1Ol00014oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000P_oonfX5o`0000kooo]Z1Ol00024oook
JP00X_oonfX5o`0000kooo]Z1Ol00014oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0008;ooo]Z1Ol0000?
oookJPCo0000Q?oonfX00:;ooo]Z1Ol0000?oookJPGo0000=_oonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000P_oonfX4o`00013ooo]Z1Ol00023oook
JP00X_oonfX4o`00013ooo]Z1Ol0000foookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2?oonfX6o`00087ooo]Z1?l0000@oookJPGo0000PooonfX00:;ooo]Z1?l0000@oookJPGo0000
@_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`00087ooo]Z1Ol0000@oookJPGo0000
PooonfX00:7ooo]Z1Ol0000AoookJPGo0000@OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z1Ol00021oookJPGo00004OoonfX5o`0008;ooo]Z002QoookJPGo00004OoonfX5
o`00047ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol00021oookJPGo00004OoonfX5
o`0008;ooo]Z002QoookJPGo00004OoonfX5o`00047ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
O`[ooo]Z1Ol00021oookJPCo00004_oonfX5o`0008;ooo]Z002QoookJPCo00004ooonfX5o`00043o
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol00021oookJPCo00004ooonfX4o`0008;o
oo]Z002QoookJPCo00004ooonfX5o`00047ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o3_oonfX5o`00087ooo]Z1?l0000CoookJPGo0000POoonfX00:7ooo]Z1?l0000CoookJPGo0000
@OoonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000POoonfX4o`0001?ooo]Z1Ol00021oookJP00X?oo
nfX5o`0001Cooo]Z1Ol00011oookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol00020oookJPGo00004ooo
nfX5o`00087ooo]Z002PoookJPGo00005?oonfX5o`0005oooo]Z1Ol00020oookJPGo00005?oonfX5
o`00083ooo]Z002PoookJPGo00005?oonfX6o`0005kooo]Z1Ol00020oookJPGo00005?oonfX5o`00
083ooo]Z002PoookJPCo00005_oonfX5o`0005kooo]Z1Ol00020oookJPCo00005OoonfX5o`00083o
oo]Z002PoookJPCo00005_oonfX6o`0005gooo]Z1Ol00020oookJPCo00005_oonfX5o`0007oooo]Z
002PoookJPCo00005ooonfX5o`0005gooo]Z1Ol00020oookJPCo00005_oonfX6o`0007kooo]Z002P
oookJPCo00005ooonfX6o`0005cooo]Z1Ol00020oookJPCo00005_oonfX6o`0007kooo]Z002Ooook
JPGo00006?oonfX6o`0005_ooo]Z1Ol0001ooookJPGo00005ooonfX6o`0007gooo]Z002OoookJPGo
00006?oonfX6o`0000Kooo]Z2_l0001;oookJPGo0000OooonfX5o`0001Sooo]Z1_l00006oookJP[o
0000K?oonfX009oooo]Z1Ol0000IoookJPOo000000?ooo]Zo`000?l000003Ol00019oookJPGo0000
OooonfX5o`0001Sooo]Z1ol00002oookJPoo0000J_oonfX009oooo]Z1?l0000KoookJQOo0000B?oo
nfX5o`0007oooo]Z1?l0000JoookJQSo0000JOoonfX009oooo]Z1?l0000KoookJQOo0000B?oonfX5
o`0007oooo]Z1?l0000KoookJQSo0000J?oonfX009oooo]Z1?l0000LoookJPco00001?oonfX7o`00
04Oooo]Z1Ol0001ooookJPCo00007?oonfX<o`0000Cooo]Z2?l0001WoookJP008_oonfX3o`00OgGo
oo]Z1Ol007l4o`0000?o001o0ooonfX5o`00Oa;ooo]Z2?l00009oookJPKo0000A_oonfX5o`0007Co
oo]Z1Ol007l4oookJP03o`00Ool0003o000000?o00001Ol007lHoookJPSo00002OoonfX7o`0004Ko
oo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z1Ol007l5o`0000?o001o0_oonfX7o`00Ob;ooo]Z
1ol00015oookJPGo0000LooonfX7o`00O`?ooo]Z00?o001oo`000?l000000ol00006o`00ObWooo]Z
1_l00016oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o00?ooo]Zo`00Ool000001?l0
0003o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o8ooonfX6o`0004Gooo]Z
1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX00ol007oo0000o`000003o`0000;o
001o00Cooo]Zo`00Ool007oo001o:_oonfX6o`0004Gooo]Z0ol007lMoookJP004ooonfX:o`00O`Go
oo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`?ooo]Z1Ol00004oookJP?o001o0ooonfX3o`00Ob?o
oo]Z1_l00014oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l3oookJPCo00000_l007l3oookJP?o
001o:_oonfX5o`0004Gooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o
0_oonfX3o`00O`?ooo]Z1?l0000;oookJP?o001o9?oonfX6o`0004?ooo]Z1Ol0001boookJP?o001o
0ooonfX3o`00O`?ooo]Z1?l00005oookJP?o001o:_oonfX6o`0004Cooo]Z0ol007lMoookJP008_oo
nfX3o`00Og?ooo]Z0ol007l3oookJPCo00002ooonfX3o`00ObCooo]Z1_l00013oookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l3oookJPCo00001OoonfX3o`00Ob_ooo]Z1_l00013oookJP?o001o7Ooo
nfX002;ooo]Z0ol007mcoookJP?o001o0ooonfX4o`0000Kooo]Z0_l007l2oookJPCo001o9OoonfX6
o`0004;ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`?ooo]Z1?l00002o`00O`;ooo]Z1?l007l[
oookJPKo0000@ooonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`?ooo]Z1?l00006oook
JPOo001o9ooonfX6o`00047ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1Ol00007o`00
Obgooo]Z1_l00012oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX5o`0000Ko
oo]Z1_l007lXoookJPKo0000@OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX5o`0000Ko
001o;ooonfX5o`0004;ooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l2oookJPGo0000
1_oonfX2o`00Obgooo]Z1_l00010oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPGo0000
0_l007lcoookJPKo0000?_oonfX6o`00Oagooo]Z000OoookJPKo001oM?oonfX3o`00O`03oookJ_l0
003o000000?o00001_oonfX2o`00Obkooo]Z1_l0000ooookJPGo0000LooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z1?l000000ooonf[o001oo`00O`0doookJPKo0000?OoonfX6o`00Oagooo]Z
000QoookJPCo001oM?oonfX4o`00O`Co00002?oonfX7o`00ObSooo]Z1ol0000noookJPGo0000Looo
nfX7o`00O`?ooo]Z1?l00002oookJPOo001o;_oonfX7o`0003kooo]Z1?l007lMoookJP008_oonfX3
o`00OgGooo]Z0ol007l4o`0000Sooo]Z1ol007lYoookJPKo0000?_oonfX5o`0007Cooo]Z1Ol007l4
oookJPCo00000_oonfX7o`00Oboooo]Z1ol0000noookJP?o001o7OoonfX009gooo]Z1?l0000ioook
JPOo00002ooonfX;o`0002Kooo]Z1Ol0001moookJPCo0000>OoonfX7o`0000cooo]Z2_l00017oook
JP00WOoonfX4o`0003[ooo]Z1ol00009oookJPoo00008ooonfX5o`0007cooo]Z1Ol0000joookJPOo
00002?oonfX@o`0004Cooo]Z002LoookJPGo0000>_oonfX8o`0000Kooo]Z4_l0000RoookJPGo0000
O?oonfX5o`0003_ooo]Z1ol00005oookJQ?o0000@ooonfX009cooo]Z1Ol0000koookJPWo000000?o
oo]Zo`000?l000005?l0000HoookJPGo00001?oonfX5o`0007cooo]Z1Ol0000loookJQoo00006?oo
nfX5o`0002Gooo]Z000aoookJPWo0000H_oonfX5o`0003gooo]Z4Ol00005oookJPWo00004ooonfXB
o`00017ooo]Z2_l0001QoookJPCo0000?_oonfXBo`0000Cooo]Z2Ol0000DoookJPco00008OoonfX0
02oooo]Z3_l0001OoookJPCo0000?_oonfX@o`0000Wooo]Z1ol0000@oookJQCo00003ooonfX>o`00
05oooo]Z1?l0000ooookJPko00002_oonfX7o`00013ooo]Z4?l0000PoookJP003_oonf[oo`000?oo
00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0
000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oook
JP007?oonfXCo`0000kooo]Z2?l0000;oookJPco0000?ooonfX5o`0005kooo]Z3ol0000@oookJQCo
00003OoonfX9o`0000cooo]Z2ol0000ooookJPGo0000G_oonfX@o`00017ooo]Z00?o0000oookJ_oo
nfX07?oonfX001gooo]Z4?l0000AoookJPWo00001ooonfX?o`0003kooo]Z1?l0001PoookJPgo0000
4OoonfXBo`00013ooo]Z2Ol00007oookJQ3o0000?_oonfX4o`00067ooo]Z3?l0000boookJP008?oo
nfX<o`0001Cooo]Z2?l00004oookJQ?o0000??oonfX4o`0006;ooo]Z2Ol0000CoookJQ7o00004ooo
nfX9o`0000Cooo]Z4_l0000moookJPCo0000H_oonfX9o`0003Cooo]Z000SoookJPGo00006OoonfXO
o`0003_ooo]Z1?l0001noookJPGo00000ooonfX5o`0001Sooo]Z7ol0000loookJPCo0000WooonfX0
04;ooo]Z4Ol00006oookJPOo0000>ooonfX4o`0007kooo]Z1Ol0000RoookJQ;o00001OoonfX7o`00
03_ooo]Z1?l0002OoookJP00A?oonfX=o`0000Wooo]Z1ol0000ioookJPGo0000O_oonfX5o`0002?o
oo]Z3Ol0000:oookJPKo0000>ooonfX4o`0009oooo]Z0014oookJP_o00003OoonfX6o`0003Sooo]Z
1Ol0001noookJPGo00009?oonfX;o`0000cooo]Z1_l0000joookJPCo0000WooonfX005cooo]Z1_l0
000hoookJPGo0000O_oonfX5o`0003cooo]Z1_l0000hoookJPGo0000WooonfX005gooo]Z1_l0000g
oookJPCo0000OooonfX5o`0003cooo]Z1ol0000goookJPGo0000WooonfX005kooo]Z1Ol0000goook
JPCo0000OooonfX5o`0003gooo]Z1_l0000goookJPGo0000WooonfX005kooo]Z1_l0000foookJPCo
0000OooonfX5o`0003kooo]Z1_l0000foookJPCo0000X?oonfX005oooo]Z1_l0000eoookJPCo0000
OooonfX5o`0003oooo]Z1_l0000eoookJPCo0000X?oonfX005oooo]Z1_l0000eoookJPCo0000Oooo
nfX5o`0003oooo]Z1ol0000doookJPCo0000X?oonfX0063ooo]Z1_l0000coookJPGo0000OooonfX5
o`00043ooo]Z1_l0000doookJPCo0000X?oonfX0067ooo]Z1_l0000boookJPGo0000OooonfX5o`00
047ooo]Z1_l0000coookJPCo0000X?oonfX0067ooo]Z1ol0000aoookJPGo0000OooonfX5o`0004;o
oo]Z1_l0000aoookJPGo0000X?oonfX006;ooo]Z1_l0000aoookJPCo0000P?oonfX5o`0004;ooo]Z
1ol0000`oookJPGo0000X?oonfX006?ooo]Z1_l0000`oookJPCo0000P?oonfX5o`0004?ooo]Z1_l0
000`oookJPGo0000X?oonfX006Cooo]Z1_l0000_oookJPCo0000P?oonfX5o`0004Cooo]Z1_l0000_
oookJPCo0000XOoonfX006Cooo]Z2?l00006oookJPWo00007_oonfX4o`00083ooo]Z1Ol00015oook
JPOo00001_oonfX:o`0001gooo]Z1?l0002QoookJP00IOoonfX8o`0000?ooo]Z3Ol0000LoookJPCo
0000P?oonfX5o`0004Gooo]Z2?l00003oookJPgo00007?oonfX4o`000:7ooo]Z001VoookJQSo0000
6_oonfX5o`00083ooo]Z1Ol00016oookJQSo00006ooonfX4o`000:7ooo]Z001WoookJQSo00006Ooo
nfX5o`00083ooo]Z1Ol00017oookJQSo00006_oonfX4o`000:7ooo]Z001YoookJPco00000ooonfX7
o`0001Wooo]Z1Ol00020oookJPGo0000BOoonfX<o`0000Cooo]Z1_l0000JoookJPCo0000XOoonfX0
06Wooo]Z2_l00006oookJPOo00006?oonfX4o`00087ooo]Z1Ol0001:oookJPWo00001ooonfX6o`00
01Sooo]Z1Ol0002QoookJP00NooonfX5o`0001Sooo]Z1?l00021oookJPGo0000FooonfX5o`0001So
oo]Z1Ol0002QoookJP00NooonfX6o`0001Oooo]Z1?l00021oookJPGo0000FooonfX5o`0001Sooo]Z
1Ol0002QoookJP00O?oonfX5o`0001Oooo]Z1?l00021oookJPGo0000G?oonfX5o`0001Oooo]Z1?l0
002RoookJP00O?oonfX5o`0001Oooo]Z1?l00021oookJPGo0000G?oonfX5o`0001Oooo]Z1?l0002R
oookJP00OOoonfX5o`0001Kooo]Z1?l00021oookJPGo0000G?oonfX6o`0001Kooo]Z1?l0002Roook
JP00OOoonfX5o`0001Gooo]Z1Ol00021oookJPGo0000GOoonfX5o`0001Kooo]Z1?l0002RoookJP00
OOoonfX6o`0001Cooo]Z1Ol00021oookJPGo0000GOoonfX6o`0001Gooo]Z1?l0002RoookJP00O_oo
nfX5o`0001Cooo]Z1Ol00021oookJPGo0000G_oonfX5o`0001Gooo]Z1?l0002RoookJP00O_oonfX5
o`0001Cooo]Z1?l00022oookJPGo0000G_oonfX6o`0001?ooo]Z1Ol0002RoookJP00OooonfX5o`00
01?ooo]Z1?l00022oookJPGo0000GooonfX5o`0001?ooo]Z1Ol0002RoookJP00OooonfX5o`0001?o
oo]Z1?l0001ToookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000GooonfX5o`0001?o
oo]Z1Ol0002RoookJP00OooonfX5o`0001?ooo]Z1?l0001SoookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007l9oookJPGo0000H?oonfX5o`0001;ooo]Z1?l0002SoookJP00P?oonfX5o`0001;ooo]Z1?l0
001SoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o2OoonfX5o`00063ooo]Z1Ol0000BoookJPCo0000XooonfX0083ooo]Z
1Ol0000AoookJPGo0000H_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z
1Ol0001PoookJPGo00004_oonfX4o`000:?ooo]Z0020oookJPGo00004OoonfX5o`0006;ooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001PoookJPGo00004OoonfX4o`000:?ooo]Z0021
oookJPGo00004?oonfX5o`0006;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001Q
oookJPGo00004?oonfX5o`000:?ooo]Z0021oookJPGo00004?oonfX4o`0006?ooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000HOoonfX5o`00013ooo]Z1Ol0002Soook
JP00POoonfX5o`00013ooo]Z1?l0001SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo
0000H_oonfX5o`0000oooo]Z1Ol0002SoookJP00P_oonfX5o`0000oooo]Z1?l0001SoookJP?o001o
0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000H_oonfX5o`0000oooo]Z1?l0002ToookJP00P_oo
nfX5o`0000kooo]Z1Ol0001SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000H_oo
nfX5o`0000oooo]Z1?l0002ToookJP00P_oonfX5o`0000kooo]Z1Ol0001ToookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001SoookJPCo00003_oonfX5o`000:Cooo]Z0023
oookJPCo00003_oonfX5o`0006Cooo]Z1ol007l9oookJPOo001o2?oonfX5o`0006?ooo]Z1Ol0000=
oookJPGo0000Y?oonfX008?ooo]Z1Ol0000=oookJPCo0000I_oonfX5o`00O`[ooo]Z1ol007l8oook
JPGo0000HooonfX5o`0000gooo]Z1Ol0002ToookJP00PooonfX5o`0000cooo]Z1Ol00024oookJPGo
0000HooonfX5o`0000gooo]Z1?l0002UoookJP00PooonfX5o`0000cooo]Z1Ol00024oookJPGo0000
I?oonfX4o`0000gooo]Z1?l0002UoookJP00Q?oonfX5o`0000_ooo]Z1Ol00024oookJPGo0000I?oo
nfX5o`0000_ooo]Z1Ol0002UoookJP00Q?oonfX5o`0000_ooo]Z1?l00025oookJPGo0000I?oonfX5
o`0000_ooo]Z1Ol0002UoookJP00Q?oonfX5o`0000_ooo]Z1?l00025oookJPGo0000I?oonfX5o`00
00_ooo]Z1Ol0002UoookJP00QOoonfX5o`0000Wooo]Z1Ol00025oookJPGo0000IOoonfX4o`0000_o
oo]Z1?l0002VoookJP00QOoonfX5o`0000Wooo]Z1Ol00025oookJPGo0000IOoonfX5o`0000Wooo]Z
1Ol0002VoookJP00QOoonfX5o`0000Wooo]Z1Ol00025oookJPGo0000IOoonfX5o`0000Wooo]Z1Ol0
002VoookJP00Q_oonfX5o`0000Sooo]Z1?l00026oookJPGo0000IOoonfX5o`0000Wooo]Z1Ol0002V
oookJP00Q_oonfX5o`0000Sooo]Z1?l00026oookJPGo0000I_oonfX5o`0000Oooo]Z1Ol0002Woook
JP00Q_oonfX5o`0000Oooo]Z1Ol00026oookJPGo0000I_oonfX5o`0000Oooo]Z1Ol0002WoookJP00
QooonfX5o`0000Kooo]Z1Ol00026oookJPGo0000I_oonfX6o`0000Kooo]Z1Ol0002WoookJP00Qooo
nfX5o`0000Kooo]Z1Ol00026oookJPGo0000IooonfX5o`0000Kooo]Z1?l0002XoookJP00QooonfX6
o`0000Gooo]Z1?l00027oookJPGo0000IooonfX5o`0000Kooo]Z1?l0002XoookJP00R?oonfX5o`00
00Cooo]Z1Ol00027oookJPGo0000J?oonfX5o`0000Cooo]Z1Ol0002XoookJP00R?oonfX6o`0000?o
oo]Z1Ol00027oookJPGo0000J?oonfX5o`0000Cooo]Z1Ol0002XoookJP00ROoonfX5o`0000?ooo]Z
1Ol00027oookJPGo0000J?oonfX6o`0000;ooo]Z1_l0002XoookJP00ROoonfX5o`0000;ooo]Z1Ol0
0028oookJPGo0000JOoonfX6o`000003oookJ_l0003o000000?o0000ZOoonfX008[ooo]Z2ol00028
oookJPGo0000JOoonfX<o`000:Wooo]Z002:oookJP_o0000R?oonfX5o`0006[ooo]Z2_l0002Zoook
JP00R_oonfX:o`0008Wooo]Z1Ol0001[oookJPWo0000Z_oonfX008_ooo]Z2?l0002:oookJPGo0000
JooonfX8o`000:_ooo]Z002<oookJPOo0000R_oonfX5o`0006cooo]Z1ol0002[oookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z
0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z0ol007l:oook
JPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooo
nfXOoookJP00oooonfX>oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX6o`00
O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ3ooo]Z1?l007l:oookJPGo0000oooonfXOoookJP00
oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`ko
oo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z
1?l007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0
003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX0
0?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o
001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000
oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4
o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoook
JP00oooonfX?oookJPGo001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXC
oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oo
oo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001o
oooonfX/oookJP00oooonfX>oookJPOo001ooooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^
oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02846 .30616 L
.03068 .30502 L
.03279 .30417 L
.03398 .30381 L
.03527 .30352 L
.03645 .30336 L
.03754 .30331 L
.03871 .30334 L
.04 .3035 L
.04065 .30362 L
.04135 .30378 L
.04262 .30417 L
.04516 .30524 L
.04793 .30678 L
.05297 .31011 L
.05531 .31167 L
.05785 .3132 L
.06008 .31432 L
.0613 .31482 L
.06244 .3152 L
.06382 .31554 L
.06455 .31567 L
.06533 .31577 L
.06605 .31582 L
.06672 .31583 L
.06799 .31577 L
.06924 .3156 L
.0704 .31535 L
.07167 .31497 L
.07302 .31447 L
.07838 .31174 L
.08147 .30995 L
.08429 .30844 L
.08675 .30739 L
.08798 .30698 L
.08867 .3068 L
.08933 .30665 L
.09004 .30653 L
.09069 .30646 L
.09139 .30641 L
.09214 .30641 L
.0928 .30644 L
.0935 .30652 L
.09476 .30676 L
.09592 .30711 L
.09717 .3076 L
.09943 .30883 L
.10212 .31076 L
.10458 .31289 L
Mistroke
.11379 .32182 L
.11645 .324 L
.11894 .32564 L
.12003 .32621 L
.12118 .32671 L
.12244 .32713 L
.1236 .3274 L
.12489 .32756 L
.12561 .3276 L
.12626 .32759 L
.12753 .32749 L
.12874 .3273 L
.12942 .32714 L
.13014 .32695 L
.13143 .32654 L
.13436 .32537 L
.1369 .32426 L
.13957 .3232 L
.14067 .32283 L
.14185 .32252 L
.14314 .32228 L
.14434 .32218 L
.14556 .32221 L
.14688 .3224 L
.14812 .32274 L
.14927 .32321 L
.1503 .32377 L
.15144 .32452 L
.15374 .3265 L
.15626 .32935 L
.15897 .3331 L
.16385 .34114 L
.18214 .36389 L
.19173 .36205 L
.19426 .36087 L
.19559 .36032 L
.19632 .36006 L
.19699 .35986 L
.19822 .35959 L
.19887 .35952 L
.19957 .35949 L
.2008 .35961 L
.20193 .35993 L
.20324 .36056 L
.20398 .36106 L
.20466 .36162 L
.20724 .36459 L
.2086 .36673 L
.2101 .36957 L
.21312 .37678 L
Mistroke
.21846 .39373 L
.22347 .41228 L
.22593 .42127 L
.22861 .43023 L
.23097 .43689 L
.23227 .43988 L
.23349 .4422 L
.23469 .44393 L
.23599 .44516 L
.23716 .44565 L
.23825 .44554 L
.23927 .44492 L
.24039 .44365 L
.24156 .44164 L
.24266 .43912 L
.24394 .43537 L
.24533 .43032 L
.24787 .41859 L
.25262 .38845 L
.26329 .29637 L
.2682 .25309 L
.27078 .23265 L
.27349 .21375 L
.27588 .19976 L
.27849 .18764 L
.27964 .18342 L
.28087 .17967 L
.28202 .17687 L
.28307 .1749 L
.28437 .17326 L
.28505 .17274 L
.28577 .17243 L
.28698 .17246 L
.28767 .17277 L
.28831 .17325 L
.28951 .17461 L
.2906 .17633 L
.29307 .18173 L
.29577 .18962 L
.29872 .19979 L
.30409 .21976 L
.30942 .23766 L
.31204 .24471 L
.31444 .24991 L
.31664 .25355 L
.31774 .25497 L
.31895 .25624 L
.32016 .25721 L
.32147 .25794 L
.3227 .25836 L
Mistroke
.32381 .25852 L
.32512 .2585 L
.32578 .25841 L
.3265 .25826 L
.32779 .25787 L
.32899 .25741 L
.33192 .25606 L
.3332 .25546 L
.3346 .25487 L
.33591 .25441 L
.33712 .25408 L
.33828 .25389 L
.33952 .25383 L
.3402 .25387 L
.34094 .25398 L
.34165 .25414 L
.34229 .25434 L
.34351 .25486 L
.3448 .25562 L
.34735 .25774 L
.34976 .26047 L
.35428 .2671 L
.35955 .27619 L
.36443 .28431 L
.36869 .29005 L
.37084 .29226 L
.37208 .29329 L
.37321 .29408 L
.37434 .29472 L
.37558 .29525 L
.37683 .29561 L
.37814 .29582 L
.3793 .29586 L
.38053 .29577 L
.3817 .29557 L
.38276 .29531 L
.38758 .29348 L
.39208 .2916 L
.39324 .29121 L
.39434 .2909 L
.39561 .29064 L
.39677 .29049 L
.39806 .29043 L
.39924 .2905 L
.40055 .29071 L
.40128 .29088 L
.40194 .29108 L
.40334 .29162 L
.40462 .29226 L
.40751 .29415 L
Mistroke
.41276 .29879 L
.41757 .30358 L
.42023 .30605 L
.42273 .30809 L
.42518 .30969 L
.42656 .3104 L
.42784 .31091 L
.42891 .31124 L
.4301 .31148 L
.43133 .31161 L
.43249 .31162 L
.4336 .31152 L
.43478 .31132 L
.43578 .31107 L
.43687 .31071 L
.43931 .30969 L
.44159 .30851 L
.44673 .30556 L
.44926 .30424 L
.45159 .30326 L
.45289 .30283 L
.45427 .30249 L
.45499 .30236 L
.45566 .30228 L
.45639 .30222 L
.45718 .3022 L
.45784 .30222 L
.45855 .30227 L
.45984 .30246 L
.4611 .30276 L
.46226 .30313 L
.46467 .30416 L
.46688 .30536 L
.47187 .30862 L
.47654 .31165 L
.47882 .31288 L
.48089 .31376 L
.48208 .31415 L
.48321 .31443 L
.48439 .31462 L
.48568 .31472 L
.487 .3147 L
.48767 .31464 L
.4884 .31453 L
.4897 .31426 L
.49092 .3139 L
.49358 .3128 L
.49601 .3115 L
.50148 .30807 L
.50625 .30532 L
Mistroke
.50762 .30469 L
.50892 .30419 L
.51008 .30384 L
.51133 .30355 L
.51244 .30339 L
.51365 .30331 L
.51491 .30334 L
.51609 .30348 L
.5172 .3037 L
.51821 .30397 L
.52047 .30483 L
.52569 .30778 L
.53124 .3115 L
.53352 .3129 L
.53597 .31418 L
.53738 .31477 L
.53867 .31521 L
.5399 .31552 L
.5412 .31573 L
.5424 .31583 L
.54348 .31582 L
.54474 .31571 L
.54592 .3155 L
.54702 .31523 L
.54803 .31491 L
.55032 .31399 L
.55547 .31122 L
.55779 .30987 L
.56029 .30854 L
.56158 .30794 L
.5628 .30744 L
.56391 .30706 L
.56509 .30674 L
.56641 .30651 L
.56762 .30641 L
.56837 .30641 L
.56907 .30645 L
.57038 .30663 L
.57168 .30696 L
.57233 .30718 L
.57305 .30747 L
.57551 .30875 L
.57838 .31081 L
.58105 .31315 L
.58608 .31809 L
.58873 .32067 L
.59153 .32314 L
.59399 .32494 L
.59529 .32572 L
.59669 .32642 L
Mistroke
.59797 .32692 L
.59915 .32726 L
.60033 .32748 L
.60145 .32759 L
.60262 .32759 L
.60368 .3275 L
.6049 .3273 L
.60605 .32703 L
.6081 .32636 L
.61033 .32547 L
.61274 .32442 L
.61534 .32335 L
.6166 .32292 L
.61779 .32258 L
.61886 .32236 L
.62002 .32221 L
.62116 .32218 L
.62241 .32228 L
.62372 .32256 L
.62495 .32299 L
.6261 .32354 L
.62715 .32418 L
.62951 .3261 L
.63194 .32872 L
.63459 .33227 L
.63994 .34096 L
.64521 .35009 L
.64811 .35465 L
.65085 .35831 L
.6534 .361 L
.65484 .36217 L
.65616 .36301 L
.65728 .36354 L
.65851 .36394 L
.6598 .36416 L
.661 .3642 L
.66225 .36407 L
.66295 .36394 L
.66358 .36378 L
.66597 .36293 L
.66858 .36174 L
.66995 .36109 L
.67139 .36047 L
.67266 .36001 L
.67333 .35982 L
.67404 .35966 L
.6753 .3595 L
.67648 .35954 L
.67777 .35981 L
.67898 .36031 L
Mistroke
.68008 .36099 L
.68127 .362 L
.68349 .36467 L
.68475 .36666 L
.68594 .36886 L
.6909 .38133 L
.6998 .41279 L
.70227 .42178 L
.7049 .43053 L
.70734 .43733 L
.70854 .44005 L
.70964 .44213 L
.71089 .44394 L
.71154 .44465 L
.71224 .4452 L
.71336 .44565 L
.71459 .44548 L
.7153 .44506 L
.71594 .44446 L
.71668 .4435 L
.71739 .44234 L
.71864 .43965 L
.72 .43578 L
.72245 .42643 L
.72466 .41534 L
.72961 .38243 L
.73851 .30518 L
.74791 .22577 L
.75264 .19684 L
.75393 .19077 L
.75532 .18522 L
.75662 .18092 L
.75782 .17774 L
.75922 .17497 L
.75996 .17392 L
.76074 .1731 L
.76206 .17241 L
.76281 .17238 L
.76351 .17259 L
.76481 .17355 L
.766 .17504 L
.76738 .17743 L
.76868 .18031 L
.77345 .19461 L
.77866 .21376 L
.78397 .23258 L
.78658 .24041 L
.78898 .24646 L
.79116 .25088 L
.79347 .25441 L
Mistroke
.79467 .25578 L
.79579 .25679 L
.79701 .25762 L
.79833 .2582 L
.79901 .25838 L
.79973 .2585 L
.80103 .25852 L
.80175 .25845 L
.80242 .25832 L
.80316 .25813 L
.80396 .25788 L
.80656 .25679 L
.8093 .25551 L
.8105 .25499 L
.81179 .25451 L
.81253 .25428 L
.8132 .25411 L
.81452 .25389 L
.8157 .25383 L
.81698 .25395 L
.81819 .25424 L
.8193 .25466 L
.82055 .25533 L
.82174 .25616 L
.82397 .25818 L
.82637 .26101 L
.82899 .26476 L
.83806 .28018 L
.84325 .28805 L
.84614 .29141 L
.84751 .29268 L
.84877 .29366 L
.84994 .29441 L
.85123 .29504 L
.85252 .29549 L
.85323 .29566 L
.85389 .29577 L
.8551 .29586 L
.85621 .29582 L
.85749 .29565 L
.8587 .29538 L
.86369 .29351 L
.86838 .29156 L
.86952 .29118 L
.87073 .29086 L
.87205 .2906 L
.87326 .29046 L
.87391 .29044 L
.87459 .29044 L
.87583 .29055 L
Mistroke
.87659 .29068 L
.87731 .29084 L
.87864 .29126 L
.87971 .29171 L
.88088 .2923 L
.88325 .29382 L
.88749 .29739 L
.89708 .30662 L
.89958 .30856 L
.9009 .30941 L
.9023 .31018 L
.90353 .31072 L
.90418 .31096 L
.90488 .31118 L
.90611 .31145 L
.90726 .3116 L
.90839 .31163 L
.90962 .31154 L
.91091 .31133 L
.91211 .31102 L
.91426 .31025 L
.91656 .30916 L
.92219 .30597 L
.92495 .30448 L
.92751 .30336 L
.9287 .30294 L
.92982 .30263 L
.93099 .30239 L
.93228 .30224 L
.93359 .3022 L
.93478 .30228 L
.93544 .30236 L
.93616 .30249 L
.93746 .30281 L
.93873 .30323 L
.9399 .30371 L
.94253 .30505 L
.9473 .3081 L
.95191 .31116 L
.95416 .31245 L
.95621 .31342 L
.95728 .31383 L
.95845 .3142 L
.95968 .31448 L
.96084 .31465 L
.96213 .31473 L
.96277 .31472 L
.96349 .31468 L
.96475 .31451 L
.96593 .31425 L
Mistroke
.96718 .31387 L
.96851 .31337 L
.97087 .31224 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00Z?oonfX6o`0006oooo]Z1Ol00028oook
JPKo0000T?oonfX00:Oooo]Z2?l0001^oookJPGo0000QooonfX8o`0008oooo]Z002WoookJPWo0000
KOoonfX5o`0008Oooo]Z2?l0002?oookJP00YooonfX9o`0006gooo]Z1Ol00027oookJPWo0000S_oo
nfX00:Kooo]Z2ol0001/oookJPGo0000QooonfX:o`0008gooo]Z002VoookJPGo000000?ooo]Zo`00
0?l000000ol0001/oookJPGo0000Q_oonfX;o`0008gooo]Z002VoookJPGo000000?ooo]Zo`000?l0
00000ol0001/oookJPGo0000Q_oonfX5o`000003oookJ_l0003o000000?o0000SOoonfX00:Kooo]Z
1?l00003oookJPCo0000K?oonfX5o`0008Gooo]Z1_l00002oookJPGo0000S?oonfX00:Gooo]Z1Ol0
0003oookJPGo0000JooonfX5o`0008Gooo]Z1Ol00003oookJPGo0000S?oonfX00:Gooo]Z1Ol00003
oookJPGo0000JooonfX5o`0008Gooo]Z1Ol00003oookJPGo0000S?oonfX00:Gooo]Z1Ol00003oook
JPGo0000JooonfX5o`0008Gooo]Z1?l00005oookJPCo0000S?oonfX00:Gooo]Z1?l00005oookJPGo
0000J_oonfX5o`0008Gooo]Z1?l00005oookJPGo0000RooonfX00:Cooo]Z1Ol00005oookJPGo0000
J_oonfX5o`0008Cooo]Z1Ol00005oookJPGo0000RooonfX00:Cooo]Z1Ol00005oookJPGo0000J_oo
nfX5o`0008Cooo]Z1Ol00005oookJPGo0000RooonfX00:Cooo]Z1Ol00006oookJPGo0000JOoonfX5
o`0008Cooo]Z1Ol00006oookJPCo0000RooonfX00:Cooo]Z1?l00007oookJPGo0000JOoonfX5o`00
08Cooo]Z1?l00007oookJPGo0000R_oonfX00:Cooo]Z1?l00007oookJPGo0000JOoonfX5o`0008Co
oo]Z1?l00007oookJPGo0000R_oonfX00:Cooo]Z1?l00008oookJPCo0000JOoonfX5o`0008?ooo]Z
1Ol00007oookJPGo0000R_oonfX00:?ooo]Z1Ol00008oookJPGo0000J?oonfX5o`0008?ooo]Z1Ol0
0008oookJPGo0000ROoonfX00:?ooo]Z1Ol00008oookJPGo0000J?oonfX5o`0008?ooo]Z1Ol00008
oookJPGo0000ROoonfX00:?ooo]Z1Ol00008oookJPGo0000J?oonfX5o`0008?ooo]Z1?l00009oook
JPGo0000ROoonfX00:;ooo]Z1Ol0000:oookJPGo0000IooonfX5o`0008?ooo]Z1?l0000:oookJPGo
0000R?oonfX00:;ooo]Z1Ol0000:oookJPGo0000IooonfX5o`0008;ooo]Z1Ol0000:oookJPGo0000
R?oonfX00:;ooo]Z1Ol0000:oookJPGo0000IooonfX5o`0008;ooo]Z1Ol0000:oookJPGo0000R?oo
nfX00:;ooo]Z1?l0000<oookJPCo0000IooonfX5o`0008;ooo]Z1Ol0000;oookJPCo0000R?oonfX0
0:;ooo]Z1?l0000<oookJPGo0000I_oonfX5o`0008;ooo]Z1?l0000<oookJPGo0000QooonfX00:;o
oo]Z1?l0000<oookJPGo0000I_oonfX5o`0008;ooo]Z1?l0000<oookJPGo0000QooonfX00:;ooo]Z
1?l0000<oookJPGo0000I_oonfX5o`00087ooo]Z1Ol0000<oookJPGo0000QooonfX00:7ooo]Z1Ol0
000=oookJPGo0000IOoonfX5o`00087ooo]Z1Ol0000=oookJPGo0000Q_oonfX00:7ooo]Z1Ol0000=
oookJPGo0000AooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`00087ooo]Z1Ol0000=
oookJPGo0000Q_oonfX00:7ooo]Z1Ol0000=oookJPGo0000A_oonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o2OoonfX5o`00087ooo]Z1?l0000>oookJPGo0000Q_oonfX00:7ooo]Z1?l0000?oookJPGo
0000AOoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol00021oookJPCo00003ooonfX4o`0008Kooo]Z002Qoook
JPCo00003ooonfX5o`0003Sooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o2?oonfX5o`00087ooo]Z1?l0000?oookJPGo0000QOoonfX00:7ooo]Z1?l0000?oookJPGo
0000>?oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l00020oookJPCo
00003ooonfX5o`0008Gooo]Z002QoookJPCo00004?oonfX5o`0004?ooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Sooo]Z1Ol00020oookJPGo00003ooonfX5o`0008Gooo]Z002QoookJPCo00004?oo
nfX5o`0004?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000P?oo
nfX5o`00013ooo]Z1?l00025oookJP00XOoonfX4o`00013ooo]Z1Ol00013oookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l9oookJPGo0000P?oonfX5o`00013ooo]Z1Ol00024oookJP00X?oonfX5o`00
017ooo]Z1?l00013oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000P?oonfX4o`00
017ooo]Z1Ol00024oookJP00X?oonfX5o`00017ooo]Z1Ol00012oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l>oookJPGo0000P?oonfX4o`00017ooo]Z1Ol00024oookJP00X?oonfX5o`00017ooo]Z
1Ol00013oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol00020oookJPCo
00004_oonfX5o`0008?ooo]Z002PoookJPCo00004_oonfX5o`0004?ooo]Z1ol007l9oookJPOo001o
2?oonfX5o`00083ooo]Z1?l0000BoookJPKo0000P_oonfX00:3ooo]Z1?l0000CoookJPGo0000@ooo
nfX5o`00O`[ooo]Z1ol007l8oookJPGo0000P?oonfX4o`0001;ooo]Z1_l00022oookJP00WooonfX5
o`0001?ooo]Z1Ol0001QoookJPGo0000P?oonfX4o`0001?ooo]Z1_l00021oookJP00WooonfX5o`00
01?ooo]Z1_l0001PoookJPGo0000OooonfX5o`0001Cooo]Z1Ol00021oookJP00WooonfX5o`0001Co
oo]Z1_l00006oookJPSo0000DOoonfX5o`0007oooo]Z1Ol0000DoookJPKo00001_oonfX7o`0007?o
oo]Z002OoookJPCo00005OoonfX7o`0000;ooo]Z3?l0001@oookJPGo0000OooonfX5o`0001Gooo]Z
1_l00003oookJPco0000L?oonfX009oooo]Z1?l0000FoookJQGo0000CooonfX5o`0007oooo]Z1?l0
000FoookJQKo0000KooonfX009oooo]Z1?l0000GoookJQGo0000C_oonfX5o`0007oooo]Z1?l0000G
oookJQGo0000KooonfX009oooo]Z1?l0000GoookJPgo000000?ooo]Zo`000?l000001_l0001=oook
JPGo0000OooonfX4o`0001Sooo]Z3?l000000ooonf[o0000o`000006o`0006kooo]Z002OoookJPCo
00006OoonfX8o`0000Kooo]Z1_l0001=oookJPGo0000OooonfX4o`0001Sooo]Z2_l00006oookJPGo
0000K_oonfX009oooo]Z1?l0000JoookJPKo00002?oonfX6o`0004cooo]Z1Ol0001ooookJPCo0000
6_oonfX6o`0000Sooo]Z1_l0001]oookJP00W_oonfX5o`0002Wooo]Z1_l0001;oookJPGo0000O_oo
nfX5o`0002Wooo]Z1Ol0001]oookJP00W_oonfX5o`0002Wooo]Z1_l0001;oookJPGo0000O_oonfX5
o`0002Wooo]Z1_l0001/oookJP00W_oonfX5o`0002[ooo]Z1_l0001:oookJPGo0000O_oonfX5o`00
02[ooo]Z1_l0001[oookJP008_oonfX3o`00OgGooo]Z1?l007l4o`000004oookJ_l007oo001oo`00
O`?ooo]Z1Ol007lPoookJPKo0000BOoonfX5o`0007Cooo]Z1Ol007l4oookJP03o`00Ool0003o0000
00;o000000?ooo]Zo`00Ool007l00ol007lUoookJPKo0000BooonfX3o`00Oagooo]Z000RoookJP?o
001oM?oonfX5o`00O`Co000000Cooo]Zo`00Ool007oo001o0_oonfX7o`00Oaoooo]Z1_l00019oook
JPGo0000LooonfX7o`00O`?ooo]Z00?o001oo`000?l000000_l00007o`00ObGooo]Z1_l0001:oook
JP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o00?ooo]Zo`00Ool000000ol000001Ooonf[o
001oo`00Ool007oooo]Z00Co001o00Cooo]Zo`00Ool007oo001o8?oonfX6o`0004Sooo]Z1Ol0001c
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX00ol007oo0000o`000002o`0000?o001o00Co
oo]Zo`00Ool007oo001o9_oonfX5o`0004[ooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol0
07mWoookJP[o001o0_oonfX3o`00O`?ooo]Z1?l00005oookJP?o001o0ooonfX3o`00Ob3ooo]Z1Ol0
0018oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l3oookJPCo00000_l007l3oookJP?o001o9Ooo
nfX6o`0004Wooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3
o`00O`?ooo]Z1?l0000;oookJP?o001o8?oonfX6o`0004Oooo]Z1Ol0001boookJP?o001o0ooonfX3
o`00O`?ooo]Z1?l00005oookJP?o001o9_oonfX6o`0004Sooo]Z0ol007lMoookJP008_oonfX3o`00
Og?ooo]Z0ol007l3oookJPCo00002ooonfX3o`00Ob7ooo]Z1_l00016oookJPGo0000L_oonfX3o`00
O`?ooo]Z0ol007l3oookJPCo00001OoonfX3o`00ObKooo]Z1_l00018oookJP?o001o7OoonfX002;o
oo]Z0ol007mcoookJP?o001o0ooonfX4o`0000Kooo]Z0_l007l2oookJPCo001o8OoonfX6o`0004Ko
oo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1Ol00002o`00O`;ooo]Z1?l007lWoookJPKo
0000AooonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`?ooo]Z1?l00006oookJPOo001o
8ooonfX6o`0004Gooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1Ol00007o`00ObWooo]Z
1_l00016oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX5o`0000Kooo]Z1_l0
07lUoookJPGo0000AOoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX5o`0000Ko001o:_oo
nfX6o`0004Kooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l2oookJPGo00001_oonfX2
o`00ObWooo]Z1_l00014oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Z
o`00Ool007l0;ooonfX7o`00047ooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l00ooo
nf[o0000o`000003o`0000Kooo]Z0_l007lZoookJPKo00002OoonfX9o`00037ooo]Z1Ol0001coook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`000003oookJ_l007oo001o033ooo]Z1ol00008
oookJPWo0000;ooonfX6o`00Oagooo]Z000QoookJPCo001oM?oonfX4o`00O`Co00002?oonfX7o`00
ObCooo]Z1ol00007oookJPco0000;ooonfX5o`0007?ooo]Z1ol007l3oookJPCo00000_oonfX7o`00
Ob[ooo]Z1ol00007oookJPco0000;ooonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX3o`00O`Co
00002?oonfX7o`00ObGooo]Z2?l00002oookJQ7o0000;OoonfX5o`0007Cooo]Z1Ol007l4oookJPCo
00000_oonfX7o`00Ob_ooo]Z2?l00002oookJQ3o0000;ooonfX3o`00Oagooo]Z002MoookJPCo0000
=OoonfXKo`0002cooo]Z1Ol0001moookJPCo0000=_oonfXIo`0004kooo]Z002MoookJPCo0000=_oo
nfX@o`0000;ooo]Z2Ol0000[oookJPGo0000OOoonfX4o`0003Kooo]Z4?l00002oookJPSo0000COoo
nfX009gooo]Z1?l0000goookJPgo00001_oonfX7o`0002_ooo]Z1Ol0001loookJPGo0000=ooonfX=
o`0000Kooo]Z1ol0001<oookJP00WOoonfX4o`0003Wooo]Z2?l0000;oookJPKo00004OoonfX7o`00
01;ooo]Z1Ol0001loookJPGo0000>OoonfX8o`0000[ooo]Z1ol0000BoookJPKo0000<ooonfX0023o
oo]Z2_l0001coookJPCo0000COoonfX7o`0000cooo]Z3Ol0000?oookJPko0000LooonfX5o`0004co
oo]Z1ol0000>oookJPco0000<?oonfX001gooo]Z3_l0001aoookJPGo0000COoonfX8o`0000Wooo]Z
4Ol0000=oookJQ7o0000L?oonfX4o`0004kooo]Z1ol0000:oookJQ3o0000;ooonfX000kooo]Zool0
003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`00
02Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go0000
3ooonfX001gooo]Z00?o0000oookJ_oonfX02ooonfXCo`0000Oooo]Z2?l0001?oookJPCo0000EOoo
nfX:o`00017ooo]Z4_l0000<oookJQ7o00002?oonfX8o`0004kooo]Z1Ol0001EoookJP_o00004?oo
nfX@o`0001kooo]Z000]oookJQ3o00002_oonfX7o`0004kooo]Z1?l0001boookJQ3o00003OoonfX>
o`0000cooo]Z1ol0001=oookJPGo0000LOoonfX=o`00023ooo]Z000_oookJPco00003OoonfX7o`00
04cooo]Z1Ol0001coookJPWo000000?ooo]Zo`000?l000000ol0000>oookJPco00003_oonfX7o`00
04cooo]Z1?l0001doookJPWo00008_oonfX0037ooo]Z1ol0000AoookJPOo00002ooonfX7o`0003Wo
oo]Z1Ol0001moookJPGo00004OoonfX7o`00017ooo]Z1ol0000;oookJPOo0000>OoonfX4o`0009oo
oo]Z001:oookJPOo00001ooonfX<o`0003Oooo]Z1Ol0001moookJPGo0000:_oonfX7o`0000Oooo]Z
3?l0000goookJPCo0000WooonfX004_ooo]Z2?l00003oookJPko0000=ooonfX4o`0007kooo]Z1Ol0
000[oookJPSo00000_oonfX@o`0003Kooo]Z1?l0002OoookJP00C?oonfXJo`0003Gooo]Z1?l0001n
oookJPGo0000;?oonfXJo`0003Gooo]Z1?l0002OoookJP00COoonfXAo`000003oookJ_l0003o0000
00Ko0000=?oonfX4o`0007kooo]Z1Ol0000]oookJQ7o000000?ooo]Zo`000?l000001_l0000doook
JPCo0000WooonfX004kooo]Z3Ol00005oookJPOo0000=?oonfX4o`0007kooo]Z1Ol0000^oookJPgo
00001_oonfX6o`0003?ooo]Z1Ol0002OoookJP00D?oonfX9o`0000Sooo]Z1ol0000coookJPCo0000
O_oonfX5o`00033ooo]Z2?l0000:oookJPKo0000<_oonfX5o`0009oooo]Z001SoookJPGo0000<ooo
nfX4o`0007kooo]Z1Ol00013oookJPGo0000<_oonfX5o`0009oooo]Z001SoookJPKo0000<OoonfX5
o`0007kooo]Z1Ol00013oookJPKo0000<OoonfX4o`000:3ooo]Z001ToookJPKo0000<?oonfX5o`00
07kooo]Z1Ol00014oookJPKo0000<?oonfX4o`000:3ooo]Z001ToookJPOo0000;ooonfX5o`0007ko
oo]Z1Ol00014oookJPOo0000;ooonfX4o`000:3ooo]Z001UoookJPKo0000;ooonfX4o`0007oooo]Z
1Ol00015oookJPKo0000;ooonfX4o`000:3ooo]Z001VoookJPKo0000;_oonfX4o`0007oooo]Z1Ol0
0016oookJPKo0000;_oonfX4o`000:3ooo]Z001WoookJPKo0000;OoonfX4o`0007oooo]Z1Ol00017
oookJPKo0000;?oonfX5o`000:3ooo]Z001WoookJPOo0000;?oonfX4o`0007oooo]Z1Ol00017oook
JPKo0000;?oonfX5o`000:3ooo]Z001XoookJPKo0000;?oonfX4o`0007oooo]Z1Ol00018oookJPKo
0000:ooonfX5o`000:3ooo]Z001YoookJPKo0000:_oonfX5o`0007oooo]Z1Ol00019oookJPGo0000
:ooonfX4o`000:7ooo]Z001ZoookJPKo0000:OoonfX5o`0007oooo]Z1Ol00019oookJPKo0000:_oo
nfX4o`000:7ooo]Z001ZoookJPOo0000:?oonfX5o`0007oooo]Z1Ol0001:oookJPGo0000:_oonfX4
o`000:7ooo]Z001[oookJPOo00009ooonfX4o`00083ooo]Z1Ol0001:oookJPKo0000:OoonfX4o`00
0:7ooo]Z001/oookJPKo00001ooonfX6o`0001[ooo]Z1?l00020oookJPGo0000BooonfX6o`0000So
oo]Z1_l0000JoookJPCo0000XOoonfX006gooo]Z1_l00004oookJP[o00006?oonfX4o`00083ooo]Z
1Ol0001;oookJPOo00001OoonfX:o`0001Oooo]Z1Ol0002QoookJP00K_oonfXCo`0001Sooo]Z1?l0
0020oookJPGo0000C?oonfX8o`000003oookJ_l0003o000000[o00005ooonfX5o`000:7ooo]Z001^
oookJQCo00005ooonfX4o`00083ooo]Z1Ol0001=oookJQGo00005_oonfX5o`000:7ooo]Z001_oook
JQCo00005OoonfX5o`00083ooo]Z1Ol0001>oookJQGo00005OoonfX4o`000:;ooo]Z001`oookJP[o
00000ooonfX6o`0001Gooo]Z1Ol00020oookJPGo0000CooonfX;o`0000?ooo]Z1ol0000DoookJPCo
0000X_oonfX0077ooo]Z1_l00007oookJPKo00005?oonfX5o`00083ooo]Z1Ol0001@oookJPSo0000
1_oonfX6o`0001Cooo]Z1?l0002RoookJP00OooonfX5o`0001Cooo]Z1?l00021oookJPGo0000Gooo
nfX5o`0001Cooo]Z1?l0002RoookJP00OooonfX6o`0001?ooo]Z1?l00021oookJPGo0000H?oonfX5
o`0001?ooo]Z1?l0002RoookJP00P?oonfX5o`0001?ooo]Z1?l00021oookJPGo0000H?oonfX5o`00
01?ooo]Z1?l0002RoookJP00P?oonfX6o`0001;ooo]Z1?l00021oookJPGo0000H?oonfX5o`0001;o
oo]Z1Ol0002RoookJP00POoonfX5o`0001;ooo]Z1?l00021oookJPGo0000HOoonfX5o`00017ooo]Z
1Ol0002RoookJP00POoonfX5o`0001;ooo]Z1?l0001SoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol0
07l:oookJPGo0000HOoonfX5o`00017ooo]Z1Ol0002RoookJP00P_oonfX5o`00013ooo]Z1Ol0001R
oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000HOoonfX5o`00017ooo]Z1?l0002S
oookJP00P_oonfX5o`00013ooo]Z1Ol0001RoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0006;ooo]Z1?l0
000AoookJPCo0000XooonfX008;ooo]Z1Ol0000@oookJPGo0000HOoonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001RoookJPGo00004?oonfX4o`000:?ooo]Z0023oook
JPCo00004?oonfX4o`0006;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001Qoook
JPGo00004?oonfX4o`000:?ooo]Z0023oookJPCo00004?oonfX4o`0006;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Sooo]Z1Ol0001RoookJPGo00004?oonfX4o`000:?ooo]Z0023oookJPGo0000
3ooonfX4o`0006;ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000
HooonfX5o`0000kooo]Z1Ol0002SoookJP00PooonfX5o`0000oooo]Z1?l0001RoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007l9oookJPGo0000HooonfX5o`0000kooo]Z1Ol0002SoookJP00PooonfX5
o`0000kooo]Z1Ol0001RoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000HooonfX5
o`0000kooo]Z1Ol0002SoookJP00Q?oonfX4o`0000kooo]Z1Ol0001RoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l>oookJPGo0000I?oonfX5o`0000gooo]Z1?l0002ToookJP00Q?oonfX5o`0000go
oo]Z1Ol0001SoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001Toook
JPGo00003OoonfX4o`000:Cooo]Z0024oookJPGo00003OoonfX4o`0006Cooo]Z1ol007l9oookJPOo
001o2?oonfX5o`0006Cooo]Z1Ol0000=oookJPCo0000Y?oonfX008Cooo]Z1Ol0000=oookJPCo0000
IOoonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000IOoonfX4o`0000gooo]Z1?l0002ToookJP00QOoo
nfX5o`0000_ooo]Z1Ol00023oookJPGo0000IOoonfX5o`0000cooo]Z1?l0002ToookJP00QOoonfX5
o`0000_ooo]Z1Ol00023oookJPGo0000IOoonfX5o`0000cooo]Z1?l0002ToookJP00QOoonfX5o`00
00_ooo]Z1Ol00023oookJPGo0000IOoonfX5o`0000_ooo]Z1Ol0002ToookJP00Q_oonfX5o`0000[o
oo]Z1?l00024oookJPGo0000I_oonfX5o`0000[ooo]Z1Ol0002ToookJP00Q_oonfX5o`0000[ooo]Z
1?l00024oookJPGo0000I_oonfX5o`0000[ooo]Z1Ol0002ToookJP00Q_oonfX5o`0000Wooo]Z1Ol0
0024oookJPGo0000I_oonfX5o`0000[ooo]Z1?l0002UoookJP00QooonfX4o`0000Wooo]Z1Ol00024
oookJPGo0000IooonfX5o`0000Wooo]Z1?l0002UoookJP00QooonfX5o`0000Sooo]Z1Ol00024oook
JPGo0000IooonfX5o`0000Wooo]Z1?l0002UoookJP00QooonfX5o`0000Sooo]Z1?l00025oookJPGo
0000IooonfX5o`0000Wooo]Z1?l0002UoookJP00QooonfX5o`0000Sooo]Z1?l00025oookJPGo0000
J?oonfX5o`0000Sooo]Z1?l0002UoookJP00R?oonfX4o`0000Sooo]Z1?l00025oookJPGo0000J?oo
nfX5o`0000Oooo]Z1Ol0002UoookJP00R?oonfX5o`0000Kooo]Z1Ol00025oookJPGo0000J?oonfX5
o`0000Oooo]Z1Ol0002UoookJP00R?oonfX5o`0000Kooo]Z1Ol00025oookJPGo0000JOoonfX5o`00
00Kooo]Z1Ol0002UoookJP00R?oonfX5o`0000Kooo]Z1Ol00025oookJPGo0000JOoonfX5o`0000Ko
oo]Z1?l0002VoookJP00ROoonfX5o`0000Gooo]Z1?l00026oookJPGo0000JOoonfX5o`0000Gooo]Z
1Ol0002VoookJP00ROoonfX5o`0000Gooo]Z1?l00026oookJPGo0000J_oonfX4o`0000Gooo]Z1Ol0
002VoookJP00ROoonfX6o`0000?ooo]Z1Ol00026oookJPGo0000J_oonfX4o`0000Gooo]Z1Ol0002V
oookJP00R_oonfX5o`0000?ooo]Z1Ol00026oookJPGo0000J_oonfX5o`0000?ooo]Z1Ol0002Woook
JP00R_oonfX5o`0000?ooo]Z1Ol00026oookJPGo0000J_oonfX5o`0000?ooo]Z1Ol0002WoookJP00
RooonfX5o`0000;ooo]Z1?l00027oookJPGo0000J_oonfX6o`000003oookJ_l0003o000000Co0000
YooonfX008_ooo]Z2ol00027oookJPGo0000JooonfX;o`000:Sooo]Z002;oookJP_o0000QooonfX5
o`0006_ooo]Z2ol0002XoookJP00S?oonfX:o`0008Oooo]Z1Ol0001/oookJPWo0000ZOoonfX008go
oo]Z2?l00028oookJPGo0000KOoonfX8o`000:Wooo]Z002=oookJPOo0000ROoonfX5o`0006gooo]Z
1ol0002ZoookJP00S_oonfX6o`0008Wooo]Z1Ol0001^oookJPKo0000Z_oonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol0
07l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPKo
0000oooonfXNoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX6o`00O`[o
oo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooo
nfX@oookJPCo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003o
oookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooook
JQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o
001oo`00Ool007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?o
oo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z
1_l0003ooookJQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o
001o2OoonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z
1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003o
oookJP7ooo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00
O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00
O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00
oooonfX>oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0
003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoook
JP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z
3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooo
nfX/oookJP00oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00
Oooooo]Z;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooo
nf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02605 .31045 L
.02846 .31185 L
.03053 .31286 L
.03163 .31329 L
.03279 .31367 L
.03344 .31384 L
.03416 .31398 L
.03543 .31415 L
.03672 .31418 L
.03793 .31409 L
.03911 .3139 L
.04019 .31362 L
.04143 .31321 L
.04262 .31272 L
.05221 .30711 L
.05354 .30639 L
.05498 .30569 L
.05624 .30519 L
.05693 .30495 L
.05758 .30476 L
.05879 .3045 L
.05943 .30441 L
.06011 .30435 L
.06133 .30433 L
.06244 .30443 L
.06309 .30454 L
.06378 .30469 L
.06501 .30507 L
.06634 .3056 L
.06781 .30634 L
.07289 .30976 L
.07795 .31356 L
.08017 .31502 L
.08259 .31629 L
.08397 .31683 L
.08525 .3172 L
.08596 .31735 L
.0866 .31745 L
.08735 .31751 L
.08805 .31754 L
.08876 .31752 L
.08952 .31745 L
.09016 .31736 L
.09087 .31722 L
.09245 .31679 L
.09393 .31624 L
.09903 .31371 L
.10172 .3123 L
.10319 .31162 L
Mistroke
.10458 .31108 L
.10594 .31067 L
.10671 .3105 L
.10741 .31039 L
.10866 .31029 L
.10998 .31034 L
.11122 .31055 L
.11237 .31089 L
.11363 .31141 L
.11499 .31215 L
.11764 .31411 L
.12016 .31648 L
.12487 .32175 L
.12918 .32662 L
.13154 .32894 L
.13375 .33074 L
.135 .33155 L
.13614 .33217 L
.1374 .3327 L
.13807 .33291 L
.13877 .33309 L
.13992 .33327 L
.14098 .33332 L
.14215 .33326 L
.1434 .33308 L
.14464 .33278 L
.146 .33235 L
.14875 .33128 L
.15132 .33025 L
.15245 .32986 L
.15367 .3295 L
.15441 .32934 L
.1551 .32922 L
.15575 .32915 L
.15645 .32912 L
.15717 .32915 L
.15786 .32922 L
.15861 .32937 L
.15942 .32961 L
.16007 .32986 L
.16078 .3302 L
.16222 .33111 L
.16355 .33221 L
.16479 .33346 L
.16989 .3407 L
.17453 .34934 L
.17959 .35907 L
.18236 .36372 L
.18495 .36726 L
.18724 .36956 L
Mistroke
.18852 .3705 L
.1897 .37111 L
.19098 .37154 L
.1917 .37167 L
.19238 .37172 L
.19361 .37165 L
.19492 .37138 L
.19611 .37097 L
.1974 .3704 L
.19974 .36916 L
.202 .36796 L
.20311 .36746 L
.20412 .3671 L
.20533 .36682 L
.20663 .36676 L
.20731 .36684 L
.20804 .36702 L
.20874 .3673 L
.20938 .36765 L
.21067 .36864 L
.2114 .36938 L
.21208 .3702 L
.21348 .37226 L
.21494 .37501 L
.21745 .38103 L
.21974 .38796 L
.2249 .40727 L
.22982 .42708 L
.23223 .43576 L
.23446 .44236 L
.2357 .44528 L
.23702 .44764 L
.23771 .44854 L
.23835 .44916 L
.23905 .4496 L
.2398 .44976 L
.24111 .44926 L
.24234 .44783 L
.24345 .44573 L
.24466 .44252 L
.24591 .43821 L
.24709 .43321 L
.24928 .42149 L
.2542 .38501 L
.26303 .29724 L
.2681 .2466 L
.27283 .20764 L
.27521 .19256 L
.27776 .18037 L
.27922 .17531 L
Mistroke
.27993 .17333 L
.28059 .1718 L
.28182 .16969 L
.28248 .16897 L
.28317 .16848 L
.28431 .1683 L
.28535 .16879 L
.28656 .17007 L
.28771 .17196 L
.28974 .17671 L
.29196 .18357 L
.30165 .22154 L
.3042 .23051 L
.30696 .2386 L
.30823 .24166 L
.30957 .24442 L
.31073 .2464 L
.31197 .24813 L
.31317 .24942 L
.31427 .25028 L
.31538 .25087 L
.31642 .25118 L
.31764 .25128 L
.31877 .25116 L
.32 .25083 L
.32132 .2503 L
.32611 .24778 L
.32743 .24718 L
.32814 .2469 L
.32881 .24668 L
.32999 .24641 L
.33128 .24631 L
.33202 .24635 L
.33272 .24647 L
.33403 .24688 L
.33476 .24723 L
.33543 .24763 L
.33696 .24881 L
.33955 .25163 L
.34229 .25564 L
.35172 .2734 L
.3542 .27782 L
.35692 .28198 L
.35948 .28506 L
.36062 .28615 L
.36185 .28711 L
.3631 .28787 L
.36428 .28839 L
.36543 .28872 L
.36649 .28887 L
Mistroke
.36763 .2889 L
.36889 .28878 L
.3702 .28852 L
.37142 .28816 L
.37596 .28638 L
.37796 .28563 L
.37902 .2853 L
.38016 .28501 L
.38142 .2848 L
.3826 .28471 L
.38325 .28472 L
.38395 .28477 L
.38518 .28498 L
.38583 .28515 L
.38653 .28538 L
.38779 .28592 L
.38928 .28677 L
.39063 .28773 L
.39574 .29261 L
.40055 .29815 L
.40488 .30276 L
.40725 .3048 L
.40946 .30625 L
.41061 .30682 L
.41185 .30728 L
.41256 .30747 L
.41323 .30761 L
.41448 .30774 L
.41563 .30773 L
.4167 .3076 L
.41787 .30736 L
.41911 .30699 L
.42366 .30493 L
.42846 .30242 L
.43097 .30138 L
.43166 .30115 L
.43239 .30094 L
.43303 .30079 L
.43372 .30066 L
.43502 .30052 L
.43625 .30051 L
.43744 .30062 L
.43855 .30083 L
.4396 .30112 L
.44073 .30153 L
.44277 .30251 L
.44742 .3056 L
.45197 .30906 L
.45446 .31078 L
.45682 .31213 L
Mistroke
.45814 .31272 L
.45883 .31298 L
.45957 .31322 L
.46087 .31352 L
.46206 .31368 L
.46326 .31371 L
.46438 .31363 L
.46561 .31342 L
.46693 .31307 L
.46835 .31255 L
.46989 .31184 L
.4727 .31028 L
.47796 .30702 L
.48057 .30561 L
.48302 .3046 L
.48425 .30424 L
.48494 .30409 L
.48557 .30398 L
.48623 .3039 L
.48695 .30386 L
.4877 .30385 L
.48839 .30389 L
.48965 .30405 L
.49084 .30432 L
.49191 .30464 L
.49306 .30508 L
.49805 .30777 L
.50261 .31067 L
.50513 .3121 L
.50752 .31318 L
.50886 .31364 L
.50962 .31383 L
.51033 .31398 L
.51157 .31414 L
.51227 .31418 L
.5129 .31418 L
.51414 .31409 L
.51485 .31398 L
.51549 .31385 L
.51668 .31353 L
.51793 .31309 L
.5281 .30729 L
.5295 .30651 L
.53102 .30576 L
.53237 .30521 L
.5331 .30496 L
.53379 .30476 L
.53507 .30448 L
.53575 .30439 L
.53649 .30434 L
Mistroke
.53779 .30435 L
.53898 .30449 L
.54019 .30475 L
.54148 .30516 L
.54269 .30567 L
.5438 .30622 L
.54906 .30974 L
.55367 .31323 L
.5561 .31486 L
.55742 .31562 L
.55866 .31624 L
.55988 .31674 L
.561 .31709 L
.56224 .31736 L
.56293 .31746 L
.56358 .31752 L
.5647 .31753 L
.56574 .31745 L
.56689 .31726 L
.5681 .31696 L
.56915 .31661 L
.57029 .31617 L
.57233 .31522 L
.57701 .31276 L
.5794 .31162 L
.58072 .3111 L
.58196 .31072 L
.58312 .31046 L
.58437 .31031 L
.58551 .3103 L
.58657 .31039 L
.58782 .31066 L
.58898 .31105 L
.59027 .31164 L
.59165 .31245 L
.59446 .31466 L
.59703 .31719 L
.61812 .33329 L
.65786 .36263 L
.66027 .36617 L
.66282 .36903 L
.66416 .37012 L
.66486 .37059 L
.66562 .37099 L
.66631 .37128 L
.66695 .37149 L
.66819 .3717 L
.66943 .3717 L
.67058 .37151 L
.67184 .37114 L
Mistroke
.67318 .37059 L
.67546 .36942 L
.67791 .3681 L
.67904 .36757 L
.68024 .36712 L
.68126 .36687 L
.68237 .36675 L
.68342 .36682 L
.68454 .36713 L
.68559 .36766 L
.68655 .36837 L
.68777 .3696 L
.6889 .37107 L
.69145 .37568 L
.6937 .38121 L
.69608 .38845 L
.70099 .40684 L
.70626 .42803 L
.70881 .43701 L
.71007 .44079 L
.71123 .4438 L
.71237 .44623 L
.7134 .44791 L
.71455 .44917 L
.71577 .44974 L
.71706 .44942 L
.71825 .44824 L
.71955 .44593 L
.72021 .44435 L
.72092 .4423 L
.72343 .43248 L
.72577 .41968 L
.73107 .37894 L
.73675 .32305 L
.74171 .27168 L
.74697 .22326 L
.74971 .20294 L
.75116 .19392 L
.75273 .18569 L
.75417 .17954 L
.75548 .17509 L
.7568 .17176 L
.75805 .16964 L
.75932 .1685 L
.76047 .1683 L
.76111 .16851 L
.7618 .16899 L
.76305 .1705 L
.76422 .1726 L
.76546 .17546 L
Mistroke
.76768 .182 L
.77318 .20293 L
.77819 .22284 L
.78052 .23093 L
.78306 .23835 L
.78545 .24383 L
.78767 .2475 L
.78888 .24894 L
.79001 .24996 L
.79125 .25073 L
.79195 .25101 L
.79259 .25118 L
.79381 .25128 L
.7945 .25124 L
.79514 .25113 L
.79644 .25074 L
.79717 .25046 L
.79783 .25016 L
.80235 .24776 L
.80359 .24719 L
.8049 .24671 L
.80602 .24644 L
.80726 .24631 L
.80842 .24638 L
.80947 .24661 L
.8107 .2471 L
.81186 .24779 L
.81292 .24861 L
.81392 .24953 L
.81616 .25219 L
.85534 .28526 L
.85659 .28496 L
.85729 .28484 L
.85793 .28476 L
.85918 .28471 L
.86035 .28479 L
.86156 .28502 L
.86288 .28544 L
.86358 .28573 L
.86432 .28609 L
.86565 .28688 L
.86841 .28905 L
.87145 .29209 L
.87679 .2982 L
.8818 .30344 L
.88317 .30459 L
.88462 .30563 L
.88587 .30637 L
.8872 .30698 L
.88847 .3074 L
Mistroke
.88962 .30764 L
.89078 .30774 L
.89187 .30772 L
.89314 .30756 L
.89432 .30729 L
.8956 .30688 L
.89697 .30634 L
.90182 .30387 L
.90421 .30263 L
.90643 .30165 L
.90763 .30122 L
.90897 .30085 L
.90966 .3007 L
.91031 .3006 L
.91099 .30053 L
.91173 .3005 L
.91296 .30054 L
.91426 .30073 L
.91537 .30099 L
.91658 .3014 L
.91898 .30252 L
.92116 .30386 L
.92607 .30748 L
.93027 .31054 L
.9325 .31187 L
.93373 .31247 L
.9349 .31294 L
.93621 .31334 L
.9374 .31358 L
.93852 .31369 L
.93974 .3137 L
.94103 .31356 L
.94175 .31343 L
.9424 .31328 L
.94367 .31288 L
.94486 .31241 L
.94928 .31003 L
.95406 .30707 L
.95678 .30559 L
.95811 .305 L
.95933 .30456 L
.96061 .3042 L
.96131 .30406 L
.96198 .30395 L
.9627 .30388 L
.96337 .30385 L
.96411 .30386 L
.96489 .30392 L
.96606 .30409 L
.96733 .3044 L
Mistroke
.96853 .3048 L
.96962 .30524 L
.97485 .30815 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o
2_oonfX5o`000?oooo]Z7ooonfX00:Oooo]Z1_l0001RoookJPCo001o2_oonfX5o`0008Oooo]Z1_l0
002AoookJP00YooonfX6o`0006?ooo]Z0ol007l:oookJPGo0000QooonfX7o`00093ooo]Z002Voook
JPSo0000KooonfX5o`0008Kooo]Z2?l0002@oookJP00Y_oonfX8o`0006oooo]Z1Ol00025oookJPWo
0000T?oonfX00:Gooo]Z2_l0001^oookJPGo0000QOoonfX:o`0008oooo]Z002UoookJP[o0000K_oo
nfX5o`0008Gooo]Z2_l0002?oookJP00YOoonfX:o`0006kooo]Z1Ol00025oookJPCo000000?ooo]Z
o`000?l000001?l0002>oookJP00YOoonfX4o`0000;ooo]Z1Ol0001]oookJPGo0000QOoonfX4o`00
00;ooo]Z1Ol0002>oookJP00YOoonfX4o`0000;ooo]Z1Ol0001]oookJPGo0000Q?oonfX5o`0000;o
oo]Z1Ol0002>oookJP00Y?oonfX5o`0000;ooo]Z1Ol0001]oookJPGo0000Q?oonfX5o`0000?ooo]Z
1?l0002>oookJP00Y?oonfX5o`0000?ooo]Z1?l0001]oookJPGo0000Q?oonfX5o`0000?ooo]Z1Ol0
002=oookJP00Y?oonfX5o`0000?ooo]Z1Ol0001/oookJPGo0000Q?oonfX4o`0000Cooo]Z1Ol0002=
oookJP00XooonfX5o`0000Cooo]Z1Ol0001/oookJPGo0000PooonfX5o`0000Cooo]Z1Ol0002=oook
JP00XooonfX5o`0000Cooo]Z1Ol0001/oookJPGo0000PooonfX5o`0000Gooo]Z1?l0002=oookJP00
XooonfX5o`0000Gooo]Z1Ol0001[oookJPGo0000PooonfX5o`0000Gooo]Z1Ol0002<oookJP00Xooo
nfX4o`0000Kooo]Z1Ol0001[oookJPGo0000PooonfX4o`0000Kooo]Z1Ol0002<oookJP00XooonfX4
o`0000Kooo]Z1Ol0001[oookJPGo0000PooonfX4o`0000Kooo]Z1Ol0002<oookJP00XooonfX4o`00
00Oooo]Z1?l0001[oookJPGo0000P_oonfX5o`0000Oooo]Z1?l0002<oookJP00X_oonfX5o`0000Oo
oo]Z1Ol0001ZoookJPGo0000P_oonfX5o`0000Oooo]Z1Ol0002;oookJP00X_oonfX5o`0000Oooo]Z
1Ol0001ZoookJPGo0000P_oonfX5o`0000Oooo]Z1Ol0002;oookJP00X_oonfX5o`0000Oooo]Z1Ol0
001ZoookJPGo0000P_oonfX4o`0000Sooo]Z1Ol0002;oookJP00X_oonfX4o`0000Wooo]Z1Ol0001Y
oookJPGo0000P_oonfX4o`0000Wooo]Z1?l0002;oookJP00X_oonfX4o`0000Wooo]Z1Ol0001Yoook
JPGo0000P_oonfX4o`0000Wooo]Z1Ol0002:oookJP00X_oonfX4o`0000Wooo]Z1Ol0001YoookJPGo
0000P_oonfX4o`0000Wooo]Z1Ol0002:oookJP00X_oonfX4o`0000[ooo]Z1?l0001YoookJPGo0000
P_oonfX4o`0000Wooo]Z1Ol0002:oookJP00XOoonfX5o`0000[ooo]Z1Ol0001XoookJPGo0000POoo
nfX5o`0000[ooo]Z1Ol00029oookJP00XOoonfX5o`0000[ooo]Z1Ol0001XoookJPGo0000POoonfX5
o`0000[ooo]Z1Ol00029oookJP00XOoonfX5o`0000[ooo]Z1Ol0001XoookJPGo0000POoonfX5o`00
00[ooo]Z1Ol00029oookJP00XOoonfX4o`0000cooo]Z1Ol0001WoookJPGo0000POoonfX4o`0000co
oo]Z1Ol00028oookJP00XOoonfX4o`0000cooo]Z1Ol0001WoookJPGo0000POoonfX4o`0000cooo]Z
1Ol00028oookJP00XOoonfX4o`0000cooo]Z1Ol0001WoookJPGo0000POoonfX4o`0000cooo]Z1Ol0
0028oookJP00XOoonfX4o`0000gooo]Z1?l00019oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:
oookJPGo0000POoonfX4o`0000gooo]Z1?l00028oookJP00X?oonfX5o`0000gooo]Z1Ol00017oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000POoonfX4o`0000gooo]Z1Ol00027oook
JP00X?oonfX5o`0000gooo]Z1Ol00017oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`00087ooo]Z1?l0000=
oookJPGo0000QooonfX00:3ooo]Z1Ol0000=oookJPGo0000>_oonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000POoonfX4o`0000gooo]Z1Ol00027oook
JP00X?oonfX4o`0000oooo]Z1?l0000joookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2?oonfX6o`0007oooo]Z1Ol0000>oookJPCo0000QooonfX00:3ooo]Z1?l0000?oookJPGo0000
AOoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`00083ooo]Z1Ol0000>oookJPCo0000
QooonfX00:3ooo]Z1?l0000?oookJPGo0000AOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z1Ol00020oookJPGo00003_oonfX5o`0008Kooo]Z002PoookJPCo00003ooonfX5
o`0004Gooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol00020oookJPCo00003ooonfX5
o`0008Kooo]Z002OoookJPGo00004?oonfX4o`0004Gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
O`[ooo]Z1Ol00020oookJPCo00003ooonfX5o`0008Kooo]Z002OoookJPGo00004?oonfX5o`0004Co
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol00020oookJPCo00004?oonfX5o`0008Go
oo]Z002OoookJPGo00004?oonfX6o`0004Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o3_oonfX5o`00083ooo]Z1?l0000@oookJPKo0000Q?oonfX009oooo]Z1?l0000AoookJPKo0000
1_oonfX7o`0003Oooo]Z1ol007l9oookJPOo001o2?oonfX5o`00083ooo]Z1?l0000@oookJPKo0000
1_oonfX7o`0007Oooo]Z002OoookJPCo00004_oonfX6o`0000?ooo]Z2ol0000foookJPGo001o2_oo
nfX7o`00O`Sooo]Z1Ol00020oookJPCo00004OoonfX7o`0000;ooo]Z2ol0001eoookJP00WooonfX4
o`0001?ooo]Z4ol0001DoookJPGo0000OooonfX5o`0001;ooo]Z4ol0001eoookJP00WooonfX4o`00
01?ooo]Z5?l0001CoookJPGo0000OooonfX5o`0001;ooo]Z5Ol0001coookJP00WooonfX4o`0001Co
oo]Z5?l0001BoookJPGo0000OooonfX5o`0001?ooo]Z5Ol0001boookJP00WooonfX4o`0001Gooo]Z
2Ol00004oookJPOo0000DOoonfX5o`0007oooo]Z1?l0000EoookJPWo00001?oonfX8o`00077ooo]Z
002OoookJPCo00005_oonfX6o`0000Oooo]Z1_l0001AoookJPGo0000OooonfX4o`0001Kooo]Z1_l0
0007oookJPSo0000L?oonfX009oooo]Z1?l0000ToookJPKo0000D?oonfX5o`0007oooo]Z1?l0000U
oookJPSo0000K_oonfX009kooo]Z1Ol0000UoookJPGo0000D?oonfX5o`0007oooo]Z1?l0000Voook
JPSo0000KOoonfX009kooo]Z1Ol0000UoookJPKo0000CooonfX5o`0007oooo]Z1?l0000WoookJPSo
0000K?oonfX009kooo]Z1Ol0000VoookJPGo0000CooonfX5o`0007oooo]Z1?l0000XoookJPSo0000
JooonfX009kooo]Z1?l0000WoookJPKo0000C_oonfX5o`0007kooo]Z1Ol0000ZoookJPOo0000J_oo
nfX009kooo]Z1?l0000XoookJPGo0000C_oonfX5o`0007kooo]Z1Ol0000[oookJPSo0000J?oonfX0
09kooo]Z1?l0000XoookJPKo0000COoonfX5o`0007kooo]Z1Ol0000/oookJPSo0000IooonfX002;o
oo]Z0ol007meoookJPCo001o1?l000001?oonf[o001oo`00Ool007l3oookJPGo001o7OoonfX5o`00
04gooo]Z1Ol0001doookJPGo001o1?oonfX00ol007oo0000o`000002o`000003oookJ_l007oo001o
00?o001o:?oonfX8o`0004Kooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z1Ol007l4o`000004
oookJ_l007oo001oo`00O`;ooo]Z1ol007lLoookJPKo0000C?oonfX5o`0007?ooo]Z1ol007l3oook
JP03o`00Ool0003o000000;o00001ol007lXoookJPSo0000AOoonfX3o`00Oagooo]Z000RoookJP?o
001oM?oonfX3o`00O`03oookJ_l007oo000000?o000000Gooo]Zo`00Ool007oo001ooookJP04o`00
O`04oookJ_l007oo001oo`00Oagooo]Z1Ol0001<oookJPGo0000LooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z00?o001oo`000?l000000_l00003o`00O`04oookJ_l007oo001oo`00Ob[ooo]Z
2?l00013oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol0
07l3oookJPCo00001OoonfX3o`00O`?ooo]Z0ol007lLoookJPKo0000BooonfX5o`0007;ooo]Z0ol0
07l3oookJP?o001o0ooonfX4o`0000;o001o0ooonfX3o`00Ob[ooo]Z2?l00012oookJP?o001o7Ooo
nfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l3oookJPCo00002ooonfX3
o`00Oagooo]Z1Ol0001;oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l3oookJPCo00001OoonfX3
o`00Ob_ooo]Z2?l00011oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0ooonfX4o`00
00_ooo]Z0ol007lMoookJPKo0000B_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0ooonfX4o`00
00Gooo]Z0ol007l/oookJPSo0000@?oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`?o
oo]Z1?l00006oookJP;o001o0_oonfX4o`00Oakooo]Z1_l00019oookJPGo0000L_oonfX3o`00O`?o
oo]Z0ol007l2oookJPGo00000_l007l2oookJPCo001o;_oonfX7o`0003oooo]Z0ol007lMoookJP00
8_oonfX3o`00Og?ooo]Z0ol007l3oookJPCo00001_oonfX7o`00Oaoooo]Z1ol00006oookJPWo0000
>OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX5o`0000Oo001o<?oonfX;o`0003[ooo]Z
0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPGo00001_oonfX6o`00Ob7ooo]Z1ol0
0003oookJPgo0000=ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX5o`0000Ko001o<_oo
nfX<o`0003Sooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l2oookJPGo00001_oonfX2
o`00ObKooo]Z5_l0000goookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Z
o`00Ool007l0=ooonfX<o`0003Cooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l00ooo
nf[o0000o`000003o`0000Kooo]Z0_l007lWoookJQKo0000=_oonfX5o`0007?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJPCo000000?ooo]Zo`00Ool007l0>?oonfX;o`0003Cooo]Z1_l007lM
oookJP008OoonfX4o`00OgCooo]Z1?l007l4o`0000Sooo]Z1ol007lQoookJPgo00000_oonfX8o`00
03Gooo]Z1Ol0001coookJPOo001o0ooonfX4o`0000;ooo]Z1ol007lfoookJPSo0000=OoonfX4o`00
Oagooo]Z000RoookJP?o001oMOoonfX3o`00O`Co00002?oonfX7o`00Ob?ooo]Z2Ol00006oookJPOo
0000=?oonfX5o`0007Cooo]Z1Ol007l4oookJPCo00000_oonfX7o`00OcWooo]Z1_l0000eoookJP?o
001o7OoonfX009gooo]Z1?l00012oookJPOo0000<ooonfX5o`0007gooo]Z1?l00012oookJPOo0000
E?oonfX009gooo]Z1?l00013oookJPOo0000<_oonfX5o`0007gooo]Z1?l00013oookJPOo0000Dooo
nfX009gooo]Z1?l00014oookJPKo00003ooonfX5o`0001kooo]Z1Ol0001loookJPGo0000A?oonfX7
o`0000gooo]Z1_l0000ooookJP00WOoonfX4o`0004Gooo]Z1_l0000:oookJP_o00007?oonfX5o`00
07cooo]Z1Ol00015oookJPOo00002_oonfX:o`0003gooo]Z000_oookJPCo0000J_oonfX4o`0004Ko
oo]Z1ol00007oookJPoo00004?oonfX8o`000003oookJ_l0003o000000?o00003ooonfX4o`0006Wo
oo]Z1Ol00016oookJPOo00001_oonfX@o`00017ooo]Z1ol0000RoookJP00;?oonfX:o`0006Oooo]Z
1?l00016oookJPSo00001?oonfXBo`0000gooo]Z4?l0000<oookJP[o0000I_oonfX4o`0004Sooo]Z
1ol00004oookJQ;o00003OoonfX<o`00023ooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>
oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000LoookJPko00003Ooo
nfXLo`0004Wooo]Z1?l0001ToookJPko00002ooonfX?o`0000gooo]Z7_l00016oookJPGo0000I?oo
nfX>o`0000gooo]Z00?o0000oookJ_oonfX07?oonfX001gooo]Z3?l0000?oookJQ7o00000ooonfX8
o`0004Sooo]Z1?l0001VoookJP_o00003?oonfX>o`0000oooo]Z4Ol00004oookJPWo0000AOoonfX5
o`0006Gooo]Z2ol0000^oookJP008?oonfX8o`00017ooo]Z3ol00006oookJPOo0000AooonfX4o`00
06Sooo]Z1_l0000?oookJPco00004_oonfX>o`0000Oooo]Z2Ol00014oookJPGo0000J?oonfX5o`00
037ooo]Z000koookJP_o00002OoonfX7o`0004Kooo]Z1?l0001moookJPGo00006_oonfX;o`0000_o
oo]Z2?l00013oookJPCo0000WooonfX003gooo]Z1_l0000=oookJPKo0000A_oonfX4o`0007gooo]Z
1Ol0000MoookJPKo00003ooonfX8o`00047ooo]Z1?l0002OoookJP00DOoonfX6o`0004Cooo]Z1Ol0
001moookJPGo0000<ooonfX8o`00043ooo]Z1?l0002OoookJP00D_oonfX6o`0004?ooo]Z1Ol0001m
oookJPGo0000=?oonfX8o`0003oooo]Z1?l0002OoookJP00D_oonfX8o`0000Oooo]Z2?l0000boook
JPGo0000OOoonfX5o`0003Gooo]Z2?l0000noookJPCo0000WooonfX005?ooo]Z2?l00003oookJPco
0000<OoonfX4o`0007kooo]Z1Ol0000goookJPOo0000?OoonfX4o`0009oooo]Z001DoookJQOo0000
<?oonfX4o`0007kooo]Z1Ol0000hoookJPSo0000>ooonfX4o`0009oooo]Z001EoookJQKo0000<?oo
nfX4o`0007kooo]Z1Ol0000ioookJPSo0000>OoonfX5o`0009oooo]Z001GoookJPgo000000?ooo]Z
o`000?l000001Ol0000_oookJPCo0000O_oonfX5o`0003[ooo]Z2?l0000hoookJPGo0000WooonfX0
05Sooo]Z2Ol00006oookJPKo0000;_oonfX4o`0007kooo]Z1Ol0000koookJPWo0000=_oonfX5o`00
09oooo]Z001WoookJPOo0000;OoonfX4o`0007kooo]Z1Ol0000moookJPSo0000=OoonfX4o`000:3o
oo]Z001XoookJPKo0000;?oonfX5o`0007kooo]Z1Ol0000noookJPWo0000<ooonfX4o`000:3ooo]Z
001YoookJPKo0000:ooonfX5o`0007kooo]Z1Ol0000ooookJPWo0000<_oonfX4o`000:3ooo]Z001Z
oookJPKo0000:_oonfX5o`0007kooo]Z1Ol00011oookJPSo0000<OoonfX4o`000:3ooo]Z001Zoook
JPKo0000:_oonfX4o`0007oooo]Z1Ol00012oookJPWo0000;ooonfX4o`000:3ooo]Z001[oookJPKo
0000:OoonfX4o`0007oooo]Z1Ol00014oookJPSo0000;_oonfX4o`000:3ooo]Z001/oookJPGo0000
:OoonfX4o`0007oooo]Z1Ol00015oookJPSo0000;OoonfX4o`000:3ooo]Z001/oookJPKo0000:?oo
nfX4o`0007oooo]Z1Ol00016oookJPWo0000:_oonfX5o`000:3ooo]Z001]oookJPGo0000:?oonfX4
o`0007oooo]Z1Ol00018oookJPSo0000:OoonfX5o`000:3ooo]Z001]oookJPGo0000:?oonfX4o`00
07oooo]Z1Ol00019oookJPWo00009ooonfX5o`000:3ooo]Z001^oookJPGo00009ooonfX4o`0007oo
oo]Z1Ol0001:oookJPWo00009_oonfX4o`000:7ooo]Z001^oookJPGo00009_oonfX5o`0007oooo]Z
1Ol0001<oookJPSo00009OoonfX4o`000:7ooo]Z001^oookJPKo00009OoonfX5o`0007oooo]Z1Ol0
001=oookJPSo00009?oonfX4o`000:7ooo]Z001_oookJPKo00009?oonfX5o`0007oooo]Z1Ol0001?
oookJPKo00009?oonfX4o`000:7ooo]Z001_oookJPKo00002?oonfX6o`0001Kooo]Z1?l00020oook
JPGo0000D?oonfX6o`0000Oooo]Z1Ol0000GoookJPCo0000XOoonfX0073ooo]Z1ol00004oookJPWo
00005OoonfX4o`00083ooo]Z1Ol0001AoookJPGo00001OoonfX9o`0001Gooo]Z1?l0002QoookJP00
LOoonfX7o`000003oookJ_l0003o000000[o00005?oonfX4o`00083ooo]Z1Ol0001AoookJPOo0000
00?ooo]Zo`000?l000002_l0000DoookJPCo0000XOoonfX0077ooo]Z5Ol0000CoookJPCo0000P?oo
nfX5o`0005;ooo]Z4ol0000CoookJPGo0000XOoonfX007;ooo]Z5?l0000CoookJPCo0000P?oonfX5
o`0005;ooo]Z5?l0000BoookJPGo0000XOoonfX007Cooo]Z2_l00003oookJPKo00004_oonfX4o`00
083ooo]Z1Ol0001CoookJP_o00000ooonfX6o`00017ooo]Z1Ol0002QoookJP00MOoonfX7o`0000Ko
oo]Z1Ol0000AoookJPGo0000P?oonfX5o`0005Gooo]Z1ol00005oookJPKo00004OoonfX4o`000:;o
oo]Z0022oookJPKo00004?oonfX5o`00083ooo]Z1Ol0001RoookJPKo00004?oonfX4o`000:;ooo]Z
0023oookJPGo00004?oonfX5o`0006;ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0
001SoookJPGo00004?oonfX4o`000:;ooo]Z0023oookJPGo00004?oonfX4o`0006;ooo]Z1ol007l3
oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001SoookJPGo00004?oonfX4o`000:;ooo]Z0024oook
JPCo00004?oonfX4o`0006;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000I?oonfX4o`00013ooo]Z1?l0
002RoookJP00Q?oonfX5o`0000oooo]Z1?l0001QoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o2?oonfX5o`0006Cooo]Z1Ol0000?oookJPCo0000X_oonfX008Cooo]Z1Ol0000?oook
JPCo0000HOoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0006?ooo]Z1Ol0000>oook
JPGo0000X_oonfX008Cooo]Z1Ol0000?oookJPCo0000HOoonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2?oonfX5o`0006Cooo]Z1Ol0000>oookJPGo0000X_oonfX008Gooo]Z1?l0000>oookJPGo0000
HOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001UoookJPCo0000
3_oonfX5o`000:;ooo]Z0025oookJPGo00003OoonfX5o`00067ooo]Z0ol007l3oookJP?o001o1ooo
nfX7o`00O`Wooo]Z1Ol0001UoookJPGo00003OoonfX4o`000:?ooo]Z0025oookJPGo00003OoonfX5
o`00067ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001UoookJPGo00003OoonfX4
o`000:?ooo]Z0025oookJPGo00003OoonfX4o`0006;ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`kooo]Z1Ol0001UoookJPGo00003OoonfX4o`000:?ooo]Z0026oookJPGo00003?oonfX4o`0006?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0006Kooo]Z1Ol0000<oook
JPCo0000XooonfX008Kooo]Z1Ol0000<oookJPCo0000HooonfX7o`00O`Wooo]Z1ol007l8oookJPGo
0000I_oonfX5o`0000_ooo]Z1Ol0002SoookJP00Q_oonfX5o`0000cooo]Z1?l0001ToookJPGo001o
2_oonfX7o`00O`Sooo]Z1Ol0001VoookJPGo00002ooonfX5o`000:?ooo]Z0027oookJPGo00002_oo
nfX5o`0008;ooo]Z1Ol0001WoookJPGo00002_oonfX5o`000:?ooo]Z0027oookJPGo00002_oonfX5
o`0008;ooo]Z1Ol0001WoookJPGo00002_oonfX4o`000:Cooo]Z0027oookJPGo00002_oonfX5o`00
08;ooo]Z1Ol0001WoookJPGo00002_oonfX4o`000:Cooo]Z0028oookJPCo00002_oonfX4o`0008?o
oo]Z1Ol0001XoookJPCo00002_oonfX4o`000:Cooo]Z0028oookJPGo00002OoonfX4o`0008?ooo]Z
1Ol0001XoookJPGo00002OoonfX4o`000:Cooo]Z0028oookJPGo00002OoonfX4o`0008?ooo]Z1Ol0
001XoookJPGo00002?oonfX5o`000:Cooo]Z0028oookJPGo00002OoonfX4o`0008?ooo]Z1Ol0001X
oookJPGo00002?oonfX5o`000:Cooo]Z0029oookJPGo00001ooonfX5o`0008?ooo]Z1Ol0001Yoook
JPCo00002?oonfX5o`000:Cooo]Z0029oookJPGo00001ooonfX5o`0008?ooo]Z1Ol0001YoookJPGo
00001ooonfX4o`000:Gooo]Z0029oookJPGo00001ooonfX5o`0008?ooo]Z1Ol0001YoookJPGo0000
1ooonfX4o`000:Gooo]Z002:oookJPCo00001ooonfX4o`0008Cooo]Z1Ol0001YoookJPGo00001ooo
nfX4o`000:Gooo]Z002:oookJPGo00001_oonfX4o`0008Cooo]Z1Ol0001ZoookJPCo00001ooonfX4
o`000:Gooo]Z002:oookJPGo00001_oonfX4o`0008Cooo]Z1Ol0001ZoookJPGo00001OoonfX5o`00
0:Gooo]Z002:oookJPGo00001OoonfX5o`0008Cooo]Z1Ol0001ZoookJPGo00001OoonfX5o`000:Go
oo]Z002;oookJPCo00001OoonfX5o`0008Cooo]Z1Ol0001ZoookJPGo00001OoonfX5o`000:Gooo]Z
002;oookJPGo00001?oonfX5o`0008Cooo]Z1Ol0001[oookJPCo00001OoonfX4o`000:Kooo]Z002;
oookJPGo00001?oonfX4o`0008Gooo]Z1Ol0001[oookJPGo00001?oonfX4o`000:Kooo]Z002;oook
JPGo00000ooonfX5o`0008Gooo]Z1Ol0001[oookJPGo00001?oonfX4o`000:Kooo]Z002<oookJPCo
00000ooonfX5o`0008Gooo]Z1Ol0001[oookJPGo00000ooonfX5o`000:Kooo]Z002<oookJPGo0000
0_oonfX5o`0008Gooo]Z1Ol0001/oookJPGo00000_oonfX5o`000:Kooo]Z002<oookJPGo00000_oo
nfX4o`0008Kooo]Z1Ol0001/oookJPGo00000_oonfX5o`000:Kooo]Z002<oookJPGo00000_oonfX4
o`0008Kooo]Z1Ol0001/oookJPGo000000?ooo]Zo`000?l000000ol0002WoookJP00SOoonfX:o`00
08Kooo]Z1Ol0001]oookJP[o0000YooonfX008gooo]Z2_l00026oookJPGo0000KOoonfX:o`000:Oo
oo]Z002=oookJP[o0000Q_oonfX5o`0006gooo]Z2Ol0002XoookJP00S_oonfX8o`0008Oooo]Z1Ol0
001^oookJPSo0000Z?oonfX008kooo]Z1ol00028oookJPGo0000KooonfX6o`000:Wooo]Z002?oook
JPKo0000R?oonfX5o`0006oooo]Z1_l0002YoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoook
JP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1_l0003ooookJQko
oo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooook
JQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o2_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ3ooo]Z1?l0
07l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`So
oo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`000?oooo]Z
7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2
oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfXOoookJP00oooonfX2oook
JP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPKo
001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z
7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0OoonfX4
o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2_oonfX7o`00
O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z
1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX6o`000?oooo]Z7_oo
nfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol007l9oook
JPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o
0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003o
oookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooonfX>oookJPOo001ooooonfX]oook
JP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oo
nfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.06244 .31349 L
.07216 .30827 L
.0735 .30758 L
.07496 .30695 L
.07563 .30671 L
.07633 .30649 L
.0776 .3062 L
.07882 .30607 L
.07996 .30607 L
.08121 .30622 L
.08191 .30637 L
.08255 .30655 L
.084 .30711 L
.08535 .30779 L
.0884 .30986 L
.09396 .31459 L
.0966 .31674 L
.0991 .31843 L
.10048 .31917 L
.10121 .31949 L
.10197 .31977 L
.10262 .31996 L
.10333 .32013 L
.10458 .32031 L
.10585 .32033 L
.10657 .32028 L
.10723 .32019 L
.10845 .31993 L
.10975 .31953 L
.11199 .31861 L
.11446 .31741 L
.11709 .31615 L
.11847 .31559 L
.11922 .31532 L
.11992 .31512 L
.1212 .31484 L
.12187 .31475 L
.12259 .31471 L
.12388 .31478 L
.12505 .315 L
.12624 .3154 L
.1275 .316 L
.12858 .31667 L
.12976 .31757 L
.13487 .32298 L
.13931 .32878 L
.14415 .33457 L
.14546 .33583 L
.14686 .33696 L
Mistroke
.14806 .33776 L
.14936 .33843 L
.15006 .3387 L
.1507 .3389 L
.15196 .33914 L
.15311 .3392 L
.15431 .33912 L
.15542 .33892 L
.15661 .33861 L
.15874 .33786 L
.16127 .33687 L
.16238 .33647 L
.1636 .3361 L
.16491 .33584 L
.16562 .33576 L
.16629 .33574 L
.16703 .33578 L
.1677 .33588 L
.16844 .33606 L
.16922 .33634 L
.17054 .33703 L
.17176 .33793 L
.1731 .33922 L
.17453 .34092 L
.17975 .3497 L
.18449 .35975 L
.18936 .36952 L
.19181 .37339 L
.19321 .37515 L
.1945 .37644 L
.19568 .37733 L
.1968 .37792 L
.19798 .37828 L
.19926 .37838 L
.20038 .37824 L
.20157 .37789 L
.20259 .37746 L
.20371 .37686 L
.20623 .37529 L
.2076 .37445 L
.20888 .37377 L
.2096 .37346 L
.21026 .37324 L
.211 .37307 L
.21178 .373 L
.21244 .37304 L
.21315 .3732 L
.21444 .3738 L
.21566 .37479 L
.21635 .37555 L
Mistroke
.21699 .37639 L
.2184 .37871 L
.21969 .3814 L
.22202 .38765 L
.22453 .3962 L
.23372 .43503 L
.235 .43981 L
.23637 .44437 L
.23759 .44774 L
.23887 .4505 L
.24002 .45221 L
.24129 .45311 L
.24245 .45298 L
.24353 .45198 L
.24419 .45092 L
.24492 .44937 L
.24624 .44549 L
.24753 .44036 L
.24872 .43443 L
.25141 .41688 L
.25428 .39256 L
.26425 .28158 L
.26882 .23227 L
.27132 .20968 L
.27363 .19241 L
.27615 .17826 L
.27749 .17284 L
.27817 .17061 L
.27891 .16862 L
.28021 .16616 L
.28144 .16502 L
.28264 .16497 L
.28374 .16578 L
.28479 .16727 L
.28593 .16958 L
.28797 .17535 L
.29262 .19361 L
.29718 .21347 L
.29968 .22328 L
.30202 .23109 L
.30335 .23477 L
.30479 .2381 L
.30598 .24034 L
.30729 .24227 L
.30853 .24359 L
.30983 .2445 L
.31104 .24494 L
.31217 .24503 L
.31285 .24496 L
.3136 .24478 L
Mistroke
.31431 .24454 L
.31496 .24425 L
.3175 .24279 L
.31892 .24188 L
.32045 .24097 L
.32119 .24059 L
.32189 .24027 L
.32321 .23984 L
.32437 .23966 L
.32543 .23969 L
.32661 .23996 L
.32786 .24054 L
.32852 .24097 L
.32924 .24154 L
.33054 .24282 L
.33297 .24606 L
.33836 .25623 L
.34332 .26685 L
.34802 .27534 L
.34937 .27724 L
.35065 .27876 L
.35181 .2799 L
.35305 .28085 L
.35412 .28148 L
.35531 .28196 L
.35639 .2822 L
.3574 .28229 L
.35859 .28224 L
.35968 .28206 L
.36088 .28174 L
.36214 .28132 L
.36459 .28036 L
.36691 .27951 L
.36819 .27916 L
.36891 .27901 L
.36958 .27891 L
.37075 .27883 L
.372 .27892 L
.37266 .27903 L
.37338 .27922 L
.37466 .2797 L
.37545 .2801 L
.37619 .28055 L
.37759 .28157 L
.38008 .28391 L
.3828 .28707 L
.38768 .29344 L
.39024 .29663 L
.39295 .2995 L
.39532 .30142 L
Mistroke
.39667 .30222 L
.39792 .30277 L
.39908 .30311 L
.40013 .30328 L
.40135 .30332 L
.4025 .30321 L
.40313 .3031 L
.40383 .30293 L
.40524 .30249 L
.40778 .3014 L
.41054 .30004 L
.41199 .29935 L
.41351 .29871 L
.41479 .29827 L
.41547 .29808 L
.4162 .29792 L
.41747 .29774 L
.41866 .2977 L
.41996 .29781 L
.42119 .29807 L
.42229 .29843 L
.42348 .29894 L
.42585 .30032 L
.42838 .30222 L
.43297 .30616 L
.43576 .30844 L
.43714 .30942 L
.43841 .31022 L
.43955 .31081 L
.44079 .31133 L
.44205 .3117 L
.44274 .31184 L
.44339 .31193 L
.44461 .31198 L
.44531 .31194 L
.44596 .31187 L
.44727 .3116 L
.448 .31139 L
.44867 .31115 L
.45116 .31003 L
.45351 .3087 L
.45871 .30569 L
.46014 .30502 L
.46167 .30444 L
.46241 .30422 L
.46312 .30405 L
.46375 .30393 L
.46444 .30385 L
.46572 .30379 L
.46688 .30387 L
Mistroke
.46752 .30397 L
.46821 .30411 L
.46947 .30447 L
.47065 .30492 L
.4719 .30551 L
.47414 .30677 L
.47946 .31026 L
.48205 .31178 L
.48319 .31234 L
.48442 .31285 L
.48555 .31322 L
.4866 .31346 L
.4876 .31361 L
.48866 .31366 L
.48978 .31361 L
.49083 .31346 L
.49197 .31319 L
.49321 .31278 L
.49567 .31165 L
.49825 .31014 L
.50286 .30722 L
.50544 .30583 L
.5067 .30529 L
.50787 .30489 L
.50893 .30462 L
.51005 .30444 L
.51117 .30437 L
.51241 .30443 L
.51309 .30452 L
.51374 .30464 L
.51495 .30497 L
.51626 .30545 L
.51768 .30611 L
.52261 .30914 L
.52723 .31207 L
.52856 .31275 L
.52981 .3133 L
.53093 .31369 L
.53214 .314 L
.53321 .31417 L
.53438 .31424 L
.53561 .31418 L
.53675 .31401 L
.53782 .31375 L
.53879 .31344 L
.54098 .3125 L
.5458 .30974 L
.54845 .30822 L
.54974 .30756 L
.55092 .30704 L
Mistroke
.55193 .30667 L
.55303 .30636 L
.55419 .30615 L
.55529 .30606 L
.5565 .30609 L
.55779 .30629 L
.559 .30663 L
.56011 .30707 L
.56141 .30772 L
.56278 .30856 L
.56524 .31037 L
.5708 .31514 L
.57312 .31699 L
.57561 .31862 L
.57703 .31933 L
.57833 .31982 L
.57964 .32016 L
.58088 .32031 L
.58202 .32033 L
.58325 .32021 L
.5844 .31999 L
.58546 .31969 L
.58793 .31872 L
.59052 .31747 L
.59289 .31632 L
.59419 .31576 L
.59542 .31532 L
.59612 .31511 L
.59687 .31493 L
.59819 .31474 L
.59884 .31471 L
.59953 .31473 L
.60077 .31489 L
.60191 .31521 L
.60296 .31563 L
.60416 .31628 L
.6053 .31706 L
.60954 .32115 L
.6146 .32759 L
.61919 .33333 L
.62156 .33575 L
.62281 .33679 L
.62413 .33769 L
.62529 .33831 L
.62656 .3388 L
.62771 .33907 L
.62879 .33919 L
.62942 .3392 L
.63012 .33916 L
.63137 .33897 L
Mistroke
.63259 .33867 L
.63373 .33831 L
.63645 .33726 L
.63779 .33674 L
.63901 .33632 L
.64001 .33605 L
.64106 .33584 L
.64211 .33574 L
.64326 .33578 L
.64443 .336 L
.64568 .33646 L
.64686 .33712 L
.64794 .33792 L
.65028 .34035 L
.65281 .34399 L
.65741 .35271 L
.66198 .36253 L
.66689 .37175 L
.66833 .37384 L
.6697 .37548 L
.67093 .37664 L
.67163 .37717 L
.67227 .37757 L
.67354 .37812 L
.67423 .37829 L
.67488 .37837 L
.67605 .37833 L
.67731 .37805 L
.67862 .37753 L
.67985 .37689 L
.68265 .37515 L
.68405 .3743 L
.68537 .37363 L
.6861 .37335 L
.68689 .37313 L
.68761 .37302 L
.68828 .37301 L
.68948 .37324 L
.69061 .37378 L
.69184 .37478 L
.69253 .37555 L
.69317 .37638 L
.69444 .37843 L
.69583 .38128 L
.69836 .3881 L
.70322 .40624 L
.70848 .42918 L
.7109 .43877 L
.71222 .4433 L
.71345 .44691 L
Mistroke
.71459 .4496 L
.71563 .45145 L
.71679 .45274 L
.71802 .45316 L
.71871 .45294 L
.71943 .45233 L
.72073 .45023 L
.72145 .4485 L
.72213 .4465 L
.72367 .44056 L
.72502 .43383 L
.72625 .42641 L
.72902 .40551 L
.73388 .35751 L
.739 .29844 L
.7439 .24347 L
.74854 .20152 L
.7511 .18461 L
.75255 .17735 L
.75388 .17213 L
.755 .16885 L
.75624 .16639 L
.75753 .16507 L
.75873 .16493 L
.75987 .16571 L
.76111 .16748 L
.76228 .16996 L
.76336 .17286 L
.76759 .18835 L
.77254 .20998 L
.7771 .22758 L
.77958 .23485 L
.78084 .2378 L
.78219 .24038 L
.78355 .24236 L
.78482 .24368 L
.78559 .24425 L
.78632 .24464 L
.78698 .24488 L
.78769 .24501 L
.78889 .24498 L
.79021 .24465 L
.79087 .24438 L
.79158 .24404 L
.79287 .2433 L
.79516 .24186 L
.79637 .24113 L
.79766 .24046 L
.79895 .23996 L
.80011 .2397 L
Mistroke
.80129 .23966 L
.8024 .23984 L
.80364 .24032 L
.80479 .24103 L
.80605 .2421 L
.80738 .24358 L
.80957 .2467 L
.81162 .25029 L
.81628 .25995 L
.82127 .27033 L
.82391 .27489 L
.82535 .27697 L
.82671 .27861 L
.82798 .27988 L
.82915 .28079 L
.83045 .28154 L
.83113 .28183 L
.83184 .28205 L
.83302 .28226 L
.83411 .28229 L
.83532 .28216 L
.8366 .28188 L
.839 .28107 L
.84159 .28004 L
.84279 .27961 L
.84405 .27924 L
.84513 .279 L
.84631 .27886 L
.84746 .27885 L
.84851 .27897 L
.84972 .27926 L
.85088 .27971 L
.85194 .28027 L
.85292 .28091 L
.85515 .28277 L
.86023 .28865 L
.86572 .29579 L
.86825 .29863 L
.86963 .29994 L
.87091 .30099 L
.8721 .3018 L
.87319 .30238 L
.87439 .30287 L
.87568 .30319 L
.87684 .30331 L
.87806 .30329 L
.87911 .30314 L
.88026 .30287 L
.8815 .30246 L
.88283 .30192 L
Mistroke
.88524 .30078 L
.88749 .29967 L
.88962 .29874 L
.89079 .29833 L
.89207 .29798 L
.89323 .29778 L
.89429 .2977 L
.89544 .29773 L
.8967 .29791 L
.89802 .29826 L
.89926 .29875 L
.90148 .29995 L
.90387 .30166 L
.90888 .30593 L
.91153 .30812 L
.91435 .31007 L
.91589 .31088 L
.91728 .31143 L
.91796 .31163 L
.91869 .3118 L
.92 .31196 L
.92065 .31198 L
.92137 .31195 L
.92211 .31187 L
.9228 .31175 L
.92405 .31143 L
.92537 .31095 L
.92808 .30963 L
.93065 .30813 L
.93313 .30666 L
.93545 .30542 L
.93767 .3045 L
.93892 .30414 L
.94006 .30392 L
.9413 .3038 L
.94201 .30379 L
.94266 .30383 L
.94386 .30399 L
.94514 .3043 L
.94583 .30453 L
.94647 .30477 L
.94791 .30541 L
.95052 .30689 L
.95541 .3101 L
.95747 .31136 L
.95968 .31248 L
.96095 .31297 L
.96211 .31331 L
.96327 .31354 L
.96437 .31365 L
Mistroke
.96551 .31364 L
.96673 .31351 L
.96776 .3133 L
.96891 .31296 L
.97013 .31248 L
.97145 .31186 L
.97385 .3105 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z002WoookJPGo0000HOoonfX6o`00O`[ooo]Z1Ol00027oookJPGo0000T_oonfX00:Kooo]Z
1_l0001QoookJPKo001o2_oonfX5o`0008Kooo]Z1ol0002AoookJP00YOoonfX8o`0006;ooo]Z1?l0
07l:oookJPGo0000QOoonfX8o`00097ooo]Z002UoookJPSo0000HooonfX3o`00O`[ooo]Z1Ol00025
oookJPSo0000TOoonfX00:Cooo]Z2Ol0001`oookJPGo0000QOoonfX9o`00093ooo]Z002ToookJP[o
0000KooonfX5o`0008Gooo]Z2Ol0002@oookJP00Y?oonfX:o`0006oooo]Z1Ol00024oookJP[o0000
T?oonfX00:Cooo]Z1?l000000ooonf[o0000o`000003o`0006oooo]Z1Ol00024oookJPGo000000?o
oo]Zo`000?l000000ol0002?oookJP00Y?oonfX4o`0000;ooo]Z1Ol0001^oookJPGo0000Q?oonfX5
o`000003oookJ_l0003o000000?o0000SooonfX00:Cooo]Z1?l00002oookJPGo0000K_oonfX5o`00
08Cooo]Z1?l00002oookJPGo0000SooonfX00:?ooo]Z1Ol00002oookJPGo0000K_oonfX5o`0008?o
oo]Z1Ol00003oookJPCo0000SooonfX00:?ooo]Z1Ol00003oookJPGo0000KOoonfX5o`0008?ooo]Z
1Ol00003oookJPCo0000SooonfX00:?ooo]Z1Ol00003oookJPGo0000KOoonfX5o`0008?ooo]Z1Ol0
0003oookJPGo0000S_oonfX00:?ooo]Z1?l00004oookJPGo0000KOoonfX5o`0008?ooo]Z1?l00004
oookJPGo0000S_oonfX00:;ooo]Z1Ol00005oookJPGo0000K?oonfX5o`0008?ooo]Z1?l00004oook
JPGo0000S_oonfX00:;ooo]Z1Ol00005oookJPGo0000K?oonfX5o`0008?ooo]Z1?l00005oookJPCo
0000S_oonfX00:;ooo]Z1Ol00005oookJPGo0000K?oonfX5o`0008;ooo]Z1Ol00005oookJPGo0000
SOoonfX00:;ooo]Z1?l00007oookJPCo0000K?oonfX5o`0008;ooo]Z1Ol00005oookJPGo0000SOoo
nfX00:;ooo]Z1?l00007oookJPCo0000K?oonfX5o`0008;ooo]Z1Ol00005oookJPGo0000SOoonfX0
0:;ooo]Z1?l00007oookJPGo0000JooonfX5o`0008;ooo]Z1?l00007oookJPGo0000S?oonfX00:7o
oo]Z1Ol00007oookJPGo0000JooonfX5o`0008;ooo]Z1?l00007oookJPGo0000S?oonfX00:7ooo]Z
1Ol00007oookJPGo0000JooonfX5o`0008;ooo]Z1?l00007oookJPGo0000S?oonfX00:7ooo]Z1Ol0
0008oookJPCo0000JooonfX5o`0008;ooo]Z1?l00008oookJPCo0000S?oonfX00:7ooo]Z1?l00009
oookJPCo0000JooonfX5o`0008;ooo]Z1?l00008oookJPGo0000RooonfX00:7ooo]Z1?l00009oook
JPGo0000J_oonfX5o`0008;ooo]Z1?l00008oookJPGo0000RooonfX00:7ooo]Z1?l00009oookJPGo
0000J_oonfX5o`00087ooo]Z1Ol00008oookJPGo0000RooonfX00:7ooo]Z1?l00009oookJPGo0000
J_oonfX5o`00087ooo]Z1Ol00009oookJPCo0000RooonfX00:7ooo]Z1?l0000:oookJPCo0000J_oo
nfX5o`00087ooo]Z1Ol00009oookJPGo0000R_oonfX00:7ooo]Z1?l0000:oookJPCo0000J_oonfX5
o`00087ooo]Z1?l0000:oookJPGo0000R_oonfX00:7ooo]Z1?l0000:oookJPCo0000J_oonfX5o`00
087ooo]Z1?l0000:oookJPGo0000R_oonfX00:7ooo]Z1?l0000:oookJPGo0000JOoonfX5o`00087o
oo]Z1?l0000;oookJPCo0000R_oonfX00:3ooo]Z1Ol0000:oookJPGo0000JOoonfX5o`00087ooo]Z
1?l0000;oookJPCo0000R_oonfX00:3ooo]Z1Ol0000:oookJPGo0000JOoonfX5o`00083ooo]Z1Ol0
000;oookJPGo0000ROoonfX00:3ooo]Z1Ol0000;oookJPCo0000BooonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o2_oonfX5o`00083ooo]Z1Ol0000;oookJPGo0000ROoonfX00:3ooo]Z1?l0000<oook
JPGo0000BOoonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`00083ooo]Z1Ol0000;oook
JPGo0000ROoonfX00:3ooo]Z1?l0000<oookJPGo0000BOoonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol00020
oookJPCo00003OoonfX4o`0008Wooo]Z002PoookJPCo00003?oonfX6o`0003_ooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`00083ooo]Z1?l0000=oook
JPGo0000R?oonfX00:3ooo]Z1?l0000=oookJPGo0000>ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Sooo]Z1_l0001ooookJPCo00003OoonfX5o`0008Sooo]Z002PoookJPCo0000
3OoonfX5o`0004Oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol00020oookJPCo0000
3OoonfX6o`0008Oooo]Z002PoookJPCo00003_oonfX4o`0004Oooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l8oookJPGo0000P?oonfX4o`0000kooo]Z1Ol00027oookJP00X?oonfX4
o`0000kooo]Z1Ol00007oookJPCo0000>ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5
o`0007oooo]Z1Ol0000>oookJPGo00001ooonfX4o`0007cooo]Z002OoookJPGo00003_oonfX6o`00
00Cooo]Z2?l0000ioookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000OooonfX5o`00
00oooo]Z1Ol00004oookJPSo0000N_oonfX009oooo]Z1Ol0000>oookJPOo000000?ooo]Zo`000?l0
00002Ol0000hoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000OooonfX5o`0000oo
oo]Z1_l000000ooonf[o0000o`000009o`0007Wooo]Z002OoookJPGo00003ooonfXBo`0003Wooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007oooo]Z1?l0000@oookJQ?o
0000N?oonfX009oooo]Z1?l0000AoookJQ;o0000>?oonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000
OooonfX4o`00017ooo]Z4ol0001goookJP00WooonfX4o`0001;ooo]Z2_l00002oookJPGo0000>Ooo
nfX5o`00O`[ooo]Z1ol007l8oookJPGo0000OooonfX4o`0001;ooo]Z2_l00002oookJPKo0000Mooo
nfX009oooo]Z1?l0000BoookJPSo00001?oonfX6o`0005Kooo]Z1Ol0001ooookJPCo00004_oonfX8
o`0000Gooo]Z1_l0001foookJP00WooonfX4o`0001oooo]Z1_l0001EoookJPGo0000OooonfX4o`00
023ooo]Z1Ol0001foookJP00WooonfX4o`0001oooo]Z1_l0001EoookJPGo0000OooonfX4o`00023o
oo]Z1_l0001eoookJP00WooonfX4o`00023ooo]Z1_l0001DoookJPGo0000OooonfX4o`00027ooo]Z
1Ol0001eoookJP00W_oonfX5o`00027ooo]Z1Ol0001DoookJPGo0000OooonfX4o`00027ooo]Z1Ol0
001eoookJP00W_oonfX5o`00027ooo]Z1_l0001CoookJPGo0000O_oonfX5o`0002;ooo]Z1Ol0001d
oookJP00W_oonfX5o`0002;ooo]Z1Ol0001CoookJPGo0000O_oonfX5o`0002;ooo]Z1Ol0001doook
JP00W_oonfX4o`0002?ooo]Z1_l0001BoookJPGo0000O_oonfX5o`0002;ooo]Z1_l0001coookJP00
W_oonfX4o`0002Cooo]Z1Ol0001BoookJPGo0000O_oonfX4o`0002Cooo]Z1Ol0001coookJP00W_oo
nfX4o`0002Cooo]Z1_l0001AoookJPGo0000O_oonfX4o`0002Cooo]Z1_l0001boookJP00W_oonfX4
o`0002Gooo]Z1Ol0001AoookJPGo0000O_oonfX4o`0002Gooo]Z1Ol0001boookJP00W_oonfX4o`00
02Gooo]Z1_l0001@oookJPGo0000O_oonfX4o`0002Gooo]Z1_l0001aoookJP008_oonfX3o`00OgGo
oo]Z1?l007l4o`000004oookJ_l007oo001oo`00O`?ooo]Z1Ol007lJoookJPKo0000CooonfX5o`00
07Cooo]Z1Ol007l4oookJP03o`00Ool0003o000000;o000000?ooo]Zo`00Ool007l00ol007lPoook
JPGo0000DOoonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX4o`00O`Go000000Cooo]Zo`00Ool0
07oo001o0_oonfX7o`00OaWooo]Z1_l0001?oookJPGo0000LooonfX7o`00O`?ooo]Z00?o001oo`00
0?l000000_l00007o`00Oaoooo]Z1_l0001@oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o
001o00?ooo]Zo`000?l000000ol000001Ooonf[o001oo`00Ool007oooo]Z00Co001o00Cooo]Zo`00
Ool007oo001o6_oonfX6o`0004kooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX00ol007oo0000o`000002o`0000?o001o00Cooo]Zo`00Ool007oo001o8?oonfX6o`0004oooo]Z
0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1Ol0
0005oookJP?o001o0ooonfX3o`00Oa[ooo]Z1Ol0001>oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol0
07l3oookJPCo00000_l007l3oookJP?o001o7ooonfX6o`0004oooo]Z0ol007lMoookJP004ooonfX:
o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1?l0000<oookJP?o001o6_oonfX7
o`0000Cooo]Z2Ol0000ooookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l3oookJPCo00001OoonfX3
o`00Ob3ooo]Z1ol00003oookJP[o0000@?oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00
O`;ooo]Z1?l0000<oookJP?o001o6ooonfXDo`0003kooo]Z1Ol0001boookJP?o001o0ooonfX3o`00
O`?ooo]Z1?l00005oookJP?o001o8OoonfXCo`00043ooo]Z0ol007lMoookJP008_oonfX3o`00Og?o
oo]Z0ol007l2oookJPCo00001ooonfX2o`00O`;ooo]Z1?l007lKoookJQGo0000?OoonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o0ooonfX4o`0000;o001o0_oonfX4o`00Ob7ooo]Z5?l0000ooookJP?o
001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4o`0000Oooo]Z1ol007lMoookJQCo0000
?OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0ooonfX4o`0000Oo001o8ooonfXDo`0003kooo]Z
0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo00001ooonfX6o`00Oaoooo]Z2ol0
0002oookJPOo0000??oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX5o`0000Ko001o9Ooo
nfX:o`0000?ooo]Z1ol0000moookJP?o001o7OoonfX001oooo]Z1_l007mcoookJP?o001o0_oonfX4
o`0000Oooo]Z0_l007lVoookJPCo00002?oonfX5o`0003cooo]Z1Ol0001boookJP?o001o0ooonfX3
o`00O`;ooo]Z1Ol00002o`00Ob_ooo]Z1Ol00007oookJPOo0000>OoonfX6o`00Oagooo]Z000Ooook
JPKo001oM?oonfX3o`00O`03oookJ_l0003o000000;o00001ooonfX2o`00Oc;ooo]Z1_l0000koook
JPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1Ol00002o`00OcSooo]Z1_l0000i
oookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJPCo001o1?l00008oookJPOo001o;OoonfX6o`00
03[ooo]Z1Ol0001coookJPOo001o0ooonfX4o`0000;ooo]Z1ol007lcoookJPKo0000>_oonfX4o`00
Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Go00002?oonfX7o`00Obgooo]Z2?l0000hoookJPGo
0000M?oonfX5o`00O`Cooo]Z1?l00002oookJPOo001o=?oonfX6o`0003[ooo]Z0ol007lMoookJP00
W?oonfX5o`0003gooo]Z2?l0000goookJPGo0000OOoonfX4o`0003gooo]Z2?l0001HoookJP00W?oo
nfX5o`0003kooo]Z1ol00008oookJPWo00009_oonfX5o`0007gooo]Z1?l0000noookJPSo00001ooo
nfX:o`0004Kooo]Z002LoookJPCo0000@?oonfX7o`0000Gooo]Z3Ol0000ToookJPGo0000OOoonfX4
o`0003oooo]Z1ol00006oookJPco0000AOoonfX009cooo]Z1?l00012oookJPOo000000?ooo]Zo`00
0?l000003ol0000RoookJPGo0000OOoonfX4o`00043ooo]Z2?l000000ooonf[o0000o`00000?o`00
04?ooo]Z002LoookJPCo0000@_oonfXJo`0000gooo]Z1ol0000=oookJPGo0000OOoonfX4o`0004;o
oo]Z6Ol0000=oookJPOo0000;_oonfX003Wooo]Z1?l0001OoookJPCo0000@ooonfX>o`0000?ooo]Z
2Ol00009oookJPco00002ooonfX>o`0000oooo]Z1_l0001OoookJPCo0000@_oonfX>o`0000Cooo]Z
2?l0000:oookJP_o0000;?oonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003o
o`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go
00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX001gooo]Z00Co0000oookJ_oonf[ooo]Z
5_l00008oookJPSo00001_oonfX;o`0004?ooo]Z1Ol0001LoookJP_o00002ooonfX@o`0000Wooo]Z
3Ol00008oookJPWo00001_oonfX;o`0004Cooo]Z1?l0001LoookJP[o00003?oonfX>o`0001kooo]Z
000/oookJPSo00003?oonfX8o`0000?ooo]Z3Ol00013oookJPGo0000G_oonfX6o`0000oooo]Z3ol0
000:oookJP_o00002ooonfX8o`0000;ooo]Z3_l00014oookJPCo0000G_oonfX6o`00013ooo]Z2_l0
000PoookJP00@OoonfXHo`0004;ooo]Z1Ol0001foookJPGo00000_oonfX5o`0000cooo]Z1ol0000>
oookJQSo0000@ooonfX4o`0007Oooo]Z1?l0000SoookJP00@_oonfX@o`000003oookJ_l0003o0000
00Go0000@OoonfX4o`0007kooo]Z1Ol0000SoookJPoo000000?ooo]Zo`000?l000001Ol00012oook
JPCo0000W_oonfX004Cooo]Z3?l00004oookJPOo0000@?oonfX4o`0007kooo]Z1Ol0000ToookJPco
00001?oonfX7o`00047ooo]Z1?l0002NoookJP00A?oonfX:o`0000Oooo]Z1ol0000ooookJPCo0000
O_oonfX5o`0002Gooo]Z2?l00008oookJPOo0000@?oonfX4o`0009kooo]Z001FoookJPOo0000?_oo
nfX4o`0007kooo]Z1Ol0000foookJPOo0000?ooonfX4o`0009kooo]Z001GoookJPOo0000?OoonfX4
o`0007kooo]Z1Ol0000goookJPOo0000?OoonfX5o`0009kooo]Z001HoookJPKo0000?OoonfX4o`00
07kooo]Z1Ol0000hoookJPOo0000??oonfX5o`0009kooo]Z001IoookJPKo0000??oonfX4o`0007ko
oo]Z1Ol0000ioookJPOo0000>ooonfX5o`0009kooo]Z001JoookJPKo0000>ooonfX4o`0007kooo]Z
1Ol0000joookJPKo0000>ooonfX4o`0009oooo]Z001JoookJPSo00000ooonfX9o`0002gooo]Z1?l0
001noookJPGo0000>ooonfX7o`0000;ooo]Z2ol0000/oookJPCo0000WooonfX005_ooo]Z5Ol0000Z
oookJPGo0000O_oonfX5o`0003cooo]Z4ol0000/oookJPCo0000WooonfX005cooo]Z5Ol0000Yoook
JPGo0000O_oonfX5o`0003cooo]Z5?l0000[oookJPCo0000WooonfX005gooo]Z5?l0000YoookJPGo
0000O_oonfX5o`0003gooo]Z5?l0000ZoookJPCo0000WooonfX005kooo]Z2_l00003oookJPOo0000
:?oonfX4o`0007oooo]Z1Ol0000noookJPWo00001?oonfX7o`0002Wooo]Z1?l0002OoookJP00KOoo
nfX5o`0002Sooo]Z1?l0001ooookJPGo0000C?oonfX6o`0002Wooo]Z1?l0002OoookJP00KOoonfX5
o`0002Sooo]Z1?l0001ooookJPGo0000COoonfX6o`0002Sooo]Z1?l0002OoookJP00K_oonfX5o`00
02Oooo]Z1?l0001ooookJPGo0000C_oonfX5o`0002Oooo]Z1Ol0002OoookJP00K_oonfX5o`0002Oo
oo]Z1?l0001ooookJPGo0000C_oonfX5o`0002Oooo]Z1Ol0002OoookJP00K_oonfX6o`0002Kooo]Z
1?l0001ooookJPGo0000CooonfX5o`0002Kooo]Z1Ol0002OoookJP00KooonfX5o`0002Kooo]Z1?l0
001ooookJPGo0000CooonfX5o`0002Kooo]Z1?l0002PoookJP00KooonfX6o`0002Gooo]Z1?l0001o
oookJPGo0000CooonfX6o`0002Gooo]Z1?l0002PoookJP00L?oonfX5o`0002Gooo]Z1?l0001ooook
JPGo0000D?oonfX6o`0002Cooo]Z1?l0002PoookJP00L?oonfX6o`0002?ooo]Z1Ol0001ooookJPGo
0000D?oonfX6o`0002Cooo]Z1?l0002PoookJP00LOoonfX5o`0002?ooo]Z1Ol0001ooookJPGo0000
DOoonfX6o`0002?ooo]Z1?l0002PoookJP00LOoonfX6o`0002;ooo]Z1Ol0001ooookJPGo0000D_oo
nfX5o`0002?ooo]Z1?l0002PoookJP00L_oonfX6o`00027ooo]Z1?l00020oookJPGo0000D_oonfX6
o`00027ooo]Z1Ol0002PoookJP00L_oonfX6o`00027ooo]Z1?l00020oookJPGo0000DooonfX5o`00
027ooo]Z1Ol0002PoookJP00LooonfX6o`00023ooo]Z1?l00020oookJPGo0000DooonfX5o`00027o
oo]Z1Ol0002PoookJP00M?oonfX5o`00023ooo]Z1?l00020oookJPGo0000E?oonfX5o`00023ooo]Z
1?l0002QoookJP00M?oonfX6o`0000Gooo]Z1ol0000CoookJPCo0000P?oonfX5o`0005Cooo]Z1_l0
0005oookJPOo00004ooonfX4o`000:7ooo]Z001eoookJPKo00000_oonfX:o`0001;ooo]Z1?l00020
oookJPGo0000E?oonfX7o`0000;ooo]Z2_l0000BoookJPCo0000XOoonfX007Gooo]Z4ol0000Aoook
JPCo0000P?oonfX5o`0005Gooo]Z4ol0000AoookJPCo0000XOoonfX007Kooo]Z4_l0000AoookJPCo
0000P?oonfX5o`0005Kooo]Z4_l0000AoookJPCo0000XOoonfX007Oooo]Z2ol000000ooonf[o0000
o`000004o`00013ooo]Z1?l0001RoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000
EooonfX;o`000003oookJ_l0003o000000Co00004?oonfX4o`000:7ooo]Z001goookJPWo00001?oo
nfX5o`0000oooo]Z1Ol0001QoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000F?oo
nfX8o`0000Cooo]Z1Ol0000?oookJPGo0000XOoonfX007Wooo]Z1_l00005oookJPGo00003ooonfX5
o`00067ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l9oookJPGo0000FOoonfX5o`0000Kooo]Z1_l0000>oookJPGo0000
XOoonfX008Gooo]Z1Ol0000>oookJPGo0000H?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Sooo]Z1Ol0001UoookJPGo00003_oonfX5o`000:7ooo]Z0025oookJPGo00003_oonfX4
o`00067ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001ToookJPKo00003OoonfX4
o`000:;ooo]Z0025oookJPGo00003_oonfX4o`00067ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Sooo]Z1Ol0001VoookJPGo00003OoonfX4o`000:;ooo]Z0026oookJPGo00003OoonfX4o`00067o
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000I_oonfX5o`0000go
oo]Z1?l0002RoookJP00Q_oonfX5o`0000gooo]Z1?l0001QoookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l9oookJPGo0000IooonfX5o`0000cooo]Z1?l0002RoookJP00Q_oonfX6o`0000cooo]Z1?l0
001QoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000IooonfX5o`0000cooo]Z1?l0
002RoookJP00QooonfX5o`0000cooo]Z1?l0001QoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>
oookJPGo0000IooonfX5o`0000cooo]Z1?l0002RoookJP00QooonfX5o`0000_ooo]Z1Ol0001Roook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001XoookJPCo00002ooonfX5
o`000:;ooo]Z0028oookJPGo00002_oonfX5o`0006;ooo]Z1ol007l9oookJPOo001o2?oonfX5o`00
06Sooo]Z1?l0000;oookJPGo0000X_oonfX008Sooo]Z1Ol0000:oookJPGo0000HooonfX5o`00O`[o
oo]Z1ol007l8oookJPGo0000J?oonfX5o`0000[ooo]Z1Ol0002RoookJP00R?oonfX5o`0000[ooo]Z
1?l00022oookJPGo0000J?oonfX5o`0000[ooo]Z1?l0002SoookJP00ROoonfX4o`0000[ooo]Z1?l0
0022oookJPGo0000J?oonfX5o`0000[ooo]Z1?l0002SoookJP00ROoonfX5o`0000Wooo]Z1?l00022
oookJPGo0000JOoonfX4o`0000[ooo]Z1?l0002SoookJP00ROoonfX5o`0000Wooo]Z1?l00022oook
JPGo0000JOoonfX4o`0000[ooo]Z1?l0002SoookJP00ROoonfX5o`0000Sooo]Z1Ol00022oookJPGo
0000JOoonfX5o`0000Wooo]Z1?l0002SoookJP00R_oonfX4o`0000Sooo]Z1Ol00022oookJPGo0000
JOoonfX5o`0000Wooo]Z1?l0002SoookJP00R_oonfX5o`0000Oooo]Z1Ol00022oookJPGo0000JOoo
nfX5o`0000Wooo]Z1?l0002SoookJP00R_oonfX5o`0000Oooo]Z1?l00023oookJPGo0000J_oonfX4
o`0000Sooo]Z1Ol0002SoookJP00R_oonfX5o`0000Oooo]Z1?l00023oookJPGo0000J_oonfX5o`00
00Oooo]Z1Ol0002SoookJP00RooonfX4o`0000Oooo]Z1?l00023oookJPGo0000J_oonfX5o`0000Oo
oo]Z1Ol0002SoookJP00RooonfX4o`0000Oooo]Z1?l00023oookJPGo0000J_oonfX5o`0000Oooo]Z
1?l0002ToookJP00RooonfX5o`0000Kooo]Z1?l00023oookJPGo0000JooonfX4o`0000Oooo]Z1?l0
002ToookJP00RooonfX5o`0000Gooo]Z1Ol00023oookJPGo0000JooonfX5o`0000Kooo]Z1?l0002T
oookJP00RooonfX5o`0000Gooo]Z1Ol00023oookJPGo0000JooonfX5o`0000Kooo]Z1?l0002Toook
JP00S?oonfX4o`0000Gooo]Z1Ol00023oookJPGo0000JooonfX5o`0000Kooo]Z1?l0002ToookJP00
S?oonfX5o`0000Cooo]Z1?l00024oookJPGo0000K?oonfX4o`0000Gooo]Z1Ol0002ToookJP00S?oo
nfX5o`0000Cooo]Z1?l00024oookJPGo0000K?oonfX5o`0000Cooo]Z1Ol0002ToookJP00S?oonfX5
o`0000Cooo]Z1?l00024oookJPGo0000K?oonfX5o`0000Cooo]Z1Ol0002ToookJP00SOoonfX4o`00
00?ooo]Z1Ol00024oookJPGo0000K?oonfX5o`0000?ooo]Z1Ol0002UoookJP00SOoonfX4o`0000?o
oo]Z1Ol00024oookJPGo0000KOoonfX4o`0000?ooo]Z1Ol0002UoookJP00SOoonfX4o`0000?ooo]Z
1Ol00024oookJPGo0000KOoonfX5o`0000;ooo]Z1Ol0002UoookJP00SOoonfX5o`000003oookJ_l0
003o000000?o0000QOoonfX5o`0006gooo]Z1Ol00002oookJPCo0000Y_oonfX008gooo]Z1Ol00000
0ooonf[o0000o`000003o`0008Gooo]Z1Ol0001]oookJPGo000000?ooo]Zo`000?l000000ol0002V
oookJP00SOoonfX;o`0008Gooo]Z1Ol0001^oookJP[o0000Y_oonfX008kooo]Z2Ol00026oookJPGo
0000K_oonfX:o`000:Kooo]Z002>oookJPWo0000Q_oonfX5o`0006kooo]Z2Ol0002WoookJP00Sooo
nfX8o`0008Kooo]Z1Ol0001_oookJPSo0000YooonfX008oooo]Z2?l00026oookJPGo0000KooonfX8
o`000:Oooo]Z002?oookJPOo0000QooonfX5o`00073ooo]Z1ol0002WoookJP00T?oonfX6o`0007[o
oo]Z0ol007l:oookJPGo0000L?oonfX6o`000:Sooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000
oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3
o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPKo0000oooonfXNoook
JP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXA
oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX@oookJPCo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooook
JP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9
oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQko
oo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3
o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00
O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoo
oo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l0
07l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003o
oookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00oooonfX>oookJPCo
001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z
003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5
o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?o
oo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooo
nfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;OoonfX0
0?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02605 .31044 L
.02846 .31178 L
.02962 .31231 L
.03072 .31271 L
.03171 .31299 L
.03279 .31319 L
.03397 .31329 L
.03527 .31323 L
.03592 .31315 L
.03663 .31301 L
.0379 .31264 L
.03916 .31215 L
.04036 .31157 L
.04262 .31029 L
.04721 .30743 L
.04853 .3067 L
.04977 .30611 L
.0509 .30567 L
.0521 .30531 L
.05274 .30518 L
.05344 .30508 L
.05467 .30502 L
.05537 .30505 L
.05612 .30514 L
.05682 .30528 L
.05746 .30545 L
.05869 .30588 L
.06002 .30649 L
.06244 .30793 L
.06792 .31182 L
.0706 .31348 L
.07177 .31406 L
.07306 .31457 L
.07431 .31492 L
.07564 .31512 L
.07633 .31515 L
.07708 .31514 L
.07778 .31507 L
.07842 .31497 L
.07918 .3148 L
.07988 .31461 L
.08146 .31402 L
.08433 .31258 L
.08678 .31119 L
.08941 .30981 L
.09069 .30926 L
.0919 .30886 L
.09298 .30861 L
.09417 .30846 L
Mistroke
.09541 .30848 L
.09611 .30856 L
.09674 .30869 L
.09797 .30906 L
.09913 .30957 L
.10049 .31036 L
.10175 .31124 L
.10458 .31366 L
.10929 .31827 L
.11189 .32057 L
.11316 .32154 L
.11434 .32229 L
.11543 .32287 L
.11662 .32335 L
.11783 .32368 L
.1191 .32384 L
.12018 .32385 L
.12134 .32371 L
.12244 .32347 L
.12344 .32317 L
.12597 .32215 L
.12867 .32091 L
.12998 .32036 L
.13121 .31993 L
.13232 .31963 L
.13352 .31944 L
.1348 .31941 L
.13545 .31948 L
.13616 .31961 L
.13741 .32001 L
.13859 .32058 L
.13998 .32152 L
.14126 .32261 L
.14412 .32579 L
.14888 .3325 L
.15336 .33878 L
.1556 .34133 L
.15676 .34241 L
.15803 .34338 L
.15933 .34414 L
.16005 .34445 L
.16071 .34467 L
.16191 .3449 L
.16318 .34495 L
.1639 .34489 L
.16457 .34479 L
.16531 .34462 L
.16608 .3444 L
.16882 .34339 L
.1701 .34289 L
Mistroke
.17147 .34242 L
.17277 .34209 L
.17396 .34195 L
.17512 .34198 L
.17639 .34224 L
.17759 .34275 L
.1787 .34347 L
.18003 .34464 L
.18124 .34601 L
.18393 .3501 L
.1933 .37073 L
.19558 .37548 L
.19802 .37964 L
.19942 .38147 L
.2007 .38275 L
.20198 .38365 L
.20319 .38414 L
.2045 .38429 L
.20516 .38423 L
.20589 .38407 L
.20718 .38356 L
.20839 .38287 L
.21134 .38077 L
.21263 .37986 L
.21331 .37944 L
.21404 .37905 L
.21526 .37858 L
.21638 .37842 L
.21767 .37864 L
.21884 .37928 L
.22012 .3805 L
.22084 .38145 L
.22151 .3825 L
.2228 .38504 L
.22402 .38805 L
.22646 .39579 L
.2287 .40461 L
.23372 .4278 L
.23583 .43731 L
.23807 .44609 L
.23935 .45015 L
.24052 .45302 L
.24169 .45501 L
.2428 .45595 L
.244 .45586 L
.24532 .45431 L
.24598 .45293 L
.24669 .451 L
.24797 .44628 L
.24925 .43999 L
Mistroke
.25046 .43258 L
.25272 .41508 L
.25786 .36053 L
.26344 .28903 L
.26799 .2338 L
.27049 .20829 L
.27288 .18873 L
.27422 .18001 L
.27568 .17246 L
.27632 .16979 L
.27701 .16739 L
.27824 .1642 L
.27889 .16309 L
.2796 .16232 L
.28088 .16203 L
.28212 .16304 L
.28327 .16497 L
.28449 .16797 L
.28579 .1721 L
.28814 .18141 L
.29349 .20625 L
.29639 .21867 L
.29914 .22815 L
.30034 .23141 L
.30161 .23425 L
.30227 .23548 L
.30301 .23664 L
.3043 .23819 L
.30561 .23916 L
.30685 .23957 L
.30754 .23961 L
.30828 .23952 L
.30958 .23907 L
.31083 .2384 L
.31215 .2375 L
.31451 .23577 L
.31568 .23499 L
.31695 .23432 L
.31768 .23404 L
.31834 .23386 L
.31964 .23375 L
.32036 .23384 L
.32102 .23402 L
.32175 .23434 L
.32252 .23482 L
.32326 .23541 L
.32396 .23609 L
.32526 .23765 L
.3276 .24138 L
.33008 .24635 L
Mistroke
.3345 .25658 L
.33932 .26693 L
.34071 .26934 L
.34203 .2713 L
.34322 .27279 L
.34449 .27406 L
.34562 .27492 L
.34686 .27559 L
.348 .27594 L
.34906 .27609 L
.35031 .27605 L
.35145 .27585 L
.35271 .2755 L
.35403 .27502 L
.35609 .27421 L
.35722 .27379 L
.35829 .27347 L
.35955 .27319 L
.36069 .27308 L
.36177 .27311 L
.36293 .27332 L
.36419 .27377 L
.36537 .27439 L
.36666 .2753 L
.36805 .27654 L
.37346 .28338 L
.37816 .29022 L
.38074 .29351 L
.38316 .29597 L
.38437 .29691 L
.38567 .29769 L
.38637 .29801 L
.38711 .29828 L
.38774 .29845 L
.38843 .29857 L
.38965 .29863 L
.39096 .2985 L
.39219 .29823 L
.39331 .29786 L
.39861 .29554 L
.40007 .29497 L
.40086 .2947 L
.40161 .2945 L
.40292 .29425 L
.40362 .29419 L
.40437 .29418 L
.40505 .29422 L
.40569 .2943 L
.40639 .29445 L
.40714 .29466 L
Mistroke
.40852 .29523 L
.40977 .29592 L
.41231 .29778 L
.41471 .29995 L
.41937 .3045 L
.42183 .30662 L
.42319 .3076 L
.42448 .30836 L
.42574 .30893 L
.42646 .30918 L
.42712 .30936 L
.42829 .30955 L
.42953 .30958 L
.43069 .30945 L
.43177 .30921 L
.43296 .30883 L
.43425 .3083 L
.43927 .30557 L
.4406 .30486 L
.44201 .30417 L
.44332 .30363 L
.44456 .30325 L
.44572 .30301 L
.44697 .30289 L
.44811 .30291 L
.44917 .30305 L
.45033 .30333 L
.45161 .30379 L
.45295 .30442 L
.4542 .30512 L
.45879 .30829 L
.46304 .31114 L
.46428 .31179 L
.46545 .31229 L
.4661 .31251 L
.4668 .31271 L
.46802 .31294 L
.46868 .313 L
.4694 .31302 L
.47015 .31298 L
.47085 .31289 L
.4721 .31262 L
.47281 .3124 L
.47345 .31217 L
.47588 .31101 L
.47853 .30943 L
.48081 .30798 L
.48333 .30652 L
.48449 .30596 L
.48574 .30545 L
Mistroke
.48692 .30509 L
.48801 .30487 L
.48922 .30475 L
.48991 .30475 L
.49055 .30479 L
.49172 .30496 L
.49297 .30528 L
.49412 .3057 L
.49537 .30626 L
.49763 .30752 L
.50187 .31021 L
.50424 .31157 L
.50554 .31219 L
.50678 .31267 L
.50792 .313 L
.50917 .31322 L
.51031 .31329 L
.51136 .31324 L
.5126 .31305 L
.51376 .31275 L
.51504 .31228 L
.51642 .31164 L
.52179 .30841 L
.52456 .30678 L
.52591 .30613 L
.52714 .30565 L
.52844 .30528 L
.52915 .30514 L
.52983 .30506 L
.53056 .30502 L
.53124 .30503 L
.53198 .3051 L
.53277 .30523 L
.53397 .30554 L
.53525 .30603 L
.53757 .30725 L
.54285 .31093 L
.54539 .31266 L
.54678 .31348 L
.5481 .31412 L
.54932 .31459 L
.55002 .3148 L
.55065 .31495 L
.55178 .31511 L
.55297 .31515 L
.55428 .31503 L
.55502 .31489 L
.55569 .31472 L
.55699 .31428 L
.55823 .31376 L
Mistroke
.564 .31062 L
.56643 .30944 L
.56765 .30899 L
.56836 .30879 L
.56901 .30864 L
.57016 .30848 L
.57139 .30846 L
.57248 .3086 L
.57363 .30888 L
.57489 .30936 L
.57622 .31007 L
.57863 .31178 L
.5841 .31692 L
.58667 .31937 L
.58908 .32134 L
.5904 .32221 L
.59159 .32286 L
.59293 .32339 L
.59366 .3236 L
.59436 .32374 L
.59505 .32383 L
.59579 .32386 L
.59649 .32384 L
.59712 .32377 L
.59787 .32365 L
.59868 .32346 L
.60014 .32299 L
.60268 .32192 L
.60547 .32065 L
.60675 .32015 L
.60745 .31991 L
.60811 .31973 L
.60941 .31948 L
.61058 .3194 L
.61123 .31943 L
.61193 .31952 L
.61317 .31984 L
.61386 .32012 L
.6145 .32043 L
.61598 .32137 L
.6184 .32357 L
.62062 .32619 L
.62562 .33332 L
.63039 .3398 L
.63176 .3413 L
.63305 .3425 L
.63423 .34339 L
.63547 .34411 L
.63656 .34456 L
.63775 .34486 L
Mistroke
.63884 .34496 L
.63986 .34492 L
.64106 .34473 L
.64215 .34444 L
.64461 .34355 L
.64708 .34261 L
.64833 .34224 L
.64904 .34208 L
.6497 .34198 L
.65043 .34194 L
.65109 .34195 L
.65182 .34205 L
.65258 .34224 L
.65385 .34279 L
.65458 .34324 L
.65525 .34375 L
.65656 .345 L
.6578 .3465 L
.66012 .3501 L
.66533 .36106 L
.67035 .3726 L
.6728 .37738 L
.67505 .38079 L
.67626 .38217 L
.67741 .38316 L
.67862 .38387 L
.67931 .38412 L
.67995 .38425 L
.68065 .38429 L
.68132 .38424 L
.68256 .38391 L
.68325 .38362 L
.68389 .38328 L
.68534 .38237 L
.68741 .38086 L
.68962 .37937 L
.69089 .37876 L
.69205 .37846 L
.69321 .37848 L
.69432 .37884 L
.69546 .37962 L
.69668 .38095 L
.69771 .38253 L
.69886 .38475 L
.7014 .39155 L
.70379 .40009 L
.7089 .42301 L
.71365 .44388 L
.71488 .44816 L
.71604 .45147 L
Mistroke
.71668 .45297 L
.71738 .45427 L
.7186 .45572 L
.71925 .45603 L
.71997 .45597 L
.72072 .45543 L
.72141 .45447 L
.72267 .45163 L
.72337 .44939 L
.72401 .44693 L
.72637 .43441 L
.72856 .41812 L
.73351 .36702 L
.74252 .25284 L
.74715 .2041 L
.74841 .1936 L
.74975 .18409 L
.7509 .17723 L
.75213 .17131 L
.7533 .16706 L
.75437 .16433 L
.75543 .16265 L
.75644 .162 L
.75762 .16233 L
.75871 .1636 L
.7599 .16595 L
.76116 .16941 L
.77108 .21249 L
.77394 .22368 L
.77535 .2282 L
.77666 .23172 L
.77794 .23452 L
.77909 .23649 L
.78038 .23809 L
.78109 .23871 L
.78175 .23914 L
.78289 .23954 L
.78413 .23957 L
.78543 .23922 L
.78665 .23862 L
.79115 .23546 L
.79246 .23466 L
.79371 .23409 L
.79483 .2338 L
.79605 .23376 L
.79668 .23386 L
.79737 .23408 L
.7981 .23443 L
.79878 .23487 L
.79999 .23592 L
Mistroke
.8013 .23745 L
.80352 .24089 L
.80595 .24568 L
.81085 .25695 L
.81505 .26606 L
.81742 .27016 L
.8196 .27301 L
.82083 .27419 L
.82217 .27515 L
.82285 .2755 L
.82358 .27578 L
.82489 .27606 L
.82554 .2761 L
.82623 .27608 L
.8275 .27588 L
.82874 .27555 L
.82989 .27515 L
.83222 .27423 L
.83336 .27381 L
.83441 .27348 L
.83563 .27321 L
.83694 .27308 L
.83805 .27312 L
.83923 .27335 L
.84053 .27383 L
.84173 .27449 L
.8431 .2755 L
.8444 .2767 L
.84922 .28276 L
.85444 .29034 L
.8572 .29383 L
.85873 .29541 L
.86018 .29663 L
.86143 .29746 L
.86209 .2978 L
.86279 .29811 L
.86403 .29847 L
.86518 .29862 L
.86645 .29859 L
.86764 .29841 L
.86871 .29813 L
.86987 .29773 L
.87486 .29552 L
.87608 .29503 L
.87738 .29461 L
.87813 .29442 L
.87881 .2943 L
.87949 .29421 L
.88014 .29418 L
.8813 .29422 L
Mistroke
.88253 .29443 L
.88358 .29475 L
.88474 .29524 L
.88598 .29593 L
.88732 .29685 L
.88974 .29886 L
.89401 .30302 L
.89636 .30523 L
.89858 .30704 L
.89982 .30788 L
.90117 .30861 L
.9024 .3091 L
.90353 .3094 L
.9046 .30956 L
.90577 .30957 L
.90699 .30943 L
.90814 .30916 L
.90879 .30896 L
.90949 .3087 L
.91078 .30814 L
.91318 .30687 L
.91603 .30526 L
.91861 .30399 L
.91992 .3035 L
.92061 .30329 L
.92134 .30311 L
.92197 .303 L
.92267 .30291 L
.9239 .30289 L
.92464 .30294 L
.92532 .30304 L
.92609 .30321 L
.92683 .30343 L
.92813 .30393 L
.92955 .30463 L
.93479 .30815 L
.93735 .30997 L
.9397 .3114 L
.94168 .3123 L
.94267 .31262 L
.94375 .31287 L
.94485 .313 L
.94602 .313 L
.94712 .31288 L
.94812 .31267 L
.94931 .31229 L
.95041 .31184 L
.9529 .31055 L
.9574 .30774 L
.9595 .30654 L
Mistroke
.96066 .30597 L
.96175 .30552 L
.96304 .30511 L
.96422 .30487 L
.96533 .30476 L
.96653 .30477 L
.96769 .30492 L
.96896 .30522 L
.9696 .30543 L
.97029 .30569 L
.97155 .30626 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00Y_oonfX4
o`0006Kooo]Z0ol007l:oookJPGo0000Q_oonfX4o`0009Cooo]Z002UoookJPKo0000IOoonfX3o`00
O`[ooo]Z1Ol00025oookJPKo0000TooonfX00:Gooo]Z1ol0001QoookJPKo001o2_oonfX5o`0008Go
oo]Z1ol0002BoookJP00Y?oonfX8o`00067ooo]Z1_l007l:oookJPGo0000Q?oonfX8o`0009;ooo]Z
002ToookJPSo0000HooonfX4o`00O`[ooo]Z1Ol00024oookJPWo0000TOoonfX00:Cooo]Z2?l0001T
oookJP?o001o2_oonfX5o`0008Cooo]Z2Ol0002AoookJP00XooonfX:o`00073ooo]Z1Ol00024oook
JPWo0000TOoonfX00:?ooo]Z2_l0001`oookJPGo0000Q?oonfX4o`000003oookJ_l0003o000000?o
0000T?oonfX00:?ooo]Z2_l0001`oookJPGo0000PooonfX5o`000003oookJ_l0003o000000?o0000
T?oonfX00:?ooo]Z1?l00002oookJPGo0000KooonfX5o`0008?ooo]Z1Ol000000ooonf[o0000o`00
0003o`00093ooo]Z002SoookJPCo00000_oonfX5o`0006oooo]Z1Ol00023oookJPGo00000_oonfX4
o`00093ooo]Z002SoookJPCo00000_oonfX5o`0006oooo]Z1Ol00022oookJPGo00000ooonfX4o`00
093ooo]Z002SoookJPCo00000ooonfX4o`0006oooo]Z1Ol00022oookJPGo00000ooonfX5o`0008oo
oo]Z002RoookJPGo00000ooonfX4o`0006oooo]Z1Ol00022oookJPGo00000ooonfX5o`0008oooo]Z
002RoookJPGo00000ooonfX5o`0006kooo]Z1Ol00022oookJPCo00001?oonfX5o`0008oooo]Z002R
oookJPGo00000ooonfX5o`0006kooo]Z1Ol00022oookJPCo00001OoonfX4o`0008oooo]Z002Roook
JPCo00001?oonfX5o`0006kooo]Z1Ol00022oookJPCo00001OoonfX4o`0008oooo]Z002RoookJPCo
00001OoonfX4o`0006kooo]Z1Ol00022oookJPCo00001OoonfX5o`0008kooo]Z002RoookJPCo0000
1OoonfX5o`0006gooo]Z1Ol00022oookJPCo00001OoonfX5o`0008kooo]Z002RoookJPCo00001Ooo
nfX5o`0006gooo]Z1Ol00022oookJPCo00001OoonfX5o`0008kooo]Z002RoookJPCo00001OoonfX5
o`0006gooo]Z1Ol00022oookJPCo00001_oonfX4o`0008kooo]Z002QoookJPGo00001_oonfX4o`00
06gooo]Z1Ol00021oookJPGo00001_oonfX4o`0008kooo]Z002QoookJPGo00001_oonfX4o`0006go
oo]Z1Ol00021oookJPGo00001_oonfX5o`0008gooo]Z002QoookJPGo00001_oonfX5o`0006cooo]Z
1Ol00021oookJPGo00001_oonfX5o`0008gooo]Z002QoookJPCo00001ooonfX5o`0006cooo]Z1Ol0
0021oookJPCo00001ooonfX5o`0008gooo]Z002QoookJPCo00001ooonfX5o`0006cooo]Z1Ol00021
oookJPCo00002?oonfX4o`0008gooo]Z002QoookJPCo00002?oonfX4o`0006cooo]Z1Ol00021oook
JPCo00002?oonfX4o`0008gooo]Z002QoookJPCo00002?oonfX5o`0006_ooo]Z1Ol00021oookJPCo
00002?oonfX5o`0008cooo]Z002QoookJPCo00002?oonfX5o`0006_ooo]Z1Ol00020oookJPGo0000
2?oonfX5o`0008cooo]Z002PoookJPGo00002?oonfX5o`0006_ooo]Z1Ol00020oookJPGo00002?oo
nfX5o`0008cooo]Z002PoookJPGo00002OoonfX5o`0006[ooo]Z1Ol00020oookJPGo00002OoonfX4
o`0008cooo]Z002PoookJPGo00002OoonfX5o`0006[ooo]Z1Ol00020oookJPCo00002_oonfX4o`00
08cooo]Z002PoookJPCo00002_oonfX5o`0006[ooo]Z1Ol00020oookJPCo00002_oonfX5o`0008_o
oo]Z002PoookJPCo00002ooonfX4o`0006[ooo]Z1Ol00020oookJPCo00002_oonfX5o`0008_ooo]Z
002PoookJPCo00002ooonfX5o`0006Wooo]Z1Ol00020oookJPCo00002_oonfX5o`0008_ooo]Z002P
oookJPCo00002ooonfX5o`0004_ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol00020
oookJPCo00002ooonfX4o`0008_ooo]Z002OoookJPGo00002ooonfX5o`0004[ooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1Ol00020oookJPCo00002ooonfX5o`0008[ooo]Z002OoookJPGo
00003?oonfX4o`0004[ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000OooonfX5o`0000_ooo]Z1Ol0002:
oookJP00WooonfX5o`0000cooo]Z1Ol0000loookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001ooookJPGo00002ooonfX6o`0008Wooo]Z002OoookJPCo
00003OoonfX5o`0000Gooo]Z1_l0000aoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2?oonfX6o`0007kooo]Z1Ol0000<oookJPGo00001OoonfX6o`0007kooo]Z002OoookJPCo0000
3OoonfX6o`0000;ooo]Z2Ol0000loookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000
OooonfX4o`0000gooo]Z1_l00002oookJP[o0000O?oonfX009oooo]Z1?l0000>oookJPGo000000?o
oo]Zo`000?l000002Ol0000koookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oo
nfX5o`0007oooo]Z1?l0000>oookJPGo000000?ooo]Zo`000?l000002Ol0001loookJP00WooonfX4
o`0000kooo]Z4_l0000joookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000OooonfX4
o`0000kooo]Z4Ol0001loookJP00WooonfX4o`0000kooo]Z4ol0000ioookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007l:oookJPGo0000OooonfX4o`0000oooo]Z4Ol0001koookJP00WooonfX4o`0000oo
oo]Z2Ol00003oookJPKo0000>OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0007oo
oo]Z1?l0000?oookJPWo00000ooonfX5o`0007_ooo]Z002OoookJPCo00004?oonfX7o`0000Gooo]Z
1_l0000ioookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001ooookJPCo
00004?oonfX7o`0000Cooo]Z1_l0001joookJP00WooonfX4o`0001gooo]Z1Ol0000ioookJPOo001o
2OoonfX7o`00O`Sooo]Z1Ol0001noookJPGo00007?oonfX6o`0007Wooo]Z002NoookJPGo00007Ooo
nfX5o`0003[ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0007kooo]Z1Ol0000LoookJPKo0000NOoo
nfX009kooo]Z1Ol0000NoookJPGo0000EooonfX5o`0007kooo]Z1Ol0000MoookJPKo0000N?oonfX0
09kooo]Z1Ol0000NoookJPGo0000EooonfX5o`0007kooo]Z1?l0000OoookJPGo0000N?oonfX009ko
oo]Z1?l0000OoookJPGo0000EooonfX5o`0007kooo]Z1?l0000OoookJPGo0000N?oonfX009kooo]Z
1?l0000PoookJPGo0000E_oonfX5o`0007kooo]Z1?l0000PoookJPGo0000MooonfX009kooo]Z1?l0
000PoookJPGo0000E_oonfX5o`0007kooo]Z1?l0000PoookJPGo0000MooonfX009kooo]Z1?l0000P
oookJPGo0000E_oonfX5o`0007kooo]Z1?l0000PoookJPGo0000MooonfX009kooo]Z1?l0000Qoook
JPGo0000EOoonfX5o`0007kooo]Z1?l0000QoookJPGo0000M_oonfX009kooo]Z1?l0000QoookJPKo
0000E?oonfX5o`0007kooo]Z1?l0000QoookJPKo0000MOoonfX009kooo]Z1?l0000QoookJPKo0000
E?oonfX5o`0007kooo]Z1?l0000QoookJPKo0000MOoonfX009kooo]Z1?l0000RoookJPKo0000Dooo
nfX5o`0007kooo]Z1?l0000RoookJPKo0000M?oonfX009kooo]Z1?l0000SoookJPGo0000DooonfX5
o`0007kooo]Z1?l0000SoookJPGo0000M?oonfX009kooo]Z1?l0000SoookJPKo0000D_oonfX5o`00
07gooo]Z1Ol0000SoookJPKo0000LooonfX002;ooo]Z0ol007meoookJPCo001o1?l000001?oonf[o
001oo`00Ool007l3oookJPGo001o6?oonfX6o`00057ooo]Z1Ol0001doookJPGo001o1?oonfX5o`00
0003oookJ_l007oo001o00?o001o7_oonfX5o`0005?ooo]Z0ol007lMoookJP008_oonfX3o`00OgCo
oo]Z1Ol007l4o`000004oookJ_l007oo001oo`00O`;ooo]Z1ol007lGoookJPOo00000_oonfX9o`00
04Gooo]Z1Ol0001coookJPOo001o0ooonfX5o`0000Oo001o7OoonfX7o`0000;ooo]Z2Ol00016oook
JP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o00?ooo]Zo`000?l000000ol000001Ooonf[o
001oo`00Ool007oooo]Z00Co001o00Cooo]Zo`00Ool007oo001o6?oonfXBo`0004Cooo]Z1Ol0001c
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`0000Co001o00Cooo]Zo`00Ool007oo001o
7_oonfXBo`0004Gooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oo
nfX3o`00O`;ooo]Z1Ol00005oookJP?o001o0ooonfX3o`00OaOooo]Z4_l00014oookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l2oookJPCo00000ol007l3oookJP?o001o7OoonfXCo`0004Cooo]Z0ol0
07lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1Ol0000;
oookJP?o001o6OoonfXAo`0004?ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00006
oookJP?o001o7_oonfXBo`0004Cooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oook
JPCo00003?oonfX3o`00OaWooo]Z2Ol00003oookJPKo0000@_oonfX5o`0007;ooo]Z0ol007l3oook
JP?o001o0_oonfX4o`0000Kooo]Z0ol007lPoookJPSo00000ooonfX6o`0004?ooo]Z0ol007lMoook
JP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo00001ooonfX2o`00O`;ooo]Z1?l007lUoookJPOo
0000@OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o00;o
oo]Z1?l007l/oookJPKo0000@_oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`;ooo]Z
1?l00007oookJPOo001o9ooonfX6o`00047ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z
1?l000000ooonf[o001oo`00O`05o`00Obgooo]Z1_l00012oookJP?o001o7OoonfX002;ooo]Z0ol0
07mcoookJP?o001o0_oonfX4o`0000Oooo]Z1_l007lYoookJPKo0000@?oonfX5o`0007;ooo]Z0ol0
07l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o00Co001o;ooonfX6o`00047ooo]Z0ol0
07lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l2oookJPCo00001ooonfX2o`00Obkooo]Z1_l0000o
oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Zo`00Ool007l0=?oonfX6
o`0003gooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l00ooonf[o0000o`000002o`00
00Oooo]Z0_l007l^oookJPOo0000?_oonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJPCo000000?ooo]Zo`00Ool007l0=?oonfX7o`0003cooo]Z1_l007lMoookJP008OoonfX4o`00
OgCooo]Z1?l007l4o`0000Sooo]Z1ol007lYoookJPKo0000?_oonfX5o`0007?ooo]Z1ol007l3oook
JPCo00000_oonfX7o`00Oboooo]Z1ol0000moookJPCo001o7OoonfX002;ooo]Z0ol007meoookJP?o
001o1?l00008oookJPOo001o:_oonfX7o`0000Kooo]Z2?l0000^oookJPGo0000M?oonfX5o`00O`Co
oo]Z1?l00002oookJPOo001o<?oonfX7o`0000Kooo]Z2?l0000_oookJP?o001o7OoonfX009gooo]Z
1?l0000joookJPOo00000ooonfX;o`0002gooo]Z1Ol0001moookJPCo0000>_oonfX7o`0000?ooo]Z
3?l0001=oookJP00WOoonfX4o`0003[ooo]Z5ol0000[oookJPGo0000O?oonfX5o`0003_ooo]Z5Ol0
001=oookJP00WOoonfX4o`0003_ooo]Z5ol0000ZoookJPGo0000O?oonfX5o`0003cooo]Z5_l0001;
oookJP00W?oonfX5o`0003gooo]Z3?l000000ooonf[o0000o`000006o`0002[ooo]Z1Ol0001loook
JPGo0000??oonfX=o`0000;ooo]Z2?l0001:oookJP00W?oonfX5o`0003kooo]Z2Ol00005oookJPOo
00002_oonfX9o`0001Kooo]Z1Ol0001loookJPCo0000?ooonfX9o`0000Gooo]Z2?l00008oookJP[o
0000=ooonfX002Wooo]Z2Ol0001ZoookJPGo0000C_oonfX7o`0000Gooo]Z3_l0000<oookJPgo0000
2OoonfX9o`0006[ooo]Z1?l0001>oookJPSo00001_oonfX=o`0000cooo]Z2Ol0000PoookJP003_oo
nf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`00
0?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo0000
9Ol0000?oookJP007?oonfX=o`0000Wooo]Z3ol00003oookJPSo0000D?oonfX4o`0006Wooo]Z2ol0
0009oookJPko00002OoonfX@o`0000;ooo]Z2Ol0001?oookJPCo0000J?oonfX<o`0000_ooo]Z00?o
0000oookJ_oonfX07?oonfX001gooo]Z2_l0000<oookJPgo00001_oonfX8o`0004kooo]Z1?l0001Z
oookJPWo00002_oonfX<o`0000gooo]Z3?l00006oookJPOo0000CooonfX4o`0006[ooo]Z2Ol0000[
oookJP00=OoonfX9o`0000Wooo]Z2?l00004oookJP[o0000?ooonfX4o`0007gooo]Z1Ol0000Eoook
JP[o00002OoonfX6o`0000Kooo]Z2Ol0000ooookJPCo0000W_oonfX004Sooo]Z2?l00002oookJPgo
0000?OoonfX4o`0007gooo]Z1Ol0000YoookJPOo00000_oonfX<o`0003kooo]Z1?l0002NoookJP00
BOoonfXFo`0003gooo]Z1?l0001moookJPGo0000:OoonfXFo`0003gooo]Z1?l0002NoookJP00Booo
nfXEo`0003_ooo]Z1Ol0001moookJPGo0000:_oonfXFo`0003_ooo]Z1Ol0002NoookJP00BooonfX;
o`0000Cooo]Z1_l0000koookJPGo0000OOoonfX5o`0002_ooo]Z3?l00003oookJPKo0000>ooonfX5
o`0009kooo]Z001=oookJPSo00001_oonfX6o`0003[ooo]Z1Ol0001moookJPGo0000;OoonfX8o`00
00Kooo]Z1_l0000joookJPGo0000W_oonfX005cooo]Z1_l0000ioookJPCo0000O_oonfX5o`0003co
oo]Z1_l0000ioookJPCo0000WooonfX005cooo]Z1ol0000hoookJPCo0000O_oonfX5o`0003cooo]Z
1ol0000hoookJPCo0000WooonfX005gooo]Z1_l0000hoookJPCo0000O_oonfX5o`0003gooo]Z1_l0
000hoookJPCo0000WooonfX005kooo]Z1_l0000goookJPCo0000O_oonfX5o`0003kooo]Z1_l0000g
oookJPCo0000WooonfX005oooo]Z1_l0000foookJPCo0000O_oonfX5o`0003oooo]Z1_l0000foook
JPCo0000WooonfX005oooo]Z1_l0000foookJPCo0000O_oonfX5o`0003oooo]Z1ol0000eoookJPCo
0000WooonfX0063ooo]Z1ol00003oookJPSo0000:OoonfX4o`0007kooo]Z1Ol00010oookJPOo0000
0ooonfX8o`0002Wooo]Z1?l0002OoookJP00HOoonfXCo`0002Oooo]Z1?l0001noookJPGo0000@Ooo
nfXBo`0002Sooo]Z1?l0002OoookJP00HOoonfXCo`0002Oooo]Z1?l0001noookJPGo0000@_oonfXC
o`0002Kooo]Z1?l0002OoookJP00H_oonfXCo`0002Kooo]Z1?l0001noookJPGo0000@_oonfXCo`00
02Kooo]Z1?l0002OoookJP00I?oonfX:o`000003oookJ_l0003o000000Go00009?oonfX5o`0007ko
oo]Z1Ol00014oookJPWo00000_oonfX7o`0002Gooo]Z1?l0002OoookJP00I_oonfX4o`0000Kooo]Z
1_l0000ToookJPGo0000O_oonfX5o`0004Kooo]Z1?l00006oookJPKo00009OoonfX4o`0009oooo]Z
001aoookJPKo00008ooonfX5o`0007kooo]Z1Ol0001AoookJPKo00008ooonfX5o`0009oooo]Z001b
oookJPGo00008ooonfX4o`0007oooo]Z1Ol0001BoookJPGo00008ooonfX5o`0009oooo]Z001boook
JPKo00008_oonfX4o`0007oooo]Z1Ol0001BoookJPKo00008_oonfX5o`0009oooo]Z001coookJPGo
00008_oonfX4o`0007oooo]Z1Ol0001CoookJPGo00008_oonfX4o`000:3ooo]Z001coookJPKo0000
8OoonfX4o`0007oooo]Z1Ol0001CoookJPKo00008OoonfX4o`000:3ooo]Z001doookJPGo00008Ooo
nfX4o`0007oooo]Z1Ol0001DoookJPGo00008OoonfX4o`000:3ooo]Z001doookJPGo00008OoonfX4
o`0007oooo]Z1Ol0001DoookJPKo00008?oonfX4o`000:3ooo]Z001eoookJPGo00008?oonfX4o`00
07oooo]Z1Ol0001EoookJPGo00008?oonfX4o`000:3ooo]Z001eoookJPGo00008?oonfX4o`0007oo
oo]Z1Ol0001EoookJPGo00008?oonfX4o`000:3ooo]Z001eoookJPKo00007ooonfX4o`0007oooo]Z
1Ol0001FoookJPGo00007ooonfX4o`000:3ooo]Z001foookJPGo00007_oonfX5o`0007oooo]Z1Ol0
001FoookJPGo00007ooonfX4o`000:3ooo]Z001foookJPKo00007OoonfX5o`0007oooo]Z1Ol0001F
oookJPGo00007ooonfX4o`000:3ooo]Z001goookJPGo00007OoonfX5o`0007oooo]Z1Ol0001Goook
JPGo00007_oonfX4o`000:3ooo]Z001goookJPGo00007OoonfX4o`00083ooo]Z1Ol0001GoookJPKo
00007?oonfX5o`000:3ooo]Z001hoookJPGo00001?oonfX8o`00013ooo]Z1?l00020oookJPGo0000
EooonfX6o`0000Gooo]Z1ol0000@oookJPGo0000X?oonfX007Sooo]Z1_l00002oookJP[o00003ooo
nfX4o`0006;ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001HoookJPKo00000_oo
nfX:o`0000oooo]Z1Ol0002PoookJP00N?oonfXBo`0000oooo]Z1?l0001QoookJPOo001o0ooonfX3
o`00O`;ooo]Z1ol007l9oookJPGo0000FOoonfXAo`0000oooo]Z1?l0002QoookJP00NOoonfXBo`00
00kooo]Z1?l0001QoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo
001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005Wooo]Z4_l0000>oookJPCo0000XOoo
nfX007[ooo]Z4Ol0000>oookJPCo0000H?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00O`Sooo]Z1Ol0001JoookJP_o000000?ooo]Zo`000?l000000ol0000>oookJPCo0000XOoonfX0
07_ooo]Z2?l00003oookJPGo00003_oonfX4o`00063ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Sooo]Z1_l0001JoookJPSo00000ooonfX5o`0000kooo]Z1?l0002QoookJP00O?oonfX6o`0000Go
oo]Z1?l0000=oookJPGo0000H?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0005co
oo]Z1_l00005oookJPGo00003OoonfX4o`000:7ooo]Z0027oookJPGo00003?oonfX5o`00063ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000IooonfX5o`0000gooo]Z
1?l0002QoookJP00QooonfX5o`0000cooo]Z1Ol0001PoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l9oookJPGo0000IooonfX5o`0000cooo]Z1Ol0002QoookJP00QooonfX6o`0000_ooo]Z1?l0001Q
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000J?oonfX4o`0000cooo]Z1Ol0002Q
oookJP00R?oonfX5o`0000_ooo]Z1?l0001QoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oook
JPGo0000J?oonfX5o`0000_ooo]Z1Ol0002QoookJP00R?oonfX5o`0000_ooo]Z1?l0001RoookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001XoookJPGo00002ooonfX4o`00
0:;ooo]Z0029oookJPGo00002_oonfX4o`0006;ooo]Z1ol007l9oookJPOo001o2?oonfX5o`0006So
oo]Z1Ol0000;oookJPCo0000X_oonfX008Wooo]Z1Ol0000:oookJPCo0000HooonfX5o`00O`[ooo]Z
1ol007l8oookJPGo0000JOoonfX4o`0000_ooo]Z1?l0002RoookJP00ROoonfX5o`0000[ooo]Z1?l0
0021oookJPGo0000JOoonfX5o`0000[ooo]Z1?l0002RoookJP00R_oonfX4o`0000[ooo]Z1?l00021
oookJPGo0000JOoonfX5o`0000[ooo]Z1?l0002RoookJP00R_oonfX4o`0000Wooo]Z1Ol00021oook
JPGo0000JOoonfX5o`0000[ooo]Z1?l0002RoookJP00R_oonfX5o`0000Sooo]Z1Ol00021oookJPGo
0000J_oonfX4o`0000Wooo]Z1Ol0002RoookJP00R_oonfX5o`0000Sooo]Z1Ol00021oookJPGo0000
J_oonfX5o`0000Sooo]Z1Ol0002RoookJP00R_oonfX5o`0000Sooo]Z1?l00022oookJPGo0000J_oo
nfX5o`0000Sooo]Z1Ol0002RoookJP00RooonfX4o`0000Sooo]Z1?l00022oookJPGo0000J_oonfX5
o`0000Sooo]Z1?l0002SoookJP00RooonfX5o`0000Oooo]Z1?l00022oookJPGo0000JooonfX4o`00
00Sooo]Z1?l0002SoookJP00RooonfX5o`0000Oooo]Z1?l00022oookJPGo0000JooonfX4o`0000So
oo]Z1?l0002SoookJP00RooonfX5o`0000Oooo]Z1?l00022oookJPGo0000JooonfX5o`0000Oooo]Z
1?l0002SoookJP00S?oonfX4o`0000Oooo]Z1?l00022oookJPGo0000JooonfX5o`0000Oooo]Z1?l0
002SoookJP00S?oonfX5o`0000Gooo]Z1Ol00022oookJPGo0000JooonfX5o`0000Oooo]Z1?l0002S
oookJP00S?oonfX5o`0000Gooo]Z1Ol00022oookJPGo0000K?oonfX4o`0000Kooo]Z1Ol0002Soook
JP00S?oonfX5o`0000Gooo]Z1Ol00022oookJPGo0000K?oonfX5o`0000Gooo]Z1Ol0002SoookJP00
SOoonfX4o`0000Gooo]Z1?l00023oookJPGo0000K?oonfX5o`0000Gooo]Z1Ol0002SoookJP00SOoo
nfX4o`0000Gooo]Z1?l00023oookJPGo0000K?oonfX5o`0000Gooo]Z1?l0002ToookJP00SOoonfX5
o`0000Cooo]Z1?l00023oookJPGo0000KOoonfX5o`0000Cooo]Z1?l0002ToookJP00SOoonfX5o`00
00Cooo]Z1?l00023oookJPGo0000KOoonfX5o`0000Cooo]Z1?l0002ToookJP00SOoonfX5o`0000?o
oo]Z1Ol00023oookJPGo0000KOoonfX5o`0000Cooo]Z1?l0002ToookJP00S_oonfX4o`0000?ooo]Z
1Ol00023oookJPGo0000K_oonfX4o`0000?ooo]Z1Ol0002ToookJP00S_oonfX4o`0000?ooo]Z1Ol0
0023oookJPGo0000K_oonfX5o`0000;ooo]Z1Ol0002ToookJP00S_oonfX5o`000003oookJ_l0003o
000000?o0000Q?oonfX5o`0006kooo]Z1Ol00002oookJPGo0000Y?oonfX008kooo]Z1Ol000000ooo
nf[o0000o`000003o`0008Cooo]Z1Ol0001^oookJPGo000000?ooo]Zo`000?l000000ol0002Uoook
JP00S_oonfX5o`000003oookJ_l0003o000000?o0000Q?oonfX5o`0006oooo]Z1?l000000ooonf[o
0000o`000003o`000:Gooo]Z002?oookJPWo0000QOoonfX5o`0006oooo]Z1?l000000ooonf[o0000
o`000003o`000:Gooo]Z002?oookJPWo0000QOoonfX5o`0006oooo]Z2Ol0002VoookJP00SooonfX9
o`0008Gooo]Z1Ol0001_oookJPWo0000Y_oonfX0093ooo]Z2?l00025oookJPGo0000KooonfX9o`00
0:Kooo]Z002@oookJPSo0000QOoonfX5o`00073ooo]Z2?l0002VoookJP00T?oonfX7o`0007Wooo]Z
0ol007l:oookJPGo0000L?oonfX8o`000:Kooo]Z002AoookJPKo0000NOoonfX3o`00O`[ooo]Z1Ol0
001aoookJPKo0000YooonfX009;ooo]Z1?l0001joookJP?o001o2_oonfX5o`00077ooo]Z1Ol0002X
oookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[o
oo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooo
nfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003o
oookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo
001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z
003ooookJQ3ooo]Z1?l007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2OoonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8oookJP?o
001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o
2?oonfX6o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo0000oooo
nfXOoookJP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfXO
oookJP00oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;o
oo]Z0ol007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o
3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oook
JP?o001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oook
JPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooookJQoo
oo]Z003ooookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oo
nfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooook
JQ;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/oookJP00
oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol0
07oooookJRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooonfX>oook
JPOo001ooooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02605 .3076 L
.02729 .30689 L
.02846 .3063 L
.02954 .30584 L
.03072 .30546 L
.0318 .30523 L
.03279 .30512 L
.03396 .30513 L
.03506 .30527 L
.03626 .30557 L
.03756 .30604 L
.0402 .30741 L
.04262 .30896 L
.04497 .3105 L
.04748 .31192 L
.04892 .31255 L
.05023 .31296 L
.05154 .31321 L
.05278 .31327 L
.05396 .31318 L
.0552 .31293 L
.05626 .3126 L
.05742 .31213 L
.06244 .30928 L
.06527 .30765 L
.06666 .30701 L
.06795 .30655 L
.06911 .30626 L
.07035 .30612 L
.07159 .30615 L
.0723 .30625 L
.07296 .30639 L
.07362 .30659 L
.07434 .30685 L
.07579 .30754 L
.07839 .30922 L
.08145 .31162 L
.08424 .31379 L
.08549 .31466 L
.08686 .31546 L
.08814 .31607 L
.08933 .31648 L
.09059 .31675 L
.09131 .31682 L
.09198 .31683 L
.09268 .31679 L
.09332 .31671 L
.09407 .31657 L
.09477 .31638 L
Mistroke
.09595 .31597 L
.09721 .31542 L
.09947 .31427 L
.10191 .31299 L
.10329 .31234 L
.10458 .31186 L
.10584 .31153 L
.10655 .31142 L
.10719 .31136 L
.10787 .31136 L
.10861 .31142 L
.10931 .31155 L
.10995 .31172 L
.11109 .31216 L
.11235 .31283 L
.11489 .31477 L
.12026 .32039 L
.12307 .32336 L
.12461 .32477 L
.12603 .32588 L
.12729 .32666 L
.12793 .32698 L
.12863 .32727 L
.1294 .32751 L
.13012 .32767 L
.13082 .32776 L
.13147 .32779 L
.13262 .32772 L
.13389 .32748 L
.13453 .32731 L
.13521 .32709 L
.13645 .32661 L
.13907 .32549 L
.14036 .32497 L
.14155 .32457 L
.14264 .32431 L
.14379 .32418 L
.14494 .32421 L
.14621 .32447 L
.14743 .32495 L
.14856 .32561 L
.1498 .32658 L
.15112 .32788 L
.15629 .33507 L
.16073 .34216 L
.16306 .34543 L
.16554 .34811 L
.16693 .34919 L
.16772 .34965 L
.16846 .34999 L
Mistroke
.16976 .35036 L
.17048 .35045 L
.17115 .35046 L
.17245 .35032 L
.17319 .35015 L
.17387 .34995 L
.17646 .34897 L
.17775 .34845 L
.17898 .34805 L
.18008 .34779 L
.18126 .34769 L
.18256 .34782 L
.18321 .34801 L
.18393 .34831 L
.1852 .34912 L
.18639 .35021 L
.19543 .36792 L
.19782 .37394 L
.20039 .37994 L
.20281 .38458 L
.20396 .3863 L
.20504 .38758 L
.2062 .38861 L
.20748 .3893 L
.20872 .38955 L
.20941 .38951 L
.21004 .38937 L
.21076 .38912 L
.21141 .3888 L
.21289 .38782 L
.21557 .3856 L
.21666 .38473 L
.21783 .38394 L
.21911 .38334 L
.2203 .38316 L
.22095 .38324 L
.22165 .38349 L
.22292 .38442 L
.22416 .38598 L
.22531 .38804 L
.22665 .39121 L
.2281 .39556 L
.23072 .40568 L
.23561 .42942 L
.23839 .44271 L
.23991 .44889 L
.24132 .45353 L
.24253 .45642 L
.24383 .4582 L
.24456 .45853 L
Mistroke
.24526 .45837 L
.24657 .4567 L
.24773 .45368 L
.249 .44859 L
.25034 .44129 L
.25159 .4326 L
.25382 .41286 L
.25622 .38623 L
.26165 .31267 L
.26669 .24294 L
.26921 .21329 L
.27158 .19058 L
.27289 .18056 L
.27431 .1719 L
.27561 .16604 L
.27679 .16232 L
.27811 .16002 L
.27935 .15952 L
.28006 .1599 L
.2807 .16065 L
.28145 .16196 L
.28215 .1636 L
.28356 .16793 L
.28487 .17296 L
.28782 .18672 L
.29284 .21126 L
.2953 .22108 L
.29756 .22786 L
.29871 .23043 L
.29992 .23246 L
.30114 .23385 L
.30183 .23437 L
.30248 .23468 L
.30318 .23485 L
.30385 .23486 L
.3051 .23454 L
.3058 .2342 L
.30645 .23381 L
.30791 .23271 L
.3103 .23069 L
.31148 .22981 L
.31258 .22914 L
.31383 .22864 L
.31449 .22851 L
.3152 .22849 L
.31646 .22878 L
.31759 .22941 L
.31876 .23044 L
.31984 .23173 L
.32227 .23572 L
Mistroke
.32666 .24576 L
.33186 .2585 L
.33439 .26355 L
.3367 .267 L
.33795 .26835 L
.33914 .26929 L
.34039 .26995 L
.3411 .27018 L
.34176 .2703 L
.34303 .27033 L
.34376 .27024 L
.34444 .27009 L
.34516 .26989 L
.34582 .26967 L
.3473 .26909 L
.34847 .26861 L
.34974 .26814 L
.35094 .2678 L
.35205 .26761 L
.35334 .26758 L
.35399 .26766 L
.35471 .26782 L
.35595 .26831 L
.35712 .26901 L
.3583 .26995 L
.35942 .27106 L
.36152 .27363 L
.36625 .28092 L
.37105 .28819 L
.37348 .29096 L
.37486 .29215 L
.37616 .29297 L
.37685 .2933 L
.37757 .29356 L
.37886 .29382 L
.37958 .29387 L
.38025 .29384 L
.38098 .29375 L
.38177 .29359 L
.38244 .29341 L
.38317 .29317 L
.38449 .29266 L
.38696 .29159 L
.38817 .2911 L
.38931 .29072 L
.39063 .2904 L
.39184 .29025 L
.39297 .29027 L
.39402 .29043 L
.39518 .29076 L
Mistroke
.3964 .29132 L
.39775 .29214 L
.39921 .29327 L
.40186 .29581 L
.4068 .30121 L
.40956 .30382 L
.4109 .30484 L
.41213 .30559 L
.41343 .30617 L
.41414 .3064 L
.41481 .30655 L
.41555 .30665 L
.41622 .30668 L
.41697 .30665 L
.41776 .30654 L
.41895 .30626 L
.42023 .30581 L
.42255 .30472 L
.42511 .30336 L
.42651 .30265 L
.42784 .30207 L
.42908 .30164 L
.42979 .30146 L
.43043 .30133 L
.43158 .30121 L
.4328 .30124 L
.43393 .30142 L
.43499 .30171 L
.43616 .30218 L
.43741 .30282 L
.44242 .30646 L
.44507 .30855 L
.44788 .31042 L
.44868 .31083 L
.44942 .31117 L
.45015 .31144 L
.45082 .31163 L
.45213 .31187 L
.45281 .31192 L
.45354 .31191 L
.45418 .31185 L
.45487 .31174 L
.4561 .31141 L
.45686 .31114 L
.45757 .31085 L
.45891 .31019 L
.4637 .30733 L
.46625 .30597 L
.46767 .30539 L
.46898 .30501 L
Mistroke
.47021 .30481 L
.4709 .30477 L
.47154 .30477 L
.47272 .30489 L
.47398 .30518 L
.47525 .30562 L
.47644 .30617 L
.47867 .30743 L
.48127 .30913 L
.48401 .31086 L
.48636 .31204 L
.487 .31229 L
.48769 .31251 L
.48894 .3128 L
.49008 .31292 L
.49131 .31289 L
.49248 .31272 L
.49357 .31244 L
.49454 .31209 L
.49561 .31161 L
.49779 .31041 L
.50237 .30753 L
.50362 .30681 L
.50496 .30616 L
.50622 .30567 L
.50737 .30535 L
.50858 .30515 L
.5099 .30511 L
.51114 .30525 L
.51228 .30552 L
.51348 .30593 L
.51479 .30653 L
.51745 .30807 L
.51993 .3097 L
.52228 .31118 L
.5244 .31226 L
.52559 .31272 L
.5267 .31303 L
.52802 .31324 L
.52921 .31326 L
.52988 .31321 L
.53059 .31311 L
.53189 .31279 L
.53257 .31256 L
.5333 .31226 L
.5348 .31155 L
.53747 .30999 L
.53999 .30846 L
.54137 .3077 L
.54269 .30708 L
Mistroke
.54391 .30662 L
.54459 .30642 L
.54523 .30628 L
.54636 .30613 L
.54755 .30613 L
.54869 .30629 L
.54994 .30663 L
.55124 .30716 L
.55245 .3078 L
.55693 .31105 L
.55966 .31322 L
.56223 .315 L
.56335 .31562 L
.56454 .31615 L
.56584 .31657 L
.56704 .31678 L
.56809 .31683 L
.56922 .31676 L
.57028 .31656 L
.57126 .31629 L
.57239 .31587 L
.57363 .31531 L
.57589 .31415 L
.57826 .3129 L
.57956 .31231 L
.58079 .31186 L
.58193 .31155 L
.58317 .31137 L
.5843 .31137 L
.58533 .31151 L
.5866 .31187 L
.5878 .31241 L
.58888 .31305 L
.59005 .3139 L
.5951 .31889 L
.59944 .32353 L
.60063 .32463 L
.6019 .32565 L
.60301 .32639 L
.60421 .32702 L
.60494 .32731 L
.60561 .32752 L
.60625 .32766 L
.60694 .32776 L
.60825 .32778 L
.60943 .32763 L
.61014 .32747 L
.6108 .32728 L
.61228 .32676 L
.61497 .32561 L
Mistroke
.61608 .32515 L
.61727 .32472 L
.61857 .32436 L
.61979 .32419 L
.62045 .32417 L
.62116 .32421 L
.62246 .32448 L
.62373 .325 L
.6249 .32571 L
.63464 .33857 L
.63729 .34272 L
.63976 .34605 L
.64111 .34752 L
.64233 .34862 L
.64369 .34954 L
.64444 .3499 L
.64515 .35017 L
.64635 .35042 L
.64762 .35045 L
.64871 .35031 L
.6499 .35 L
.65119 .34955 L
.65257 .349 L
.65376 .34852 L
.65506 .34808 L
.65633 .34778 L
.6575 .34769 L
.65862 .3478 L
.65982 .34817 L
.66099 .34883 L
.66209 .34973 L
.66309 .35078 L
.66416 .35218 L
.67285 .37104 L
.67515 .3767 L
.67764 .38212 L
.67878 .3842 L
.67999 .38607 L
.68104 .38738 L
.68216 .38844 L
.68348 .38923 L
.68471 .38953 L
.68542 .38953 L
.68617 .38939 L
.68681 .38918 L
.68751 .38885 L
.68873 .38808 L
.69003 .38707 L
.69238 .3851 L
.69361 .38419 L
Mistroke
.69426 .3838 L
.69495 .38347 L
.69621 .38317 L
.69737 .3833 L
.69849 .38388 L
.69953 .38487 L
.70068 .38649 L
.7019 .3889 L
.70324 .3923 L
.70447 .39617 L
.70726 .40724 L
.71235 .43215 L
.71473 .44335 L
.71697 .45188 L
.71809 .45504 L
.7193 .45739 L
.71995 .45814 L
.72064 .45852 L
.72188 .45802 L
.7232 .45574 L
.7244 .45199 L
.72506 .44922 L
.72578 .44563 L
.72709 .4376 L
.72961 .41674 L
.73194 .39182 L
.73725 .32117 L
.74295 .24206 L
.74555 .21174 L
.74801 .18863 L
.75022 .17346 L
.75147 .16734 L
.75263 .16326 L
.75382 .16065 L
.75493 .15957 L
.75593 .15967 L
.75702 .16084 L
.7582 .16324 L
.75945 .16689 L
.76169 .17569 L
.76681 .20078 L
.76932 .21254 L
.77165 .22162 L
.77292 .22564 L
.77432 .22922 L
.77573 .2319 L
.77651 .23298 L
.77723 .23376 L
.77851 .23462 L
.77968 .23487 L
Mistroke
.78097 .23466 L
.78161 .2344 L
.78232 .23401 L
.78485 .23207 L
.78724 .23011 L
.78857 .22925 L
.78931 .22888 L
.79 .22865 L
.79122 .22849 L
.7925 .22872 L
.79363 .2293 L
.79483 .23032 L
.79597 .23165 L
.79701 .23317 L
.79956 .23797 L
.80197 .24357 L
.80622 .25424 L
.80855 .2596 L
.81075 .26384 L
.812 .26581 L
.81335 .26754 L
.81458 .26873 L
.81571 .26953 L
.81678 .27002 L
.81795 .2703 L
.81917 .27033 L
.82031 .27017 L
.82158 .26982 L
.82292 .26932 L
.82534 .26836 L
.82598 .26813 L
.82668 .26792 L
.82793 .26765 L
.8287 .26758 L
.82943 .26758 L
.83008 .26765 L
.83079 .2678 L
.8321 .26829 L
.83328 .26899 L
.83465 .27009 L
.83594 .27141 L
.84071 .27811 L
.84505 .28506 L
.84742 .28841 L
.84963 .29092 L
.85079 .29194 L
.85203 .29279 L
.85273 .29316 L
.8534 .29344 L
.85466 .29377 L
Mistroke
.85581 .29387 L
.85687 .2938 L
.85804 .29357 L
.85928 .2932 L
.86384 .2913 L
.86495 .29089 L
.86614 .29054 L
.86744 .2903 L
.86865 .29024 L
.86933 .29028 L
.87006 .29039 L
.87076 .29056 L
.8714 .29078 L
.87262 .29133 L
.87391 .29212 L
.87621 .29399 L
.87874 .29655 L
.88329 .30151 L
.8858 .30386 L
.88704 .3048 L
.88818 .30551 L
.88925 .30603 L
.89039 .30641 L
.89165 .30664 L
.8928 .30667 L
.89384 .30656 L
.89497 .30631 L
.89604 .30596 L
.89702 .30556 L
.90173 .30313 L
.90297 .30253 L
.90432 .30196 L
.90559 .30155 L
.90677 .30131 L
.90787 .30121 L
.90908 .30125 L
.91034 .30147 L
.91153 .30184 L
.91262 .3023 L
.91362 .30283 L
.91587 .30432 L
.92109 .30843 L
.92363 .31017 L
.92474 .31077 L
.92594 .3113 L
.9272 .31168 L
.92839 .31188 L
.92905 .31192 L
.92975 .31191 L
.93101 .31175 L
Mistroke
.93166 .3116 L
.93237 .31139 L
.93364 .3109 L
.93654 .30937 L
.94126 .30656 L
.94241 .30598 L
.94364 .30547 L
.94435 .30523 L
.945 .30505 L
.94628 .30482 L
.94756 .30477 L
.94829 .30481 L
.94896 .3049 L
.94968 .30505 L
.95033 .30523 L
.95179 .30577 L
.95441 .30716 L
.95689 .30875 L
.95923 .31027 L
.9617 .31166 L
.96272 .31211 L
.96382 .31249 L
.96502 .31278 L
.96614 .31291 L
.96743 .3129 L
.96816 .31281 L
.96883 .31269 L
.97007 .31233 L
.97139 .3118 L
.97391 .31046 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z002UoookJPGo0000I_oonfX3o`00O`[ooo]Z1Ol00025oookJPGo0000U?oo
nfX00:Gooo]Z1_l0001UoookJP?o001o2_oonfX5o`0008Gooo]Z1Ol0002DoookJP00Y?oonfX7o`00
06Gooo]Z0ol007l:oookJPGo0000Q?oonfX7o`0009?ooo]Z002ToookJPOo0000H_oonfX6o`00O`[o
oo]Z1Ol00024oookJPOo0000TooonfX00:?ooo]Z2Ol0001QoookJPKo001o2_oonfX5o`0008?ooo]Z
2Ol0002BoookJP00XooonfX9o`0006?ooo]Z1?l007l:oookJPGo0000PooonfX9o`0009;ooo]Z002S
oookJPWo0000I?oonfX3o`00O`[ooo]Z1Ol00023oookJPWo0000T_oonfX00:?ooo]Z1?l000000ooo
nf[o0000o`000002o`00077ooo]Z1Ol00023oookJPCo000000?ooo]Zo`000?l000000ol0002Aoook
JP00XooonfX4o`000003oookJ_l0003o000000;o0000LOoonfX5o`0008?ooo]Z1?l000000ooonf[o
0000o`000003o`00097ooo]Z002SoookJPCo000000?ooo]Zo`000?l000000_l0001aoookJPGo0000
PooonfX4o`000003oookJ_l0003o000000?o0000TOoonfX00:;ooo]Z1Ol000000ooonf[o0000o`00
0003o`00073ooo]Z1Ol00023oookJPCo00000_oonfX4o`00097ooo]Z002RoookJPGo000000?ooo]Z
o`000?l000000ol0001`oookJPGo0000P_oonfX5o`0000;ooo]Z1?l0002AoookJP00X_oonfX5o`00
0003oookJ_l0003o000000?o0000L?oonfX5o`0008;ooo]Z1Ol00002oookJPGo0000T?oonfX00:;o
oo]Z1?l00003oookJPCo0000L?oonfX5o`0008;ooo]Z1Ol00002oookJPGo0000T?oonfX00:;ooo]Z
1?l00003oookJPGo0000KooonfX5o`0008;ooo]Z1?l00003oookJPGo0000T?oonfX00:7ooo]Z1Ol0
0003oookJPGo0000KooonfX5o`00087ooo]Z1Ol00004oookJPCo0000T?oonfX00:7ooo]Z1Ol00003
oookJPGo0000KooonfX5o`00087ooo]Z1Ol00004oookJPGo0000SooonfX00:7ooo]Z1Ol00004oook
JPCo0000KooonfX5o`00087ooo]Z1Ol00004oookJPGo0000SooonfX00:7ooo]Z1?l00005oookJPGo
0000K_oonfX5o`00087ooo]Z1?l00005oookJPGo0000SooonfX00:7ooo]Z1?l00005oookJPGo0000
K_oonfX5o`00087ooo]Z1?l00006oookJPCo0000SooonfX00:7ooo]Z1?l00005oookJPGo0000K_oo
nfX5o`00087ooo]Z1?l00006oookJPCo0000SooonfX00:7ooo]Z1?l00006oookJPCo0000K_oonfX5
o`00087ooo]Z1?l00006oookJPGo0000S_oonfX00:7ooo]Z1?l00006oookJPGo0000KOoonfX5o`00
087ooo]Z1?l00006oookJPGo0000S_oonfX00:7ooo]Z1?l00006oookJPGo0000KOoonfX5o`00083o
oo]Z1Ol00006oookJPGo0000S_oonfX00:3ooo]Z1Ol00006oookJPGo0000KOoonfX5o`00083ooo]Z
1Ol00007oookJPCo0000S_oonfX00:3ooo]Z1Ol00007oookJPCo0000KOoonfX5o`00083ooo]Z1Ol0
0007oookJPCo0000S_oonfX00:3ooo]Z1Ol00007oookJPCo0000KOoonfX5o`00083ooo]Z1?l00008
oookJPGo0000SOoonfX00:3ooo]Z1?l00008oookJPGo0000K?oonfX5o`00083ooo]Z1?l00008oook
JPGo0000SOoonfX00:3ooo]Z1?l00008oookJPGo0000K?oonfX5o`00083ooo]Z1?l00008oookJPGo
0000SOoonfX00:3ooo]Z1?l00008oookJPGo0000K?oonfX5o`00083ooo]Z1?l00009oookJPCo0000
SOoonfX00:3ooo]Z1?l00009oookJPCo0000K?oonfX5o`00083ooo]Z1?l00009oookJPCo0000SOoo
nfX00:3ooo]Z1?l00009oookJPGo0000JooonfX5o`00083ooo]Z1?l00009oookJPCo0000SOoonfX0
0:3ooo]Z1?l00009oookJPGo0000JooonfX5o`00083ooo]Z1?l00009oookJPGo0000S?oonfX00:3o
oo]Z1?l00009oookJPGo0000JooonfX5o`00083ooo]Z1?l00009oookJPGo0000S?oonfX00:3ooo]Z
1?l0000:oookJPCo0000JooonfX5o`00083ooo]Z1?l00009oookJPGo0000S?oonfX00:3ooo]Z1?l0
000:oookJPCo0000JooonfX5o`00083ooo]Z1?l0000:oookJPCo0000S?oonfX00:3ooo]Z1?l0000:
oookJPGo0000C?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`00083ooo]Z1?l0000:
oookJPGo0000RooonfX00:3ooo]Z1?l0000:oookJPGo00001OoonfX5o`00047ooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001ooookJPGo00002_oonfX5o`0000Gooo]Z1Ol00021oook
JP00WooonfX5o`0000[ooo]Z1_l00003oookJPSo0000?ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001o
oookJPGo00002_oonfX6o`0000;ooo]Z2Ol0001ooookJP00WooonfX5o`0000_ooo]Z1Ol00002oook
JPWo0000<_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000OooonfX5o`0000_ooo]Z1Ol000000ooonf[o0000o`000008o`0007oooo]Z002OoookJPGo
00002ooonfXAo`00037ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo
0000O_oonfX4o`0000cooo]Z4Ol0001noookJP00WooonfX4o`0000gooo]Z4Ol0000loookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000OooonfX4o`0000gooo]Z4?l0001noookJP00Wooo
nfX4o`0000gooo]Z2_l000000ooonf[o0000o`000004o`0003cooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l8oookJPGo0000OooonfX4o`0000gooo]Z2Ol00002oookJPKo0000OOoo
nfX009oooo]Z1?l0000>oookJPSo00000ooonfX6o`0003_ooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Wooo]Z1Ol0001ooookJPCo00003_oonfX7o`0000Cooo]Z1Ol0001moookJP00WooonfX4o`00
00oooo]Z1Ol00006oookJPGo0000>ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`00
07oooo]Z1?l0000?oookJPKo00001?oonfX5o`0007gooo]Z002OoookJPCo00006_oonfX5o`0003_o
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001ooookJPCo00006_oonfX5o`0007co
oo]Z002OoookJPCo00006ooonfX5o`0003_ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o3_oonfX5o`0007oooo]Z1?l0000JoookJPKo0000NooonfX009oooo]Z1?l0000KoookJPGo0000
>ooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000OooonfX4o`0001[ooo]Z1_l0001koookJP00Wooo
nfX4o`0001_ooo]Z1Ol0000loookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001ooookJPCo00006ooo
nfX6o`0007[ooo]Z002OoookJPCo00007?oonfX5o`0005Wooo]Z1Ol0001ooookJPCo00007?oonfX5
o`0007[ooo]Z002OoookJPCo00007?oonfX5o`0005Wooo]Z1Ol0001ooookJPCo00007?oonfX5o`00
07[ooo]Z002OoookJPCo00007?oonfX6o`0005Sooo]Z1Ol0001ooookJPCo00007OoonfX5o`0007Wo
oo]Z002NoookJPGo00007OoonfX5o`0005Sooo]Z1Ol0001ooookJPCo00007OoonfX5o`0007Wooo]Z
002NoookJPGo00007OoonfX5o`0005Sooo]Z1Ol0001noookJPGo00007OoonfX6o`0007Sooo]Z002N
oookJPGo00007_oonfX5o`0005Oooo]Z1Ol0001noookJPGo00007_oonfX5o`0007Sooo]Z002Noook
JPCo00007ooonfX5o`0005Oooo]Z1Ol0001noookJPGo00007_oonfX5o`0007Sooo]Z002NoookJPCo
00007ooonfX6o`0005Kooo]Z1Ol0001noookJPCo00008?oonfX5o`0007Oooo]Z002NoookJPCo0000
8?oonfX6o`0005Gooo]Z1Ol0001noookJPCo00008?oonfX5o`0007Oooo]Z002NoookJPCo00008?oo
nfX7o`0005Cooo]Z1Ol0001noookJPCo00008?oonfX6o`0007Kooo]Z002NoookJPCo00008OoonfX6
o`000003oookJ_l0003o000000So0000BOoonfX5o`0007kooo]Z1?l0000QoookJPKo00000_oonfX9
o`0006[ooo]Z002NoookJPCo00008_oonfXAo`0004Sooo]Z1Ol0001noookJPCo00008OoonfXAo`00
06[ooo]Z000RoookJP?o001oMOoonfX4o`00O`Co000000Cooo]Zo`00Ool007oo001o0ooonfX5o`00
OaOooo]Z4?l00018oookJPGo0000M?oonfX5o`00O`Cooo]Z00?o001oo`000?l000000_l000000ooo
nf[o001oo`00O`03o`00Oacooo]Z4Ol00019oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJPGo
001o1?l000001?oonf[o001oo`00Ool007l2oookJPOo001o5_oonfXAo`0004Oooo]Z1Ol0001coook
JPOo001o0ooonfX00ol007oo0000o`000002o`0000Oo001o7?oonfXAo`0004Sooo]Z0ol007lMoook
JP008_oonfX3o`00OgCooo]Z0ol007l00ooonf[o001oo`000003o`000005oookJ_l007oo001oo`00
OooonfX01?l007l01?oonf[o001oo`00Ool007lGoookJPOo00000ooonfX6o`0004Oooo]Z1Ol0001c
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX00ol007oo0000o`000002o`0000?o001o00Co
oo]Zo`00Ool007oo001o7OoonfX8o`0000;ooo]Z1ol00017oookJP?o001o7OoonfX001?ooo]Z2_l0
07l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l3oookJPCo00001OoonfX3o`00O`?ooo]Z0ol0
07lQoookJPKo0000A_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0ooonfX4o`0000;o001o0ooo
nfX3o`00ObOooo]Z1ol00016oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:
o`00O`;ooo]Z0ol007l2oookJPGo00002ooonfX3o`00Ob;ooo]Z1_l00015oookJPGo0000L_oonfX3
o`00O`?ooo]Z0ol007l3oookJPCo00001OoonfX3o`00ObSooo]Z1_l00016oookJP?o001o7OoonfX0
02;ooo]Z0ol007mcoookJP?o001o0_oonfX5o`0000_ooo]Z0ol007lRoookJPOo0000A?oonfX5o`00
07;ooo]Z0ol007l3oookJP?o001o0ooonfX4o`0000Gooo]Z0ol007lYoookJPKo0000AOoonfX3o`00
Oagooo]Z000RoookJP?o001oLooonfX3o`00O`;ooo]Z1Ol00006oookJP;o001o0_oonfX4o`00Ob?o
oo]Z1_l00014oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPGo00000_l007l2oookJPCo
001o:_oonfX5o`0004Gooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo0000
1ooonfX7o`00ObGooo]Z1_l00013oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPGo0000
1ol007l[oookJPKo0000A?oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`;ooo]Z1?l0
0007oookJPKo001o9ooonfX5o`0004?ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1Ol0
0006o`00Obgooo]Z1Ol00014oookJP?o001o7OoonfX001oooo]Z1_l007mcoookJP?o001o0_oonfX4
o`0000Oooo]Z0_l007l[oookJPKo0000@_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4
o`000003oookJ_l007oo001o037ooo]Z1_l00010oookJPKo001o7OoonfX001oooo]Z1_l007mdoook
JP?o001o00?ooo]Zo`000?l000000_l00007oookJP;o001o;?oonfX6o`0000Cooo]Z2Ol0000doook
JPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1?l000000ooonf[o001oo`00O`0b
oookJPKo00000ooonfX:o`0003;ooo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z1?l007l4o`00
00Sooo]Z1ol007lVoookJQCo0000<ooonfX5o`0007?ooo]Z1ol007l3oookJPCo00000_oonfX7o`00
Obcooo]Z5?l0000coookJPCo001o7OoonfX002;ooo]Z0ol007meoookJP?o001o1?l00008oookJPOo
001o9ooonfXDo`0003;ooo]Z1Ol0001doookJPGo001o1?oonfX4o`0000;ooo]Z1ol007l]oookJQCo
0000<ooonfX3o`00Oagooo]Z002MoookJPCo0000=ooonfXDo`00037ooo]Z1Ol0001moookJPCo0000
=ooonfXDo`0005;ooo]Z002MoookJPCo0000>?oonfX;o`0000;ooo]Z1_l0000aoookJPGo0000OOoo
nfX4o`0003Sooo]Z2Ol00004oookJPOo0000DOoonfX009gooo]Z1?l0000ioookJPOo00001_oonfX6
o`00033ooo]Z1Ol0001moookJPCo0000>_oonfX6o`0000Kooo]Z1ol0001@oookJP00WOoonfX4o`00
04Oooo]Z1ol00007oookJPSo00007ooonfX5o`0007gooo]Z1?l00017oookJPOo00001ooonfX9o`00
03oooo]Z002LoookJPGo0000AooonfX8o`0000Cooo]Z3?l0000MoookJPGo0000OOoonfX4o`0004So
oo]Z1ol00004oookJPco0000?_oonfX001kooo]Z2Ol0000=oookJPGo0000HooonfX5o`0004Sooo]Z
6?l00009oookJP[o00002OoonfX;o`0000kooo]Z1Ol0001ToookJPCo0000BOoonfXGo`0000[ooo]Z
2Ol0000ZoookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?
oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP00
3_oonf[oo`000?oo00009Ol0000?oookJP007OoonfX00ol0003ooo]ZoookJP06oookJPco00002?oo
nfXGo`0004_ooo]Z1?l0001QoookJP[o00002OoonfX>o`0000Oooo]Z3?l00007oookJQSo0000B_oo
nfX4o`00067ooo]Z2Ol0000:oookJPco00007_oonfX002Sooo]Z2Ol0000:oookJQOo0000B_oonfX4
o`0006?ooo]Z1_l0000=oookJPco00002?oonfX9o`0000[ooo]Z6?l00019oookJPCo0000HooonfX6
o`0000gooo]Z2?l0000PoookJP00??oonfX<o`0000Cooo]Z1ol00019oookJPCo0000OOoonfX5o`00
01gooo]Z2ol00004oookJPOo0000BOoonfX4o`0009kooo]Z000moookJP[o00001_oonfX7o`0004So
oo]Z1?l0001moookJPGo00007OoonfX9o`0000Sooo]Z1_l00018oookJPCo0000W_oonfX004kooo]Z
1ol00006oookJPKo0000>ooonfX4o`0007gooo]Z1Ol0000_oookJPOo00001OoonfX6o`0003_ooo]Z
1?l0002NoookJP00CooonfX7o`0000?ooo]Z2_l0000ioookJPCo0000OOoonfX5o`0002oooo]Z2?l0
0002oookJP[o0000>OoonfX4o`0009kooo]Z001@oookJQCo0000=ooonfX5o`0007gooo]Z1Ol0000`
oookJQ?o0000>OoonfX4o`0009kooo]Z001AoookJQ?o0000=ooonfX5o`0007gooo]Z1Ol0000aoook
JQ?o0000>?oonfX4o`0009kooo]Z001BoookJQ?o0000=_oonfX5o`0007gooo]Z1Ol0000boookJQ?o
0000=ooonfX4o`0009kooo]Z001CoookJPWo00000ooonfX7o`0003Gooo]Z1?l0001noookJPGo0000
<ooonfX9o`0000?ooo]Z1ol0000foookJPCo0000W_oonfX0063ooo]Z1ol0000doookJPCo0000O_oo
nfX5o`00043ooo]Z1_l0000eoookJPGo0000W_oonfX0067ooo]Z1_l0000doookJPCo0000O_oonfX5
o`00047ooo]Z1_l0000doookJPGo0000W_oonfX006;ooo]Z1_l0000coookJPCo0000O_oonfX5o`00
04;ooo]Z1_l0000coookJPGo0000W_oonfX006?ooo]Z1Ol0000coookJPCo0000O_oonfX5o`0004;o
oo]Z1_l0000coookJPCo0000WooonfX006?ooo]Z1_l0000boookJPCo0000O_oonfX5o`0004?ooo]Z
1_l0000boookJPCo0000WooonfX006Cooo]Z1Ol0000boookJPCo0000O_oonfX5o`0004Cooo]Z1_l0
000aoookJPCo0000WooonfX006Cooo]Z1ol0000`oookJPCo0000O_oonfX5o`0004Cooo]Z1ol0000`
oookJPCo0000WooonfX006Gooo]Z1ol00002oookJPSo00009OoonfX4o`0007kooo]Z1Ol00015oook
JPOo00000_oonfX8o`0002Gooo]Z1?l0002OoookJP00IOoonfXBo`0002Cooo]Z1?l0001noookJPGo
0000A_oonfXAo`0002Cooo]Z1?l0002OoookJP00I_oonfXAo`0002?ooo]Z1Ol0001noookJPGo0000
AooonfXAo`0002?ooo]Z1?l0002OoookJP00J?oonfX@o`0002;ooo]Z1Ol0001noookJPGo0000Aooo
nfXAo`0002?ooo]Z1?l0002OoookJP00J?oonfX@o`0002;ooo]Z1Ol0001noookJPGo0000BOoonfX@
o`0002;ooo]Z1?l0002OoookJP00LooonfX6o`00027ooo]Z1?l0001ooookJPGo0000DooonfX6o`00
02;ooo]Z1?l0002OoookJP00M?oonfX5o`00027ooo]Z1?l0001ooookJPGo0000E?oonfX6o`00023o
oo]Z1Ol0002OoookJP00M?oonfX6o`00023ooo]Z1?l0001ooookJPGo0000EOoonfX5o`00023ooo]Z
1Ol0002OoookJP00MOoonfX5o`00023ooo]Z1?l0001ooookJPGo0000EOoonfX6o`0001oooo]Z1Ol0
002OoookJP00MOoonfX6o`0001oooo]Z1?l0001ooookJPGo0000E_oonfX5o`0001oooo]Z1?l0002P
oookJP00M_oonfX5o`0001oooo]Z1?l0001ooookJPGo0000E_oonfX5o`0001oooo]Z1?l0002Poook
JP00M_oonfX6o`0001kooo]Z1?l0001ooookJPGo0000EooonfX5o`0001kooo]Z1?l0002PoookJP00
MooonfX5o`0001kooo]Z1?l0001ooookJPGo0000EooonfX5o`0001kooo]Z1?l0002PoookJP00Mooo
nfX6o`0001gooo]Z1?l0001ooookJPGo0000EooonfX6o`0001gooo]Z1?l0002PoookJP00N?oonfX5
o`0001gooo]Z1?l0001ooookJPGo0000F?oonfX5o`0001gooo]Z1?l0002PoookJP00N?oonfX5o`00
01cooo]Z1Ol0001ooookJPGo0000F?oonfX6o`0001cooo]Z1?l0002PoookJP00NOoonfX5o`0001_o
oo]Z1Ol0001ooookJPGo0000FOoonfX5o`0001cooo]Z1?l0002PoookJP00NOoonfX6o`0001[ooo]Z
1Ol0001ooookJPGo0000FOoonfX5o`0001cooo]Z1?l0002PoookJP00NOoonfX6o`0001[ooo]Z1?l0
001RoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000F_oonfX5o`0001_ooo]Z1?l0
002PoookJP00N_oonfX6o`0000Gooo]Z1Ol0000?oookJPCo0000HOoonfX7o`00O`?ooo]Z0ol007l2
oookJPOo001o2OoonfX5o`0005[ooo]Z1Ol00006oookJPGo00003ooonfX5o`000:3ooo]Z001koook
JPGo00000ooonfX8o`0000kooo]Z1?l0001QoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005[ooo]Z1_l0
0003oookJPSo00003_oonfX5o`000:3ooo]Z001koookJPKo000000?ooo]Zo`000?l000002?l0000=
oookJPCo0000H?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001K
oookJPKo000000?ooo]Zo`000?l000002?l0000=oookJPGo0000X?oonfX007cooo]Z4?l0000=oook
JPCo0000H?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0005[ooo]Z4Ol0000=oook
JPCo0000XOoonfX007cooo]Z4?l0000=oookJPCo0000H?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2?oonfX5o`0005cooo]Z4?l0000=oookJPCo0000XOoonfX007gooo]Z2_l000000ooonf[o0000
o`000003o`0000cooo]Z1?l0001PoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o
2?oonfX5o`0005gooo]Z2Ol00002oookJPGo00003?oonfX4o`000:7ooo]Z001moookJPSo00000ooo
nfX5o`0000cooo]Z1?l0001PoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000G_oo
nfX7o`0000?ooo]Z1Ol0000<oookJPCo0000XOoonfX007kooo]Z1_l00004oookJPKo00002ooonfX4
o`00063ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001NoookJPKo00001?oonfX6
o`0000_ooo]Z1?l0002QoookJP00ROoonfX5o`0000_ooo]Z1?l0001PoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l>oookJPGo0000JOoonfX5o`0000_ooo]Z1?l0002QoookJP00ROoonfX5o`0000_o
oo]Z1?l0001QoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001Yoook
JPGo00002_oonfX5o`000:7ooo]Z002:oookJPGo00002OoonfX5o`00067ooo]Z1ol007l9oookJPOo
001o2?oonfX5o`0006[ooo]Z1?l0000:oookJPGo0000XOoonfX008[ooo]Z1Ol00009oookJPGo0000
H_oonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000J_oonfX5o`0000Wooo]Z1Ol0002QoookJP00R_oo
nfX5o`0000Wooo]Z1Ol00020oookJPGo0000J_oonfX5o`0000Wooo]Z1?l0002RoookJP00RooonfX4
o`0000Wooo]Z1?l00021oookJPGo0000J_oonfX5o`0000Wooo]Z1?l0002RoookJP00RooonfX4o`00
00Wooo]Z1?l00021oookJPGo0000JooonfX4o`0000Wooo]Z1?l0002RoookJP00RooonfX5o`0000So
oo]Z1?l00021oookJPGo0000JooonfX4o`0000Wooo]Z1?l0002RoookJP00RooonfX5o`0000Sooo]Z
1?l00021oookJPGo0000JooonfX5o`0000Oooo]Z1Ol0002RoookJP00RooonfX5o`0000Sooo]Z1?l0
0021oookJPGo0000JooonfX5o`0000Oooo]Z1Ol0002RoookJP00S?oonfX4o`0000Sooo]Z1?l00021
oookJPGo0000JooonfX5o`0000Oooo]Z1Ol0002RoookJP00S?oonfX5o`0000Oooo]Z1?l00021oook
JPGo0000K?oonfX4o`0000Oooo]Z1?l0002SoookJP00S?oonfX5o`0000Kooo]Z1Ol00021oookJPGo
0000K?oonfX4o`0000Oooo]Z1?l0002SoookJP00S?oonfX5o`0000Kooo]Z1Ol00021oookJPGo0000
K?oonfX5o`0000Kooo]Z1?l0002SoookJP00SOoonfX4o`0000Kooo]Z1Ol00021oookJPGo0000K?oo
nfX5o`0000Kooo]Z1?l0002SoookJP00SOoonfX4o`0000Kooo]Z1?l00022oookJPGo0000K?oonfX5
o`0000Kooo]Z1?l0002SoookJP00SOoonfX5o`0000Gooo]Z1?l00022oookJPGo0000KOoonfX4o`00
00Kooo]Z1?l0002SoookJP00SOoonfX5o`0000Cooo]Z1Ol00022oookJPGo0000KOoonfX4o`0000Go
oo]Z1Ol0002SoookJP00SOoonfX5o`0000Cooo]Z1Ol00022oookJPGo0000KOoonfX5o`0000Cooo]Z
1Ol0002SoookJP00S_oonfX4o`0000Cooo]Z1Ol00022oookJPGo0000KOoonfX5o`0000Cooo]Z1Ol0
002SoookJP00S_oonfX4o`0000Cooo]Z1?l00023oookJPGo0000KOoonfX5o`0000Cooo]Z1?l0002T
oookJP00S_oonfX5o`0000?ooo]Z1?l00023oookJPGo0000K_oonfX4o`0000Cooo]Z1?l0002Toook
JP00S_oonfX5o`0000?ooo]Z1?l00023oookJPGo0000K_oonfX4o`0000Cooo]Z1?l0002ToookJP00
S_oonfX5o`0000?ooo]Z1?l00023oookJPGo0000K_oonfX5o`0000?ooo]Z1?l0002ToookJP00Sooo
nfX4o`0000?ooo]Z1?l00023oookJPGo0000K_oonfX5o`0000?ooo]Z1?l0002ToookJP00SooonfX4
o`0000?ooo]Z1?l00023oookJPGo0000K_oonfX5o`0000;ooo]Z1Ol0002ToookJP00SooonfX4o`00
00?ooo]Z1?l00023oookJPGo0000KooonfX4o`0000;ooo]Z1Ol0002ToookJP00SooonfX5o`000003
oookJ_l0003o000000?o0000PooonfX5o`0006oooo]Z1Ol000000ooonf[o0000o`000003o`000:Co
oo]Z002?oookJPGo000000?ooo]Zo`000?l000000ol00023oookJPGo0000KooonfX5o`000003oook
J_l0003o000000;o0000YOoonfX008oooo]Z1Ol000000ooonf[o0000o`000003o`0008?ooo]Z1Ol0
001_oookJP[o0000YOoonfX0093ooo]Z2Ol00024oookJPGo0000L?oonfX9o`000:Gooo]Z002@oook
JPWo0000Q?oonfX5o`00073ooo]Z2Ol0002UoookJP00T?oonfX9o`0008Cooo]Z1Ol0001aoookJPSo
0000YOoonfX0097ooo]Z1ol0001hoookJP?o001o2_oonfX5o`00077ooo]Z2?l0002UoookJP00TOoo
nfX7o`0007Sooo]Z0ol007l:oookJPGo0000LOoonfX8o`000:Gooo]Z002AoookJPOo0000N?oonfX3
o`00O`[ooo]Z1Ol0001boookJPKo0000Y_oonfX009;ooo]Z1Ol0001ioookJP?o001o2_oonfX5o`00
07;ooo]Z1Ol0002WoookJP00oooonfXAoookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z
4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooo
nfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00
O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00
oooonfX>oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX2
oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00oooonfX2oook
JP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o
001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXNoookJP00oooo
nfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9
oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oook
JPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l007l:oookJPGo
0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00o_oo
nfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00oooonfX1oookJPCo001o2_oonfX7
o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o2?oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9
o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoook
JP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4o`00O`cooo]Z
1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oookJPKo0000oooonfXNoookJP00oooonfXA
oookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z1Ol0003ooook
JQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o
oooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX4
o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z003ooookJPoo
oo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02605 .31043 L
.02729 .31113 L
.02846 .31169 L
.02954 .31212 L
.03072 .31245 L
.0318 .31262 L
.03279 .31266 L
.03396 .31256 L
.03506 .31233 L
.03626 .31193 L
.03756 .31136 L
.04262 .30832 L
.04516 .30687 L
.04659 .30623 L
.04728 .30599 L
.04793 .30581 L
.04921 .30559 L
.05037 .30555 L
.05162 .30569 L
.05232 .30585 L
.05297 .30604 L
.05411 .30649 L
.05517 .30701 L
.05758 .3085 L
.06244 .31182 L
.06371 .31253 L
.06506 .31313 L
.06576 .31338 L
.06654 .31358 L
.06724 .31371 L
.06791 .31378 L
.06921 .31377 L
.0704 .31359 L
.0717 .31322 L
.07236 .31297 L
.07308 .31266 L
.07816 .30982 L
.08038 .30868 L
.08163 .3082 L
.08278 .30788 L
.08343 .30777 L
.08414 .30771 L
.08489 .3077 L
.08559 .30777 L
.08687 .30805 L
.08758 .3083 L
.08824 .30858 L
.08967 .30937 L
.09123 .31046 L
Mistroke
.09407 .31286 L
.09668 .31516 L
.09804 .31627 L
.09949 .3173 L
.10075 .31803 L
.10142 .31835 L
.10214 .31863 L
.1034 .31897 L
.10458 .3191 L
.10527 .3191 L
.10591 .31904 L
.10662 .31893 L
.10736 .31875 L
.10861 .31834 L
.10999 .31775 L
.11237 .31657 L
.11361 .31596 L
.11492 .31539 L
.11613 .31497 L
.11745 .31468 L
.11865 .3146 L
.11976 .31469 L
.12091 .31498 L
.12195 .31542 L
.12316 .31612 L
.12429 .31697 L
.14528 .33115 L
.1838 .35382 L
.20332 .38097 L
.20607 .38736 L
.20742 .38987 L
.20867 .39172 L
.20935 .39252 L
.2101 .39323 L
.21086 .39375 L
.21167 .3941 L
.21235 .39423 L
.21308 .39422 L
.21377 .39406 L
.21441 .39381 L
.21565 .39305 L
.21682 .3921 L
.21945 .38959 L
.22077 .38847 L
.22202 .38769 L
.22271 .38743 L
.22346 .38732 L
.22477 .38764 L
.22595 .38857 L
.22722 .39033 L
Mistroke
.22841 .39276 L
.22951 .39567 L
.23219 .40538 L
.23473 .41744 L
.23738 .4315 L
.24021 .44583 L
.24158 .45168 L
.24287 .45609 L
.24403 .45891 L
.24529 .46052 L
.24638 .46053 L
.24758 .45891 L
.24883 .45528 L
.25 .45002 L
.2511 .44342 L
.2521 .43602 L
.25434 .41472 L
.25942 .34744 L
.26422 .27317 L
.26662 .23841 L
.26921 .20616 L
.2704 .19373 L
.27165 .18252 L
.27273 .17447 L
.27389 .1676 L
.27509 .16233 L
.27622 .15915 L
.2769 .158 L
.27755 .15744 L
.27876 .1577 L
.27942 .1585 L
.28011 .1598 L
.28135 .16321 L
.28268 .16816 L
.28415 .17477 L
.28874 .19883 L
.29127 .21111 L
.29251 .21627 L
.29367 .2204 L
.29484 .22387 L
.2959 .22638 L
.29707 .22847 L
.29832 .22991 L
.29937 .23054 L
.30051 .23071 L
.30159 .23044 L
.30257 .2299 L
.30729 .22568 L
.30794 .22514 L
.30865 .22465 L
Mistroke
.30994 .22401 L
.31119 .22379 L
.31234 .224 L
.31343 .22459 L
.31445 .2255 L
.31556 .22688 L
.31676 .2288 L
.31921 .23391 L
.32145 .23957 L
.32652 .25291 L
.32791 .25606 L
.32939 .25896 L
.33077 .26118 L
.33205 .26277 L
.33336 .26394 L
.33405 .26438 L
.33477 .26471 L
.33599 .265 L
.33669 .26503 L
.33734 .26499 L
.33855 .26473 L
.33965 .26436 L
.34213 .26332 L
.34323 .2629 L
.34441 .26256 L
.34571 .26238 L
.34693 .26244 L
.34823 .2628 L
.34888 .26311 L
.3496 .26354 L
.35086 .26455 L
.35204 .26577 L
.35647 .27229 L
.36121 .28052 L
.36389 .28448 L
.3653 .28614 L
.3668 .28751 L
.36811 .28836 L
.36885 .2887 L
.36955 .28893 L
.37077 .28913 L
.37208 .28909 L
.37335 .28885 L
.37406 .28864 L
.37473 .28841 L
.37724 .28739 L
.37842 .28692 L
.37953 .28655 L
.38081 .28624 L
.38196 .28612 L
Mistroke
.38313 .28616 L
.38438 .28643 L
.38556 .28689 L
.38663 .28749 L
.38789 .28841 L
.38926 .28964 L
.39175 .29235 L
.39676 .29836 L
.39928 .30087 L
.40072 .30196 L
.40137 .30236 L
.40207 .30272 L
.40325 .30316 L
.40449 .3034 L
.40563 .30343 L
.4067 .3033 L
.40796 .30297 L
.40911 .30255 L
.41168 .30134 L
.41387 .30026 L
.41503 .29976 L
.41625 .29934 L
.41731 .29908 L
.41849 .29894 L
.41956 .29895 L
.42055 .29909 L
.42957 .30503 L
.43195 .30707 L
.4332 .30803 L
.43451 .30889 L
.43567 .3095 L
.43694 .30998 L
.43809 .31025 L
.43916 .31034 L
.44042 .31026 L
.44157 .31002 L
.44221 .30983 L
.4429 .30957 L
.44416 .30901 L
.44684 .30752 L
.44968 .3059 L
.45084 .30533 L
.45209 .30482 L
.4528 .3046 L
.45346 .30443 L
.45474 .30425 L
.45589 .30425 L
.45714 .30442 L
.45832 .30475 L
.45942 .30518 L
Mistroke
.46219 .30673 L
.4648 .30854 L
.46718 .31015 L
.46847 .31093 L
.46968 .31154 L
.47099 .31204 L
.47168 .31224 L
.47242 .31238 L
.47374 .31249 L
.47494 .31241 L
.47567 .31227 L
.47634 .3121 L
.47708 .31186 L
.47786 .31154 L
.48062 .31006 L
.48523 .30721 L
.48649 .30656 L
.48781 .306 L
.48895 .30565 L
.49018 .30543 L
.4909 .30538 L
.49155 .30539 L
.4923 .30545 L
.493 .30557 L
.49426 .30592 L
.49497 .30618 L
.49563 .30646 L
.50074 .30949 L
.50313 .31094 L
.50432 .31154 L
.50541 .312 L
.50667 .31239 L
.50733 .31253 L
.50804 .31262 L
.50929 .31265 L
.51043 .31251 L
.5116 .31223 L
.51268 .31184 L
.51511 .31063 L
.5195 .30789 L
.52182 .30664 L
.52312 .30611 L
.5243 .30577 L
.52497 .30564 L
.52569 .30556 L
.52702 .30558 L
.52833 .3058 L
.52955 .30618 L
.53081 .30673 L
.532 .30737 L
Mistroke
.53469 .30914 L
.53752 .31111 L
.5389 .31197 L
.54015 .31265 L
.54138 .31318 L
.54254 .31354 L
.54377 .31376 L
.54446 .3138 L
.5451 .31379 L
.54635 .31364 L
.54707 .31347 L
.54773 .31327 L
.54907 .31275 L
.55051 .31204 L
.55294 .31065 L
.55558 .30916 L
.55678 .30859 L
.55807 .30812 L
.55916 .30784 L
.56037 .3077 L
.56163 .30775 L
.56278 .30797 L
.56404 .30841 L
.56467 .3087 L
.56537 .30907 L
.5678 .31076 L
.57006 .31267 L
.57229 .31466 L
.57465 .31659 L
.57667 .31789 L
.57782 .31844 L
.57889 .31881 L
.58016 .31905 L
.58132 .3191 L
.58196 .31906 L
.58266 .31896 L
.58393 .31864 L
.58466 .31839 L
.58531 .31814 L
.58677 .31747 L
.5894 .31615 L
.5906 .3156 L
.59186 .31512 L
.59252 .31492 L
.59324 .31475 L
.59452 .3146 L
.59572 .31466 L
.59701 .31495 L
.59822 .31546 L
.59933 .31611 L
Mistroke
.60171 .31807 L
.60391 .32043 L
.60888 .32641 L
.61114 .32878 L
.61326 .33047 L
.61433 .33109 L
.61547 .33156 L
.61675 .33186 L
.61791 .33192 L
.61919 .33179 L
.6204 .33151 L
.62149 .33115 L
.62266 .33069 L
.62512 .32968 L
.62637 .32926 L
.62707 .32909 L
.62773 .32897 L
.62893 .32889 L
.63002 .329 L
.63128 .32939 L
.63248 .33002 L
.63357 .33082 L
.63458 .33177 L
.63686 .33456 L
.65757 .35483 L
.67642 .37271 L
.6789 .37938 L
.68155 .38586 L
.68284 .3885 L
.68405 .39058 L
.68514 .39207 L
.68633 .39326 L
.68759 .39401 L
.68822 .39419 L
.68892 .39424 L
.69016 .394 L
.69131 .39341 L
.69202 .39292 L
.69269 .39238 L
.69394 .39122 L
.69531 .3899 L
.69677 .38861 L
.69752 .38807 L
.69823 .38768 L
.69955 .38732 L
.70079 .38756 L
.70149 .38797 L
.70213 .38855 L
.70283 .38942 L
.70348 .39045 L
Mistroke
.70497 .39365 L
.70642 .39792 L
.70797 .40368 L
.71289 .42786 L
.71549 .44147 L
.71691 .44815 L
.71825 .45346 L
.71959 .45752 L
.7203 .45905 L
.72106 .46017 L
.72173 .46064 L
.72242 .46061 L
.72367 .45912 L
.72494 .45558 L
.72612 .45039 L
.72742 .44253 L
.72881 .43166 L
.7314 .40487 L
.73385 .37305 L
.73844 .30368 L
.74346 .22977 L
.74591 .20058 L
.74816 .18 L
.74937 .1716 L
.75052 .16544 L
.75173 .16086 L
.75242 .15912 L
.75306 .15804 L
.75376 .15743 L
.75443 .15738 L
.75567 .15859 L
.75636 .15995 L
.757 .16158 L
.75845 .16645 L
.76303 .18871 L
.76736 .21066 L
.76975 .22004 L
.7711 .22407 L
.77235 .22692 L
.7734 .22867 L
.77456 .22994 L
.77577 .23061 L
.7769 .23069 L
.77809 .23029 L
.77935 .22947 L
.7816 .22744 L
.78287 .22623 L
.78422 .22508 L
.7855 .22427 L
.78666 .22386 L
Mistroke
.78773 .22381 L
.7889 .22416 L
.78999 .22489 L
.79101 .22591 L
.79211 .2274 L
.79332 .22946 L
.79576 .23476 L
.80091 .24838 L
.80375 .25532 L
.80515 .25818 L
.80645 .26041 L
.80763 .26207 L
.80895 .26345 L
.81026 .26439 L
.81099 .26472 L
.81167 .26492 L
.81286 .26503 L
.81396 .26492 L
.81516 .2646 L
.81643 .26412 L
.81766 .2636 L
.819 .26306 L
.82026 .26265 L
.82142 .26242 L
.82247 .26238 L
.82363 .26254 L
.82483 .26298 L
.82596 .26366 L
.82727 .26476 L
.82852 .26611 L
.83087 .26936 L
.83615 .27841 L
.83835 .28203 L
.8407 .28525 L
.84184 .28649 L
.84292 .28745 L
.84388 .28812 L
.84493 .28866 L
.84608 .28901 L
.84735 .28915 L
.84799 .28912 L
.84868 .28903 L
.84992 .28874 L
.85115 .28832 L
.85232 .28785 L
.8545 .28696 L
.85565 .28657 L
.85687 .28627 L
.85803 .28612 L
.8591 .28614 L
Mistroke
.86028 .28634 L
.86157 .2868 L
.86222 .28713 L
.86291 .28755 L
.86417 .28848 L
.86693 .29119 L
.86954 .29429 L
.87192 .29718 L
.87443 .29991 L
.87662 .30176 L
.87786 .30252 L
.87903 .30303 L
.8801 .30331 L
.88107 .30343 L
.8822 .3034 L
.88327 .30322 L
.88442 .30289 L
.88565 .30241 L
.88785 .30135 L
.89024 .30018 L
.8915 .29965 L
.89219 .29941 L
.89285 .29923 L
.89356 .29907 L
.8942 .29898 L
.89547 .29893 L
.89616 .29899 L
.89679 .2991 L
.89749 .29928 L
.89823 .29954 L
.89944 .3001 L
.90058 .30078 L
.90317 .30274 L
.90615 .30538 L
.90899 .30774 L
.91022 .30859 L
.91153 .30934 L
.91229 .30968 L
.91297 .30993 L
.91366 .31013 L
.91431 .31025 L
.9155 .31034 L
.91674 .31024 L
.91781 .31001 L
.91898 .30962 L
.92024 .30906 L
.9216 .30835 L
.92404 .30693 L
.92538 .30616 L
.92685 .30541 L
Mistroke
.92823 .30484 L
.92951 .30447 L
.93066 .30428 L
.93193 .30424 L
.93257 .3043 L
.93325 .30441 L
.9345 .30474 L
.93951 .3075 L
.94227 .30943 L
.94362 .31032 L
.94487 .31104 L
.94603 .31161 L
.9473 .31208 L
.94858 .31238 L
.94928 .31246 L
.94993 .31249 L
.95109 .31241 L
.95215 .31221 L
.95337 .31182 L
.95453 .31132 L
.95975 .30821 L
.9623 .30674 L
.9634 .30623 L
.9646 .3058 L
.96591 .30549 L
.96715 .30538 L
.96784 .30539 L
.96857 .30546 L
.96987 .30574 L
.97056 .30595 L
.97129 .30623 L
.97261 .30686 L
.97562 .30865 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z2_l007l6oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX00:Cooo]Z1Ol0001WoookJP?o001o
2_oonfX5o`0008Cooo]Z1Ol0002EoookJP00Y?oonfX6o`0006Kooo]Z0ol007l:oookJPGo0000Q?oo
nfX6o`0009Cooo]Z002ToookJPKo0000I_oonfX3o`00O`[ooo]Z1Ol00023oookJPOo0000U?oonfX0
0:?ooo]Z2?l0001UoookJP?o001o2_oonfX5o`0008?ooo]Z1ol0002DoookJP00XooonfX8o`0006;o
oo]Z1_l007l:oookJPGo0000PooonfX8o`0009?ooo]Z002RoookJPWo0000H_oonfX6o`00O`[ooo]Z
1Ol00023oookJPSo0000TooonfX00:;ooo]Z2Ol0001ToookJPCo001o2_oonfX5o`0008?ooo]Z2?l0
002CoookJP00X_oonfX9o`0006Gooo]Z0ol007l:oookJPGo0000P_oonfX9o`0009?ooo]Z002Roook
JPCo000000?ooo]Zo`000?l000000ol0001aoookJPGo0000P_oonfX:o`0009;ooo]Z002RoookJPCo
000000?ooo]Zo`000?l000000ol0001aoookJPGo0000P_oonfX:o`0009;ooo]Z002RoookJPCo0000
00?ooo]Zo`000?l000000ol0001aoookJPGo0000P_oonfX4o`000003oookJ_l0003o000000?o0000
T_oonfX00:;ooo]Z1?l00002oookJPCo0000LOoonfX5o`00087ooo]Z1Ol00002oookJPCo0000T_oo
nfX00:7ooo]Z1Ol00002oookJPGo0000L?oonfX5o`00087ooo]Z1Ol00002oookJPGo0000TOoonfX0
0:7ooo]Z1Ol00002oookJPGo0000L?oonfX5o`00087ooo]Z1Ol00002oookJPGo0000TOoonfX00:7o
oo]Z1Ol00002oookJPGo0000L?oonfX5o`00087ooo]Z1?l00003oookJPGo0000TOoonfX00:7ooo]Z
1?l00004oookJPCo0000L?oonfX5o`00087ooo]Z1?l00004oookJPCo0000TOoonfX00:7ooo]Z1?l0
0004oookJPGo0000KooonfX5o`00087ooo]Z1?l00004oookJPGo0000T?oonfX00:7ooo]Z1?l00004
oookJPGo0000KooonfX5o`00087ooo]Z1?l00004oookJPGo0000T?oonfX00:7ooo]Z1?l00004oook
JPGo0000KooonfX5o`00083ooo]Z1Ol00004oookJPGo0000T?oonfX00:7ooo]Z1?l00005oookJPCo
0000KooonfX5o`00083ooo]Z1Ol00005oookJPCo0000T?oonfX00:7ooo]Z1?l00005oookJPCo0000
KooonfX5o`00083ooo]Z1Ol00005oookJPCo0000T?oonfX00:7ooo]Z1?l00005oookJPGo0000K_oo
nfX5o`00083ooo]Z1?l00006oookJPGo0000SooonfX00:7ooo]Z1?l00005oookJPGo0000K_oonfX5
o`00083ooo]Z1?l00006oookJPGo0000SooonfX00:7ooo]Z1?l00005oookJPGo0000K_oonfX5o`00
083ooo]Z1?l00006oookJPGo0000SooonfX00:3ooo]Z1Ol00006oookJPCo0000K_oonfX5o`00083o
oo]Z1?l00007oookJPCo0000SooonfX00:3ooo]Z1Ol00006oookJPCo0000K_oonfX5o`00083ooo]Z
1?l00007oookJPCo0000SooonfX00:3ooo]Z1Ol00006oookJPGo0000KOoonfX5o`00083ooo]Z1?l0
0007oookJPCo0000SooonfX00:3ooo]Z1?l00007oookJPGo0000KOoonfX5o`00083ooo]Z1?l00007
oookJPGo0000S_oonfX00:3ooo]Z1?l00007oookJPGo0000KOoonfX5o`00083ooo]Z1?l00007oook
JPGo0000S_oonfX00:3ooo]Z1?l00008oookJPCo0000KOoonfX5o`00083ooo]Z1?l00007oookJPGo
0000S_oonfX00:3ooo]Z1?l00008oookJPCo0000KOoonfX5o`00083ooo]Z1?l00008oookJPCo0000
S_oonfX00:3ooo]Z1?l00008oookJPGo0000K?oonfX5o`00083ooo]Z1?l00008oookJPCo0000S_oo
nfX00:3ooo]Z1?l00008oookJPGo0000K?oonfX5o`0007oooo]Z1Ol00008oookJPGo0000SOoonfX0
0:3ooo]Z1?l00008oookJPGo0000K?oonfX5o`0007oooo]Z1Ol00008oookJPGo0000SOoonfX00:3o
oo]Z1?l00009oookJPCo0000K?oonfX5o`0007oooo]Z1Ol00008oookJPGo0000SOoonfX00:3ooo]Z
1?l00009oookJPCo0000K?oonfX5o`0007oooo]Z1?l0000:oookJPCo0000SOoonfX009oooo]Z1Ol0
0009oookJPGo00000ooonfX7o`00067ooo]Z1Ol0001ooookJPCo00002_oonfX5o`0000Cooo]Z1_l0
0022oookJP00WooonfX5o`0000Wooo]Z1Ol00002oookJPSo0000@ooonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o2_oonfX5o`0007oooo]Z1?l0000:oookJPGo00000_oonfX9o`00087ooo]Z002Ooook
JPGo00002OoonfX@o`00047ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001ooook
JPCo00002_oonfX@o`00087ooo]Z002OoookJPCo00002ooonfX@o`00043ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9
oookJPGo0000OooonfX4o`0000_ooo]Z4?l00020oookJP00WooonfX4o`0000_ooo]Z4?l0000coook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001ooook
JPCo00002ooonfX@o`00083ooo]Z002OoookJPCo00003?oonfX8o`0000;ooo]Z1_l0000boookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007kooo]Z1?l0000<oookJPWo
000000?ooo]Zo`000?l000001?l0001ooookJP00WooonfX4o`0000gooo]Z1_l00004oookJPGo0000
?_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0007oooo]Z1?l0000=oookJPKo0000
1?oonfX5o`0007oooo]Z002OoookJPCo00003OoonfX5o`0000Gooo]Z1_l0000moookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0007oooo]Z1?l0000=oookJPGo00001Ooo
nfX5o`0007oooo]Z002OoookJPCo00006?oonfX5o`0003gooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Wooo]Z1Ol0001ooookJPCo00006?oonfX5o`0007kooo]Z002OoookJPCo00006?oonfX5o`00
03gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001ooookJPCo00006?oonfX5o`00
07kooo]Z002OoookJPCo00006OoonfX5o`0003cooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`ko
oo]Z1Ol0001ooookJPCo00006?oonfX6o`0007gooo]Z002OoookJPCo00006OoonfX5o`0003gooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007kooo]Z1Ol0000IoookJPGo
0000OOoonfX009oooo]Z1?l0000IoookJPGo0000?OoonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000
O_oonfX5o`0001Wooo]Z1Ol0001moookJP00WooonfX4o`0001[ooo]Z1Ol0000moookJPGo001o2_oo
nfX7o`00O`Sooo]Z1Ol0001noookJPGo00006_oonfX5o`0007cooo]Z002NoookJPGo00006_oonfX5
o`0005_ooo]Z1Ol0001noookJPCo00006ooonfX5o`0007cooo]Z002NoookJPGo00006_oonfX5o`00
05_ooo]Z1Ol0001noookJPCo00006ooonfX6o`0007_ooo]Z002NoookJPGo00006ooonfX5o`0005[o
oo]Z1Ol0001noookJPCo00007?oonfX5o`0007_ooo]Z002NoookJPCo00007?oonfX6o`0005Wooo]Z
1Ol0001noookJPCo00007?oonfX6o`0007[ooo]Z002NoookJPCo00007?oonfX6o`0005Wooo]Z1Ol0
001noookJPCo00007OoonfX5o`0007[ooo]Z002NoookJPCo00007OoonfX6o`0005Sooo]Z1Ol0001n
oookJPCo00007OoonfX5o`0007[ooo]Z002NoookJPCo00007_oonfX5o`0005Sooo]Z1Ol0001noook
JPCo00007_oonfX5o`0007Wooo]Z002NoookJPCo00007_oonfX6o`000003oookJ_l0003o000000Ko
0000C_oonfX5o`0007kooo]Z1?l0000NoookJPKo000000?ooo]Zo`000?l000001ol0001^oookJP00
W_oonfX4o`0001oooo]Z3ol0001=oookJPGo0000O_oonfX4o`0001kooo]Z4?l0001^oookJP00WOoo
nfX5o`0001oooo]Z4?l0001<oookJPGo0000O_oonfX4o`0001oooo]Z4?l0001]oookJP00WOoonfX5
o`00023ooo]Z3ol0001<oookJPGo0000OOoonfX5o`00023ooo]Z3ol0001]oookJP00WOoonfX5o`00
027ooo]Z1ol00002oookJPKo0000BooonfX5o`0007gooo]Z1Ol0000QoookJPOo00000_oonfX6o`00
06cooo]Z000RoookJP?o001oMOoonfX3o`00O`Co00000_oonfX3o`00O`?ooo]Z1Ol007lOoookJPKo
0000B_oonfX5o`0007Cooo]Z1Ol007l4oookJPGo000000?ooo]Zo`00Ool007l00ol007lUoookJPGo
0000C?oonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX4o`00O`Co00000_oonfX3o`00O`;ooo]Z
1ol007lNoookJPKo0000B_oonfX5o`0007?ooo]Z1ol007l3oookJPCo000000?ooo]Zo`00Ool007l0
1Ol007lToookJPKo0000BooonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`03oookJ_l0
003o000000;o00000_oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
7ooonfX6o`0004Wooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`0000Co
001o00Cooo]Zo`00Ool007oo001o9OoonfX6o`0004[ooo]Z0ol007lMoookJP004ooonfX:o`00O`Go
oo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1?l00006oookJP?o001o0ooonfX3o`00Oaoo
oo]Z1_l00018oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00000ol007l3oookJP?o
001o9?oonfX7o`0004Wooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o
0_oonfX3o`00O`;ooo]Z1?l0000<oookJP?o001o7ooonfX6o`0004Sooo]Z1Ol0001boookJP?o001o
0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o9OoonfX6o`0004Wooo]Z0ol007lMoookJP008_oo
nfX3o`00Og?ooo]Z0ol007l2oookJPCo00003?oonfX3o`00Ob3ooo]Z1_l00017oookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l2oookJPCo00001_oonfX3o`00ObKooo]Z1_l00018oookJP?o001o7Ooo
nfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4o`0000Oooo]Z0_l007l2oookJPCo001o8OoonfX5
o`0004Oooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02
oookJPCo001o9ooonfX6o`0004Oooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oook
JPCo00001ooonfX7o`00Ob;ooo]Z1_l00016oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oook
JPCo000000?ooo]Zo`00Ool007l01Ol007lXoookJPOo0000A_oonfX3o`00Oagooo]Z000RoookJP?o
001oLooonfX3o`00O`;ooo]Z1?l00007oookJPKo001o9?oonfX7o`000003oookJ_l0003o000000So
0000>OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o00Co
001o:_oonfX7o`0000;ooo]Z2Ol0000joookJP?o001o7OoonfX001oooo]Z1_l007mcoookJP?o001o
0_oonfX4o`0000Oooo]Z0_l007lXoookJQ;o0000>OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o
0_oonfX4o`000003oookJ_l007oo001o02oooo]Z4_l0000foookJPKo001o7OoonfX001oooo]Z1_l0
07mdoookJP?o001o00?ooo]Zo`000?l000000_l00007oookJP;o001o:OoonfXBo`0003Sooo]Z1Ol0
001coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`000003oookJ_l007oo001o033ooo]Z
4_l0000eoookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJPCo001o1?l00008oookJPOo001o9?oo
nfXBo`0003Oooo]Z1Ol0001coookJPOo001o0_oonfX5o`0000;ooo]Z1ol007lZoookJQ;o0000=ooo
nfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Go00002?oonfX7o`00ObKooo]Z1ol00003
oookJPOo0000=_oonfX5o`0007Cooo]Z1Ol007l3oookJPGo00000_oonfX7o`00Ob_ooo]Z2Ol00002
oookJPOo0000=ooonfX3o`00Oagooo]Z002LoookJPGo0000@?oonfX7o`0003Gooo]Z1Ol0001loook
JPGo0000@OoonfX6o`0005Kooo]Z002LoookJPGo0000@OoonfX7o`0003Cooo]Z1Ol0001loookJPCo
0000@_oonfX7o`0005Gooo]Z002LoookJPCo0000@ooonfX6o`0000Gooo]Z2Ol0000VoookJPGo0000
O?oonfX4o`0004?ooo]Z1ol00004oookJPWo0000AooonfX009cooo]Z1?l00014oookJPSo000000?o
oo]Zo`000?l000002_l0000ToookJPGo0000O?oonfX4o`0004Cooo]Z1ol000000ooonf[o0000o`00
000:o`0004Kooo]Z002LoookJPCo0000AOoonfXEo`0000[ooo]Z1Ol0000DoookJPGo0000O?oonfX4
o`0004Gooo]Z5Ol0000:oookJPGo0000=OoonfX002Sooo]Z1ol0001]oookJPCo0000AOoonfXFo`00
00Kooo]Z2ol0000:oookJPco00002?oonfX7o`0006gooo]Z1?l00016oookJQKo00001_oonfX:o`00
00_ooo]Z1ol0000PoookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo0000
9Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?
oookJP003_oonf[oo`000?oo00009Ol0000?oookJP007?oonfX;o`0000Sooo]Z3?l00004oookJPSo
00001?oonfX;o`0004Kooo]Z1?l0001KoookJPKo00002_oonfX;o`0000Oooo]Z3?l00008oookJPgo
00001?oonfX8o`0000?ooo]Z2_l00017oookJPCo0000FooonfX6o`0000[ooo]Z2ol00009oookJP03
o`000?oonf[ooo]Z01cooo]Z000NoookJPSo00002_oonfX:o`0000Oooo]Z5_l00015oookJPCo0000
KOoonfX8o`0000Sooo]Z2ol0000:oookJP[o00001ooonfXEo`0004Kooo]Z1?l0001]oookJPSo0000
:OoonfX003;ooo]Z1_l0000:oookJQOo0000@ooonfX4o`0007gooo]Z1Ol0000CoookJPGo00002_oo
nfXEo`0004Gooo]Z1?l0002NoookJP00@ooonfXGo`0004;ooo]Z1?l0001moookJPGo00008ooonfXE
o`0004?ooo]Z1Ol0002NoookJP00A?oonfX:o`0000Gooo]Z2Ol00010oookJPCo0000OOoonfX5o`00
02Gooo]Z2Ol00004oookJPOo0000@_oonfX5o`0009kooo]Z001DoookJPWo0000?ooonfX4o`0007go
oo]Z1Ol0000coookJPOo0000@OoonfX5o`0009kooo]Z001FoookJPWo0000?OoonfX4o`0007gooo]Z
1Ol0000doookJPKo0000@OoonfX4o`0009oooo]Z001GoookJPWo0000??oonfX4o`0007gooo]Z1Ol0
000eoookJPKo00000ooonfX9o`0003Cooo]Z1?l0002OoookJP00FOoonfX9o`0003Wooo]Z1Ol0001m
oookJPGo0000=_oonfXBo`0003?ooo]Z1?l0002OoookJP00F_oonfX:o`0003Oooo]Z1Ol0001moook
JPGo0000=_oonfXBo`0003?ooo]Z1?l0002OoookJP00G?oonfX9o`0003Kooo]Z1Ol0001moookJPGo
0000=ooonfXBo`0003;ooo]Z1?l0002OoookJP00GOoonfX:o`0003Cooo]Z1?l0001noookJPGo0000
>?oonfX9o`0000;ooo]Z1ol0000aoookJPCo0000WooonfX005oooo]Z2_l0000boookJPCo0000O_oo
nfX5o`0004Cooo]Z1ol0000`oookJPCo0000WooonfX0067ooo]Z2_l0000`oookJPCo0000O_oonfX5
o`0004Gooo]Z1ol0000_oookJPCo0000WooonfX006;ooo]Z2_l0000_oookJPCo0000O_oonfX5o`00
04Kooo]Z1ol0000^oookJPCo0000WooonfX006Cooo]Z2_l0000]oookJPCo0000O_oonfX5o`0004Oo
oo]Z1ol0000]oookJPCo0000WooonfX006Kooo]Z2_l0000[oookJPCo0000O_oonfX5o`0004Sooo]Z
1ol0000/oookJPCo0000WooonfX006Sooo]Z2_l0000YoookJPCo0000O_oonfX5o`0004Wooo]Z1ol0
000[oookJPCo0000WooonfX006Wooo]Z2_l0000XoookJPCo0000O_oonfX5o`0004[ooo]Z1ol0000Z
oookJPCo0000WooonfX006_ooo]Z2_l0000VoookJPCo0000O_oonfX5o`0004_ooo]Z1ol0000Yoook
JPCo0000WooonfX006gooo]Z2Ol0000UoookJPCo0000O_oonfX5o`0004cooo]Z1ol0000XoookJPCo
0000WooonfX006oooo]Z1ol0000UoookJPCo0000O_oonfX5o`0004gooo]Z2?l0000VoookJPCo0000
WooonfX0073ooo]Z1ol0000ToookJPCo0000O_oonfX5o`0004kooo]Z2?l0000ToookJPGo0000Wooo
nfX007;ooo]Z1_l0000SoookJPCo0000O_oonfX5o`0004oooo]Z2?l0000SoookJPGo0000WooonfX0
07;ooo]Z1_l0000RoookJPGo0000O_oonfX5o`00053ooo]Z2?l0000RoookJPGo0000WooonfX007?o
oo]Z1_l0000QoookJPGo0000O_oonfX5o`0005;ooo]Z1ol0000QoookJPCo0000X?oonfX007Cooo]Z
1_l0000PoookJPGo0000O_oonfX5o`0005?ooo]Z1ol0000PoookJPCo0000X?oonfX007Cooo]Z1_l0
000PoookJPCo0000OooonfX5o`0005Cooo]Z1ol0000OoookJPCo0000X?oonfX007Gooo]Z1_l0000O
oookJPCo0000OooonfX5o`0005Gooo]Z1ol0000NoookJPCo0000X?oonfX007Kooo]Z1_l0000Noook
JPCo0000OooonfX5o`0005Kooo]Z1ol0000MoookJPCo0000X?oonfX007Kooo]Z1_l0000NoookJPCo
0000OooonfX5o`0005Oooo]Z1ol0000LoookJPCo0000X?oonfX007Oooo]Z1_l0000MoookJPCo0000
OooonfX5o`0005Sooo]Z1ol0000KoookJPCo0000X?oonfX007Sooo]Z1_l0000LoookJPCo0000Oooo
nfX5o`0005Wooo]Z1_l0000KoookJPCo0000X?oonfX007Sooo]Z1_l0000LoookJPCo0000OooonfX5
o`0005[ooo]Z1_l0000JoookJPCo0000X?oonfX007Wooo]Z1_l0000KoookJPCo0000OooonfX5o`00
05_ooo]Z1Ol0000JoookJPCo0000X?oonfX007[ooo]Z1_l0000JoookJPCo0000HOoonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`0005_ooo]Z1Ol0000JoookJPCo0000X?oonfX007[ooo]Z
1_l0000IoookJPGo0000H?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0005cooo]Z
1?l0000IoookJPGo0000X?oonfX007_ooo]Z1_l0000HoookJPGo0000H?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wo
oo]Z1Ol0001LoookJPGo00006?oonfX5o`000:3ooo]Z001loookJPKo00001OoonfX4o`0000kooo]Z
1Ol0001OoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0005cooo]Z
1Ol00006oookJPCo00003_oonfX5o`000:3ooo]Z001loookJPKo00001?oonfX6o`0000gooo]Z1?l0
001PoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000FooonfX6o`0000Cooo]Z1ol0
000<oookJPCo0000XOoonfX007gooo]Z1Ol00003oookJPSo00003?oonfX4o`00063ooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001MoookJPKo00000_oonfX8o`0000cooo]Z1?l0002Q
oookJP00O_oonfX5o`000003oookJ_l0003o000000So00002ooonfX4o`00063ooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000GOoonfX@o`0000cooo]Z1?l0002Qoook
JP00O_oonfX@o`0000_ooo]Z1?l0001PoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo
0000G_oonfX@o`0000_ooo]Z1?l0002QoookJP00O_oonfX@o`0000_ooo]Z1?l0001PoookJP?o001o
0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000GooonfX?o`0000_ooo]Z1?l0002QoookJP00Oooo
nfX9o`0000;ooo]Z1?l0000;oookJPCo0000H?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oo
nfX5o`0005oooo]Z2Ol000000ooonf[o0000o`000004o`0000[ooo]Z1?l0002QoookJP00P?oonfX7
o`0000?ooo]Z1Ol0000:oookJPCo0000HOoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l0
07l>oookJPGo0000H?oonfX7o`0000?ooo]Z1Ol00009oookJPGo0000XOoonfX008[ooo]Z1Ol0000:
oookJPCo0000HOoonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000J_oonfX6o`0000Sooo]Z1Ol0002Q
oookJP00R_oonfX5o`0000[ooo]Z1?l0001RoookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001[oook
JPGo00002?oonfX5o`000:7ooo]Z002;oookJPGo00002?oonfX5o`00083ooo]Z1Ol0001[oookJPGo
00002?oonfX4o`000:;ooo]Z002;oookJPGo00002?oonfX5o`00083ooo]Z1Ol0001/oookJPCo0000
2?oonfX4o`000:;ooo]Z002;oookJPGo00002?oonfX5o`00083ooo]Z1Ol0001/oookJPCo00002?oo
nfX4o`000:;ooo]Z002<oookJPCo00002?oonfX4o`00087ooo]Z1Ol0001/oookJPGo00001ooonfX4
o`000:;ooo]Z002<oookJPGo00001ooonfX4o`00087ooo]Z1Ol0001/oookJPGo00001ooonfX4o`00
0:;ooo]Z002<oookJPGo00001ooonfX4o`00087ooo]Z1Ol0001/oookJPGo00001ooonfX4o`000:;o
oo]Z002<oookJPGo00001ooonfX4o`00087ooo]Z1Ol0001]oookJPCo00001ooonfX4o`000:;ooo]Z
002=oookJPCo00001ooonfX4o`00087ooo]Z1Ol0001]oookJPCo00001ooonfX4o`000:;ooo]Z002=
oookJPCo00001ooonfX4o`00087ooo]Z1Ol0001]oookJPCo00001_oonfX5o`000:;ooo]Z002=oook
JPCo00001ooonfX4o`00087ooo]Z1Ol0001]oookJPCo00001_oonfX5o`000:;ooo]Z002=oookJPGo
00001_oonfX4o`00087ooo]Z1Ol0001]oookJPGo00001OoonfX5o`000:;ooo]Z002=oookJPGo0000
1_oonfX4o`00087ooo]Z1Ol0001]oookJPGo00001OoonfX4o`000:?ooo]Z002=oookJPGo00001Ooo
nfX5o`00087ooo]Z1Ol0001]oookJPGo00001OoonfX4o`000:?ooo]Z002>oookJPGo00001?oonfX5
o`00087ooo]Z1Ol0001^oookJPCo00001OoonfX4o`000:?ooo]Z002>oookJPGo00001?oonfX5o`00
087ooo]Z1Ol0001^oookJPCo00001OoonfX4o`000:?ooo]Z002>oookJPGo00001?oonfX4o`0008;o
oo]Z1Ol0001^oookJPGo00001?oonfX4o`000:?ooo]Z002?oookJPCo00001?oonfX4o`0008;ooo]Z
1Ol0001^oookJPGo00001?oonfX4o`000:?ooo]Z002?oookJPCo00001?oonfX4o`0008;ooo]Z1Ol0
001^oookJPGo00001?oonfX4o`000:?ooo]Z002?oookJPCo00001?oonfX4o`0008;ooo]Z1Ol0001_
oookJPCo00000ooonfX5o`000:?ooo]Z002?oookJPGo00000ooonfX4o`0008;ooo]Z1Ol0001_oook
JPGo00000_oonfX5o`000:?ooo]Z002?oookJPGo00000_oonfX5o`0008;ooo]Z1Ol0001_oookJPGo
00000_oonfX5o`000:?ooo]Z002?oookJPGo00000_oonfX5o`0008;ooo]Z1Ol0001_oookJPGo0000
0_oonfX4o`000:Cooo]Z002@oookJPCo00000_oonfX5o`0008;ooo]Z1Ol0001`oookJPGo000000?o
oo]Zo`000?l000000_l0002ToookJP00T?oonfX4o`0000;ooo]Z1?l00023oookJPGo0000L?oonfX5
o`000003oookJ_l0003o000000;o0000Y?oonfX0093ooo]Z1Ol000000ooonf[o0000o`000002o`00
08?ooo]Z1Ol0001`oookJPGo000000?ooo]Zo`000?l000000_l0002ToookJP00T?oonfX5o`000003
oookJ_l0003o000000;o0000PooonfX5o`00077ooo]Z1?l000000ooonf[o0000o`000002o`000:Co
oo]Z002@oookJP[o0000PooonfX5o`00077ooo]Z1?l000000ooonf[o0000o`000002o`000:Cooo]Z
002AoookJPWo0000PooonfX5o`00077ooo]Z2Ol0002ToookJP00TOoonfX9o`0008?ooo]Z1Ol0001a
oookJPWo0000Y?oonfX0097ooo]Z2?l0001goookJP?o001o2_oonfX5o`00077ooo]Z2Ol0002Toook
JP00T_oonfX7o`0007Oooo]Z0ol007l:oookJPGo0000LOoonfX8o`000:Gooo]Z002BoookJPOo0000
MooonfX3o`00O`[ooo]Z1Ol0001boookJPOo0000YOoonfX009;ooo]Z1_l0001hoookJP?o001o2_oo
nfX5o`0007;ooo]Z1_l0002VoookJP00TooonfX5o`0007Sooo]Z0ol007l:oookJPKo0000L_oonfX5
o`000:Kooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o
001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z
003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfX>oookJPKo001o2_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ3o
oo]Z1?l007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3
o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`00
0?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9
oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`00
0?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2_oo
nfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooook
JPkooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX6o`000?oo
oo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol0
07l9oookJPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/oookJP00oooonfX=oook
JP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRco
oo]Z003ooookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooonfX>oookJPOo001ooooo
nfX]oookJP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02605 .30761 L
.02729 .30693 L
.02846 .30639 L
.02954 .30601 L
.03072 .30574 L
.0318 .30564 L
.03279 .30568 L
.03396 .30588 L
.03506 .30621 L
.03626 .30671 L
.03756 .3074 L
.04262 .31061 L
.04385 .31129 L
.04516 .3119 L
.04591 .31217 L
.04659 .31236 L
.04728 .3125 L
.04793 .31258 L
.04919 .31259 L
.05035 .31243 L
.05162 .31207 L
.05227 .31182 L
.05297 .31151 L
.05784 .30866 L
.059 .30798 L
.06023 .30735 L
.06137 .30687 L
.06244 .30654 L
.0637 .30632 L
.06436 .30629 L
.06508 .30632 L
.06581 .30642 L
.06657 .30659 L
.06723 .3068 L
.06795 .30709 L
.07054 .30857 L
.07296 .31034 L
.07577 .31243 L
.07714 .31331 L
.07841 .31398 L
.07911 .31428 L
.07988 .31454 L
.08065 .31473 L
.08146 .31484 L
.08215 .31487 L
.0829 .31484 L
.0836 .31475 L
.08424 .31461 L
.08549 .31421 L
Mistroke
.08683 .31363 L
.08923 .31235 L
.09058 .3116 L
.09203 .31084 L
.0927 .31054 L
.09341 .31026 L
.09467 .30989 L
.09596 .30971 L
.09715 .30973 L
.09847 .31 L
.0992 .31026 L
.09987 .31056 L
.10103 .31122 L
.10229 .31213 L
.10458 .31414 L
.10912 .31849 L
.11036 .31951 L
.11167 .32042 L
.11278 .32102 L
.114 .32149 L
.11471 .32167 L
.11535 .32176 L
.11609 .3218 L
.11678 .32177 L
.11802 .32157 L
.11872 .32138 L
.11937 .32116 L
.12196 .32003 L
.12323 .31943 L
.12439 .31892 L
.12552 .3185 L
.12674 .31818 L
.12804 .31805 L
.12926 .31815 L
.1299 .31829 L
.13061 .31854 L
.13135 .31888 L
.13204 .31929 L
.13328 .32021 L
.13461 .32146 L
.1402 .3285 L
.14293 .3319 L
.14412 .33315 L
.14541 .33429 L
.14665 .33513 L
.14779 .33567 L
.14888 .33598 L
.15003 .3361 L
.15125 .33602 L
.15238 .33577 L
Mistroke
.15363 .33537 L
.15497 .33484 L
.15631 .33431 L
.15702 .33405 L
.15777 .33381 L
.1585 .33364 L
.15915 .33353 L
.16043 .3335 L
.16167 .33374 L
.16237 .33401 L
.16301 .33435 L
.16419 .33519 L
.16543 .3364 L
.18652 .35989 L
.18889 .35885 L
.19019 .35832 L
.19141 .35799 L
.19273 .35791 L
.19342 .35801 L
.19418 .35826 L
.19483 .35859 L
.19551 .35907 L
.19673 .36028 L
.19789 .36185 L
.19912 .36398 L
.20135 .36887 L
.2064 .38286 L
.20874 .38912 L
.20998 .39196 L
.21128 .39448 L
.21243 .39621 L
.21368 .39755 L
.21482 .39825 L
.21589 .39846 L
.21701 .39826 L
.21806 .39772 L
.21901 .39699 L
.22005 .396 L
.22235 .39353 L
.22348 .39242 L
.22451 .39161 L
.22575 .39106 L
.2264 .391 L
.22709 .39115 L
.2282 .39187 L
.22942 .39346 L
.23073 .39615 L
.23213 .40019 L
.23465 .41037 L
.23915 .43461 L
Mistroke
.24152 .44737 L
.24282 .45332 L
.24404 .45782 L
.24471 .45973 L
.24543 .46128 L
.24623 .46232 L
.24696 .46257 L
.24763 .4622 L
.24835 .4611 L
.24967 .45712 L
.25037 .45394 L
.251 .4504 L
.25243 .44019 L
.25499 .41417 L
.25745 .38107 L
.26012 .33898 L
.26496 .25841 L
.26733 .22307 L
.26987 .19207 L
.2711 .18023 L
.27227 .17112 L
.27332 .16474 L
.27446 .15973 L
.27571 .15648 L
.27642 .15564 L
.27708 .15547 L
.27778 .15591 L
.27843 .15684 L
.27913 .15838 L
.27987 .16055 L
.28111 .16524 L
.28227 .17057 L
.28489 .18471 L
.2874 .19875 L
.29012 .21195 L
.29137 .21678 L
.2927 .22089 L
.29383 .22355 L
.29507 .22557 L
.29581 .22634 L
.29649 .22679 L
.29727 .22702 L
.29801 .22698 L
.29933 .2264 L
.30008 .22584 L
.30077 .22521 L
.30347 .22233 L
.30465 .22117 L
.30595 .22019 L
.30723 .21965 L
Mistroke
.30842 .21962 L
.30969 .22015 L
.31039 .22072 L
.31104 .2214 L
.31239 .22333 L
.31386 .22614 L
.31654 .23274 L
.32137 .24637 L
.32402 .25273 L
.32531 .2552 L
.3265 .25702 L
.32758 .25831 L
.32872 .25927 L
.32986 .25986 L
.3311 .26013 L
.33237 .26004 L
.33309 .25988 L
.33373 .25967 L
.33618 .25862 L
.33725 .25816 L
.33839 .25777 L
.33963 .25753 L
.34078 .25754 L
.34185 .25778 L
.34285 .25824 L
.34394 .259 L
.34512 .26012 L
.3547 .27633 L
.35703 .27996 L
.35826 .2815 L
.35954 .28278 L
.36023 .28332 L
.36098 .28379 L
.3623 .28434 L
.36295 .28448 L
.36365 .28455 L
.3649 .28447 L
.36565 .28432 L
.36634 .28413 L
.36791 .28357 L
.36926 .28302 L
.37075 .28247 L
.37139 .28227 L
.37209 .2821 L
.37334 .28194 L
.37407 .28194 L
.37477 .28202 L
.37608 .28239 L
.37732 .283 L
.37802 .28346 L
Mistroke
.37865 .28395 L
.38103 .28631 L
.38643 .29331 L
.38893 .29629 L
.39029 .29762 L
.39156 .29861 L
.39265 .29925 L
.39381 .29971 L
.3951 .29996 L
.39628 .29996 L
.39694 .29987 L
.39764 .29972 L
.3989 .29932 L
.40175 .29805 L
.40424 .29695 L
.40493 .29671 L
.40565 .2965 L
.40693 .29627 L
.4081 .29624 L
.40919 .29639 L
.41039 .29674 L
.41166 .29734 L
.41286 .29809 L
.41399 .29895 L
.41611 .30085 L
.42093 .30543 L
.42225 .30645 L
.42367 .30734 L
.42436 .30767 L
.42501 .30793 L
.42624 .30824 L
.42741 .30834 L
.42865 .30824 L
.42983 .30796 L
.43089 .30758 L
.4335 .30629 L
.43596 .30492 L
.43722 .30429 L
.43854 .30374 L
.43967 .3034 L
.44091 .30319 L
.44161 .30316 L
.44225 .30318 L
.44298 .30327 L
.44368 .30342 L
.44491 .30384 L
.44561 .30415 L
.44625 .30449 L
.45088 .30771 L
.45314 .30938 L
Mistroke
.45521 .31063 L
.45633 .31113 L
.45739 .31148 L
.45851 .31169 L
.45973 .31174 L
.46098 .31158 L
.46168 .31141 L
.46231 .31121 L
.46355 .3107 L
.46471 .31011 L
.46714 .30865 L
.46975 .30708 L
.47101 .30644 L
.47221 .30596 L
.47329 .30564 L
.47446 .30546 L
.4757 .30544 L
.47701 .30562 L
.47813 .30594 L
.47937 .30645 L
.48215 .30802 L
.48477 .30973 L
.48702 .31106 L
.48816 .3116 L
.4894 .31204 L
.49047 .31228 L
.4916 .31239 L
.49268 .31235 L
.49365 .31218 L
.49488 .31182 L
.49602 .31135 L
.49858 .30992 L
.50097 .30839 L
.50324 .30705 L
.5044 .30649 L
.50567 .30603 L
.50683 .30576 L
.5079 .30565 L
.50918 .3057 L
.51033 .30592 L
.51097 .30611 L
.51166 .30637 L
.51292 .30694 L
.51724 .30962 L
.51953 .31102 L
.52079 .31166 L
.52198 .31213 L
.52266 .31233 L
.5234 .31249 L
.52469 .31261 L
Mistroke
.526 .31252 L
.52721 .31226 L
.52848 .31181 L
.52989 .31115 L
.53273 .30947 L
.53519 .30799 L
.53647 .30732 L
.53718 .30702 L
.53783 .30677 L
.53902 .30645 L
.54033 .3063 L
.54143 .30634 L
.54261 .30655 L
.54762 .30919 L
.5523 .31266 L
.55351 .31341 L
.55465 .31401 L
.55597 .31451 L
.55718 .31479 L
.55783 .31486 L
.55851 .31487 L
.55975 .31475 L
.56051 .31459 L
.56122 .31438 L
.56255 .31385 L
.56518 .31249 L
.56795 .31098 L
.5694 .31034 L
.57022 .31006 L
.57099 .30986 L
.5717 .30975 L
.57234 .3097 L
.57308 .30971 L
.57378 .3098 L
.57504 .31012 L
.57567 .31038 L
.57637 .31072 L
.57875 .31234 L
.58414 .31742 L
.58541 .31858 L
.5868 .3197 L
.58803 .32052 L
.58934 .32118 L
.59063 .32161 L
.5918 .32178 L
.59298 .32177 L
.59409 .3216 L
.59539 .32122 L
.59677 .32067 L
.59923 .31952 L
Mistroke
.60051 .31894 L
.60188 .31844 L
.60267 .31824 L
.60339 .31811 L
.60411 .31805 L
.6048 .31807 L
.6059 .31824 L
.60713 .31868 L
.60841 .3194 L
.60961 .32033 L
.61175 .3225 L
.61406 .32538 L
.61659 .32876 L
.61929 .33208 L
.6206 .33342 L
.62183 .33446 L
.62294 .33519 L
.62415 .33573 L
.6253 .33602 L
.62657 .3361 L
.62789 .33593 L
.62913 .3356 L
.63148 .33471 L
.63264 .33425 L
.63372 .33388 L
.63498 .33358 L
.63564 .3335 L
.63635 .33349 L
.63762 .33367 L
.63876 .33411 L
.63946 .33451 L
.64011 .33497 L
.64156 .33633 L
.64284 .33789 L
.64419 .33986 L
.64905 .34867 L
.65172 .35349 L
.65425 .35718 L
.65568 .35871 L
.65649 .35937 L
.65724 .35984 L
.65856 .36037 L
.65922 .3605 L
.65996 .36053 L
.66065 .36047 L
.66128 .36035 L
.66198 .36015 L
.66271 .35989 L
.66528 .35876 L
.66652 .35828 L
Mistroke
.66722 .35807 L
.66787 .35795 L
.66905 .35792 L
.6703 .35823 L
.67142 .35886 L
.67247 .35978 L
.67362 .36118 L
.67485 .36313 L
.67759 .36899 L
.68019 .37598 L
.68255 .38275 L
.68506 .38943 L
.68723 .39405 L
.68847 .39601 L
.68963 .39734 L
.69069 .3981 L
.69166 .39843 L
.69273 .3984 L
.69386 .39796 L
.695 .39716 L
.69623 .39602 L
.69843 .39364 L
.69978 .39232 L
.70105 .39141 L
.7022 .39102 L
.70344 .39121 L
.70467 .39216 L
.70579 .39376 L
.70709 .39657 L
.70832 .40019 L
.7105 .40882 L
.71289 .42083 L
.7157 .43662 L
.71834 .45039 L
.7195 .45526 L
.72072 .45926 L
.72136 .46078 L
.72206 .46194 L
.72329 .46254 L
.72461 .46096 L
.72535 .45897 L
.72602 .45645 L
.72733 .44956 L
.72857 .44058 L
.73127 .41315 L
.7342 .37279 L
.73942 .28668 L
.74198 .24548 L
.74432 .2124 L
.74653 .18731 L
Mistroke
.74765 .17721 L
.74885 .16855 L
.75006 .16207 L
.75118 .15806 L
.75187 .15653 L
.75252 .15571 L
.75373 .15569 L
.75499 .15758 L
.75562 .15919 L
.75632 .16141 L
.75871 .17182 L
.76411 .20148 L
.76539 .20785 L
.76679 .21391 L
.76803 .21835 L
.76934 .22206 L
.77014 .2238 L
.77087 .22503 L
.7716 .22596 L
.77228 .22656 L
.77357 .22703 L
.7743 .22696 L
.77496 .22672 L
.77619 .2259 L
.77732 .22485 L
.77991 .22207 L
.7812 .22086 L
.78242 .22003 L
.7831 .21974 L
.78383 .21958 L
.78512 .21976 L
.78634 .2205 L
.78746 .22169 L
.78876 .22363 L
.78999 .226 L
.79455 .23788 L
.79716 .24528 L
.79994 .25215 L
.80129 .25482 L
.80256 .25684 L
.80371 .25824 L
.80494 .25929 L
.80616 .2599 L
.80684 .26007 L
.80749 .26013 L
.80878 .26 L
.80951 .25981 L
.81018 .25957 L
.81268 .25848 L
.81378 .25803 L
Mistroke
.81499 .25766 L
.8163 .2575 L
.81702 .25754 L
.81769 .25768 L
.81843 .25793 L
.8191 .25828 L
.81985 .25877 L
.82063 .25943 L
.82195 .26086 L
.82318 .26251 L
.82597 .26717 L
.83101 .27654 L
.83239 .27877 L
.83386 .2808 L
.83512 .28221 L
.83582 .28285 L
.83648 .28336 L
.83776 .28408 L
.83892 .28444 L
.84002 .28455 L
.84121 .28445 L
.84252 .28414 L
.84325 .28389 L
.84391 .28364 L
.84513 .28315 L
.84641 .28265 L
.84756 .28228 L
.84881 .28201 L
.84995 .28193 L
.85101 .28203 L
.85227 .28239 L
.85341 .28294 L
.85474 .28386 L
.85599 .28499 L
.86064 .29066 L
.865 .29616 L
.86721 .29822 L
.86846 .29905 L
.8696 .29958 L
.87078 .29989 L
.87207 .29998 L
.87272 .29993 L
.87341 .29982 L
.87467 .29947 L
.8772 .2984 L
.87854 .29776 L
.87995 .29714 L
.88119 .29668 L
.88189 .29649 L
.88254 .29635 L
Mistroke
.8837 .29623 L
.88493 .29631 L
.88617 .2966 L
.88687 .29686 L
.88752 .29716 L
.88998 .29879 L
.89459 .3031 L
.89678 .30514 L
.89884 .30673 L
.89987 .30734 L
.90099 .30785 L
.90223 .30821 L
.90336 .30834 L
.90463 .30827 L
.90584 .30801 L
.90691 .30765 L
.90809 .30713 L
.91054 .30581 L
.91314 .30442 L
.91423 .30393 L
.91539 .30353 L
.91668 .30324 L
.91788 .30316 L
.91905 .30325 L
.92016 .30351 L
.92116 .30386 L
.92225 .30438 L
.92744 .308 L
.92881 .30901 L
.93029 .31 L
.93157 .31072 L
.9323 .31105 L
.93298 .3113 L
.93362 .31149 L
.9343 .31164 L
.93503 .31172 L
.9357 .31174 L
.93698 .31162 L
.9382 .31131 L
.93938 .31086 L
.94047 .31034 L
.94294 .3089 L
.94485 .30771 L
.94686 .3066 L
.94791 .30614 L
.94907 .30575 L
.95011 .30552 L
.95109 .30543 L
.95209 .30545 L
.95303 .30559 L
Mistroke
.95387 .3058 L
.95479 .30611 L
.95685 .30711 L
.95874 .30828 L
.96085 .30966 L
.96312 .31101 L
.96422 .31154 L
.96526 .31194 L
.9662 .31219 L
.96722 .31236 L
.96829 .31239 L
.96944 .31227 L
.97051 .31201 L
.97149 .31166 L
.97266 .31113 L
.97391 .31044 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00oooonfX1oookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z002SoookJPKo
0000EooonfX:o`00O`Kooo]Z0ol007l:oookJPKo0000P_oonfX6o`0009Gooo]Z002SoookJPKo0000
IooonfX3o`00O`[ooo]Z1Ol00023oookJPKo0000UOoonfX00:?ooo]Z1_l0001WoookJP?o001o2_oo
nfX5o`0008?ooo]Z1ol0002DoookJP00XooonfX7o`0006Kooo]Z0ol007l:oookJPGo0000PooonfX7
o`0009Cooo]Z002RoookJPSo0000I_oonfX3o`00O`[ooo]Z1Ol00023oookJPOo0000U?oonfX00:;o
oo]Z2?l0001SoookJPKo001o2_oonfX5o`0008?ooo]Z1ol0002DoookJP00X_oonfX8o`0006?ooo]Z
1_l007l:oookJPGo0000P_oonfX8o`0009Cooo]Z002RoookJPWo0000I?oonfX4o`00O`[ooo]Z1Ol0
0022oookJPWo0000TooonfX00:;ooo]Z2Ol0001UoookJP?o001o2_oonfX5o`0008;ooo]Z2Ol0002C
oookJP00X_oonfX9o`0007;ooo]Z1Ol00022oookJPWo0000TooonfX00:;ooo]Z1?l000000ooonf[o
0000o`000002o`0007;ooo]Z1Ol00021oookJPGo000000?ooo]Zo`000?l000000_l0002CoookJP00
XOoonfX5o`000003oookJ_l0003o000000;o0000L_oonfX5o`00087ooo]Z1Ol000000ooonf[o0000
o`000002o`0009?ooo]Z002QoookJPGo000000?ooo]Zo`000?l000000_l0001boookJPGo0000POoo
nfX5o`000003oookJ_l0003o000000;o0000TooonfX00:7ooo]Z1Ol000000ooonf[o0000o`000003
o`00077ooo]Z1Ol00021oookJPCo00000_oonfX5o`0009;ooo]Z002QoookJPCo00000_oonfX5o`00
077ooo]Z1Ol00021oookJPCo00000_oonfX5o`0009;ooo]Z002QoookJPCo00000_oonfX5o`00077o
oo]Z1Ol00021oookJPCo00000_oonfX5o`0009;ooo]Z002QoookJPCo00000ooonfX4o`00077ooo]Z
1Ol00021oookJPCo00000ooonfX4o`0009;ooo]Z002PoookJPGo00000ooonfX4o`00077ooo]Z1Ol0
0021oookJPCo00000ooonfX4o`0009;ooo]Z002PoookJPGo00000ooonfX4o`00077ooo]Z1Ol00021
oookJPCo00000ooonfX5o`00097ooo]Z002PoookJPGo00000ooonfX5o`00073ooo]Z1Ol00021oook
JPCo00000ooonfX5o`00097ooo]Z002PoookJPCo00001?oonfX5o`00073ooo]Z1Ol00021oookJPCo
00000ooonfX5o`00097ooo]Z002PoookJPCo00001?oonfX5o`00073ooo]Z1Ol00020oookJPGo0000
1?oonfX4o`00097ooo]Z002PoookJPCo00001OoonfX5o`0006oooo]Z1Ol00020oookJPGo00001?oo
nfX4o`00097ooo]Z002PoookJPCo00001OoonfX5o`0006oooo]Z1Ol00020oookJPGo00001?oonfX5
o`00093ooo]Z002PoookJPCo00001OoonfX5o`0006oooo]Z1Ol00020oookJPCo00001OoonfX5o`00
093ooo]Z002PoookJPCo00001_oonfX4o`0006oooo]Z1Ol00020oookJPCo00001OoonfX5o`00093o
oo]Z002PoookJPCo00001_oonfX4o`0006oooo]Z1Ol00020oookJPCo00001_oonfX4o`00093ooo]Z
002PoookJPCo00001_oonfX5o`0006kooo]Z1Ol00020oookJPCo00001_oonfX5o`0008oooo]Z002P
oookJPCo00001_oonfX5o`0006kooo]Z1Ol0001ooookJPGo00001_oonfX5o`0008oooo]Z002Ooook
JPGo00001_oonfX5o`0006kooo]Z1Ol0001ooookJPGo00001_oonfX5o`0008oooo]Z002OoookJPGo
00001ooonfX4o`0006kooo]Z1Ol0001ooookJPGo00001ooonfX5o`0008kooo]Z002OoookJPGo0000
1ooonfX4o`0006kooo]Z1Ol0001ooookJPCo00002?oonfX5o`0008kooo]Z002OoookJPCo00002?oo
nfX5o`0006gooo]Z1Ol0001ooookJPCo00002?oonfX5o`0008kooo]Z002OoookJPCo00002?oonfX5
o`0006gooo]Z1Ol0001ooookJPCo00002OoonfX4o`0008kooo]Z002OoookJPCo00002?oonfX5o`00
06gooo]Z1Ol0001ooookJPCo00002OoonfX4o`0008kooo]Z002OoookJPCo00002OoonfX5o`0000;o
oo]Z1ol0001SoookJPGo0000OooonfX4o`0000Wooo]Z1?l00003oookJPOo0000Q?oonfX009oooo]Z
1?l00009oookJPGo000000?ooo]Zo`000?l000001ol0001RoookJPGo0000OooonfX4o`0000Wooo]Z
1Ol000000ooonf[o0000o`000007o`0008?ooo]Z002OoookJPCo00002OoonfX5o`000003oookJ_l0
003o000000Oo0000H_oonfX5o`0007oooo]Z1?l00009oookJPoo0000PooonfX009oooo]Z1?l0000:
oookJPoo0000@ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0007oooo]Z1?l00009
oookJQ3o0000P_oonfX009oooo]Z1?l0000:oookJPWo000000?ooo]Zo`000?l000000ol00012oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000OooonfX4o`0000[ooo]Z3ol00022oook
JP00WooonfX4o`0000[ooo]Z2Ol000000ooonf[o0000o`000004o`00047ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9
oookJPGo0000OooonfX4o`0000[ooo]Z2?l00002oookJPKo0000POoonfX009oooo]Z1?l0000;oook
JPOo00000ooonfX5o`0003Cooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o2?oonfX5o`0007kooo]Z1Ol0000;oookJPOo00000ooonfX5o`00087ooo]Z002OoookJPCo
00003?oonfX5o`0000Cooo]Z1_l0000coookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2?oonfX6o`0007gooo]Z1Ol0000<oookJPGo00001?oonfX6o`00083ooo]Z002OoookJPCo0000
5_oonfX5o`0003oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001noookJPGo0000
5_oonfX5o`00083ooo]Z002OoookJPCo00005_oonfX5o`0003oooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l8oookJPGo0000O_oonfX4o`0001Oooo]Z1_l0001ooookJP00WooonfX4
o`0001Oooo]Z1Ol0000noookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000O_oonfX4
o`0001Sooo]Z1Ol0001ooookJP00WooonfX4o`0001Oooo]Z1Ol0000noookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007l:oookJPGo0000O_oonfX4o`0001Sooo]Z1Ol0001ooookJP00W_oonfX5o`0001Oo
oo]Z1Ol0000noookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000O_oonfX4o`0001Wo
oo]Z1Ol0001noookJP00W_oonfX5o`0001Sooo]Z1Ol0000noookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00O`kooo]Z1Ol0001noookJPCo00006OoonfX5o`0007kooo]Z002NoookJPGo0000
6?oonfX5o`0003kooo]Z1ol007l9oookJPOo001o2?oonfX5o`0007kooo]Z1?l0000IoookJPGo0000
O_oonfX009kooo]Z1?l0000IoookJPGo0000?ooonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000O_oo
nfX4o`0001[ooo]Z1Ol0001moookJP00W_oonfX4o`0001[ooo]Z1Ol0001LoookJPGo0000O_oonfX4
o`0001[ooo]Z1Ol0001moookJP00W_oonfX4o`0001[ooo]Z1Ol0001LoookJPGo0000O_oonfX4o`00
01[ooo]Z1_l0001loookJP00W_oonfX4o`0001[ooo]Z1_l0001KoookJPGo0000O_oonfX4o`0001_o
oo]Z1Ol0001loookJP00W_oonfX4o`0001_ooo]Z1Ol0001KoookJPGo0000O_oonfX4o`0001_ooo]Z
1Ol0001loookJP00W_oonfX4o`0001_ooo]Z1_l00002oookJPKo0000D_oonfX5o`0007kooo]Z1?l0
000LoookJPGo00000_oonfX7o`0007;ooo]Z002NoookJPCo00007?oonfX>o`00057ooo]Z1Ol0001n
oookJPCo00007?oonfX?o`00077ooo]Z002NoookJPCo00007?oonfX?o`00053ooo]Z1Ol0001noook
JPCo00007?oonfX?o`00077ooo]Z002NoookJPCo00007OoonfX>o`00053ooo]Z1Ol0001noookJPCo
00007OoonfX?o`00073ooo]Z002NoookJPCo00007_oonfX>o`0004oooo]Z1Ol0001noookJPCo0000
7_oonfX?o`0006oooo]Z002NoookJPCo00007ooonfX4o`0000Cooo]Z1_l0001>oookJPGo0000O_oo
nfX4o`0001oooo]Z1Ol00003oookJPOo0000K_oonfX009kooo]Z1?l0000WoookJPKo0000C_oonfX5
o`0007gooo]Z1Ol0000XoookJPKo0000K_oonfX009kooo]Z1?l0000XoookJPKo0000COoonfX5o`00
07gooo]Z1Ol0000YoookJPKo0000KOoonfX002;ooo]Z0ol007meoookJPCo001o1?l000001?oonf[o
001oo`00Ool007l3oookJPGo001o7OoonfX5o`0004gooo]Z1Ol0001doookJPGo001o1?oonfX5o`00
0003oookJ_l007oo001o00?o001o9?oonfX5o`0004gooo]Z0ol007lMoookJP008_oonfX3o`00OgCo
oo]Z1?l007l5o`000004oookJ_l007oo001oo`00O`;ooo]Z1ol007lLoookJPKo0000C?oonfX5o`00
07?ooo]Z1ol007l3oookJPCo000000?ooo]Zo`00Ool007l01Ol007lSoookJPGo0000COoonfX3o`00
Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`03oookJ_l0003o000000?o000000Gooo]Zo`00Ool0
07oo001ooookJP04o`00O`04oookJ_l007oo001oo`00Oagooo]Z1_l0001;oookJPGo0000LooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1?l00004o`00O`04oookJ_l007oo001oo`00ObCooo]Z
1Ol0001<oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol0
07l2oookJPGo00001OoonfX3o`00O`?ooo]Z0ol007lLoookJPOo0000B_oonfX5o`0007;ooo]Z0ol0
07l3oookJP?o001o0_oonfX4o`0000?o001o0ooonfX3o`00Ob?ooo]Z1Ol0001<oookJP?o001o7Ooo
nfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l2oookJPCo00003?oonfX3
o`00Oagooo]Z1ol00019oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00001_oonfX3
o`00Ob?ooo]Z1_l0001;oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4o`00
00cooo]Z0ol007lNoookJPKo00001?oonfX5o`00043ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00
O`;ooo]Z1?l00006oookJP?o001o9?oonfX6o`0000Cooo]Z1Ol00011oookJP?o001o7OoonfX002;o
oo]Z0ol007mcoookJP?o001o0_oonfX4o`0000Oooo]Z0_l007l2oookJPCo001o7ooonfX@o`0003ko
oo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02oookJPCo
001o9?oonfXAo`0003oooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo0000
1ooonfX7o`00Ob7ooo]Z4?l0000moookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo0000
00?ooo]Zo`00Ool007l01Ol007lVoookJQ7o0000?_oonfX3o`00Oagooo]Z000RoookJP?o001oLooo
nfX3o`00O`;ooo]Z1?l00007oookJPKo001o8_oonfXAo`0003cooo]Z1Ol0001boookJP?o001o0ooo
nfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`04o`00ObSooo]Z4?l0000noookJP?o001o7Ooo
nfX001oooo]Z1_l007mcoookJP?o001o0_oonfX4o`0000Oooo]Z0_l007lWoookJQ3o0000??oonfX5
o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o02gooo]Z4?l0000j
oookJPKo001o7OoonfX001oooo]Z1_l007mdoookJP?o001o00?ooo]Zo`000?l000000_l00007oook
JP;o001o:?oonfX7o`0000?ooo]Z1_l0000koookJPGo0000LooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z1?l000000ooonf[o001oo`00O`0^oookJPOo00000ooonfX6o`0003Wooo]Z1_l007lM
oookJP008OoonfX4o`00OgCooo]Z1?l007l4o`0000Sooo]Z1ol007l]oookJPGo0000>ooonfX5o`00
07?ooo]Z1ol007l3oookJPCo00000_oonfX7o`00Oc;ooo]Z1ol0000joookJPCo001o7OoonfX002;o
oo]Z0ol007meoookJP?o001o1?l00008oookJPOo001o;OoonfX7o`0003Wooo]Z1Ol0001doookJPGo
001o1?oonfX4o`0000;ooo]Z1ol007lcoookJPOo0000>_oonfX3o`00Oagooo]Z002MoookJPCo0000
?OoonfX7o`0000Cooo]Z1ol0000]oookJPGo0000OOoonfX4o`0003gooo]Z1ol00005oookJPOo0000
COoonfX009gooo]Z1?l0000moookJPSo000000?ooo]Zo`000?l000002Ol0000[oookJPGo0000OOoo
nfX4o`0003kooo]Z1ol000000ooonf[o0000o`000009o`0004cooo]Z002LoookJPGo0000?_oonfXD
o`0002[ooo]Z1Ol0001moookJPCo0000?ooonfXCo`0004_ooo]Z002LoookJPGo0000@?oonfXCo`00
02Wooo]Z1Ol0001moookJPCo0000@?oonfXCo`0004[ooo]Z002LoookJPGo0000@OoonfX:o`000003
oookJ_l0003o000000Ko00001_oonfX9o`0001Wooo]Z1Ol0001loookJPGo0000@OoonfXCo`0000Ko
oo]Z2?l0000koookJP007_oonfX6o`0007Sooo]Z1?l00013oookJPOo00001?oonfX8o`0000Cooo]Z
2ol00009oookJPOo00002?oonfX:o`0007Oooo]Z1Ol00012oookJPOo00001OoonfX7o`0000?ooo]Z
3Ol00008oookJPSo0000:?oonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003o
o`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go
00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX001gooo]Z00?o0000oookJ_oonfX01Ooo
nfX:o`0000Oooo]Z5_l0001@oookJPCo0000IOoonfX9o`0000Sooo]Z3?l00006oookJPWo00001ooo
nfXFo`00053ooo]Z1?l0001ToookJP[o00002?oonfX:o`0001kooo]Z000WoookJPOo00002OoonfX;
o`0000?ooo]Z2?l00004oookJPSo0000@ooonfX4o`0006Oooo]Z1?l0000<oookJP_o00001ooonfX7
o`0000Wooo]Z2ol00004oookJPOo00001?oonfX8o`0004?ooo]Z1?l0001WoookJPCo00003?oonfX7
o`00023ooo]Z000ioookJPSo00001_oonfX8o`000003oookJ_l0003o000000So0000@_oonfX4o`00
07gooo]Z1Ol0000IoookJPSo00001_oonfXDo`00047ooo]Z1?l0002NoookJP00B?oonfXCo`00047o
oo]Z1?l0001moookJPGo0000:?oonfXDo`00043ooo]Z1?l0002NoookJP00BOoonfXBo`00047ooo]Z
1?l0001moookJPGo0000:OoonfXCo`00043ooo]Z1?l0002NoookJP00B_oonfX;o`000003oookJ_l0
003o000000Co0000@?oonfX4o`0007gooo]Z1Ol0000ZoookJP_o000000?ooo]Zo`000?l000001Ol0
000ooookJPCo0000W_oonfX004_ooo]Z2?l00004oookJPKo0000?_oonfX5o`0007gooo]Z1Ol0000[
oookJPSo00001OoonfX5o`0003oooo]Z1?l0002NoookJP00EooonfX7o`0003gooo]Z1Ol0001moook
JPGo0000>?oonfX6o`0003kooo]Z1?l0002NoookJP00F?oonfX7o`0003cooo]Z1Ol0001moookJPGo
0000>OoonfX6o`0003cooo]Z1Ol0002NoookJP00FOoonfX7o`0000Cooo]Z1_l0000aoookJPCo0000
O_oonfX5o`0003Wooo]Z1ol00004oookJPKo0000<OoonfX5o`0009kooo]Z001JoookJQ7o0000<?oo
nfX4o`0007kooo]Z1Ol0000joookJQ7o0000<?oonfX5o`0009kooo]Z001KoookJQ7o0000;ooonfX4
o`0007kooo]Z1Ol0000koookJQ7o0000;ooonfX4o`0009oooo]Z001LoookJQ3o0000;ooonfX4o`00
07kooo]Z1Ol0000loookJQ3o0000;ooonfX4o`0009oooo]Z001MoookJQ3o0000;_oonfX4o`0007ko
oo]Z1Ol0000moookJQ3o0000;_oonfX4o`0009oooo]Z001OoookJPKo00000ooonfX6o`0002gooo]Z
1?l0001noookJPGo0000?_oonfX6o`0000Cooo]Z1Ol0000^oookJPCo0000WooonfX006Sooo]Z1ol0
000/oookJPCo0000O_oonfX5o`0004Sooo]Z1_l0000]oookJPCo0000WooonfX006Wooo]Z1ol0000[
oookJPCo0000O_oonfX5o`0004Wooo]Z1_l0000/oookJPCo0000WooonfX006[ooo]Z1ol0000Zoook
JPCo0000O_oonfX5o`0004Wooo]Z1_l0000/oookJPCo0000WooonfX006_ooo]Z1ol0000YoookJPCo
0000O_oonfX5o`0004[ooo]Z1_l0000[oookJPCo0000WooonfX006cooo]Z1_l0000YoookJPCo0000
O_oonfX5o`0004_ooo]Z1Ol0000[oookJPCo0000WooonfX006gooo]Z1_l0000XoookJPCo0000O_oo
nfX5o`0004_ooo]Z1_l0000ZoookJPCo0000WooonfX006kooo]Z1_l0000WoookJPCo0000O_oonfX5
o`0004cooo]Z1_l0000YoookJPCo0000WooonfX006kooo]Z1ol0000VoookJPCo0000O_oonfX5o`00
04cooo]Z1ol0000XoookJPCo0000WooonfX006oooo]Z3Ol0000OoookJPCo0000O_oonfX5o`0004go
oo]Z3ol0000OoookJPCo0000WooonfX0073ooo]Z3Ol0000MoookJPGo0000O_oonfX5o`0004kooo]Z
3ol0000MoookJPGo0000WooonfX0077ooo]Z3?l0000MoookJPGo0000O_oonfX5o`0004oooo]Z3ol0
000LoookJPGo0000WooonfX007;ooo]Z3?l0000LoookJPGo0000O_oonfX5o`0004oooo]Z3ol0000L
oookJPGo0000WooonfX007?ooo]Z1?l00002oookJPGo00007?oonfX4o`0007oooo]Z1Ol0001@oook
JPOo000000?ooo]Zo`000?l000001?l0000LoookJPCo0000X?oonfX007Wooo]Z1_l0000KoookJPCo
0000OooonfX5o`0005[ooo]Z1Ol0000KoookJPCo0000X?oonfX007[ooo]Z1Ol0000KoookJPCo0000
OooonfX5o`0005[ooo]Z1Ol0000KoookJPCo0000X?oonfX007[ooo]Z1_l0000JoookJPCo0000Oooo
nfX5o`0005[ooo]Z1Ol0000KoookJPCo0000X?oonfX007_ooo]Z1Ol0000JoookJPCo0000OooonfX5
o`0005_ooo]Z1Ol0000JoookJPCo0000X?oonfX007_ooo]Z1Ol0000JoookJPCo0000OooonfX5o`00
05_ooo]Z1_l0000IoookJPCo0000X?oonfX007cooo]Z1Ol0000IoookJPCo0000OooonfX5o`0005_o
oo]Z1_l0000IoookJPCo0000X?oonfX007cooo]Z1Ol0000IoookJPCo0000OooonfX5o`0005cooo]Z
1Ol0000IoookJPCo0000X?oonfX007cooo]Z1Ol0000IoookJPCo0000HOoonfX5o`00O`Cooo]Z0ol0
07l3oookJPGo001o2_oonfX5o`0005gooo]Z1Ol0000HoookJPCo0000X?oonfX007gooo]Z1Ol0000H
oookJPCo0000H?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0005gooo]Z1Ol0000H
oookJPCo0000X?oonfX007gooo]Z1Ol0000HoookJPCo0000H?oonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0
001MoookJPGo00005ooonfX5o`000:3ooo]Z001moookJPKo00005ooonfX4o`0005oooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000G_oonfX4o`0001Oooo]Z1Ol0002P
oookJP00O_oonfX5o`0001Oooo]Z1?l0001OoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oook
JPKo0000GOoonfX5o`0001Kooo]Z1Ol0002PoookJP00O_oonfX5o`0000Gooo]Z1Ol0000<oookJPGo
0000GooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0005kooo]Z1Ol00006oookJPCo
00003?oonfX4o`000:7ooo]Z001ooookJPGo00000ooonfX7o`0000_ooo]Z1Ol0001OoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0005kooo]Z1Ol00004oookJPOo0000
2ooonfX4o`000:7ooo]Z001ooookJPKo000000?ooo]Zo`000?l000001_l0000;oookJPGo0000Gooo
nfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`0005oooo]Z1Ol00002oookJPWo00002_oo
nfX4o`000:7ooo]Z001ooookJQ3o00002_oonfX4o`00063ooo]Z0ol007l3oookJP?o001o1ooonfX6
o`00O`[ooo]Z1Ol0001OoookJQ3o00002_oonfX4o`000:7ooo]Z0020oookJPoo00002_oonfX4o`00
063ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001OoookJQ3o00002_oonfX4o`00
0:7ooo]Z0021oookJPoo00002OoonfX4o`00067ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oook
JP;o001o3_oonfX5o`00063ooo]Z4?l00009oookJPCo0000XOoonfX0087ooo]Z2?l00002oookJPGo
00002OoonfX4o`00067ooo]Z1ol007l9oookJPOo001o2?oonfX5o`00067ooo]Z2?l00002oookJPGo
00002OoonfX4o`000:7ooo]Z0022oookJPOo00000_oonfX5o`0000Wooo]Z1?l0001RoookJPGo001o
2_oonfX7o`00O`Sooo]Z1Ol0001RoookJPOo00000_oonfX5o`0000Wooo]Z1?l0002QoookJP00Pooo
nfX4o`0000Gooo]Z1?l00009oookJPCo0000P?oonfX5o`0006cooo]Z1Ol00007oookJPGo0000XOoo
nfX008cooo]Z1Ol00007oookJPGo0000P?oonfX5o`0006cooo]Z1Ol00007oookJPGo0000XOoonfX0
08cooo]Z1Ol00007oookJPGo0000P?oonfX5o`0006cooo]Z1Ol00007oookJPGo0000XOoonfX008co
oo]Z1Ol00007oookJPGo0000P?oonfX5o`0006gooo]Z1?l00007oookJPCo0000X_oonfX008gooo]Z
1?l00007oookJPCo0000POoonfX5o`0006gooo]Z1?l00007oookJPCo0000X_oonfX008gooo]Z1?l0
0007oookJPCo0000POoonfX5o`0006gooo]Z1?l00007oookJPCo0000X_oonfX008gooo]Z1Ol00006
oookJPCo0000POoonfX5o`0006gooo]Z1Ol00006oookJPCo0000X_oonfX008gooo]Z1Ol00006oook
JPCo0000POoonfX5o`0006gooo]Z1Ol00006oookJPCo0000X_oonfX008gooo]Z1Ol00006oookJPCo
0000POoonfX5o`0006gooo]Z1Ol00006oookJPCo0000X_oonfX008kooo]Z1?l00006oookJPCo0000
POoonfX5o`0006kooo]Z1?l00006oookJPCo0000X_oonfX008kooo]Z1Ol00005oookJPCo0000POoo
nfX5o`0006kooo]Z1?l00006oookJPCo0000X_oonfX008kooo]Z1Ol00005oookJPCo0000POoonfX5
o`0006kooo]Z1?l00006oookJPCo0000X_oonfX008kooo]Z1Ol00005oookJPCo0000POoonfX5o`00
06kooo]Z1Ol00004oookJPGo0000X_oonfX008oooo]Z1?l00004oookJPGo0000POoonfX5o`0006ko
oo]Z1Ol00004oookJPGo0000X_oonfX008oooo]Z1?l00004oookJPGo0000POoonfX5o`0006kooo]Z
1Ol00004oookJPGo0000X_oonfX008oooo]Z1Ol00003oookJPGo0000POoonfX5o`0006oooo]Z1?l0
0004oookJPCo0000XooonfX008oooo]Z1Ol00003oookJPCo0000P_oonfX5o`0006oooo]Z1Ol00003
oookJPCo0000XooonfX008oooo]Z1Ol00003oookJPCo0000P_oonfX5o`0006oooo]Z1Ol00003oook
JPCo0000XooonfX0093ooo]Z1?l00003oookJPCo0000P_oonfX5o`0006oooo]Z1Ol00003oookJPCo
0000XooonfX0093ooo]Z1?l00003oookJPCo0000P_oonfX5o`00073ooo]Z1?l00003oookJPCo0000
XooonfX0093ooo]Z1Ol00002oookJPCo0000P_oonfX5o`00073ooo]Z1?l00003oookJPCo0000Xooo
nfX0093ooo]Z1Ol00002oookJPCo0000P_oonfX5o`00073ooo]Z1?l00003oookJPCo0000XooonfX0
093ooo]Z1Ol00002oookJPCo0000P_oonfX5o`00073ooo]Z1Ol000000ooonf[o0000o`000003o`00
0:?ooo]Z002AoookJPCo000000?ooo]Zo`000?l000000ol00022oookJPGo0000L?oonfX5o`000003
oookJ_l0003o000000?o0000XooonfX0097ooo]Z1?l000000ooonf[o0000o`000003o`0008;ooo]Z
1Ol0001`oookJPGo000000?ooo]Zo`000?l000000ol0002SoookJP00TOoonfX:o`0008;ooo]Z1Ol0
001aoookJPCo000000?ooo]Zo`000?l000000_l0002ToookJP00TOoonfX9o`0008?ooo]Z1Ol0001a
oookJPCo000000?ooo]Zo`000?l000000_l0002ToookJP00TOoonfX9o`0008?ooo]Z1Ol0001aoook
JPWo0000Y?oonfX009;ooo]Z2?l00023oookJPGo0000LOoonfX9o`000:Cooo]Z002BoookJPSo0000
M_oonfX3o`00O`[ooo]Z1Ol0001aoookJPWo0000Y?oonfX009;ooo]Z2?l0001foookJP?o001o2_oo
nfX5o`0007;ooo]Z1ol0002UoookJP00T_oonfX7o`0007Oooo]Z0ol007l:oookJPGo0000L_oonfX7
o`000:Gooo]Z002BoookJPOo0000MooonfX3o`00O`[ooo]Z1Ol0001coookJPKo0000YOoonfX009?o
oo]Z1_l0001goookJP?o001o2_oonfX6o`0007;ooo]Z1_l0002UoookJP00TooonfX5o`0007Sooo]Z
0ol007l:oookJPGo0000LooonfX5o`000:Kooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooo
nfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00
O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00
oooonfX>oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX2
oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00oooonfX2oook
JP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o
001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXNoookJP00oooo
nfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9
oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oook
JPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l007l:oookJPGo
0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00o_oo
nfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00oooonfX1oookJPCo001o2_oonfX7
o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o2?oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9
o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoook
JP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4o`00O`cooo]Z
1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oookJPKo0000oooonfXNoookJP00oooonfXA
oookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z1Ol0003ooook
JQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o
oooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX4
o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z003ooookJPoo
oo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02605 .31042 L
.02729 .31108 L
.02846 .31159 L
.02954 .31194 L
.03072 .31215 L
.0318 .31218 L
.03279 .31208 L
.03396 .3118 L
.03506 .31139 L
.03626 .31081 L
.03756 .31007 L
.04018 .3084 L
.04262 .30702 L
.04385 .3065 L
.04516 .30612 L
.0459 .306 L
.04661 .30596 L
.04793 .30606 L
.04919 .30636 L
.05035 .30682 L
.05162 .30748 L
.05297 .30831 L
.05552 .31005 L
.05793 .31157 L
.05898 .31209 L
.06009 .31253 L
.06131 .31283 L
.06244 .31294 L
.06367 .31286 L
.06483 .31261 L
.06609 .31217 L
.06746 .31152 L
.07008 .30999 L
.0715 .30915 L
.07283 .30845 L
.074 .30795 L
.07525 .30758 L
.07596 .30745 L
.07663 .3074 L
.07789 .30746 L
.07905 .30773 L
.08012 .30814 L
.08129 .30876 L
.08253 .30957 L
.08759 .31363 L
.08905 .31467 L
.09043 .31547 L
.09168 .316 L
.09238 .3162 L
Mistroke
.09303 .31633 L
.09381 .31641 L
.09455 .3164 L
.09521 .31633 L
.09592 .31619 L
.0967 .31597 L
.09752 .31567 L
.099 .31499 L
.10187 .31348 L
.10328 .31281 L
.10458 .31234 L
.10574 .31208 L
.10696 .31201 L
.1082 .31217 L
.1089 .31237 L
.10955 .31263 L
.11069 .31324 L
.11173 .31397 L
.11408 .31607 L
.11895 .32118 L
.12028 .32238 L
.1217 .32343 L
.12239 .32384 L
.12304 .32416 L
.12426 .32458 L
.12534 .32476 L
.12649 .32474 L
.12747 .32459 L
.12855 .32429 L
.12971 .32385 L
.13095 .32331 L
.1332 .32233 L
.13441 .32192 L
.13572 .32165 L
.13697 .32162 L
.13812 .32183 L
.13915 .32223 L
.14029 .3229 L
.14148 .32386 L
.1426 .32499 L
.18126 .35831 L
.1836 .36189 L
.18492 .36335 L
.18614 .36431 L
.1872 .36482 L
.18837 .36506 L
.1896 .36499 L
.19074 .36468 L
.19143 .36441 L
.19208 .36412 L
Mistroke
.1933 .36353 L
.19399 .3632 L
.19473 .36289 L
.19542 .36265 L
.19605 .3625 L
.19724 .36243 L
.19836 .36268 L
.19957 .36337 L
.20088 .36467 L
.20158 .3656 L
.20223 .36662 L
.2037 .36948 L
.20668 .37712 L
.20947 .3855 L
.21201 .39278 L
.21324 .3958 L
.21458 .39852 L
.21584 .40044 L
.21701 .40162 L
.21824 .40221 L
.21895 .40226 L
.21961 .40213 L
.2203 .40182 L
.22094 .40139 L
.22237 .40005 L
.22468 .3973 L
.22594 .39587 L
.22714 .39484 L
.22826 .39433 L
.22947 .39443 L
.23057 .39523 L
.23158 .39665 L
.23279 .39926 L
.23391 .40263 L
.23648 .41344 L
.23914 .42813 L
.24166 .44306 L
.24411 .4556 L
.24478 .4583 L
.24549 .46069 L
.24677 .46353 L
.24804 .46419 L
.24923 .4626 L
.25029 .45919 L
.25145 .45329 L
.25272 .44404 L
.25411 .43065 L
.25693 .39418 L
.26196 .30804 L
.26448 .26284 L
Mistroke
.26722 .21885 L
.26848 .20171 L
.26981 .18615 L
.27096 .17508 L
.2722 .16576 L
.2734 .15934 L
.27449 .15565 L
.27559 .15394 L
.27664 .15405 L
.27785 .15607 L
.27897 .15951 L
.28021 .1647 L
.28152 .17144 L
.28424 .1873 L
.28717 .20379 L
.28852 .21012 L
.28995 .21557 L
.29116 .21913 L
.29185 .22068 L
.2925 .22183 L
.29379 .2233 L
.29501 .22375 L
.29611 .22351 L
.2973 .2227 L
.2986 .22136 L
.29998 .21971 L
.30116 .2183 L
.30245 .21698 L
.30369 .21612 L
.30483 .21578 L
.30604 .21597 L
.30734 .21688 L
.30855 .21839 L
.30969 .22036 L
.31182 .2253 L
.31707 .24074 L
.31938 .24689 L
.3206 .24959 L
.32192 .25195 L
.32307 .25353 L
.32412 .25457 L
.32517 .25524 L
.32618 .25556 L
.32729 .2556 L
.32833 .2554 L
.32947 .25498 L
.33068 .25442 L
.33192 .25382 L
.33257 .25354 L
.33326 .25329 L
Mistroke
.33452 .253 L
.33567 .25299 L
.33679 .25328 L
.33783 .25383 L
.33897 .25475 L
.34019 .25612 L
.34516 .26472 L
.34982 .27373 L
.35216 .27711 L
.35347 .27847 L
.35468 .27935 L
.35592 .2799 L
.35663 .28006 L
.35729 .28012 L
.35798 .2801 L
.35862 .28001 L
.35935 .27984 L
.36003 .27963 L
.36265 .27863 L
.36334 .27837 L
.36408 .27814 L
.36478 .27796 L
.36541 .27785 L
.36615 .2778 L
.36686 .27782 L
.36762 .27795 L
.36845 .27821 L
.36915 .27854 L
.3699 .27899 L
.37124 .28006 L
.37377 .28291 L
.37616 .28623 L
.37875 .28996 L
.38013 .29177 L
.38159 .29346 L
.38291 .29468 L
.38412 .29551 L
.38532 .29608 L
.38646 .29637 L
.38774 .29642 L
.38892 .29624 L
.39022 .29585 L
.3916 .29529 L
.3937 .29435 L
.39486 .29388 L
.39597 .29353 L
.39726 .2933 L
.39845 .29328 L
.39956 .29345 L
.40078 .29387 L
Mistroke
.40145 .29421 L
.40218 .29465 L
.4035 .29563 L
.40597 .29798 L
.40867 .30086 L
.41014 .30237 L
.41151 .30362 L
.41281 .30459 L
.41399 .30527 L
.4153 .30578 L
.41602 .30594 L
.4167 .30601 L
.41789 .30597 L
.41899 .30576 L
.4202 .30536 L
.42148 .30479 L
.42385 .30355 L
.42605 .30247 L
.42716 .30205 L
.42834 .30175 L
.42966 .30162 L
.43085 .30171 L
.43215 .30204 L
.43289 .30233 L
.43356 .30266 L
.43612 .30434 L
.43862 .30637 L
.44096 .30823 L
.443 .30955 L
.44414 .31009 L
.44519 .31042 L
.44633 .31062 L
.44757 .31061 L
.44875 .31041 L
.44984 .31007 L
.45107 .30954 L
.45223 .30893 L
.45439 .30764 L
.4556 .30693 L
.4569 .30624 L
.45802 .30574 L
.45924 .30535 L
.46049 .30513 L
.46168 .30511 L
.46284 .30527 L
.46391 .30557 L
.46509 .30606 L
.46639 .30676 L
.46903 .30849 L
.4716 .31021 L
Mistroke
.47302 .311 L
.47371 .31133 L
.47436 .31158 L
.47561 .31193 L
.47627 .31203 L
.47697 .31208 L
.47822 .31199 L
.47936 .31174 L
.48401 .30939 L
.48628 .30795 L
.48835 .30682 L
.48947 .30636 L
.49053 .30605 L
.49165 .30587 L
.49288 .30587 L
.49413 .30606 L
.49476 .30624 L
.49546 .30648 L
.49785 .30767 L
.50033 .30923 L
.50164 .31006 L
.50301 .31085 L
.50422 .31142 L
.50554 .31189 L
.50674 .31213 L
.50786 .31219 L
.50906 .31207 L
.51019 .31179 L
.51121 .31141 L
.51231 .31088 L
.51708 .30797 L
.51828 .30728 L
.51958 .30667 L
.52032 .3064 L
.521 .3062 L
.52168 .30606 L
.52233 .30598 L
.523 .30596 L
.52372 .306 L
.525 .30625 L
.52578 .30651 L
.52652 .30681 L
.5279 .30753 L
.53267 .31069 L
.53397 .31148 L
.53537 .31218 L
.53669 .31265 L
.53789 .31289 L
.53914 .31293 L
.5403 .31279 L
Mistroke
.54157 .31244 L
.54221 .3122 L
.54291 .31189 L
.54767 .30917 L
.54892 .3085 L
.55023 .30794 L
.55092 .30771 L
.55167 .30753 L
.55299 .30739 L
.55424 .30749 L
.55495 .30764 L
.55558 .30784 L
.55682 .30839 L
.55799 .30907 L
.5623 .31243 L
.56466 .31427 L
.56581 .31502 L
.56686 .31559 L
.56801 .31605 L
.56924 .31634 L
.56988 .3164 L
.57059 .31641 L
.57186 .31624 L
.57302 .31592 L
.57425 .31544 L
.57647 .31432 L
.57909 .31298 L
.58041 .31246 L
.58115 .31224 L
.58185 .3121 L
.5831 .31201 L
.58424 .31214 L
.58555 .31255 L
.58679 .31319 L
.58814 .31414 L
.58957 .31539 L
.59214 .31804 L
.59493 .32098 L
.59648 .32239 L
.59794 .32347 L
.59918 .32414 L
.59988 .32442 L
.60053 .3246 L
.60168 .32476 L
.6029 .32472 L
.60416 .32447 L
.60534 .32408 L
.60755 .32313 L
.60884 .32255 L
.60954 .32227 L
Mistroke
.6102 .32204 L
.61136 .32174 L
.61263 .3216 L
.61334 .32164 L
.61402 .32176 L
.61528 .3222 L
.61599 .32258 L
.61665 .32302 L
.61813 .3243 L
.65739 .35821 L
.69514 .40226 L
.70002 .39833 L
.70124 .39685 L
.7024 .39561 L
.70344 .39478 L
.70456 .39431 L
.70575 .39447 L
.70685 .39533 L
.70804 .39714 L
.7093 .40013 L
.71057 .40429 L
.71177 .40918 L
.71448 .42321 L
.71717 .43912 L
.71973 .45301 L
.72113 .4589 L
.72193 .46139 L
.72267 .46306 L
.72397 .46424 L
.7247 .46383 L
.72536 .46273 L
.72665 .4585 L
.72783 .45208 L
.72913 .44216 L
.7305 .42851 L
.73281 .39876 L
.73534 .35833 L
.74059 .26424 L
.74318 .22231 L
.74557 .19092 L
.74668 .17931 L
.74773 .17038 L
.74882 .16314 L
.75003 .1576 L
.75125 .15452 L
.75237 .1538 L
.75359 .15511 L
.75488 .15853 L
.76009 .1853 L
.76265 .20006 L
Mistroke
.76501 .21135 L
.76633 .2162 L
.76772 .22 L
.76845 .22143 L
.76913 .22245 L
.76987 .22321 L
.77067 .22366 L
.77133 .22376 L
.77205 .22362 L
.77336 .22281 L
.77463 .22155 L
.77581 .22015 L
.778 .2176 L
.77923 .21652 L
.78036 .21592 L
.78162 .2158 L
.78226 .21599 L
.78296 .21639 L
.78422 .21766 L
.78539 .21946 L
.78672 .22214 L
.78797 .2252 L
.79032 .23189 L
.79288 .23961 L
.79559 .24693 L
.79777 .2514 L
.79901 .25323 L
.80017 .25445 L
.80123 .25518 L
.80221 .25553 L
.80333 .25561 L
.8044 .25543 L
.80677 .25447 L
.80801 .25387 L
.80933 .25333 L
.81048 .25303 L
.81174 .25298 L
.81289 .25325 L
.81396 .25379 L
.81523 .25483 L
.81639 .25613 L
.819 .26017 L
.82356 .26919 L
.82607 .27384 L
.8274 .27588 L
.82881 .27764 L
.83004 .27879 L
.83074 .27928 L
.83139 .27963 L
.83254 .28001 L
Mistroke
.83378 .28012 L
.83494 .27998 L
.83601 .2797 L
.8372 .27928 L
.83846 .27878 L
.83978 .27829 L
.84103 .27795 L
.84216 .2778 L
.84338 .27787 L
.84444 .27814 L
.8456 .27868 L
.84682 .27953 L
.84795 .28057 L
.85217 .28597 L
.85459 .28947 L
.85716 .29277 L
.85864 .29428 L
.85997 .29531 L
.86062 .29569 L
.86132 .29601 L
.86259 .29636 L
.86378 .29642 L
.86509 .29624 L
.86576 .29607 L
.86646 .29583 L
.86774 .29532 L
.8702 .29422 L
.87128 .2938 L
.87247 .29346 L
.87363 .29328 L
.87486 .2933 L
.87551 .2934 L
.8762 .29358 L
.87746 .29411 L
.87872 .29488 L
.87992 .29582 L
.88218 .29799 L
.88436 .30033 L
.88672 .30275 L
.88781 .3037 L
.88896 .30456 L
.88994 .30515 L
.89101 .30563 L
.89226 .30595 L
.89297 .30602 L
.89361 .30602 L
.89485 .30584 L
.89603 .30549 L
.89717 .30503 L
.89822 .30451 L
Mistroke
.90059 .30325 L
.90172 .3027 L
.90294 .30219 L
.90364 .30196 L
.90428 .3018 L
.90554 .30163 L
.90676 .30167 L
.90746 .30179 L
.9081 .30196 L
.90941 .30248 L
.9108 .30327 L
.91576 .30715 L
.91694 .30808 L
.91819 .30896 L
.91935 .30963 L
.92043 .31013 L
.9214 .31043 L
.92243 .31061 L
.92358 .31063 L
.92463 .31048 L
.92575 .31017 L
.92697 .30968 L
.92919 .30848 L
.93175 .30696 L
.93309 .30624 L
.93383 .3059 L
.93451 .30563 L
.93576 .30527 L
.93642 .30516 L
.93712 .3051 L
.93838 .30516 L
.93952 .30539 L
.94072 .30581 L
.94183 .30634 L
.94433 .30788 L
.94653 .30939 L
.94889 .31084 L
.95019 .31144 L
.95138 .31183 L
.95253 .31204 L
.95373 .31206 L
.95505 .31187 L
.95628 .31149 L
.95698 .3112 L
.95763 .31089 L
.95906 .31009 L
.96173 .30841 L
.96314 .30756 L
.96462 .30678 L
.96592 .30627 L
Mistroke
.96666 .30606 L
.96735 .30593 L
.96857 .30585 L
.96987 .30597 L
.97067 .30615 L
.97142 .30639 L
.97311 .30715 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXO
oookJP00XooonfX5o`0005Sooo]Z2_l007l6oookJP?o001o2_oonfX5o`0008?ooo]Z1Ol0002Foook
JP00XooonfX6o`0005Oooo]Z2_l007l6oookJP?o001o2_oonfX6o`0008;ooo]Z1Ol0002FoookJP00
XooonfX6o`0006Oooo]Z0ol007l:oookJPGo0000PooonfX6o`0009Gooo]Z002RoookJPOo0000Iooo
nfX3o`00O`[ooo]Z1Ol00023oookJPKo0000UOoonfX00:;ooo]Z1ol0001WoookJP?o001o2_oonfX5
o`0008;ooo]Z1ol0002EoookJP00X_oonfX8o`0006Kooo]Z0ol007l:oookJPGo0000P_oonfX8o`00
09Cooo]Z002RoookJPSo0000HooonfX6o`00O`[ooo]Z1Ol00022oookJPSo0000U?oonfX00:;ooo]Z
2?l0001SoookJPKo001o2_oonfX5o`0008;ooo]Z2?l0002DoookJP00X_oonfX9o`0006Cooo]Z1?l0
07l:oookJPGo0000POoonfX9o`0009Cooo]Z002QoookJP[o0000IOoonfX3o`00O`[ooo]Z1Ol00021
oookJPWo0000U?oonfX00:7ooo]Z2_l0001boookJPGo0000POoonfX:o`0009?ooo]Z002QoookJPGo
000000?ooo]Zo`000?l000000_l0001boookJPGo0000POoonfX4o`000003oookJ_l0003o000000?o
0000TooonfX00:7ooo]Z1?l00002oookJPCo0000L_oonfX5o`00087ooo]Z1?l000000ooonf[o0000
o`000003o`0009?ooo]Z002QoookJPCo00000_oonfX4o`0007;ooo]Z1Ol00021oookJPCo00000_oo
nfX4o`0009?ooo]Z002QoookJPCo00000_oonfX5o`00077ooo]Z1Ol00021oookJPCo00000_oonfX4
o`0009?ooo]Z002PoookJPGo00000_oonfX5o`00077ooo]Z1Ol00021oookJPCo00000_oonfX5o`00
09;ooo]Z002PoookJPGo00000_oonfX5o`00077ooo]Z1Ol00021oookJPCo00000_oonfX5o`0009;o
oo]Z002PoookJPGo00000ooonfX4o`00077ooo]Z1Ol00021oookJPCo00000_oonfX5o`0009;ooo]Z
002PoookJPCo00001?oonfX4o`00077ooo]Z1Ol00020oookJPGo00000ooonfX4o`0009;ooo]Z002P
oookJPCo00001?oonfX4o`00077ooo]Z1Ol00020oookJPGo00000ooonfX4o`0009;ooo]Z002Poook
JPCo00001?oonfX4o`00077ooo]Z1Ol00020oookJPGo00000ooonfX4o`0009;ooo]Z002PoookJPCo
00001?oonfX5o`00073ooo]Z1Ol00020oookJPCo00001?oonfX4o`0009;ooo]Z002PoookJPCo0000
1?oonfX5o`00073ooo]Z1Ol00020oookJPCo00001?oonfX5o`00097ooo]Z002PoookJPCo00001?oo
nfX5o`00073ooo]Z1Ol00020oookJPCo00001?oonfX5o`00097ooo]Z002PoookJPCo00001OoonfX4
o`00073ooo]Z1Ol00020oookJPCo00001?oonfX5o`00097ooo]Z002PoookJPCo00001OoonfX4o`00
073ooo]Z1Ol00020oookJPCo00001OoonfX4o`00097ooo]Z002PoookJPCo00001OoonfX5o`0006oo
oo]Z1Ol00020oookJPCo00001OoonfX4o`00097ooo]Z002PoookJPCo00001OoonfX5o`0006oooo]Z
1Ol00020oookJPCo00001OoonfX5o`00093ooo]Z002PoookJPCo00001OoonfX5o`0006oooo]Z1Ol0
0020oookJPCo00001OoonfX5o`00093ooo]Z002PoookJPCo00001_oonfX4o`0006oooo]Z1Ol0001o
oookJPGo00001OoonfX5o`00093ooo]Z002PoookJPCo00001_oonfX4o`0006oooo]Z1Ol0001ooook
JPGo00001_oonfX5o`0008oooo]Z002OoookJPGo00001_oonfX4o`0006oooo]Z1Ol0001ooookJPGo
00001_oonfX5o`0008oooo]Z002OoookJPGo00001_oonfX5o`0006kooo]Z1Ol0001ooookJPCo0000
1ooonfX5o`0008oooo]Z002OoookJPGo00001_oonfX5o`0006kooo]Z1Ol0001ooookJPCo00002?oo
nfX4o`0008oooo]Z002OoookJPCo00001ooonfX5o`0000?ooo]Z1ol0001ToookJPGo0000OooonfX4
o`0000Sooo]Z1?l00003oookJPKo0000Q_oonfX009oooo]Z1?l00008oookJPGo000000?ooo]Zo`00
0?l000001_l0001ToookJPGo0000OooonfX4o`0000Sooo]Z1?l00002oookJPWo0000Q?oonfX009oo
oo]Z1?l00008oookJPGo000000?ooo]Zo`000?l000001ol0001SoookJPGo0000OooonfX4o`0000So
oo]Z3ol00024oookJP00WooonfX4o`0000Sooo]Z3ol0001SoookJPGo0000OooonfX4o`0000Sooo]Z
3ol00024oookJP00WooonfX4o`0000Wooo]Z3ol0001RoookJPGo0000OooonfX4o`0000Sooo]Z3ol0
0024oookJP00WooonfX4o`0000Wooo]Z2Ol000000ooonf[o0000o`000003o`0004Cooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001ooookJPCo00002OoonfX8o`0000;ooo]Z1Ol00023
oookJP00WooonfX4o`0000[ooo]Z1ol00002oookJPGo0000@ooonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o2OoonfX5o`0007oooo]Z1?l00009oookJPSo00000_oonfX5o`0008?ooo]Z002OoookJPCo
00002_oonfX6o`0000Cooo]Z1Ol00012oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0007oooo]Z1?l0000:
oookJPGo00001?oonfX6o`0008;ooo]Z002NoookJPGo00005?oonfX5o`0003Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0007oooo]Z1?l0000Doook
JPGo0000P_oonfX009kooo]Z1Ol0000DoookJPGo0000=OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Sooo]Z1_l0001noookJPCo00005?oonfX5o`0008;ooo]Z002NoookJPGo0000
5OoonfX5o`00043ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001noookJPGo0000
5OoonfX5o`00087ooo]Z002NoookJPCo00005_oonfX5o`00043ooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l8oookJPGo0000O_oonfX5o`0001Gooo]Z1Ol00021oookJP00W_oonfX4
o`0001Kooo]Z1Ol00010oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000O_oonfX5
o`0001Gooo]Z1_l00020oookJP00W_oonfX4o`0001Oooo]Z1Ol0000ooookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007l:oookJPGo0000O_oonfX4o`0001Oooo]Z1Ol00020oookJP00W_oonfX4o`0001Oo
oo]Z1Ol0000ooookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000O_oonfX4o`0001Oo
oo]Z1Ol00020oookJP00W_oonfX4o`0001Oooo]Z1_l0000ooookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00O`kooo]Z1Ol0001noookJPCo00006?oonfX5o`0007oooo]Z002NoookJPCo0000
6?oonfX5o`0003oooo]Z1ol007l9oookJPOo001o2?oonfX5o`0007kooo]Z1?l0000HoookJPGo0000
OooonfX009kooo]Z1?l0000HoookJPGo0000@?oonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000O_oo
nfX4o`0001Sooo]Z1Ol0001ooookJP00W_oonfX4o`0001Wooo]Z1Ol0001MoookJPGo0000O_oonfX4
o`0001Wooo]Z1Ol0001noookJP00W_oonfX4o`0001Wooo]Z1Ol0001MoookJPGo0000O_oonfX4o`00
01Wooo]Z1Ol0001noookJP00WOoonfX5o`0001Wooo]Z3_l0001DoookJPGo0000O_oonfX4o`0001Wo
oo]Z3_l0001eoookJP00WOoonfX5o`0001[ooo]Z3_l0001CoookJPGo0000OOoonfX5o`0001[ooo]Z
3_l0001doookJP00WOoonfX5o`0001[ooo]Z3_l0001CoookJPGo0000OOoonfX5o`0001[ooo]Z3_l0
001doookJP00WOoonfX4o`0001cooo]Z3_l0001BoookJPGo0000OOoonfX5o`0001_ooo]Z3_l0001c
oookJP00WOoonfX4o`0001gooo]Z1ol000000ooonf[o0000o`000004o`00057ooo]Z1Ol0001moook
JPCo00007OoonfX6o`0000;ooo]Z1_l0001boookJP00WOoonfX4o`0002Gooo]Z1_l0001AoookJPGo
0000OOoonfX4o`0002Gooo]Z1_l0001boookJP00WOoonfX4o`0002Kooo]Z1_l0001@oookJPGo0000
OOoonfX4o`0002Kooo]Z1_l0001aoookJP00WOoonfX4o`0002Oooo]Z1Ol0001@oookJPGo0000OOoo
nfX4o`0002Oooo]Z1Ol0001aoookJP00WOoonfX4o`0002Oooo]Z1_l0001?oookJPGo0000OOoonfX4
o`0002Oooo]Z1_l0001`oookJP00WOoonfX4o`0002Sooo]Z1_l0001>oookJPGo0000OOoonfX4o`00
02Sooo]Z1Ol0001`oookJP008_oonfX3o`00OgGooo]Z0ol007l4o`0000;ooo]Z0ol007l3oookJPGo
001o6ooonfX6o`0004kooo]Z1Ol0001doookJPGo001o1?oonfX4o`0000;ooo]Z1Ol007lQoookJPKo
0000CooonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX4o`00O`Co00000_oonfX3o`00O`;ooo]Z
1ol007lKoookJPKo0000COoonfX5o`0007?ooo]Z1ol007l3oookJPCo000000?ooo]Zo`00Ool007l0
1Ol007lQoookJPKo0000C_oonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`03oookJ_l0
003o000000;o00000_oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
7?oonfX5o`0004gooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`0000Co
001o00Cooo]Zo`00Ool007oo001o8OoonfX6o`0004kooo]Z0ol007lMoookJP004ooonfX:o`00O`Go
oo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1?l00006oookJP?o001o0ooonfX3o`00Oa_o
oo]Z1ol000000ooonf[o0000o`000005o`0004?ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;o
oo]Z1?l00003o`00O`?ooo]Z0ol007lQoookJPKo00000_oonfX7o`0004Cooo]Z0ol007lMoookJP00
4ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1?l0000<oookJP?o001o
7?oonfX?o`0004;ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o
8_oonfX?o`0004?ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo00003?oo
nfX3o`00Oacooo]Z4?l00011oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00001_oo
nfX3o`00Ob;ooo]Z4?l00012oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4
o`0000Oooo]Z0_l007l2oookJPCo001o7OoonfX@o`00043ooo]Z1Ol0001boookJP?o001o0ooonfX3
o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02oookJPCo001o8ooonfX?o`0004;ooo]Z0ol007lM
oookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo00001ooonfX7o`00Oaoooo]Z3ol00010oook
JPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Zo`00Ool007l01Ol007lUoook
JPoo0000@OoonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000?o
00001ooonfX6o`00Ob[ooo]Z1_l0000ooookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo
000000?ooo]Zo`00Ool007l01?l007l`oookJPKo0000@?oonfX3o`00Oagooo]Z000OoookJPKo001o
LooonfX3o`00O`03oookJ_l0003o000000?o00001ooonfX2o`00Oboooo]Z1Ol0000ooookJPGo0000
L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Zo`00Ool007l0=?oonfX7o`0003cooo]Z
1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l5o`0000Oooo]Z0_l007l_oookJPKo0000?_oo
nfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPGo000000?ooo]Zo`00Ool007l0
=OoonfX7o`0003_ooo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol0
07lZoookJPKo0000?OoonfX5o`0007?ooo]Z1ol007l2oookJPGo00000_oonfX7o`00Oc3ooo]Z1ol0
000loookJPCo001o7OoonfX002;ooo]Z0ol007meoookJP;o001o1?l00009oookJPOo001o:_oonfX8
o`000003oookJ_l0003o000000Oo0000<OoonfX5o`0007Cooo]Z1Ol007l3oookJPGo00000_oonfX7
o`00Oc7ooo]Z1_l00002oookJPWo0000<_oonfX3o`00Oagooo]Z002LoookJPCo0000>ooonfXBo`00
033ooo]Z1Ol0001loookJPCo0000??oonfXAo`00057ooo]Z002LoookJPCo0000??oonfXBo`0002oo
oo]Z1Ol0001loookJPCo0000?OoonfXAo`00053ooo]Z002LoookJPCo0000?OoonfXBo`0002kooo]Z
1Ol0001loookJPCo0000?OoonfXBo`0004oooo]Z002LoookJPCo0000?_oonfX8o`0000?ooo]Z1ol0
0005oookJPSo00008?oonfX5o`0007cooo]Z1?l0000noookJPSo00000ooonfX7o`0000Gooo]Z2?l0
0011oookJP00W?oonfX4o`0004[ooo]Z1ol00002oookJP_o00007ooonfX5o`0007cooo]Z1?l0001:
oookJPOo00000ooonfX:o`00043ooo]Z000WoookJPGo0000L?oonfX4o`0004_ooo]Z5?l00007oook
JPSo00002_oonfX:o`0000Oooo]Z1Ol0001`oookJPCo0000BooonfXDo`0000Oooo]Z2?l0000:oook
JPKo00008?oonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go0000
3ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX0
00kooo]Zool0003oo`0002Go00003ooonfX001cooo]Z2_l00006oookJPco00001?oonfXDo`0004co
oo]Z1?l0001OoookJPOo00002?oonfX9o`0000Kooo]Z2ol00007oookJP[o00001OoonfXDo`0004co
oo]Z1?l0001OoookJPOo00002?oonfX:o`0000Oooo]Z00?o0000oookJ_oonfX07?oonfX001kooo]Z
1_l0000:oookJPSo00001ooonfXCo`0004cooo]Z1?l0001`oookJPKo00001ooonfX:o`0000Wooo]Z
2?l00007oookJQCo0000BooonfX4o`00073ooo]Z1_l0000XoookJP00?_oonfX:o`0000?ooo]Z1_l0
001;oookJPCo0000OOoonfX5o`0001kooo]Z2_l00003oookJPKo0000BooonfX4o`0009kooo]Z000o
oookJPSo00001OoonfX7o`0000?ooo]Z1ol0000ooookJPCo0000OOoonfX5o`0001oooo]Z2?l00005
oookJPOo00000ooonfX8o`0003kooo]Z1?l0002NoookJP00C?oonfXCo`0003gooo]Z1?l0001moook
JPGo0000;OoonfXCo`0003cooo]Z1?l0002NoookJP00COoonfXCo`0003_ooo]Z1Ol0001moookJPGo
0000;OoonfXDo`0003_ooo]Z1?l0002NoookJP00C_oonfXCo`0003[ooo]Z1Ol0001moookJPGo0000
;_oonfXDo`0003[ooo]Z1?l0002NoookJP00D?oonfX9o`000003oookJ_l0003o000000Ko0000>Ooo
nfX5o`0007gooo]Z1Ol0000`oookJPWo000000?ooo]Zo`000?l000001ol0000ioookJPCo0000W_oo
nfX005;ooo]Z1Ol00004oookJPSo0000>?oonfX4o`0007kooo]Z1Ol0000boookJPGo00001_oonfX7
o`0003Sooo]Z1?l0002NoookJP00GOoonfX7o`0003Oooo]Z1?l0001noookJPGo0000?_oonfX7o`00
03Oooo]Z1?l0002NoookJP00G_oonfX7o`0003Kooo]Z1?l0001noookJPGo0000?ooonfX7o`0003Ko
oo]Z1?l0002NoookJP00GooonfX8o`0003Cooo]Z1?l0001noookJPGo0000@?oonfX7o`0003Cooo]Z
1Ol0002NoookJP00H?oonfX8o`0003?ooo]Z1?l0001noookJPGo0000@OoonfX7o`0003?ooo]Z1Ol0
002NoookJP00HOoonfX8o`0003;ooo]Z1?l0001noookJPGo0000@_oonfX8o`00037ooo]Z1Ol0002N
oookJP00H_oonfX8o`00037ooo]Z1?l0001noookJPGo0000@ooonfX8o`00033ooo]Z1?l0002Ooook
JP00I?oonfX7o`00033ooo]Z1?l0001noookJPGo0000A?oonfX8o`0002oooo]Z1?l0002OoookJP00
IOoonfX7o`0002oooo]Z1?l0001noookJPGo0000AOoonfX8o`0002kooo]Z1?l0002OoookJP00I_oo
nfX8o`0002gooo]Z1?l0001noookJPGo0000AooonfX7o`0002gooo]Z1?l0002OoookJP00IooonfX8
o`0002cooo]Z1?l0001noookJPGo0000B?oonfX7o`0002cooo]Z1?l0002OoookJP00J?oonfX8o`00
02_ooo]Z1?l0001noookJPGo0000BOoonfX7o`0002_ooo]Z1?l0002OoookJP00JOoonfX8o`0002Wo
oo]Z1Ol0001noookJPGo0000B_oonfX7o`0002[ooo]Z1?l0002OoookJP00JooonfX7o`0002Sooo]Z
1Ol0001noookJPGo0000BooonfX7o`0002Wooo]Z1?l0002OoookJP00K?oonfX7o`0002Oooo]Z1Ol0
001noookJPGo0000C?oonfX7o`0002Sooo]Z1?l0002OoookJP00KOoonfX7o`0002Kooo]Z1?l0001o
oookJPGo0000COoonfX7o`0002Oooo]Z1?l0002OoookJP00K_oonfX7o`0002Gooo]Z1?l0001ooook
JPGo0000C_oonfX6o`0002Oooo]Z1?l0002OoookJP00KooonfX7o`000003oookJ_l0003o000000Go
00007?oonfX4o`0007oooo]Z1Ol0001?oookJPKo00009_oonfX4o`0009oooo]Z001`oookJPoo0000
6ooonfX4o`0007oooo]Z1Ol0001@oookJPKo00009OoonfX4o`0009oooo]Z001aoookJPoo00006_oo
nfX4o`0007oooo]Z1Ol0001@oookJPOo00009?oonfX4o`0009oooo]Z001boookJPko00006_oonfX4
o`0007oooo]Z1Ol0001AoookJPOo00008ooonfX4o`0009oooo]Z001coookJPgo00006_oonfX4o`00
07oooo]Z1Ol0001BoookJPOo00008OoonfX5o`0009oooo]Z001koookJPGo00006_oonfX4o`0007oo
oo]Z1Ol0001CoookJPOo00008?oonfX5o`0009oooo]Z001loookJPGo00006OoonfX4o`0007oooo]Z
1Ol0001DoookJPOo00007ooonfX5o`0009oooo]Z001loookJPGo00006OoonfX4o`0007oooo]Z1Ol0
001EoookJPKo00007ooonfX4o`000:3ooo]Z001loookJPKo00006?oonfX4o`0007oooo]Z1Ol0001F
oookJPKo00007_oonfX4o`000:3ooo]Z001moookJPGo00006?oonfX4o`0007oooo]Z1Ol0001Goook
JPKo00007OoonfX4o`000:3ooo]Z001moookJPKo00005_oonfX5o`00067ooo]Z1Ol007l4oookJP?o
001o0ooonfX5o`00O`[ooo]Z1Ol0001GoookJPOo00007?oonfX4o`000:3ooo]Z001noookJPGo0000
5_oonfX5o`00063ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001HoookJPOo0000
6ooonfX4o`000:3ooo]Z001noookJPKo00005OoonfX5o`00063ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo
0000FOoonfX7o`0001[ooo]Z1?l0002PoookJP00OooonfX5o`0001Gooo]Z1?l0001PoookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0005[ooo]Z1ol0000IoookJPCo0000
X?oonfX007oooo]Z1Ol0000EoookJPCo0000H?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oo
nfX6o`0005[ooo]Z1ol0000HoookJPCo0000X?oonfX0083ooo]Z1Ol0000DoookJPCo0000H?oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0005cooo]Z1_l0000GoookJPGo0000X?oonfX0
083ooo]Z1Ol0000DoookJPCo0000H?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00
O`Sooo]Z1Ol0001MoookJPKo00005_oonfX5o`000:3ooo]Z0020oookJPGo00001OoonfX4o`0000_o
oo]Z1?l0001PoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000G_oonfX6o`0000Ko
oo]Z1Ol0000:oookJPGo0000X?oonfX0087ooo]Z1Ol00002oookJPOo00002_oonfX4o`00063ooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001NoookJPOo00001?oonfX6o`0000[ooo]Z
1?l0002QoookJP00POoonfX5o`0000;ooo]Z2?l00009oookJPCo0000H?oonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o3_oonfX5o`0005oooo]Z1ol000000ooonf[o0000o`000007o`0000Wooo]Z1?l0
002QoookJP00POoonfX5o`000003oookJ_l0003o000000Oo00002OoonfX4o`00067ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`00063ooo]Z4?l00009oookJPCo0000XOoo
nfX008;ooo]Z3_l00009oookJPCo0000HOoonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000HOoonfX?
o`0000Wooo]Z1?l0002QoookJP00P_oonfX?o`0000Sooo]Z1?l0001RoookJPGo001o2_oonfX7o`00
O`Sooo]Z1Ol0001RoookJPoo00002?oonfX4o`000:7ooo]Z0022oookJPWo000000?ooo]Zo`000?l0
00000ol00008oookJPCo0000P?oonfX5o`0006?ooo]Z2?l000000ooonf[o0000o`000003o`0000So
oo]Z1?l0002QoookJP00PooonfX7o`0000;ooo]Z1Ol00008oookJPCo0000P?oonfX5o`0006Cooo]Z
1_l00002oookJPGo00002?oonfX4o`000:7ooo]Z0024oookJPGo00001?oonfX4o`0000Sooo]Z1?l0
0020oookJPGo0000IOoonfX4o`0000Cooo]Z1Ol00007oookJPCo0000XOoonfX008gooo]Z1Ol00007
oookJPCo0000P?oonfX5o`0006gooo]Z1Ol00007oookJPCo0000XOoonfX008gooo]Z1Ol00007oook
JPCo0000P?oonfX5o`0006gooo]Z1Ol00007oookJPCo0000XOoonfX008gooo]Z1Ol00006oookJPGo
0000P?oonfX5o`0006kooo]Z1?l00007oookJPCo0000XOoonfX008kooo]Z1?l00006oookJPGo0000
P?oonfX5o`0006kooo]Z1?l00006oookJPGo0000XOoonfX008kooo]Z1?l00006oookJPGo0000P?oo
nfX5o`0006kooo]Z1Ol00005oookJPGo0000XOoonfX008kooo]Z1Ol00005oookJPCo0000POoonfX5
o`0006kooo]Z1Ol00005oookJPGo0000XOoonfX008kooo]Z1Ol00005oookJPCo0000POoonfX5o`00
06kooo]Z1Ol00005oookJPCo0000X_oonfX008kooo]Z1Ol00005oookJPCo0000POoonfX5o`0006oo
oo]Z1?l00005oookJPCo0000X_oonfX008oooo]Z1?l00005oookJPCo0000POoonfX5o`0006oooo]Z
1?l00005oookJPCo0000X_oonfX008oooo]Z1Ol00004oookJPCo0000POoonfX5o`0006oooo]Z1?l0
0005oookJPCo0000X_oonfX008oooo]Z1Ol00004oookJPCo0000POoonfX5o`0006oooo]Z1Ol00004
oookJPCo0000X_oonfX008oooo]Z1Ol00004oookJPCo0000POoonfX5o`0006oooo]Z1Ol00004oook
JPCo0000X_oonfX0093ooo]Z1?l00004oookJPCo0000POoonfX5o`0006oooo]Z1Ol00004oookJPCo
0000X_oonfX0093ooo]Z1?l00004oookJPCo0000POoonfX5o`00073ooo]Z1?l00004oookJPCo0000
X_oonfX0093ooo]Z1?l00004oookJPCo0000POoonfX5o`00073ooo]Z1?l00003oookJPGo0000X_oo
nfX0093ooo]Z1Ol00002oookJPGo0000POoonfX5o`00073ooo]Z1Ol00002oookJPGo0000X_oonfX0
093ooo]Z1Ol00002oookJPGo0000POoonfX5o`00073ooo]Z1Ol00002oookJPGo0000X_oonfX0093o
oo]Z1Ol00002oookJPGo0000POoonfX5o`00073ooo]Z1Ol00002oookJPCo0000XooonfX0097ooo]Z
1?l00002oookJPCo0000P_oonfX5o`00077ooo]Z1?l00002oookJPCo0000XooonfX0097ooo]Z1?l0
0002oookJPCo0000P_oonfX5o`00077ooo]Z1?l00002oookJPCo0000XooonfX0097ooo]Z1?l00002
oookJPCo0000P_oonfX5o`00077ooo]Z1Ol000000ooonf[o0000o`000002o`000:?ooo]Z002Aoook
JPCo000000?ooo]Zo`000?l000000ol00022oookJPGo0000LOoonfX:o`000:?ooo]Z002AoookJP[o
0000P_oonfX5o`00077ooo]Z2_l0002SoookJP00TOoonfX:o`0008;ooo]Z1Ol0001boookJPWo0000
XooonfX0097ooo]Z2Ol00023oookJPGo0000L_oonfX8o`000:Cooo]Z002BoookJPSo0000PooonfX5
o`0007;ooo]Z2?l0002ToookJP00T_oonfX8o`0007Kooo]Z0ol007l:oookJPGo0000L_oonfX8o`00
0:Cooo]Z002BoookJPSo0000M_oonfX3o`00O`[ooo]Z1Ol0001boookJPSo0000Y?oonfX009;ooo]Z
2?l0001foookJP?o001o2_oonfX5o`0007?ooo]Z1ol0002ToookJP00TooonfX7o`0007Kooo]Z0ol0
07l:oookJPGo0000LooonfX7o`000:Cooo]Z002CoookJPOo0000M_oonfX3o`00O`[ooo]Z1_l0001b
oookJPOo0000Y?oonfX009?ooo]Z1_l0001goookJP?o001o2_oonfX5o`0007?ooo]Z1_l0002Uoook
JP00U?oonfX4o`0007Sooo]Z0ol007l:oookJPGo0000M?oonfX5o`000:Gooo]Z003ooookJQ7ooo]Z
0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1_l007l:oook
JPGo0000oooonfXOoookJP00oooonfX@oookJPCo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o
0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXOoookJP00oooonfX2
oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oook
JP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o
2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooo
nfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`ko
oo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=
oookJPGo0000oooonfXOoookJP00oooonfX>oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000
oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3
o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgo
oo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z
;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02605 .30762 L
.02729 .30697 L
.02846 .3065 L
.02954 .3062 L
.03072 .30605 L
.0318 .30609 L
.03279 .30627 L
.03396 .30664 L
.03506 .30714 L
.03756 .30861 L
.04015 .31028 L
.04143 .311 L
.04262 .31154 L
.04377 .31191 L
.045 .31211 L
.04571 .31213 L
.04637 .31209 L
.04761 .31185 L
.04875 .31146 L
.0498 .31097 L
.05217 .30959 L
.05475 .30801 L
.05602 .30736 L
.05717 .3069 L
.05838 .3066 L
.05968 .30649 L
.06036 .30654 L
.0611 .30666 L
.0618 .30685 L
.06244 .30708 L
.06714 .31 L
.0697 .31182 L
.07095 .31256 L
.07208 .31309 L
.07333 .31348 L
.07402 .3136 L
.07467 .31366 L
.07538 .31365 L
.07603 .31357 L
.07675 .31343 L
.0775 .3132 L
.07873 .3127 L
.07987 .31213 L
.08247 .31064 L
.08395 .30985 L
.08467 .30953 L
.08535 .30927 L
.0866 .30893 L
.08726 .30884 L
Mistroke
.08797 .30882 L
.08874 .30888 L
.08957 .30906 L
.09035 .30932 L
.09107 .30965 L
.09243 .31046 L
.09388 .31154 L
.09653 .31389 L
.09904 .31604 L
.10043 .31701 L
.10117 .31742 L
.10194 .31778 L
.10259 .31802 L
.10331 .3182 L
.10458 .31832 L
.10584 .3182 L
.10699 .31791 L
.10825 .31742 L
.10958 .31679 L
.11201 .31558 L
.1132 .31508 L
.11427 .31476 L
.11535 .31458 L
.11636 .31458 L
.11743 .31477 L
.11859 .3152 L
.11979 .3159 L
.12105 .31689 L
.12331 .31917 L
.12803 .32452 L
.12939 .32579 L
.13068 .32675 L
.13184 .32737 L
.1331 .32778 L
.13376 .32788 L
.1345 .32791 L
.13526 .32785 L
.13598 .32771 L
.13727 .32733 L
.13865 .32677 L
.13994 .32621 L
.14116 .32573 L
.14184 .32551 L
.14257 .32533 L
.14385 .32519 L
.1451 .32533 L
.14573 .32552 L
.14642 .32582 L
.14765 .3266 L
.14879 .32762 L
Mistroke
.15101 .33027 L
.1534 .33381 L
.1562 .33813 L
.15758 .34004 L
.15887 .34155 L
.16002 .34265 L
.16126 .34352 L
.16196 .34386 L
.16262 .34409 L
.16386 .34427 L
.16509 .34418 L
.16578 .34402 L
.16643 .34383 L
.16785 .3433 L
.16914 .34279 L
.17035 .3424 L
.17149 .34218 L
.17269 .34219 L
.174 .34255 L
.17531 .34335 L
.17606 .34401 L
.17676 .34477 L
.17969 .34927 L
.18495 .36025 L
.18723 .36448 L
.18848 .36632 L
.18966 .36767 L
.19033 .36826 L
.19105 .36875 L
.19232 .36923 L
.19361 .36927 L
.1948 .369 L
.19603 .36847 L
.19719 .36787 L
.19857 .36718 L
.19983 .36673 L
.20114 .36658 L
.20239 .36689 L
.20371 .3678 L
.20446 .36861 L
.20515 .36955 L
.22366 .40452 L
.22614 .40153 L
.2275 .39972 L
.22876 .3983 L
.22942 .39774 L
.23013 .39735 L
.23092 .39721 L
.23163 .3974 L
.23228 .39786 L
Mistroke
.23299 .39871 L
.23427 .40121 L
.23546 .40472 L
.23678 .40989 L
.23945 .42387 L
.24195 .43934 L
.24424 .45276 L
.24537 .45824 L
.24661 .46275 L
.24778 .46522 L
.24887 .46565 L
.25013 .46357 L
.25128 .45909 L
.25192 .45548 L
.25261 .45066 L
.25385 .43949 L
.25613 .41137 L
.25855 .3725 L
.26286 .29037 L
.26519 .24682 L
.26773 .20593 L
.26889 .19054 L
.27012 .1769 L
.27117 .16762 L
.27233 .15996 L
.27365 .15452 L
.27439 .15292 L
.27507 .15233 L
.27633 .15326 L
.27765 .15672 L
.27884 .16164 L
.27996 .16738 L
.28249 .18267 L
.28488 .19719 L
.28605 .20352 L
.28713 .20861 L
.2881 .21244 L
.28916 .21582 L
.29022 .21831 L
.29135 .21999 L
.29258 .22078 L
.29371 .22067 L
.29501 .21978 L
.29624 .2184 L
.29844 .21547 L
.2996 .21407 L
.30082 .21295 L
.30147 .21257 L
.30218 .21235 L
.30342 .21251 L
Mistroke
.30468 .21344 L
.30586 .21502 L
.30702 .21719 L
.30807 .21965 L
.31043 .2264 L
.31533 .24143 L
.31667 .24475 L
.3181 .24759 L
.31932 .24939 L
.32001 .25015 L
.32066 .2507 L
.32182 .25129 L
.32303 .25145 L
.32407 .25128 L
.32521 .25086 L
.32758 .24966 L
.32826 .24933 L
.32891 .24908 L
.33011 .24877 L
.33127 .24877 L
.33234 .24908 L
.33351 .24979 L
.33475 .25099 L
.33581 .25236 L
.3368 .25392 L
.33906 .2582 L
.34405 .26862 L
.34541 .27099 L
.34687 .27305 L
.34811 .27436 L
.34882 .27492 L
.34948 .27533 L
.35069 .27577 L
.35196 .27588 L
.35305 .27574 L
.35424 .27539 L
.35562 .27487 L
.35693 .27436 L
.3581 .27399 L
.35937 .27378 L
.36054 .27381 L
.36179 .27414 L
.36285 .27469 L
.36401 .27557 L
.36525 .27681 L
.36658 .27845 L
.36898 .28198 L
.3733 .28844 L
.37455 .28993 L
.37573 .29108 L
Mistroke
.37678 .29187 L
.37792 .29245 L
.37855 .29266 L
.37925 .2928 L
.37997 .29284 L
.38065 .2928 L
.38186 .29256 L
.38316 .29211 L
.38549 .29112 L
.38672 .29064 L
.38803 .29028 L
.38876 .29016 L
.38957 .29012 L
.3903 .29018 L
.39099 .29032 L
.3917 .29055 L
.39234 .29084 L
.3938 .29175 L
.39502 .29278 L
.39636 .29412 L
.39906 .29721 L
.40165 .30009 L
.40292 .30128 L
.40409 .30218 L
.40474 .30258 L
.40544 .30293 L
.40616 .3032 L
.40691 .30338 L
.40823 .30347 L
.40947 .30329 L
.41072 .30291 L
.41191 .30241 L
.41414 .30129 L
.4153 .30073 L
.41654 .30022 L
.41725 .3 L
.41789 .29985 L
.41915 .29972 L
.42036 .29981 L
.42149 .30011 L
.42272 .30065 L
.42404 .30147 L
.42921 .30587 L
.4304 .30686 L
.43169 .30778 L
.43291 .30847 L
.43404 .30892 L
.43506 .30915 L
.43618 .30921 L
.43735 .30907 L
Mistroke
.43844 .30877 L
.43972 .30825 L
.44113 .30752 L
.44368 .30605 L
.44488 .30542 L
.44617 .30488 L
.44738 .30453 L
.44848 .30438 L
.44915 .30438 L
.44987 .30444 L
.45115 .30474 L
.45186 .305 L
.45252 .30531 L
.45404 .30617 L
.45676 .3081 L
.45928 .30986 L
.46053 .31057 L
.4617 .31108 L
.46292 .31142 L
.46357 .31151 L
.46428 .31154 L
.46494 .31151 L
.46566 .3114 L
.46641 .3112 L
.46711 .31096 L
.46837 .31039 L
.46972 .30964 L
.47238 .30799 L
.47369 .30723 L
.4749 .30665 L
.476 .30625 L
.47716 .30598 L
.47833 .3059 L
.47961 .30603 L
.48085 .30637 L
.48202 .30685 L
.48423 .3081 L
.4868 .30977 L
.48806 .31053 L
.48919 .31111 L
.49026 .31154 L
.49127 .31182 L
.49233 .31197 L
.49348 .31195 L
.49467 .31174 L
.49592 .31132 L
.49699 .31083 L
.49816 .31018 L
.50068 .30858 L
.502 .30776 L
Mistroke
.50341 .30701 L
.50464 .3065 L
.50534 .30629 L
.50599 .30615 L
.50714 .30605 L
.50838 .30614 L
.50951 .30642 L
.51075 .3069 L
.51204 .30756 L
.51324 .30829 L
.51538 .30968 L
.51769 .31104 L
.51838 .31136 L
.51911 .31165 L
.52042 .31201 L
.52165 .31213 L
.52234 .31211 L
.52299 .31203 L
.52421 .31172 L
.52532 .31129 L
.52781 .30993 L
.53046 .30829 L
.53186 .30752 L
.53263 .30718 L
.53335 .3069 L
.53404 .30671 L
.53479 .30656 L
.53608 .3065 L
.5374 .30669 L
.53861 .30708 L
.57818 .3178 L
.57941 .31818 L
.58056 .31832 L
.58177 .31824 L
.5824 .31812 L
.58309 .31793 L
.58454 .31738 L
.58586 .31674 L
.58719 .31607 L
.58842 .31548 L
.58957 .31502 L
.59079 .31469 L
.59149 .31459 L
.59215 .31456 L
.59338 .31471 L
.59457 .3151 L
.59565 .31569 L
.59684 .31655 L
.5981 .31769 L
.60227 .32238 L
Mistroke
.60457 .32487 L
.6057 .32589 L
.60675 .32667 L
.60797 .32735 L
.60862 .3276 L
.60931 .32779 L
.61042 .32791 L
.61165 .32782 L
.61279 .32755 L
.61401 .32712 L
.61623 .32617 L
.61738 .32572 L
.61861 .32536 L
.61931 .32524 L
.61995 .32519 L
.6212 .32531 L
.6225 .32576 L
.62323 .32617 L
.6239 .32665 L
.62513 .32777 L
.62644 .32927 L
.63095 .33594 L
.63344 .3396 L
.63466 .34112 L
.6358 .34229 L
.63709 .3433 L
.63777 .34369 L
.63849 .34399 L
.63978 .34426 L
.64095 .34423 L
.64214 .34398 L
.64343 .34354 L
.64577 .34264 L
.64641 .34243 L
.6471 .34227 L
.64785 .34216 L
.64855 .34216 L
.64934 .34227 L
.65009 .34251 L
.65076 .34284 L
.65148 .34334 L
.65281 .34461 L
.65421 .34647 L
.65674 .35092 L
.65915 .35601 L
.66172 .3614 L
.66297 .36372 L
.66415 .36561 L
.66522 .36701 L
.66635 .36813 L
Mistroke
.66756 .36891 L
.66867 .36926 L
.66987 .36927 L
.67119 .36893 L
.6725 .36833 L
.67392 .3676 L
.67456 .36728 L
.67524 .36698 L
.67647 .36663 L
.67757 .3666 L
.67879 .36699 L
.68009 .36798 L
.68131 .36951 L
.68247 .37149 L
.68353 .37374 L
.68591 .38014 L
.69038 .39408 L
.69255 .39989 L
.6935 .40189 L
.69453 .40362 L
.69565 .40492 L
.69671 .40558 L
.69792 .40567 L
.69904 .40518 L
.70018 .4042 L
.70143 .40272 L
.70276 .40095 L
.70397 .39937 L
.70524 .39803 L
.70645 .39731 L
.70772 .39735 L
.70844 .39783 L
.70911 .39861 L
.71033 .4009 L
.71143 .40399 L
.71271 .40877 L
.71392 .41436 L
.71879 .44336 L
.72008 .45087 L
.72146 .45777 L
.72276 .46262 L
.72394 .46518 L
.72461 .46571 L
.72533 .46545 L
.72664 .46261 L
.72738 .45954 L
.72817 .45508 L
.72959 .44391 L
.73086 .43048 L
.73206 .41512 L
Mistroke
.73478 .37163 L
.73988 .27445 L
.74237 .2299 L
.74462 .19627 L
.74577 .1825 L
.74702 .17043 L
.74833 .16105 L
.74957 .15537 L
.75022 .15358 L
.75094 .15251 L
.75169 .15236 L
.75238 .15304 L
.75364 .15604 L
.75434 .15859 L
.75498 .16138 L
.75952 .18793 L
.76192 .20186 L
.76324 .20823 L
.76448 .2131 L
.76566 .21663 L
.76693 .2192 L
.76809 .22047 L
.76915 .22082 L
.77016 .22055 L
.77126 .21972 L
.77241 .21842 L
.77349 .21701 L
.77475 .21532 L
.77593 .21392 L
.77716 .21285 L
.77781 .21251 L
.77851 .21233 L
.77927 .21239 L
.78 .21271 L
.78064 .21321 L
.78135 .214 L
.78201 .21495 L
.78271 .21619 L
.78397 .21895 L
.78908 .23421 L
.79159 .2416 L
.79268 .24434 L
.79389 .24687 L
.79507 .2488 L
.79617 .25012 L
.79732 .251 L
.79857 .25142 L
.79922 .25145 L
.79993 .25137 L
.80122 .25095 L
Mistroke
.80247 .25034 L
.80363 .24973 L
.80461 .24927 L
.80566 .2489 L
.80682 .24873 L
.80791 .24886 L
.80907 .24936 L
.81029 .2503 L
.81133 .25146 L
.81246 .25306 L
.83206 .27477 L
.83338 .27427 L
.8341 .27404 L
.83479 .27388 L
.83543 .27379 L
.83613 .27376 L
.83735 .27394 L
.83802 .27416 L
.83874 .27451 L
.84002 .27542 L
.84156 .27695 L
.84296 .27871 L
.84779 .28604 L
.85033 .28947 L
.85161 .2908 L
.85301 .29189 L
.85369 .29227 L
.85443 .29257 L
.85512 .29275 L
.85575 .29283 L
.85705 .29277 L
.85828 .29249 L
.85951 .29205 L
.86066 .29156 L
.86199 .29099 L
.86324 .29053 L
.86447 .29023 L
.86517 .29014 L
.8658 .29012 L
.86646 .29018 L
.86718 .29032 L
.86793 .29057 L
.86863 .29088 L
.87007 .29182 L
.87139 .29295 L
.87434 .29614 L
.87676 .29894 L
.87932 .30146 L
.88065 .30242 L
.88141 .30283 L
Mistroke
.88212 .30313 L
.88337 .30343 L
.88407 .30347 L
.88471 .30345 L
.88596 .30322 L
.88711 .30283 L
.88973 .3016 L
.89094 .30099 L
.89221 .30042 L
.8933 .30004 L
.89449 .29978 L
.89564 .29972 L
.89688 .29988 L
.89805 .30025 L
.89911 .30076 L
.90033 .30154 L
.90167 .30257 L
.90409 .30471 L
.90637 .30669 L
.90762 .30761 L
.90878 .30831 L
.90978 .30876 L
.91085 .30908 L
.91203 .30921 L
.91312 .30915 L
.91438 .30885 L
.91509 .3086 L
.91573 .30833 L
.91816 .30703 L
.92081 .30555 L
.92153 .30521 L
.9223 .3049 L
.92295 .30469 L
.92367 .30451 L
.92496 .30437 L
.92568 .3044 L
.92634 .30449 L
.92762 .30484 L
.92884 .30537 L
.93117 .3068 L
.93371 .30865 L
.93604 .3102 L
.93735 .31086 L
.93855 .31129 L
.93961 .3115 L
.94077 .31153 L
.94198 .31137 L
.94311 .31104 L
.94375 .31078 L
.94446 .31045 L
Mistroke
.94573 .30974 L
.94812 .30826 L
.94948 .30745 L
.95091 .30673 L
.95214 .30626 L
.95283 .30608 L
.95348 .30596 L
.95478 .30591 L
.95552 .30598 L
.9562 .30612 L
.95745 .30652 L
.95814 .30682 L
.95877 .30714 L
.96361 .31016 L
.96492 .31089 L
.9663 .31149 L
.96703 .31172 L
.96782 .31189 L
.96854 .31197 L
.96922 .31198 L
.9699 .31193 L
.97055 .31182 L
.97176 .31146 L
.97307 .31089 L
.97449 .31009 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z002SoookJPCo0000JOoonfX3o`00O`[ooo]Z1Ol00023
oookJPCo0000UooonfX00:;ooo]Z1_l0001HoookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol00023oook
JPGo0000U_oonfX00:;ooo]Z1ol0001GoookJP[o001o1_oonfX3o`00O`[ooo]Z1_l00021oookJPKo
0000U_oonfX00:;ooo]Z1ol0001WoookJP?o001o2_oonfX5o`0008;ooo]Z1_l0002FoookJP00X_oo
nfX7o`0006Oooo]Z0ol007l:oookJPGo0000P_oonfX7o`0009Gooo]Z002RoookJPOo0000IooonfX3
o`00O`[ooo]Z1Ol00022oookJPOo0000UOoonfX00:;ooo]Z1ol0001WoookJP?o001o2_oonfX5o`00
08;ooo]Z1ol0002EoookJP00XOoonfX9o`0006?ooo]Z1_l007l:oookJPGo0000P_oonfX7o`0009Go
oo]Z002QoookJPWo0000HooonfX6o`00O`[ooo]Z1Ol00021oookJPWo0000U?oonfX00:7ooo]Z2Ol0
001UoookJPCo001o2_oonfX5o`00087ooo]Z2Ol0002DoookJP00XOoonfX4o`000003oookJ_l0003o
000000;o0000I_oonfX3o`00O`[ooo]Z1Ol00021oookJPWo0000U?oonfX00:3ooo]Z1Ol000000ooo
nf[o0000o`000002o`0007?ooo]Z1Ol00021oookJPCo000000?ooo]Zo`000?l000000_l0002Doook
JP00X?oonfX5o`000003oookJ_l0003o000000;o0000LooonfX5o`00087ooo]Z1?l000000ooonf[o
0000o`000002o`0009Cooo]Z002PoookJPGo000000?ooo]Zo`000?l000000ol0001boookJPGo0000
POoonfX4o`000003oookJ_l0003o000000?o0000TooonfX00:3ooo]Z1?l00002oookJPGo0000L_oo
nfX5o`00083ooo]Z1Ol000000ooonf[o0000o`000003o`0009?ooo]Z002PoookJPCo00000_oonfX5
o`0007;ooo]Z1Ol00020oookJPGo000000?ooo]Zo`000?l000000ol0002CoookJP00X?oonfX4o`00
00?ooo]Z1?l0001boookJPGo0000P?oonfX5o`0000;ooo]Z1?l0002CoookJP00X?oonfX4o`0000?o
oo]Z1?l0001boookJPGo0000P?oonfX4o`0000?ooo]Z1?l0002CoookJP00X?oonfX4o`0000?ooo]Z
1?l0001boookJPGo0000P?oonfX4o`0000?ooo]Z1Ol0002BoookJP00X?oonfX4o`0000?ooo]Z1?l0
001boookJPGo0000P?oonfX4o`0000?ooo]Z1Ol0002BoookJP00X?oonfX4o`0000?ooo]Z1?l0001b
oookJPGo0000P?oonfX4o`0000?ooo]Z1Ol0002BoookJP00X?oonfX4o`0000?ooo]Z1Ol0001aoook
JPGo0000P?oonfX4o`0000Cooo]Z1?l0002BoookJP00X?oonfX4o`0000?ooo]Z1Ol0001aoookJPGo
0000P?oonfX4o`0000Cooo]Z1?l0002BoookJP00X?oonfX4o`0000?ooo]Z1Ol0001aoookJPGo0000
P?oonfX4o`0000Cooo]Z1?l0002BoookJP00X?oonfX4o`0000Cooo]Z1?l0001aoookJPGo0000P?oo
nfX4o`0000Cooo]Z1Ol0002AoookJP00X?oonfX4o`0000Cooo]Z1?l0001aoookJPGo0000P?oonfX4
o`0000Cooo]Z1Ol0002AoookJP00WooonfX5o`0000Cooo]Z1?l0001aoookJPGo0000P?oonfX4o`00
00Cooo]Z1Ol0002AoookJP00WooonfX5o`0000Cooo]Z1Ol0001`oookJPGo0000P?oonfX4o`0000Go
oo]Z1?l0002AoookJP00WooonfX5o`0000Cooo]Z1Ol0001`oookJPGo0000P?oonfX4o`0000Gooo]Z
1?l0002AoookJP00WooonfX4o`0000Gooo]Z1Ol0001`oookJPGo0000OooonfX5o`0000Gooo]Z1Ol0
002@oookJP00WooonfX4o`0000Kooo]Z1Ol0001_oookJPGo0000OooonfX5o`0000Gooo]Z1Ol0002@
oookJP00WooonfX4o`0000Kooo]Z1Ol0001_oookJPGo0000OooonfX5o`0000Gooo]Z1Ol0002@oook
JP00WooonfX4o`0000Kooo]Z1Ol0001_oookJPGo0000OooonfX4o`0000Oooo]Z1?l0002@oookJP00
WooonfX4o`0000Oooo]Z1?l00003oookJPKo0000I_oonfX5o`0007oooo]Z1?l00007oookJPCo0000
0ooonfX6o`0008Oooo]Z002OoookJPCo00001ooonfX4o`0000;ooo]Z2?l0001UoookJPGo0000Oooo
nfX4o`0000Oooo]Z1?l00002oookJPSo0000Q_oonfX009oooo]Z1?l00007oookJPGo000000?ooo]Z
o`000?l000001_l0001UoookJPGo0000OooonfX4o`0000Oooo]Z3_l00026oookJP00WooonfX4o`00
00Oooo]Z3_l0001UoookJPGo0000OooonfX4o`0000Oooo]Z3ol00025oookJP00WooonfX4o`0000Oo
oo]Z3ol0001ToookJPGo0000OooonfX4o`0000Oooo]Z3ol00025oookJP00WooonfX4o`0000Sooo]Z
3_l0001ToookJPGo0000O_oonfX5o`0000Sooo]Z2?l000000ooonf[o0000o`000004o`0008Cooo]Z
002OoookJPCo00002?oonfX8o`000003oookJ_l0003o000000Co0000HooonfX5o`0007kooo]Z1Ol0
0009oookJPOo00000_oonfX5o`0008Cooo]Z002OoookJPCo00002OoonfX6o`0000?ooo]Z1Ol00015
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000O_oonfX5o`0000Wooo]Z1_l00003
oookJPGo0000Q?oonfX009kooo]Z1Ol0000BoookJPGo0000A?oonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o2OoonfX5o`0007kooo]Z1?l0000DoookJPGo0000PooonfX009kooo]Z1Ol0000CoookJPGo
0000@ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001noookJPCo00005?oonfX5o`0008?ooo]Z002Noook
JPGo00004ooonfX5o`0003Kooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o2?oonfX5o`0007kooo]Z1?l0000DoookJPGo0000PooonfX009kooo]Z1?l0000DoookJPGo
0000=_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001moookJPCo
00005OoonfX5o`0008;ooo]Z002NoookJPCo00005OoonfX5o`00047ooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Sooo]Z1Ol0001noookJPCo00005OoonfX5o`0008;ooo]Z002NoookJPCo00005Ooo
nfX5o`00047ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000O_oo
nfX4o`0001Gooo]Z1Ol00022oookJP00W_oonfX4o`0001Gooo]Z1Ol00011oookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l9oookJPGo0000O_oonfX4o`0001Kooo]Z1Ol00021oookJP00W_oonfX4o`00
01Kooo]Z1Ol00010oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000O_oonfX4o`00
01Kooo]Z1Ol00021oookJP00W_oonfX4o`0001Kooo]Z1Ol00010oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l>oookJPGo0000O_oonfX4o`0001Kooo]Z1Ol00021oookJP00W_oonfX4o`0001Kooo]Z
1_l00010oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001noookJPCo
00005ooonfX5o`00083ooo]Z002NoookJPCo00005ooonfX5o`00043ooo]Z1ol007l9oookJPOo001o
2?oonfX5o`0007kooo]Z1?l0000GoookJPGo0000P?oonfX009kooo]Z1?l0000GoookJPGo00000ooo
nfX5o`0003Wooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0007kooo]Z1?l0000GoookJPKo00000_oo
nfX5o`0007Sooo]Z002NoookJPCo00006?oonfX=o`0005Kooo]Z1Ol0001noookJPCo00006?oonfX=
o`0007Oooo]Z002NoookJPCo00006?oonfX>o`0005Gooo]Z1Ol0001noookJPCo00006?oonfX>o`00
07Kooo]Z002NoookJPCo00006?oonfX?o`0005Cooo]Z1Ol0001moookJPGo00006OoonfX=o`0007Ko
oo]Z002NoookJPCo00006OoonfX>o`0005Cooo]Z1Ol0001moookJPGo00006_oonfX=o`0007Gooo]Z
002NoookJPCo00006_oonfX6o`000003oookJ_l0003o000000Go0000DooonfX5o`0007gooo]Z1Ol0
000JoookJPKo00000_oonfX6o`0007Cooo]Z002MoookJPGo00008ooonfX5o`0005?ooo]Z1Ol0001m
oookJPCo00008ooonfX7o`0007?ooo]Z002MoookJPGo00008ooonfX6o`0005;ooo]Z1Ol0001moook
JPCo00009?oonfX7o`0007;ooo]Z002MoookJPGo00009?oonfX5o`0005;ooo]Z1Ol0001moookJPCo
00009OoonfX7o`00077ooo]Z002MoookJPCo00009OoonfX5o`0005;ooo]Z1Ol0001moookJPCo0000
9_oonfX7o`00073ooo]Z002MoookJPCo00009_oonfX5o`00057ooo]Z1Ol0001moookJPCo00009ooo
nfX7o`0006oooo]Z002MoookJPCo00009_oonfX5o`00057ooo]Z1Ol0001moookJPCo0000:?oonfX7
o`0006kooo]Z002MoookJPCo00009_oonfX6o`00053ooo]Z1Ol0001moookJPCo0000:OoonfX7o`00
06gooo]Z000RoookJP?o001oMOoonfX3o`00O`Co00000_oonfX3o`00O`?ooo]Z1Ol007lJoookJPGo
0000D?oonfX5o`0007Cooo]Z1Ol007l4oookJPCo00000_oonfX5o`00Ob?ooo]Z1ol0001<oookJP?o
001o7OoonfX002;ooo]Z0ol007mdoookJPCo001o1?l00002oookJP?o001o0_oonfX7o`00OaWooo]Z
3ol00016oookJPGo0000LooonfX7o`00O`?ooo]Z1?l000000ooonf[o001oo`00O`05o`00Ob?ooo]Z
2ol00017oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o00?ooo]Zo`000?l000000_l0
0002oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lJoookJPko0000
A_oonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJPCo00001?l007l01?oonf[o
001oo`00Ool007lToookJP[o0000AooonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOo
oo]Z2_l007l2oookJP?o001o0_oonfX4o`0000Kooo]Z0ol007l3oookJP?o001o6OoonfX@o`0004Co
oo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00003o`00O`?ooo]Z0ol007lToookJP[o
0000A_oonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o
0_oonfX4o`0000cooo]Z0ol007lJoookJPoo0000A?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o
0_oonfX4o`0000Kooo]Z0ol007lUoookJP[o0000AOoonfX3o`00Oagooo]Z000RoookJP?o001oLooo
nfX3o`00O`03oookJ_l0003o000000?o00003?oonfX3o`00Oa_ooo]Z3ol00013oookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l2oookJPCo00001_oonfX3o`00ObWooo]Z1_l00015oookJP?o001o7Ooo
nfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000ol00007oookJP;o001o0_oonfX4
o`00ObCooo]Z1_l00013oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Z
o`00Ool007l00_oonfX4o`00Ob[ooo]Z1_l00014oookJP?o001o7OoonfX002;ooo]Z0ol007mcoook
JP?o001o00?ooo]Zo`000?l000000ol00007oookJPOo001o9_oonfX6o`0004;ooo]Z1Ol0001boook
JP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`05o`00Obcooo]Z1Ol00014oook
JP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oo
oo]ZoookJP05oookJPKo001o:?oonfX5o`0004;ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;o
oo]Z1?l000000ooonf[o001oo`00O`04o`00Obgooo]Z1ol00012oookJP?o001o7OoonfX001oooo]Z
1_l007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP05oookJP;o001o
;?oonfX6o`00047ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001o
o`00O`0boookJPOo0000?_oonfX6o`00Oagooo]Z000OoookJPKo001oM?oonfX3o`00O`Co00002?oo
nfX2o`00Obgooo]Z1ol000000ooonf[o0000o`000006o`0003Kooo]Z1Ol0001coookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX4o`000003oookJ_l007oo001o03;ooo]Z2?l000000ooonf[o0000
o`000006o`0003Cooo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol0
07lWoookJQ7o0000=OoonfX5o`0007?ooo]Z1ol007l2oookJPGo00000_oonfX7o`00Obgooo]Z4Ol0
000eoookJPCo001o7OoonfX002;ooo]Z0ol007meoookJP;o001o1?l00009oookJPOo001o:?oonfXA
o`0003Cooo]Z1Ol0001doookJPGo001o0ooonfX5o`0000;ooo]Z1ol007l_oookJQ3o0000=OoonfX3
o`00Oagooo]Z002LoookJPCo0000>OoonfX@o`0003Cooo]Z1Ol0001loookJPGo0000>OoonfX@o`00
05Cooo]Z002LoookJPCo0000>_oonfX8o`000003oookJ_l0003o000000Ko0000<_oonfX5o`0007co
oo]Z1?l0000joookJPSo00000_oonfX6o`0005Cooo]Z002LoookJPCo0000AOoonfX7o`0000Cooo]Z
1ol0000VoookJPGo0000O?oonfX4o`0004Gooo]Z1ol00004oookJPOo0000AooonfX009cooo]Z1?l0
0015oookJQCo00009?oonfX5o`0007cooo]Z1?l00016oookJPOo000000?ooo]Zo`000?l000002?l0
0016oookJP00W?oonfX4o`0004Kooo]Z5?l0000SoookJPGo0000O?oonfX4o`0004Kooo]Z4ol00015
oookJP007ooonfX4o`0007Wooo]Z1?l00018oookJQ?o00000ooonfX:o`0000Wooo]Z1Ol00007oook
JPWo0000N?oonfX4o`0004Oooo]Z4ol00005oookJPWo00002?oonfX6o`0002Sooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`00
00oooo]Z000MoookJP03o`000?oonf[ooo]Z00Cooo]Z2Ol00005oookJPgo000000?ooo]Zo`000?l0
00001_l000000ooonf[o0000o`000009o`0004Oooo]Z1Ol0001XoookJPSo00001ooonfX;o`0000Go
oo]Z2Ol00008oookJQ7o00000ooonfX9o`0004Wooo]Z1?l0001WoookJPWo00001_oonfX:o`0001ko
oo]Z000VoookJPKo00002?oonfX9o`0000Cooo]Z4ol00017oookJPCo0000NOoonfX:o`0000Kooo]Z
1Ol0000?oookJQ[o0000B?oonfX4o`0007Wooo]Z1Ol0000PoookJP00=_oonfX5o`0000Oooo]Z4ol0
0016oookJPCo0000O_oonfX5o`0001gooo]Z6?l00017oookJPCo0000W_oonfX004Cooo]Z4_l00015
oookJPCo0000O_oonfX5o`00027ooo]Z5Ol00016oookJPCo0000W_oonfX004Gooo]Z2?l00003oook
JPOo0000A?oonfX4o`0007kooo]Z1Ol0000ToookJPWo00000ooonfX7o`0004Cooo]Z1Ol0002Noook
JP00DOoonfX7o`0000;ooo]Z1ol0000joookJPCo0000O_oonfX5o`00037ooo]Z1ol00002oookJPSo
0000>OoonfX5o`0009kooo]Z001BoookJQ7o0000>?oonfX4o`0007kooo]Z1Ol0000boookJQ7o0000
>?oonfX5o`0009kooo]Z001CoookJQ3o0000>?oonfX4o`0007kooo]Z1Ol0000coookJQ7o0000=ooo
nfX4o`0009oooo]Z001DoookJQ3o0000=ooonfX4o`0007kooo]Z1Ol0000doookJQ3o0000=ooonfX4
o`0009oooo]Z001EoookJPSo000000?ooo]Zo`000?l000001Ol0000foookJPCo0000O_oonfX5o`00
03Gooo]Z2?l000000ooonf[o0000o`000005o`0003Kooo]Z1?l0002OoookJP00GooonfX6o`0003Ko
oo]Z1?l0001noookJPGo0000@?oonfX5o`0003Kooo]Z1?l0002OoookJP00H?oonfX6o`0003Gooo]Z
1?l0001noookJPGo0000@?oonfX6o`0003Gooo]Z1?l0002OoookJP00HOoonfX6o`0003Cooo]Z1?l0
001noookJPGo0000@OoonfX5o`0003Gooo]Z1?l0002OoookJP00HOoonfX6o`0003Cooo]Z1?l0001n
oookJPGo0000@OoonfX7o`0003?ooo]Z1?l0002OoookJP00H_oonfX7o`000003oookJ_l0003o0000
00Co0000:ooonfX4o`0007kooo]Z1Ol00012oookJPOo000000?ooo]Zo`000?l000001Ol0000Zoook
JPCo0000WooonfX006?ooo]Z3ol0000YoookJPCo0000O_oonfX5o`0004;ooo]Z4?l0000YoookJPCo
0000WooonfX006?ooo]Z3ol0000YoookJPCo0000O_oonfX5o`0004?ooo]Z4?l0000XoookJPCo0000
WooonfX006Cooo]Z3ol0000XoookJPCo0000O_oonfX5o`0004Gooo]Z3_l0000XoookJPCo0000Wooo
nfX006Gooo]Z3_l0000XoookJPCo0000O_oonfX5o`0004Gooo]Z3ol0000WoookJPCo0000WooonfX0
06kooo]Z1Ol0000XoookJPCo0000O_oonfX5o`0004oooo]Z1Ol0000WoookJPCo0000WooonfX006oo
oo]Z1Ol0000VoookJPGo0000O_oonfX5o`0004oooo]Z1Ol0000WoookJPCo0000WooonfX006oooo]Z
1Ol0000VoookJPGo0000O_oonfX5o`00053ooo]Z1Ol0000VoookJPCo0000WooonfX006oooo]Z1_l0
000UoookJPGo0000O_oonfX5o`00053ooo]Z1Ol0000UoookJPGo0000WooonfX0073ooo]Z1Ol0000U
oookJPCo0000OooonfX5o`00053ooo]Z1_l0000ToookJPGo0000WooonfX0073ooo]Z1_l0000Toook
JPCo0000OooonfX5o`00057ooo]Z1_l0000SoookJPGo0000WooonfX0077ooo]Z1Ol0000ToookJPCo
0000OooonfX5o`00057ooo]Z1_l0000SoookJPCo0000X?oonfX0077ooo]Z1_l0000SoookJPCo0000
OooonfX5o`0005;ooo]Z1Ol0000SoookJPCo0000X?oonfX007;ooo]Z1_l00002oookJPKo00006_oo
nfX4o`0007oooo]Z1Ol0001CoookJPKo000000?ooo]Zo`000?l000001?l0000JoookJPCo0000X?oo
nfX007;ooo]Z3ol0000IoookJPCo0000OooonfX5o`0005?ooo]Z3_l0000IoookJPCo0000X?oonfX0
07?ooo]Z3_l0000IoookJPCo0000OooonfX5o`0005?ooo]Z3_l0000IoookJPCo0000X?oonfX007Co
oo]Z3Ol0000IoookJPCo0000OooonfX5o`0005Cooo]Z3_l0000HoookJPCo0000X?oonfX007Gooo]Z
3Ol0000HoookJPCo0000OooonfX5o`0005Gooo]Z3Ol0000HoookJPCo0000X?oonfX007Kooo]Z1_l0
00000ooonf[o0000o`000003o`0001Sooo]Z1?l0001ooookJPGo0000E_oonfX5o`0000;ooo]Z1Ol0
000HoookJPCo0000X?oonfX007gooo]Z1_l0000GoookJPCo0000OooonfX5o`0005kooo]Z1Ol0000G
oookJPCo0000X?oonfX007kooo]Z1Ol0000GoookJPCo0000OooonfX5o`0005kooo]Z1Ol0000Goook
JPCo0000X?oonfX007kooo]Z1_l0000FoookJPCo0000HOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o2_oonfX5o`0005kooo]Z1_l0000FoookJPCo0000X?oonfX007oooo]Z1Ol0000FoookJPCo0000
H?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0005oooo]Z1Ol0000FoookJPCo0000
X?oonfX007oooo]Z1_l0000EoookJPCo0000H?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001OoookJPGo
00005_oonfX4o`000:3ooo]Z0020oookJPGo00005OoonfX4o`0005oooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000H?oonfX5o`0001Gooo]Z1?l0002PoookJP00P?oo
nfX6o`0001Cooo]Z1?l0001OoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000Gooo
nfX5o`0001Gooo]Z1?l0002PoookJP00POoonfX6o`0001?ooo]Z1?l0001OoookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l8oookJPGo0000H?oonfX5o`0001Gooo]Z1?l0002PoookJP00POoonfX6o`00
01;ooo]Z1Ol0001OoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`00
067ooo]Z1Ol0000DoookJPCo0000X?oonfX008;ooo]Z1_l0000AoookJPGo0000GooonfX3o`00O`?o
oo]Z0ol007l7oookJPOo001o2OoonfX5o`00067ooo]Z1Ol0000DoookJPCo0000X?oonfX008?ooo]Z
1Ol0000AoookJPGo0000GooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`00067ooo]Z
1Ol0000CoookJPGo0000X?oonfX008?ooo]Z1_l000000ooonf[o0000o`000004o`0000Wooo]Z1?l0
001PoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000H_oonfX5o`0000?ooo]Z1_l0
0009oookJPGo0000X?oonfX008Cooo]Z3?l00009oookJPCo0000HOoonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0_l007l>oookJPGo0000H_oonfX5o`0000?ooo]Z1_l00009oookJPGo0000X?oo
nfX008Cooo]Z3Ol00008oookJPCo0000HOoonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000H_oonfX6
o`000003oookJ_l0003o000000Ko00002?oonfX4o`000:7ooo]Z0025oookJPco00002?oonfX4o`00
06;ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0006?ooo]Z3ol00007oookJPCo0000XOoonfX008Go
oo]Z3Ol00007oookJPCo0000P?oonfX5o`0006?ooo]Z3ol00007oookJPCo0000XOoonfX008Kooo]Z
3?l00007oookJPCo0000P?oonfX5o`0006Cooo]Z3_l00007oookJPCo0000XOoonfX008Kooo]Z1_l0
00000ooonf[o0000o`000003o`0000Oooo]Z1?l00020oookJPGo0000I?oonfX8o`0000;ooo]Z1?l0
0007oookJPCo0000XOoonfX008Oooo]Z1?l00003oookJPCo00001ooonfX4o`00083ooo]Z1Ol0001U
oookJPKo00000ooonfX4o`0000Oooo]Z1?l0002QoookJP00S_oonfX4o`0000Oooo]Z1?l00020oook
JPGo0000K_oonfX5o`0000Kooo]Z1?l0002QoookJP00S_oonfX4o`0000Oooo]Z1?l00020oookJPGo
0000K_oonfX5o`0000Kooo]Z1?l0002QoookJP00S_oonfX5o`0000Kooo]Z1?l00020oookJPGo0000
K_oonfX5o`0000Kooo]Z1?l0002QoookJP00S_oonfX5o`0000Kooo]Z1?l00020oookJPGo0000Kooo
nfX4o`0000Kooo]Z1?l0002QoookJP00S_oonfX5o`0000Kooo]Z1?l00020oookJPGo0000KooonfX4
o`0000Kooo]Z1?l0002QoookJP00SooonfX5o`0000Gooo]Z1?l00020oookJPGo0000KooonfX5o`00
00Gooo]Z1?l0002QoookJP00SooonfX5o`0000Gooo]Z1?l00020oookJPGo0000KooonfX5o`0000Go
oo]Z1?l0002QoookJP00SooonfX5o`0000Gooo]Z1?l00020oookJPGo0000KooonfX5o`0000Cooo]Z
1Ol0002QoookJP00T?oonfX4o`0000Cooo]Z1Ol00020oookJPGo0000L?oonfX4o`0000Cooo]Z1Ol0
002QoookJP00T?oonfX4o`0000Cooo]Z1Ol00020oookJPGo0000L?oonfX4o`0000Cooo]Z1Ol0002Q
oookJP00T?oonfX4o`0000Cooo]Z1Ol00020oookJPGo0000L?oonfX5o`0000?ooo]Z1?l0002Roook
JP00T?oonfX5o`0000?ooo]Z1?l00021oookJPGo0000L?oonfX5o`0000?ooo]Z1?l0002RoookJP00
T?oonfX5o`0000?ooo]Z1?l00021oookJPGo0000L?oonfX5o`0000?ooo]Z1?l0002RoookJP00T?oo
nfX5o`0000?ooo]Z1?l00021oookJPGo0000LOoonfX4o`0000?ooo]Z1?l0002RoookJP00TOoonfX4
o`0000?ooo]Z1?l00021oookJPGo0000LOoonfX4o`0000;ooo]Z1Ol0002RoookJP00TOoonfX4o`00
00?ooo]Z1?l00021oookJPGo0000LOoonfX5o`000003oookJ_l0003o000000?o0000X_oonfX0097o
oo]Z1?l00003oookJPCo0000POoonfX5o`00077ooo]Z1Ol000000ooonf[o0000o`000003o`000:;o
oo]Z002AoookJPCo00000ooonfX4o`00087ooo]Z1Ol0001aoookJPGo000000?ooo]Zo`000?l00000
0_l0002SoookJP00TOoonfX4o`0000?ooo]Z1?l00021oookJPGo0000L_oonfX4o`000003oookJ_l0
003o000000;o0000XooonfX0097ooo]Z1Ol000000ooonf[o0000o`000003o`00087ooo]Z1Ol0001b
oookJPCo000000?ooo]Zo`000?l000000_l0002SoookJP00TOoonfX5o`000003oookJ_l0003o0000
00?o0000POoonfX5o`0007;ooo]Z1?l000000ooonf[o0000o`000002o`000:?ooo]Z002AoookJPGo
000000?ooo]Zo`000?l000000ol00021oookJPGo0000L_oonfX4o`000003oookJ_l0003o000000;o
0000XooonfX009;ooo]Z1?l000000ooonf[o0000o`000002o`0008;ooo]Z1Ol0001boookJPCo0000
00?ooo]Zo`000?l000000_l0002SoookJP00T_oonfX4o`000003oookJ_l0003o000000;o0000P_oo
nfX5o`0007;ooo]Z1?l000000ooonf[o0000o`000002o`000:?ooo]Z002BoookJPWo0000P_oonfX5
o`0007;ooo]Z2Ol0002SoookJP00T_oonfX9o`0007Gooo]Z0ol007l:oookJPGo0000L_oonfX9o`00
0:?ooo]Z002BoookJPWo0000MOoonfX3o`00O`[ooo]Z1Ol0001boookJPWo0000XooonfX009?ooo]Z
2?l0001eoookJP?o001o2_oonfX5o`0007?ooo]Z2?l0002SoookJP00TooonfX7o`0007Kooo]Z0ol0
07l:oookJPGo0000LooonfX7o`000:Cooo]Z002CoookJPOo0000M_oonfX3o`00O`[ooo]Z1_l0001b
oookJPOo0000Y?oonfX009Cooo]Z1_l0001foookJP?o001o2_oonfX5o`0007Cooo]Z1_l0002Toook
JP00U?oonfX6o`0007Kooo]Z0ol007l:oookJPGo0000M?oonfX6o`000:Cooo]Z002DoookJPGo0000
MooonfX3o`00O`[ooo]Z1Ol0001doookJPGo0000YOoonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX>oook
JPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[ooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o
1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oo
nfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXNoookJP00oooonfX2oookJP?o
001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJP;o001o
0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPOo001o2Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l007l:oookJPGo0000oooonfXO
oookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wo
oo]Z0_l007l>oookJPGo0000oooonfXOoookJP00oooonfX1oookJPCo001o2_oonfX7o`00O`Sooo]Z
1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z
1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=
oookJPCo001o3OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4o`00O`cooo]Z1Ol0003ooook
JQoooo]Z003ooookJPoooo]Z1Ol007l:oookJPKo0000oooonfXNoookJP00oooonfXAoookJPCo001o
2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oook
JP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z
0ol007oooookJRcooo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z003ooookJPoooo]Z1Ol007oo
oookJRkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02605 .31041 L
.02729 .31104 L
.02846 .31148 L
.02954 .31174 L
.03072 .31183 L
.0318 .31172 L
.03279 .31148 L
.03396 .31104 L
.03506 .31048 L
.03756 .30895 L
.0388 .30816 L
.04015 .30739 L
.04143 .30682 L
.04262 .30646 L
.04388 .30629 L
.04503 .30635 L
.04567 .30647 L
.04636 .30666 L
.04761 .30717 L
.04876 .30779 L
.04998 .30856 L
.05217 .31004 L
.05339 .31081 L
.0547 .31152 L
.05594 .312 L
.05707 .31227 L
.05839 .31234 L
.05914 .31226 L
.05983 .31212 L
.0611 .3117 L
.06174 .31141 L
.06244 .31106 L
.0651 .30948 L
.06655 .30863 L
.0679 .30797 L
.06906 .30756 L
.07029 .30732 L
.07099 .30729 L
.07166 .30733 L
.0729 .30759 L
.07355 .30783 L
.07427 .30816 L
.07572 .30901 L
.07831 .31096 L
.07988 .31219 L
.08138 .31323 L
.08272 .31398 L
.08347 .3143 L
.08418 .31452 L
Mistroke
.08547 .31473 L
.08664 .3147 L
.08729 .31459 L
.08799 .3144 L
.08926 .31392 L
.09192 .31253 L
.09337 .31175 L
.09472 .31113 L
.0959 .31074 L
.09717 .31054 L
.09789 .31054 L
.09858 .31062 L
.09986 .311 L
.10103 .31158 L
.10212 .31232 L
.10458 .31446 L
.10685 .31667 L
.10923 .31873 L
.11048 .31955 L
.11118 .31991 L
.11184 .32017 L
.113 .32044 L
.11423 .32049 L
.1154 .32031 L
.11667 .31991 L
.11787 .3194 L
.11898 .31887 L
.12105 .31792 L
.12222 .31752 L
.12328 .31731 L
.12455 .3173 L
.12575 .31756 L
.12685 .31806 L
.12806 .31886 L
.12938 .32004 L
.13078 .32157 L
.1333 .32469 L
.13572 .3276 L
.137 .32889 L
.13834 .32996 L
.13905 .33039 L
.13983 .33075 L
.14054 .33098 L
.1412 .33109 L
.14251 .3311 L
.14324 .33098 L
.1439 .33081 L
.14509 .3304 L
.1462 .32994 L
.14753 .3294 L
Mistroke
.14874 .329 L
.15 .32878 L
.15121 .32882 L
.15248 .32919 L
.1532 .32956 L
.15386 .33002 L
.15507 .33111 L
.1562 .33242 L
.15832 .33547 L
.16306 .34315 L
.16437 .34491 L
.16559 .34625 L
.16687 .34728 L
.16754 .34766 L
.16826 .34795 L
.16955 .34817 L
.17077 .34807 L
.17186 .34778 L
.17305 .34734 L
.17445 .34678 L
.17577 .34636 L
.17643 .34623 L
.17714 .34618 L
.17793 .34625 L
.17866 .34645 L
.17987 .34711 L
.18119 .34832 L
.18185 .34913 L
.18257 .35014 L
.18385 .35231 L
.18885 .36317 L
.1913 .36813 L
.19237 .36987 L
.19353 .37138 L
.19474 .37247 L
.19588 .37306 L
.19719 .37324 L
.19841 .373 L
.19911 .37272 L
.19977 .3724 L
.20101 .3717 L
.20233 .371 L
.20308 .37068 L
.20378 .37049 L
.20444 .37042 L
.20515 .37049 L
.2059 .37076 L
.20659 .3712 L
.20723 .37178 L
.20792 .37261 L
Mistroke
.20918 .37465 L
.21065 .37791 L
.21221 .38223 L
.21501 .39132 L
.21738 .39895 L
.21869 .40256 L
.21994 .40535 L
.22064 .40658 L
.2214 .40763 L
.2221 .40831 L
.22274 .40869 L
.22401 .40879 L
.22472 .40848 L
.22537 .408 L
.22785 .40492 L
.23017 .40161 L
.23134 .40041 L
.2326 .39985 L
.23331 .39997 L
.23399 .40043 L
.23526 .4023 L
.23593 .40385 L
.23664 .40595 L
.23793 .41084 L
.24083 .42654 L
.2433 .44257 L
.2446 .4507 L
.24596 .45816 L
.24715 .46314 L
.24844 .46641 L
.24962 .46694 L
.25072 .46503 L
.25185 .46038 L
.25288 .45369 L
.25406 .44299 L
.25518 .43001 L
.25773 .39125 L
.26007 .3468 L
.26537 .23967 L
.26776 .19982 L
.26894 .18408 L
.27004 .17213 L
.27129 .16174 L
.27195 .15769 L
.27266 .15446 L
.27392 .15134 L
.27506 .15124 L
.27623 .1535 L
.2773 .15736 L
.27848 .16314 L
Mistroke
.27973 .17046 L
.28412 .19832 L
.28539 .20492 L
.28658 .21003 L
.28724 .21233 L
.28796 .21439 L
.28922 .21688 L
.29041 .21802 L
.29168 .21808 L
.29277 .21736 L
.29397 .216 L
.29665 .21212 L
.29738 .21115 L
.29815 .2103 L
.29881 .20974 L
.29953 .20933 L
.30084 .20926 L
.30158 .20963 L
.30224 .21021 L
.30354 .21206 L
.30476 .2146 L
.3248 .24527 L
.32586 .2449 L
.32699 .24479 L
.32823 .24508 L
.32937 .24579 L
.33043 .24683 L
.33143 .24815 L
.33371 .25219 L
.3387 .26324 L
.34092 .26739 L
.34204 .26901 L
.34326 .27037 L
.34453 .2713 L
.3457 .27175 L
.34678 .27185 L
.34794 .2717 L
.34859 .27152 L
.34929 .27128 L
.35058 .27077 L
.35172 .27033 L
.35298 .26998 L
.35416 .26986 L
.35527 .27 L
.35644 .27046 L
.3577 .27132 L
.35887 .27245 L
.35997 .2738 L
.36206 .2769 L
.36684 .28458 L
Mistroke
.36821 .28635 L
.36951 .28766 L
.37067 .28851 L
.37193 .28907 L
.37261 .28922 L
.37335 .28928 L
.37412 .28923 L
.37484 .28909 L
.37613 .28869 L
.37752 .28813 L
.37891 .28756 L
.38023 .28714 L
.38142 .28693 L
.38271 .28695 L
.38393 .28726 L
.38504 .2878 L
.38627 .28867 L
.38756 .28987 L
.39211 .29536 L
.39451 .29807 L
.39585 .29924 L
.39707 .30004 L
.39776 .30036 L
.39851 .3006 L
.39922 .30073 L
.39988 .30076 L
.40114 .30062 L
.40178 .30046 L
.40249 .30022 L
.40517 .299 L
.4065 .29838 L
.40772 .29792 L
.4084 .29773 L
.40913 .29759 L
.40993 .29753 L
.41066 .29757 L
.41132 .29768 L
.41204 .29789 L
.41334 .29849 L
.41457 .2993 L
.41592 .3004 L
.41864 .303 L
.42116 .30531 L
.42227 .30613 L
.4235 .30684 L
.42472 .3073 L
.42602 .3075 L
.4267 .30749 L
.42743 .3074 L
.42812 .30724 L
Mistroke
.42876 .30704 L
.42998 .30652 L
.43131 .30583 L
.43373 .3045 L
.43494 .30395 L
.43607 .30356 L
.43738 .30332 L
.43856 .30332 L
.43969 .30353 L
.44072 .30389 L
.44185 .30445 L
.44305 .30522 L
.44786 .30887 L
.44925 .30973 L
.45056 .31032 L
.45174 .31064 L
.45303 .31074 L
.4537 .31069 L
.45445 .31055 L
.45523 .31032 L
.45597 .31004 L
.45869 .30856 L
.46001 .30775 L
.46143 .30694 L
.46274 .30632 L
.46398 .30591 L
.46516 .30571 L
.46644 .30573 L
.4676 .30595 L
.46867 .30632 L
.46986 .3069 L
.47116 .30768 L
.4738 .30946 L
.47512 .31029 L
.47638 .31095 L
.47707 .31124 L
.47782 .31149 L
.47914 .31173 L
.4804 .31171 L
.4811 .3116 L
.48174 .31144 L
.48298 .31097 L
.48414 .31038 L
.48847 .30771 L
.48952 .30715 L
.49065 .30668 L
.49188 .30633 L
.49303 .30621 L
.49368 .30623 L
.49438 .30631 L
Mistroke
.49565 .30665 L
.49689 .30717 L
.49804 .30779 L
.50028 .3092 L
.50264 .31063 L
.5038 .31118 L
.50507 .3116 L
.50622 .3118 L
.50728 .31181 L
.50855 .3116 L
.5097 .31123 L
.51034 .31095 L
.51103 .3106 L
.51228 .30988 L
.51457 .30842 L
.51582 .30767 L
.51699 .30708 L
.51799 .30669 L
.51906 .3064 L
.52024 .30629 L
.52133 .30636 L
.5226 .30668 L
.52331 .30695 L
.52396 .30725 L
.52639 .30871 L
.52904 .31048 L
.53044 .31129 L
.5312 .31165 L
.5319 .31193 L
.53319 .31226 L
.53387 .31233 L
.5346 .31234 L
.5359 .31215 L
.53708 .31178 L
.53827 .31124 L
.53958 .31053 L
.54194 .30909 L
.54314 .30842 L
.54429 .30789 L
.5456 .30747 L
.54681 .3073 L
.54794 .30734 L
.54899 .30756 L
.55015 .308 L
.55138 .30867 L
.55637 .3124 L
.55774 .31334 L
.55848 .31377 L
.55918 .31411 L
.56042 .31454 L
Mistroke
.56107 .31467 L
.56177 .31474 L
.5625 .31473 L
.5633 .31462 L
.56405 .31444 L
.56474 .31421 L
.56605 .31364 L
.56745 .3129 L
.56878 .31216 L
.57021 .31143 L
.57087 .31114 L
.57156 .31089 L
.5728 .31059 L
.57398 .31053 L
.57507 .31068 L
.57627 .31109 L
.57755 .31179 L
.57897 .31283 L
.5803 .31401 L
.5828 .31644 L
.58503 .31843 L
.58628 .31932 L
.58743 .31993 L
.58807 .32018 L
.58878 .32037 L
.59006 .3205 L
.59133 .32036 L
.59252 .32004 L
.5953 .3188 L
.59667 .31816 L
.59792 .31767 L
.59906 .31737 L
.60027 .31727 L
.60148 .31743 L
.60217 .31765 L
.60281 .31793 L
.60397 .31865 L
.60507 .31956 L
.60713 .32175 L
.60953 .32474 L
.61175 .32741 L
.61396 .32954 L
.61508 .3303 L
.61631 .33085 L
.61754 .33111 L
.61823 .33113 L
.61886 .33108 L
.62003 .33083 L
.62126 .3304 L
.6225 .32989 L
Mistroke
.62384 .32935 L
.62511 .32895 L
.62628 .32877 L
.62733 .32881 L
.62849 .32912 L
.6297 .32976 L
.63083 .33068 L
.63215 .33212 L
.6334 .3338 L
.63575 .3375 L
.63832 .34173 L
.63972 .34382 L
.64104 .34548 L
.64208 .34653 L
.64321 .34738 L
.64446 .34795 L
.64561 .34816 L
.64659 .34813 L
.64767 .3479 L
.64879 .34752 L
.64984 .3471 L
.65108 .34662 L
.65226 .34629 L
.65332 .34618 L
.65447 .34633 L
.65572 .34688 L
.65635 .34733 L
.65704 .34796 L
.65827 .34943 L
.65942 .3512 L
.6982 .40824 L
.69942 .40883 L
.70073 .40858 L
.70196 .40762 L
.7031 .40626 L
.70443 .40435 L
.70584 .4023 L
.70702 .40087 L
.70832 .39996 L
.70906 .39986 L
.70975 .4001 L
.71053 .40082 L
.71128 .40197 L
.71196 .40346 L
.7126 .40521 L
.71404 .41051 L
.71526 .41637 L
.71662 .42404 L
.71935 .44166 L
.72178 .45629 L
Mistroke
.723 .46192 L
.7237 .4643 L
.72434 .4659 L
.72505 .46689 L
.7257 .46701 L
.72644 .46614 L
.72715 .46428 L
.72838 .45843 L
.72907 .45363 L
.72972 .44823 L
.73197 .42206 L
.73444 .38185 L
.73944 .28111 L
.74194 .2327 L
.74326 .21037 L
.74466 .19003 L
.74601 .17429 L
.74723 .16353 L
.74846 .15611 L
.74961 .15217 L
.75075 .15098 L
.75194 .15232 L
.75296 .15527 L
.75408 .16007 L
.75658 .17466 L
.7589 .18982 L
.7602 .1977 L
.76162 .20512 L
.76295 .21071 L
.76419 .21448 L
.7653 .21672 L
.76652 .21798 L
.7678 .2181 L
.769 .21733 L
.7715 .21408 L
.77287 .21208 L
.77416 .21048 L
.7749 .20982 L
.77569 .20935 L
.77642 .20918 L
.77708 .20928 L
.7784 .21018 L
.77907 .21101 L
.7798 .21219 L
.78115 .21509 L
.78239 .21841 L
.78516 .2273 L
.78776 .23573 L
.79017 .24205 L
.79135 .24432 L
Mistroke
.7926 .24607 L
.79385 .24714 L
.79456 .24747 L
.79523 .2476 L
.79644 .2475 L
.79754 .2471 L
.79876 .24646 L
.80003 .24574 L
.80119 .24518 L
.80225 .24486 L
.80346 .24482 L
.80461 .24517 L
.80568 .24588 L
.80666 .24687 L
.80774 .24832 L
.80888 .25022 L
.81393 .26116 L
.81633 .26605 L
.8175 .26799 L
.81855 .26942 L
.81967 .27057 L
.82087 .27137 L
.82217 .2718 L
.82339 .27182 L
.82454 .27159 L
.8256 .27123 L
.82683 .27074 L
.82798 .2703 L
.82912 .26999 L
.83033 .26986 L
.83103 .26992 L
.83168 .27006 L
.83291 .27062 L
.83421 .27159 L
.83541 .27285 L
.83812 .27668 L
.84032 .28034 L
.8427 .28411 L
.84379 .28561 L
.84494 .28694 L
.84592 .28785 L
.847 .28858 L
.84812 .28906 L
.84932 .28927 L
.85045 .28921 L
.85148 .28897 L
.8527 .28855 L
.85402 .288 L
.85528 .2875 L
.85642 .28714 L
Mistroke
.85764 .28692 L
.85879 .28694 L
.86 .28722 L
.86132 .28786 L
.86248 .28869 L
.8637 .28983 L
.86591 .29235 L
.86849 .29559 L
.86985 .29718 L
.87128 .29861 L
.87253 .2996 L
.87325 .30003 L
.87391 .30034 L
.87508 .30068 L
.87633 .30076 L
.87762 .30056 L
.87835 .30034 L
.87902 .30009 L
.88156 .2989 L
.88276 .29835 L
.88387 .29793 L
.88504 .29764 L
.88633 .29754 L
.88701 .29759 L
.88775 .29774 L
.88845 .29797 L
.88911 .29826 L
.89034 .29899 L
.89165 .3 L
.89444 .30261 L
.89596 .30408 L
.89738 .30533 L
.89871 .30629 L
.89993 .30695 L
.90063 .30721 L
.90129 .30739 L
.90198 .30749 L
.90274 .3075 L
.90398 .30733 L
.9053 .3069 L
.90642 .30639 L
.90766 .30573 L
.91043 .30425 L
.91118 .30392 L
.91198 .30364 L
.91266 .30346 L
.9134 .30333 L
.91411 .30329 L
.91475 .30332 L
.9155 .30343 L
Mistroke
.9162 .30362 L
.91744 .30413 L
.91879 .30491 L
.92389 .30875 L
.92513 .30955 L
.92646 .31021 L
.92722 .31048 L
.92792 .31064 L
.92862 .31073 L
.92929 .31074 L
.93045 .3106 L
.93169 .31023 L
.93286 .30971 L
.93392 .30914 L
.93632 .30768 L
.9376 .30695 L
.9383 .3066 L
.93896 .30631 L
.94019 .30591 L
.94131 .30571 L
.94236 .3057 L
.9435 .30588 L
.94471 .30626 L
.94599 .30687 L
.94829 .3083 L
.95025 .30963 L
.95237 .31085 L
.95358 .31135 L
.95468 .31164 L
.95574 .31175 L
.95686 .31168 L
.95807 .31139 L
.95918 .31096 L
.96045 .31031 L
.96165 .30959 L
.96381 .30822 L
.96499 .30752 L
.9661 .30697 L
.9673 .30652 L
.96862 .30625 L
.96974 .30622 L
.97094 .30639 L
.97162 .30657 L
.97235 .30684 L
.97369 .30748 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4Ooo
nfX3o`00O`[ooo]Z1Ol00023oookJPCo0000UooonfX00:;ooo]Z1Ol0001YoookJP?o001o2_oonfX5
o`0008;ooo]Z1_l0002FoookJP00X_oonfX6o`0005Sooo]Z2_l007l6oookJP?o001o2_oonfX5o`00
08;ooo]Z1_l0002FoookJP00X_oonfX6o`0005Sooo]Z2_l007l6oookJP?o001o2_oonfX6o`00087o
oo]Z1_l0002FoookJP00XOoonfX7o`0006Sooo]Z0ol007l:oookJPGo0000P_oonfX6o`0009Kooo]Z
002QoookJPOo0000J?oonfX3o`00O`[ooo]Z1Ol00022oookJPOo0000UOoonfX00:7ooo]Z2?l0001W
oookJP?o001o2_oonfX5o`00087ooo]Z2?l0002EoookJP00XOoonfX8o`0006Oooo]Z0ol007l:oook
JPGo0000POoonfX8o`0009Gooo]Z002QoookJPSo0000I?oonfX6o`00O`[ooo]Z1Ol00021oookJPSo
0000UOoonfX00:7ooo]Z2?l0001ToookJPKo001o2_oonfX5o`00087ooo]Z2?l0002EoookJP00X?oo
nfX:o`0006Gooo]Z1?l007l:oookJPGo0000POoonfX9o`0009Cooo]Z002PoookJP[o0000I_oonfX3
o`00O`[ooo]Z1Ol00020oookJP[o0000U?oonfX00:3ooo]Z2_l0001coookJPGo0000P?oonfX:o`00
09Cooo]Z002PoookJPCo00000_oonfX4o`0007?ooo]Z1Ol00020oookJPGo000000?ooo]Zo`000?l0
00000_l0002DoookJP00X?oonfX4o`0000;ooo]Z1?l0001coookJPGo0000P?oonfX4o`0000;ooo]Z
1?l0002DoookJP00X?oonfX4o`0000;ooo]Z1?l0001coookJPGo0000P?oonfX4o`0000;ooo]Z1?l0
002DoookJP00X?oonfX4o`0000;ooo]Z1Ol0001boookJPGo0000P?oonfX4o`0000;ooo]Z1?l0002D
oookJP00X?oonfX4o`0000;ooo]Z1Ol0001boookJPGo0000P?oonfX4o`0000;ooo]Z1?l0002Doook
JP00X?oonfX4o`0000;ooo]Z1Ol0001boookJPGo0000P?oonfX4o`0000;ooo]Z1Ol0002CoookJP00
X?oonfX4o`0000?ooo]Z1?l0001boookJPGo0000P?oonfX4o`0000;ooo]Z1Ol0002CoookJP00X?oo
nfX4o`0000?ooo]Z1?l0001boookJPGo0000P?oonfX4o`0000;ooo]Z1Ol0002CoookJP00X?oonfX4
o`0000?ooo]Z1?l0001boookJPGo0000P?oonfX4o`0000?ooo]Z1?l0002CoookJP00X?oonfX4o`00
00?ooo]Z1?l0001boookJPGo0000P?oonfX4o`0000?ooo]Z1?l0002CoookJP00WooonfX5o`0000?o
oo]Z1Ol0001aoookJPGo0000P?oonfX4o`0000?ooo]Z1?l0002CoookJP00WooonfX5o`0000?ooo]Z
1Ol0001aoookJPGo0000P?oonfX4o`0000?ooo]Z1Ol0002BoookJP00WooonfX5o`0000?ooo]Z1Ol0
001aoookJPGo0000P?oonfX4o`0000?ooo]Z1Ol0002BoookJP00WooonfX4o`0000Gooo]Z1?l0001a
oookJPGo0000P?oonfX4o`0000?ooo]Z1Ol0002BoookJP00WooonfX4o`0000Gooo]Z1?l0001aoook
JPGo0000P?oonfX4o`0000Cooo]Z1?l0002BoookJP00WooonfX4o`0000Gooo]Z1?l0001aoookJPGo
0000OooonfX5o`0000Cooo]Z1?l0002BoookJP00WooonfX4o`0000Gooo]Z1Ol0001`oookJPGo0000
OooonfX5o`0000Cooo]Z1Ol0002AoookJP00WooonfX4o`0000Gooo]Z1Ol0001`oookJPGo0000Oooo
nfX5o`0000Cooo]Z1Ol0002AoookJP00WooonfX4o`0000Gooo]Z1Ol0001`oookJPGo0000OooonfX4
o`0000Gooo]Z1Ol0002AoookJP00WooonfX4o`0000Kooo]Z1?l00003oookJPKo0000IooonfX5o`00
07oooo]Z1?l00006oookJPGo00000_oonfX6o`0008Sooo]Z002OoookJPCo00001_oonfX4o`0000;o
oo]Z2?l0001VoookJPGo0000OooonfX4o`0000Kooo]Z1Ol000000ooonf[o0000o`000005o`0008So
oo]Z002OoookJPCo00001_oonfX5o`000003oookJ_l0003o000000Ko0000I_oonfX5o`0007oooo]Z
1?l00006oookJPGo000000?ooo]Zo`000?l000001_l00027oookJP00WooonfX4o`0000Kooo]Z3_l0
001VoookJPGo0000OooonfX4o`0000Oooo]Z3Ol00027oookJP00WooonfX4o`0000Kooo]Z3_l0001V
oookJPGo0000OooonfX4o`0000Oooo]Z3Ol00027oookJP00WooonfX4o`0000Oooo]Z3_l0001Uoook
JPGo0000OooonfX4o`0000Oooo]Z3_l00026oookJP00W_oonfX5o`0000Oooo]Z2?l000000ooonf[o
0000o`000004o`0006Cooo]Z1Ol0001ooookJPCo00001ooonfX8o`000003oookJ_l0003o000000?o
0000Q_oonfX009kooo]Z1Ol00008oookJPKo00000_oonfX6o`0006Cooo]Z1Ol0001ooookJPCo0000
2?oonfX6o`0000;ooo]Z1_l00025oookJP00W_oonfX5o`0000Sooo]Z1Ol00004oookJPKo0000Hooo
nfX5o`0007kooo]Z1Ol00008oookJPGo00001?oonfX5o`0008Gooo]Z002NoookJPCo00004ooonfX6
o`0004Cooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001noookJPGo00004OoonfX5
o`0008Gooo]Z002NoookJPCo00004ooonfX6o`0004?ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`Wooo]Z1Ol0001noookJPGo00004_oonfX5o`0008Cooo]Z002NoookJPCo00005?oonfX6o`0004;o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oo
nf[o001oo`00Ool007l9oookJPGo0000O_oonfX4o`0001?ooo]Z1Ol00024oookJP00W_oonfX4o`00
01Gooo]Z1_l0000doookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Sooo]Z1Ol0001noookJPCo00004ooonfX5o`0008Cooo]Z002NoookJPCo00005OoonfX7o`0003?o
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000OOoonfX4o`0001Co
oo]Z1Ol00023oookJP00W_oonfX4o`0001Kooo]Z1_l0000ooookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l8oookJPGo0000O_oonfX4o`0001Cooo]Z1Ol00023oookJP00W_oonfX4o`0001Oooo]Z1_l0
000noookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0007kooo]Z1?l0
000DoookJPGo0000PooonfX009kooo]Z1?l0000HoookJPKo0000?OoonfX3o`00O`?ooo]Z0ol007l7
oookJPOo001o2OoonfX5o`0007kooo]Z1?l0000EoookJPCo0000PooonfX009kooo]Z1?l0000Hoook
JPKo0000?OoonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0007kooo]Z1?l0000Eoook
JPGo0000P_oonfX009kooo]Z1?l0000IoookJPKo0000??oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o3_oonfX5o`0007kooo]Z1?l0000EoookJPGo0000P_oonfX009kooo]Z1?l0000JoookJPSo0000
>_oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000O_oonfX4o`0001Go
oo]Z1_l000000ooonf[o0000o`000004o`0007[ooo]Z002NoookJPCo00006_oonfX9o`0003Wooo]Z
1ol007l9oookJPOo001o2?oonfX5o`0007kooo]Z1?l0000FoookJPgo0000NOoonfX009kooo]Z1?l0
000KoookJPWo0000>OoonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000O_oonfX4o`0001Kooo]Z3_l0
001hoookJP00W_oonfX4o`0001cooo]Z2?l0001GoookJPGo0000O_oonfX4o`0001Oooo]Z3Ol0001h
oookJP00W_oonfX4o`0001oooo]Z1_l0001FoookJPGo0000O_oonfX4o`0001Sooo]Z3?l0001hoook
JP00W_oonfX4o`00023ooo]Z1Ol0001FoookJPGo0000O_oonfX4o`0001Wooo]Z1Ol00002oookJPGo
0000MooonfX009kooo]Z1?l0000PoookJPKo0000EOoonfX5o`0007kooo]Z1?l0000PoookJPGo0000
MooonfX009kooo]Z1?l0000QoookJPGo0000EOoonfX5o`0007kooo]Z1?l0000PoookJPKo0000M_oo
nfX009gooo]Z1Ol0000QoookJPKo0000E?oonfX5o`0007gooo]Z1Ol0000QoookJPGo0000M_oonfX0
09gooo]Z1Ol0000RoookJPGo0000E?oonfX5o`0007gooo]Z1Ol0000QoookJPKo0000MOoonfX009go
oo]Z1Ol0000RoookJPKo0000DooonfX5o`0007gooo]Z1Ol0000RoookJPGo0000MOoonfX009gooo]Z
1?l0000ToookJPGo0000DooonfX5o`0007gooo]Z1?l0000SoookJPKo0000M?oonfX009gooo]Z1?l0
000ToookJPKo0000D_oonfX5o`0007gooo]Z1?l0000ToookJPGo0000M?oonfX009gooo]Z1?l0000U
oookJPGo0000D_oonfX5o`0007gooo]Z1?l0000ToookJPKo0000LooonfX009gooo]Z1?l0000Uoook
JPgo0000B_oonfX5o`0007gooo]Z1?l0000UoookJPgo0000JooonfX002;ooo]Z0ol007meoookJP?o
001o1?l00002oookJP?o001o0ooonfX5o`00OaWooo]Z3_l00018oookJPGo0000M?oonfX5o`00O`Co
oo]Z1?l00002oookJPGo001o7_oonfX?o`0004Wooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z
1?l007l4o`0000;ooo]Z0ol007l2oookJPOo001o6?oonfX>o`0004Sooo]Z1Ol0001coookJPOo001o
0ooonfX4o`000003oookJ_l007oo001o00Go001o7_oonfX>o`0004Wooo]Z0ol007lMoookJP008_oo
nfX3o`00OgCooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00OaWooo]Z3Ol00018oookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z1?l00004o`00O`04oookJ_l007oo001oo`00Oaoooo]Z3_l00018oook
JP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l2oookJPCo
00001_oonfX3o`00O`?ooo]Z0ol007lIoookJPKo000000?ooo]Zo`000?l000001?l00017oookJPGo
0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00000ol007l3oookJP?o001o7ooonfX6o`000003
oookJ_l0003o000000Co0000B?oonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z
2_l007l2oookJP?o001o0_oonfX4o`0000cooo]Z0ol007lQoookJPGo0000AooonfX5o`0007;ooo]Z
0ol007l3oookJP?o001o0_oonfX4o`0000Kooo]Z0ol007lWoookJPKo0000AooonfX3o`00Oagooo]Z
000RoookJP?o001oLooonfX3o`00O`;ooo]Z1?l0000<oookJP?o001o8OoonfX6o`0004Kooo]Z1Ol0
001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o:?oonfX5o`0004Oooo]Z0ol0
07lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo00001ooonfX2o`00O`;ooo]Z1?l007lR
oookJPKo0000AOoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo
001o00;ooo]Z1?l007lXoookJPKo0000A_oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00
O`;ooo]Z1?l00007oookJPOo001o8ooonfX7o`0004Cooo]Z1Ol0001boookJP?o001o0ooonfX3o`00
O`;ooo]Z1?l000000ooonf[o001oo`00O`05o`00Ob[ooo]Z1_l00015oookJP?o001o7OoonfX002;o
oo]Z0ol007mcoookJP?o001o0_oonfX4o`0000Oooo]Z1_l007lUoookJPOo000000?ooo]Zo`000?l0
00001Ol0000koookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Zo`00Ool0
07l01?l007l[oookJPOo00000_oonfX6o`0003cooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z
0ol007l2oookJPCo00001ooonfX2o`00Ob[ooo]Z3ol0000joookJPGo0000L_oonfX3o`00O`?ooo]Z
0ol007l2oookJPCo000000?ooo]Zo`00Ool007l0<?oonfX?o`0003Sooo]Z1_l007lMoookJP007ooo
nfX6o`00OgCooo]Z0ol007l00ooonf[o0000o`000002o`0000Oooo]Z0_l007l[oookJPoo0000>Ooo
nfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJPCo000000?ooo]Zo`00Ool007l0
<OoonfX?o`0003Oooo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z1?l007l4o`0000Sooo]Z1ol0
07lVoookJPoo0000>?oonfX5o`0007?ooo]Z1ol007l3oookJPCo00000_oonfX7o`00Obcooo]Z3ol0
000hoookJPCo001o7OoonfX002;ooo]Z0ol007meoookJP;o001o1Ol00008oookJPOo001o9ooonfX?
o`0003Oooo]Z1Ol0001doookJPGo001o1?oonfX4o`0000;ooo]Z1ol007l/oookJQ3o0000>?oonfX3
o`00Oagooo]Z002LoookJPGo0000?ooonfX7o`0003Kooo]Z1Ol0001moookJPCo0000?ooonfX7o`00
05Oooo]Z002LoookJPGo0000@?oonfX7o`0000;ooo]Z2?l0000[oookJPGo0000OOoonfX4o`00043o
oo]Z1ol00002oookJPSo0000C?oonfX009cooo]Z1?l00012oookJQ7o0000:_oonfX5o`0007cooo]Z
1Ol00011oookJQ7o0000BooonfX009cooo]Z1?l00013oookJQ7o0000:OoonfX5o`0007cooo]Z1Ol0
0012oookJQ7o0000B_oonfX009cooo]Z1?l00014oookJQ7o00001OoonfX7o`0001cooo]Z1Ol0001l
oookJPGo0000@_oonfXCo`0000?ooo]Z2?l0000moookJP00W?oonfX4o`0004Gooo]Z2Ol000000ooo
nf[o0000o`000006o`000003oookJ_l0003o000000Wo00001_oonfX6o`0000kooo]Z1Ol0001loook
JPCo0000AOoonfX9o`000003oookJ_l0003o000000Go00000_oonfX;o`0000Oooo]Z1Ol0000_oook
JP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oo
nf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`00
0?oo00009Ol0000?oookJP007?oonfX9o`0000Gooo]Z2_l00004oookJQCo0000D?oonfX4o`0006;o
oo]Z1ol00007oookJPSo00001OoonfX:o`0000Kooo]Z2Ol00005oookJQ?o0000D?oonfX4o`0006;o
oo]Z1ol00007oookJPWo00001_oonfX00ol0003ooo]ZoookJP0LoookJP007_oonfX5o`0000Wooo]Z
1_l00007oookJQCo00000_oonfX8o`0004Gooo]Z1?l0001boookJPCo00001ooonfX8o`0000Wooo]Z
1ol00007oookJP[o000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000007o`0004Gooo]Z
1?l0001boookJPCo0000:?oonfX003_ooo]Z1ol00005oookJQ7o0000A?oonfX4o`0007gooo]Z1Ol0
000KoookJPSo00001?oonfXAo`0004Cooo]Z1?l0002NoookJP00B?oonfXAo`0004?ooo]Z1?l0001m
oookJPGo0000:?oonfXAo`0004?ooo]Z1?l0002NoookJP00BOoonfX@o`0004?ooo]Z1?l0001moook
JPGo0000:OoonfX@o`0004?ooo]Z1?l0002NoookJP00B_oonfX8o`0000;ooo]Z1ol00011oookJPCo
0000OOoonfX5o`0002[ooo]Z1ol00003oookJPOo0000@OoonfX4o`0009kooo]Z001EoookJPOo0000
@?oonfX4o`0007gooo]Z1Ol0000eoookJPOo0000@?oonfX4o`0009kooo]Z001EoookJQ3o0000=ooo
nfX4o`0007gooo]Z1Ol0000eoookJQ3o0000=ooonfX4o`0009kooo]Z001FoookJQ3o0000=OoonfX5
o`0007gooo]Z1Ol0000foookJQ3o0000=_oonfX4o`0009kooo]Z001HoookJPoo0000=?oonfX5o`00
07gooo]Z1Ol0000hoookJPoo0000=?oonfX5o`0009kooo]Z001HoookJQ3o0000<ooonfX5o`0007go
oo]Z1Ol0000ioookJPoo0000<ooonfX5o`0009kooo]Z001IoookJPSo000000?ooo]Zo`000?l00000
1?l0000coookJPCo0000O_oonfX5o`0003Wooo]Z2?l000000ooonf[o0000o`000005o`0003;ooo]Z
1Ol0002NoookJP00HooonfX6o`0003;ooo]Z1?l0001noookJPGo0000@ooonfX6o`0003;ooo]Z1?l0
002OoookJP00I?oonfX5o`0003;ooo]Z1?l0001noookJPGo0000A?oonfX6o`00037ooo]Z1?l0002O
oookJP00I?oonfX5o`0003;ooo]Z1?l0001noookJPGo0000AOoonfX5o`00037ooo]Z1?l0002Ooook
JP00IOoonfX6o`00033ooo]Z1?l0001noookJPGo0000AOoonfX6o`00033ooo]Z1?l0002OoookJP00
IOoonfX7o`000003oookJ_l0003o000000Co0000:?oonfX4o`0007kooo]Z1Ol00016oookJPKo0000
00?ooo]Zo`000?l000001?l0000XoookJPCo0000WooonfX006Gooo]Z3ol0000WoookJPCo0000O_oo
nfX5o`0004Kooo]Z3_l0000WoookJPCo0000WooonfX006Kooo]Z3ol0000VoookJPCo0000O_oonfX5
o`0004Oooo]Z3_l0000VoookJPCo0000WooonfX006Sooo]Z3_l0000UoookJPCo0000O_oonfX5o`00
04Oooo]Z3_l0000VoookJPCo0000WooonfX006Sooo]Z3_l0000UoookJPCo0000O_oonfX5o`0004Wo
oo]Z3?l0000VoookJPCo0000WooonfX0077ooo]Z1_l0000ToookJPCo0000O_oonfX5o`00057ooo]Z
1Ol0000UoookJPCo0000WooonfX007;ooo]Z1Ol0000ToookJPCo0000O_oonfX5o`00057ooo]Z1_l0
000ToookJPCo0000WooonfX007;ooo]Z1Ol0000ToookJPCo0000O_oonfX5o`00057ooo]Z1_l0000T
oookJPCo0000WooonfX007?ooo]Z1Ol0000SoookJPCo0000O_oonfX5o`0005;ooo]Z1_l0000Soook
JPCo0000WooonfX007?ooo]Z1Ol0000SoookJPCo0000O_oonfX5o`0005?ooo]Z1_l0000RoookJPCo
0000WooonfX007?ooo]Z1Ol0000SoookJPCo0000O_oonfX5o`0005?ooo]Z1_l0000RoookJPCo0000
WooonfX007Cooo]Z1Ol0000RoookJPCo0000O_oonfX5o`0005Cooo]Z1_l0000QoookJPCo0000Wooo
nfX007Cooo]Z1_l0000QoookJPCo0000O_oonfX5o`0005Gooo]Z1_l0000OoookJPGo0000WooonfX0
07Cooo]Z1_l00002oookJPKo00006OoonfX4o`0007kooo]Z1Ol0001EoookJPKo00007ooonfX5o`00
09oooo]Z001eoookJPko00005ooonfX5o`0007kooo]Z1Ol0001FoookJPKo00007_oonfX5o`0009oo
oo]Z001foookJPgo00005ooonfX5o`0007kooo]Z1Ol0001GoookJPKo00007OoonfX4o`000:3ooo]Z
001foookJPgo00005ooonfX5o`0007kooo]Z1Ol0001GoookJPKo00007OoonfX4o`000:3ooo]Z001g
oookJPgo00005_oonfX4o`0007oooo]Z1Ol0001HoookJPKo00007?oonfX4o`000:3ooo]Z001hoook
JPKo000000?ooo]Zo`000?l000000ol0000FoookJPCo0000OooonfX5o`0005Wooo]Z1_l0000Koook
JPCo0000X?oonfX007oooo]Z1_l0000EoookJPCo0000HOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o2_oonfX5o`0005Wooo]Z1ol0000JoookJPCo0000X?oonfX0083ooo]Z1Ol0000EoookJPCo0000
H?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0005[ooo]Z1_l0000JoookJPCo0000
X?oonfX0083ooo]Z1Ol0000EoookJPCo0000H?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001KoookJPKo
00006OoonfX4o`000:3ooo]Z0021oookJPGo00005?oonfX4o`0005oooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000G?oonfX6o`0001Sooo]Z1?l0002PoookJP00POoo
nfX5o`0001Cooo]Z1?l0001OoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000Fooo
nfX6o`0001Sooo]Z1?l0002PoookJP00POoonfX5o`0001Cooo]Z1?l0001OoookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l8oookJPGo0000GOoonfX6o`0001Oooo]Z1?l0002PoookJP00P_oonfX5o`00
01?ooo]Z1?l0001OoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`00
05kooo]Z1_l0000FoookJPCo0000X?oonfX008;ooo]Z1Ol0000CoookJPCo0000GooonfX3o`00O`?o
oo]Z0ol007l7oookJPOo001o2OoonfX5o`0005kooo]Z1_l0000FoookJPCo0000X?oonfX008;ooo]Z
1Ol0000CoookJPCo0000GooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0005oooo]Z
1_l0000EoookJPCo0000X?oonfX008?ooo]Z1Ol0000BoookJPCo0000GooonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o3_oonfX5o`00063ooo]Z1_l0000DoookJPCo0000X?oonfX008?ooo]Z1Ol00004
oookJPCo00002_oonfX4o`00063ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oo
nfX5o`00063ooo]Z1_l00006oookJPGo00002OoonfX4o`000:3ooo]Z0023oookJPGo00000ooonfX6
o`0000Wooo]Z1?l0001PoookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001QoookJPKo00001?oonfX7
o`0000Sooo]Z1?l0002PoookJP00Q?oonfX5o`0000;ooo]Z1ol00007oookJPGo0000HOoonfX5o`00
O`[ooo]Z1ol007l8oookJPGo0000H_oonfX6o`0000?ooo]Z1ol00007oookJPGo0000X?oonfX008Co
oo]Z1Ol000000ooonf[o0000o`000006o`0000Oooo]Z1Ol0001ooookJPGo0000H_oonfX6o`0000;o
oo]Z2?l00007oookJPGo0000X?oonfX008Cooo]Z3_l00007oookJPGo0000OooonfX5o`0006?ooo]Z
3ol00007oookJPGo0000X?oonfX008Gooo]Z3Ol00007oookJPCo0000P?oonfX5o`0006Cooo]Z3ol0
0006oookJPCo0000XOoonfX008Gooo]Z3_l00006oookJPCo0000P?oonfX5o`0006Cooo]Z3ol00006
oookJPCo0000XOoonfX008Kooo]Z1ol000000ooonf[o0000o`000003o`0000Kooo]Z1?l00020oook
JPGo0000IOoonfX8o`000003oookJ_l0003o000000?o00001_oonfX4o`000:7ooo]Z0026oookJPKo
00000_oonfX5o`0000Kooo]Z1?l00020oookJPGo0000I_oonfX6o`0000?ooo]Z1Ol00005oookJPCo
0000XOoonfX008oooo]Z1Ol00005oookJPCo0000P?oonfX5o`0006oooo]Z1Ol00005oookJPCo0000
XOoonfX008oooo]Z1Ol00005oookJPCo0000P?oonfX5o`0006oooo]Z1Ol00005oookJPCo0000XOoo
nfX008oooo]Z1Ol00005oookJPCo0000P?oonfX5o`00073ooo]Z1?l00005oookJPCo0000XOoonfX0
093ooo]Z1?l00005oookJPCo0000P?oonfX5o`00073ooo]Z1?l00005oookJPCo0000XOoonfX0093o
oo]Z1?l00004oookJPGo0000P?oonfX5o`00073ooo]Z1?l00005oookJPCo0000XOoonfX0093ooo]Z
1Ol00003oookJPGo0000P?oonfX5o`00073ooo]Z1?l00005oookJPCo0000XOoonfX0093ooo]Z1Ol0
0003oookJPGo0000P?oonfX5o`00073ooo]Z1?l00005oookJPCo0000XOoonfX0093ooo]Z1Ol00003
oookJPCo0000POoonfX5o`00073ooo]Z1Ol00003oookJPGo0000XOoonfX0097ooo]Z1?l00003oook
JPCo0000POoonfX5o`00073ooo]Z1Ol00003oookJPGo0000XOoonfX0097ooo]Z1?l00003oookJPCo
0000POoonfX5o`00073ooo]Z1Ol00003oookJPGo0000XOoonfX0097ooo]Z1?l00003oookJPCo0000
POoonfX5o`00077ooo]Z1?l00003oookJPCo0000X_oonfX0097ooo]Z1Ol00002oookJPCo0000POoo
nfX5o`00077ooo]Z1?l00003oookJPCo0000X_oonfX0097ooo]Z1Ol00002oookJPCo0000POoonfX5
o`00077ooo]Z1Ol00002oookJPCo0000X_oonfX0097ooo]Z1Ol00002oookJPCo0000POoonfX5o`00
077ooo]Z1Ol00002oookJPCo0000X_oonfX009;ooo]Z1?l00002oookJPCo0000POoonfX5o`00077o
oo]Z1Ol000000ooonf[o0000o`000003o`000:;ooo]Z002BoookJPCo00000_oonfX4o`00087ooo]Z
1Ol0001boookJPCo000000?ooo]Zo`000?l000000ol0002RoookJP00T_oonfX4o`0000;ooo]Z1?l0
0021oookJPGo0000L_oonfX4o`000003oookJ_l0003o000000?o0000X_oonfX009;ooo]Z1Ol00000
0ooonf[o0000o`000002o`00087ooo]Z1Ol0001boookJPCo000000?ooo]Zo`000?l000000_l0002S
oookJP00T_oonfX:o`00087ooo]Z1Ol0001boookJPCo000000?ooo]Zo`000?l000000_l0002Soook
JP00T_oonfX:o`00087ooo]Z1Ol0001boookJPWo0000XooonfX009?ooo]Z2Ol00021oookJPGo0000
L_oonfX9o`000:?ooo]Z002CoookJPSo0000P_oonfX5o`0007;ooo]Z2Ol0002SoookJP00TooonfX8
o`0008;ooo]Z1Ol0001coookJPSo0000XooonfX009?ooo]Z2?l0001eoookJP?o001o2_oonfX5o`00
07?ooo]Z2?l0002SoookJP00TooonfX8o`0007Gooo]Z0ol007l:oookJPGo0000LooonfX8o`000:?o
oo]Z002CoookJPSo0000MOoonfX3o`00O`[ooo]Z1Ol0001coookJPSo0000XooonfX009?ooo]Z2?l0
001eoookJP?o001o2_oonfX5o`0007?ooo]Z2?l0002SoookJP00TooonfX8o`0007Gooo]Z0ol007l:
oookJPKo0000LooonfX7o`000:?ooo]Z002DoookJPOo0000MOoonfX3o`00O`[ooo]Z1Ol0001doook
JPKo0000Y?oonfX009Cooo]Z1_l0001foookJP?o001o2_oonfX5o`0007Cooo]Z1_l0002ToookJP00
UOoonfX5o`0007Kooo]Z0ol007l:oookJPGo0000MOoonfX5o`000:Cooo]Z002EoookJPCo0000Mooo
nfX3o`00O`[ooo]Z1Ol0001eoookJPCo0000YOoonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003o
oookJQoooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX@oookJPCo
001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z
003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8
oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooook
JQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6
o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooook
JQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z
1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol0
07l8oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0
003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00oooonfX>oook
JPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQko
oo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00
O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00
oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;Ooo
nfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;o
oo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30827 L
.02605 .30763 L
.02721 .30706 L
.02846 .30661 L
.02961 .3064 L
.03068 .30638 L
.0317 .30654 L
.03279 .30687 L
.03395 .30739 L
.0352 .3081 L
.03746 .30956 L
.03884 .31041 L
.04016 .31107 L
.04133 .3115 L
.04262 .31175 L
.04326 .31177 L
.04396 .31173 L
.04523 .31145 L
.04646 .31098 L
.04759 .31039 L
.05012 .30884 L
.05146 .30803 L
.0522 .30764 L
.0529 .30732 L
.05415 .30689 L
.0553 .3067 L
.05637 .30671 L
.05754 .30694 L
.05878 .3074 L
.06009 .30811 L
.06244 .30971 L
.06487 .31137 L
.06608 .31205 L
.06678 .31235 L
.06742 .31257 L
.06812 .31274 L
.06886 .31284 L
.06956 .31285 L
.07021 .31278 L
.07144 .31249 L
.07214 .31223 L
.07277 .31195 L
.07519 .31061 L
.07652 .30983 L
.07779 .30918 L
.07896 .3087 L
.08023 .3084 L
.0814 .30835 L
.08247 .30852 L
Mistroke
.08377 .30898 L
.08495 .30962 L
.08759 .31162 L
.09052 .31404 L
.0918 .31492 L
.09253 .31533 L
.09321 .31564 L
.09387 .31588 L
.09458 .31604 L
.09534 .31613 L
.09603 .31612 L
.09678 .31602 L
.09759 .31582 L
.09836 .31555 L
.09907 .31525 L
.10195 .31376 L
.1032 .31316 L
.10387 .31289 L
.10458 .31267 L
.10575 .31247 L
.10685 .31249 L
.10809 .3128 L
.10923 .31332 L
.11046 .31416 L
.1118 .31531 L
.11423 .3178 L
.11652 .32012 L
.11777 .32119 L
.11894 .32198 L
.11994 .32247 L
.12101 .32278 L
.1222 .32288 L
.12328 .32275 L
.12456 .32239 L
.1252 .32214 L
.12591 .32183 L
.12835 .32073 L
.12901 .32049 L
.12972 .32028 L
.13049 .32013 L
.13119 .32008 L
.13247 .32023 L
.13319 .32047 L
.13386 .32079 L
.13517 .3217 L
.1364 .32287 L
.13871 .32566 L
.14139 .32925 L
.1427 .33087 L
.1439 .33214 L
Mistroke
.14504 .33312 L
.14612 .33379 L
.14727 .33422 L
.14852 .33438 L
.1498 .33423 L
.15051 .33405 L
.15116 .33383 L
.1536 .33286 L
.15425 .33264 L
.15493 .33244 L
.15615 .33227 L
.15746 .33241 L
.15821 .33266 L
.1589 .33303 L
.16016 .33401 L
.16131 .33525 L
.16389 .33906 L
.16843 .34686 L
.16967 .34863 L
.17099 .35014 L
.17212 .35107 L
.17336 .35169 L
.17452 .35191 L
.17559 .35184 L
.17676 .35154 L
.17799 .35107 L
.17899 .35066 L
.18006 .35028 L
.18124 .35004 L
.18233 .35006 L
.18357 .35048 L
.18427 .35092 L
.18492 .35149 L
.18625 .35306 L
.18767 .35538 L
.19258 .36644 L
.19401 .36966 L
.19556 .37268 L
.19628 .37383 L
.19703 .37486 L
.19774 .37564 L
.19839 .37619 L
.19908 .3766 L
.19983 .37685 L
.20048 .37692 L
.20117 .37684 L
.20238 .37643 L
.20369 .3757 L
.20505 .37487 L
.20633 .37423 L
Mistroke
.20748 .37397 L
.20873 .37419 L
.20938 .37455 L
.21009 .37517 L
.21084 .37608 L
.21154 .37717 L
.21279 .37972 L
.21413 .38324 L
.21883 .39898 L
.22007 .40294 L
.22142 .40661 L
.22268 .40926 L
.22385 .41088 L
.22449 .4114 L
.22518 .41168 L
.22591 .41166 L
.2266 .41137 L
.2278 .41029 L
.22909 .40853 L
.23141 .40482 L
.23273 .40313 L
.23395 .4023 L
.23463 .40226 L
.23538 .40264 L
.23617 .40358 L
.23691 .40499 L
.23761 .40684 L
.23826 .40896 L
.23972 .41525 L
.24228 .43042 L
.24497 .44872 L
.24621 .45633 L
.24738 .46225 L
.24802 .46479 L
.24872 .46682 L
.24994 .46825 L
.25111 .46671 L
.25235 .4616 L
.2534 .45423 L
.25457 .44286 L
.25593 .42526 L
.25718 .40546 L
.25999 .35083 L
.26506 .24166 L
.26752 .19806 L
.26873 .18126 L
.26984 .16891 L
.27112 .15849 L
.2718 .15468 L
.27251 .15187 L
Mistroke
.27366 .14984 L
.27493 .15086 L
.27612 .15449 L
.27721 .15958 L
.27966 .17486 L
.2818 .1894 L
.28408 .2027 L
.28534 .20828 L
.28601 .21062 L
.28673 .21264 L
.28799 .21495 L
.28918 .21577 L
.28986 .21574 L
.29059 .21534 L
.29136 .21459 L
.29208 .21367 L
.29473 .20949 L
.29604 .2077 L
.29729 .20662 L
.2984 .20632 L
.29961 .20683 L
.30092 .20843 L
.30159 .20963 L
.30232 .21123 L
.30481 .2185 L
.30731 .22716 L
.30863 .23159 L
.31004 .2358 L
.31126 .23885 L
.31191 .2402 L
.31261 .24142 L
.31384 .24299 L
.31499 .24381 L
.31612 .24406 L
.31735 .24385 L
.31864 .24324 L
.31984 .24251 L
.32094 .24185 L
.32199 .24138 L
.32319 .24112 L
.32429 .24126 L
.32549 .2419 L
.32618 .2425 L
.32682 .24323 L
.32811 .24512 L
.3295 .24775 L
.33431 .25889 L
.3357 .26183 L
.33722 .26448 L
.33792 .26545 L
Mistroke
.33866 .26632 L
.33936 .26697 L
.33999 .26742 L
.34128 .26793 L
.342 .26802 L
.34267 .26799 L
.3439 .26771 L
.34519 .26722 L
.34641 .26672 L
.34705 .26649 L
.34774 .26629 L
.34899 .26612 L
.35015 .26626 L
.35126 .2667 L
.3523 .26742 L
.35344 .26855 L
.35467 .27012 L
.35962 .27846 L
.36093 .28059 L
.36232 .28256 L
.36364 .28401 L
.36483 .28496 L
.36596 .28551 L
.36718 .28576 L
.36834 .2857 L
.3694 .28545 L
.37056 .28504 L
.37183 .28452 L
.37252 .28425 L
.37317 .28402 L
.3744 .28373 L
.37545 .28366 L
.37658 .28382 L
.3778 .2843 L
.37893 .28504 L
.38001 .28598 L
.38098 .28702 L
.38317 .28978 L
.3857 .29317 L
.38806 .29582 L
.38925 .2968 L
.39052 .29753 L
.39125 .29778 L
.39194 .29792 L
.39322 .29792 L
.39434 .29769 L
.39553 .29727 L
.39765 .29631 L
.39875 .29583 L
.39994 .29542 L
Mistroke
.40124 .29518 L
.40246 .2952 L
.40313 .29533 L
.40384 .29556 L
.40512 .29621 L
.40591 .29675 L
.40665 .29734 L
.40804 .29863 L
.4108 .30152 L
.41201 .30272 L
.41334 .30387 L
.41454 .30469 L
.41566 .30522 L
.41685 .30552 L
.41812 .30556 L
.41879 .30546 L
.41951 .30528 L
.42083 .30478 L
.4233 .30351 L
.42443 .30293 L
.42562 .30242 L
.42693 .30203 L
.42814 .3019 L
.42926 .302 L
.43031 .30228 L
.43146 .30279 L
.43268 .30355 L
.43766 .30757 L
.43902 .30851 L
.43977 .30892 L
.44046 .30924 L
.4417 .30959 L
.44235 .30967 L
.44305 .30968 L
.44378 .3096 L
.44457 .30942 L
.44531 .30916 L
.44601 .30887 L
.44871 .30737 L
.45015 .30654 L
.45151 .30587 L
.45273 .30543 L
.45405 .3052 L
.45528 .30523 L
.45658 .30552 L
.45768 .30597 L
.45889 .30663 L
.46158 .30847 L
.46405 .31012 L
.46527 .31074 L
Mistroke
.46657 .31118 L
.46787 .31135 L
.46861 .31133 L
.4693 .31122 L
.47055 .31086 L
.4717 .31035 L
.47427 .30883 L
.47541 .30811 L
.47662 .30742 L
.47775 .30688 L
.47881 .30651 L
.48001 .30629 L
.48109 .30628 L
.48229 .30648 L
.48358 .30693 L
.48887 .31009 L
.49016 .31079 L
.49087 .31111 L
.49154 .31135 L
.49233 .31155 L
.49306 .31165 L
.49373 .31167 L
.49447 .3116 L
.49516 .31147 L
.4958 .31129 L
.497 .31079 L
.49968 .30922 L
.50218 .30767 L
.5034 .30706 L
.50451 .30665 L
.50567 .30641 L
.50677 .30637 L
.50792 .30654 L
.50918 .30695 L
.51048 .30757 L
.51185 .30838 L
.51431 .30997 L
.51553 .31068 L
.51685 .31128 L
.51809 .31164 L
.51923 .31177 L
.51991 .31175 L
.52055 .31167 L
.52126 .3115 L
.522 .31125 L
.52339 .31061 L
.52464 .30989 L
.52687 .30849 L
.52808 .3078 L
.52922 .30727 L
Mistroke
.53045 .30687 L
.5311 .30674 L
.53179 .30668 L
.53303 .30678 L
.53417 .30708 L
.53531 .30757 L
.53637 .30816 L
.53877 .30981 L
.5409 .31127 L
.54206 .31194 L
.54314 .31241 L
.54429 .31274 L
.54555 .31285 L
.54662 .31275 L
.54777 .31245 L
.54841 .3122 L
.54911 .31188 L
.55038 .3112 L
.55276 .3098 L
.55394 .30919 L
.55504 .30874 L
.55619 .30844 L
.55746 .30835 L
.55855 .30849 L
.55955 .3088 L
.5607 .30936 L
.5618 .31006 L
.56657 .31394 L
.56794 .31489 L
.56924 .31558 L
.5704 .31597 L
.57165 .31613 L
.57233 .31611 L
.57307 .316 L
.57384 .3158 L
.57456 .31555 L
.57723 .31424 L
.57853 .31356 L
.57925 .31322 L
.57991 .31295 L
.5811 .31259 L
.5824 .31245 L
.58366 .31261 L
.58482 .31301 L
.58608 .31374 L
.58742 .31479 L
.59025 .31761 L
.59287 .32027 L
.59405 .32126 L
.59517 .322 L
Mistroke
.59645 .32258 L
.59761 .32284 L
.5989 .32284 L
.6001 .3226 L
.6014 .32214 L
.60279 .32152 L
.60392 .321 L
.60499 .32056 L
.60623 .3202 L
.60736 .32008 L
.60842 .32018 L
.60941 .32048 L
.61049 .32105 L
.61163 .32193 L
.61401 .32451 L
.61625 .32747 L
.61889 .33087 L
.62018 .33223 L
.62135 .33321 L
.62252 .33389 L
.62362 .33426 L
.62478 .33438 L
.62604 .33422 L
.62733 .33384 L
.6287 .3333 L
.62999 .33279 L
.63117 .33243 L
.63239 .33227 L
.63371 .33242 L
.63493 .33293 L
.63609 .33377 L
.63674 .33439 L
.63743 .33517 L
.63868 .33685 L
.64151 .34155 L
.64391 .34573 L
.64517 .34769 L
.6465 .34942 L
.64767 .35059 L
.64896 .35144 L
.65012 .35184 L
.65121 .35191 L
.65235 .35172 L
.65343 .35137 L
.65545 .35056 L
.65659 .35019 L
.65763 .35002 L
.65878 .35011 L
.66 .35062 L
.66114 .35151 L
Mistroke
.66239 .35299 L
.66369 .35507 L
.6649 .35743 L
.66938 .36785 L
.67059 .37047 L
.6719 .37292 L
.67313 .37474 L
.67427 .37594 L
.6749 .3764 L
.6756 .37673 L
.67632 .3769 L
.677 .3769 L
.6782 .37659 L
.67949 .37594 L
.68062 .37524 L
.68183 .37454 L
.68253 .37423 L
.68316 .37404 L
.68439 .37402 L
.68554 .37453 L
.68679 .37575 L
.68796 .37759 L
.68904 .37988 L
.69107 .3855 L
.69329 .39298 L
.69562 .40093 L
.69777 .407 L
.69899 .40947 L
.70029 .41111 L
.7016 .41171 L
.70234 .41159 L
.70303 .41121 L
.70428 .40994 L
.70543 .4083 L
.70677 .40614 L
.70801 .40424 L
.70911 .40294 L
.71029 .40226 L
.7116 .40267 L
.71279 .40433 L
.71391 .40715 L
.71512 .41163 L
.71733 .42315 L
.72007 .44133 L
.72263 .4576 L
.72392 .4637 L
.72464 .46613 L
.7253 .46758 L
.72602 .46824 L
.7268 .46774 L
Mistroke
.72754 .466 L
.72823 .46323 L
.72942 .45564 L
.73054 .44525 L
.73177 .43025 L
.73309 .41015 L
.73826 .30534 L
.74064 .25408 L
.74288 .21149 L
.74413 .19195 L
.74547 .17474 L
.7467 .16298 L
.74782 .1555 L
.74908 .15087 L
.74979 .14987 L
.75046 .14993 L
.75116 .15095 L
.7518 .15265 L
.75254 .15542 L
.75324 .15875 L
.75829 .19131 L
.7596 .19915 L
.76082 .20535 L
.76151 .20819 L
.76224 .21075 L
.76352 .21394 L
.76475 .2155 L
.76605 .21573 L
.76716 .21501 L
.76838 .21351 L
.77113 .20917 L
.77192 .20808 L
.77267 .20724 L
.77334 .2067 L
.77407 .20637 L
.77471 .20633 L
.77541 .20657 L
.77615 .20715 L
.77683 .208 L
.77806 .21022 L
.77938 .21352 L
.78402 .22894 L
.78525 .23292 L
.78657 .23672 L
.78774 .23947 L
.78897 .24169 L
.78968 .24262 L
.79045 .24336 L
.79116 .2438 L
.79182 .24401 L
Mistroke
.79307 .24398 L
.79376 .24376 L
.7944 .24347 L
.79685 .24201 L
.79809 .24141 L
.79879 .2412 L
.79945 .24112 L
.80075 .24136 L
.80147 .24175 L
.80214 .24229 L
.80336 .24368 L
.80464 .24571 L
.81028 .2584 L
.81265 .26323 L
.81398 .26528 L
.81519 .26665 L
.81587 .26721 L
.81662 .26765 L
.81732 .2679 L
.81797 .26801 L
.81923 .26793 L
.81986 .26778 L
.82056 .26754 L
.82176 .26706 L
.82304 .26656 L
.82378 .26633 L
.82445 .26618 L
.82576 .26615 L
.82698 .26647 L
.8283 .26727 L
.82955 .26846 L
.8307 .26989 L
.83549 .27791 L
.83784 .28165 L
.83886 .28298 L
.83997 .28415 L
.84117 .28505 L
.84231 .28556 L
.84361 .28577 L
.84481 .28565 L
.84604 .2853 L
.84739 .28478 L
.84882 .28421 L
.85012 .28382 L
.85142 .28366 L
.85207 .28369 L
.85279 .28383 L
.85351 .28407 L
.85427 .28446 L
.855 .28494 L
Mistroke
.85566 .28548 L
.85833 .28842 L
.86085 .2918 L
.86308 .29461 L
.86431 .29588 L
.86548 .29683 L
.86614 .29724 L
.86685 .29758 L
.86811 .29791 L
.86939 .29792 L
.87057 .29768 L
.87336 .29654 L
.87472 .29592 L
.87597 .29547 L
.87712 .29521 L
.87833 .29517 L
.87954 .29539 L
.88022 .29564 L
.88087 .29595 L
.88203 .29669 L
.88313 .29759 L
.88518 .29962 L
.88758 .30213 L
.88864 .30313 L
.8898 .30408 L
.89095 .30481 L
.89202 .30528 L
.89315 .30554 L
.89436 .30555 L
.89563 .3053 L
.89626 .30509 L
.89695 .30481 L
.89932 .3036 L
.90056 .30297 L
.90187 .3024 L
.90255 .30217 L
.9033 .302 L
.90462 .30191 L
.90587 .30209 L
.90657 .3023 L
.90721 .30257 L
.90845 .30327 L
.90962 .3041 L
.91415 .3078 L
.91525 .30854 L
.91644 .30915 L
.91775 .30957 L
.91897 .30969 L
.9196 .30965 L
.92029 .30954 L
Mistroke
.92102 .30934 L
.92169 .30909 L
.92418 .3078 L
.92666 .30636 L
.92788 .30579 L
.92901 .30541 L
.92965 .30527 L
.93033 .30519 L
.93102 .30519 L
.93177 .30527 L
.93307 .30563 L
.93429 .30618 L
.93571 .30703 L
.93701 .30793 L
.93852 .30901 L
.93994 .30994 L
.94103 .31054 L
.94222 .31102 L
.9433 .31128 L
.94429 .31135 L
.94537 .31125 L
.94655 .31093 L
.94778 .3104 L
.94893 .30978 L
.95098 .3085 L
.95207 .30784 L
.95322 .30721 L
.95422 .30677 L
.95532 .30643 L
.95633 .30628 L
.95727 .30628 L
.95847 .30648 L
.95957 .30685 L
.96078 .30742 L
.96205 .30817 L
.96416 .30953 L
.96532 .31024 L
.96641 .31082 L
.96768 .31133 L
.96883 .3116 L
.96991 .31167 L
.97108 .31153 L
.97237 .31115 L
.97302 .31087 L
.97374 .31051 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00:;ooo]Z1Ol0
001YoookJP?o001o2_oonfX5o`0008;ooo]Z1Ol0002GoookJP00X_oonfX5o`0006Wooo]Z0ol007l:
oookJPGo0000P_oonfX5o`0009Oooo]Z002QoookJPOo0000F?oonfX:o`00O`Kooo]Z0ol007l:oook
JPGo0000POoonfX6o`0009Oooo]Z002QoookJPOo0000F?oonfX:o`00O`Kooo]Z0ol007l:oookJPKo
0000P?oonfX7o`0009Kooo]Z002QoookJPOo0000J?oonfX3o`00O`[ooo]Z1Ol00021oookJPOo0000
U_oonfX00:7ooo]Z1ol0001XoookJP?o001o2_oonfX5o`00087ooo]Z1ol0002FoookJP00XOoonfX7
o`0006Sooo]Z0ol007l:oookJPGo0000POoonfX7o`0009Kooo]Z002QoookJPOo0000J?oonfX3o`00
O`[ooo]Z1Ol00021oookJPOo0000U_oonfX00:3ooo]Z2Ol0001ToookJPKo001o2_oonfX5o`00087o
oo]Z1ol0002FoookJP00X?oonfX9o`0006Cooo]Z1_l007l:oookJPGo0000POoonfX8o`0009Gooo]Z
002PoookJPWo0000I_oonfX4o`00O`[ooo]Z1Ol00021oookJPSo0000UOoonfX00:3ooo]Z1?l00000
0ooonf[o0000o`000002o`0006Oooo]Z0ol007l:oookJPGo0000P?oonfX9o`0009Gooo]Z002Poook
JPCo000000?ooo]Zo`000?l000000ol0001coookJPGo0000P?oonfX9o`0009Gooo]Z002PoookJPCo
000000?ooo]Zo`000?l000000ol0001coookJPGo0000P?oonfX9o`0009Gooo]Z002PoookJPCo0000
00?ooo]Zo`000?l000000ol0001coookJPGo0000P?oonfX4o`000003oookJ_l0003o000000?o0000
U?oonfX00:3ooo]Z1?l00002oookJPCo0000LooonfX5o`00083ooo]Z1?l000000ooonf[o0000o`00
0003o`0009Cooo]Z002PoookJPCo00000_oonfX4o`0007?ooo]Z1Ol00020oookJPCo000000?ooo]Z
o`000?l000000ol0002DoookJP00X?oonfX4o`0000;ooo]Z1?l0001coookJPGo0000P?oonfX4o`00
00;ooo]Z1?l0002DoookJP00X?oonfX4o`0000;ooo]Z1Ol0001boookJPGo0000P?oonfX4o`0000;o
oo]Z1?l0002DoookJP00X?oonfX4o`0000;ooo]Z1Ol0001boookJPGo0000OooonfX5o`0000;ooo]Z
1?l0002DoookJP00X?oonfX4o`0000;ooo]Z1Ol0001boookJPGo0000OooonfX5o`0000;ooo]Z1Ol0
002CoookJP00X?oonfX4o`0000?ooo]Z1?l0001boookJPGo0000OooonfX5o`0000;ooo]Z1Ol0002C
oookJP00WooonfX5o`0000?ooo]Z1?l0001boookJPGo0000OooonfX4o`0000?ooo]Z1Ol0002Coook
JP00WooonfX5o`0000?ooo]Z1?l0001boookJPGo0000OooonfX4o`0000Cooo]Z1?l0002CoookJP00
WooonfX5o`0000?ooo]Z1?l0001boookJPGo0000OooonfX4o`0000Cooo]Z1?l0002CoookJP00Wooo
nfX4o`0000Cooo]Z1Ol0001aoookJPGo0000OooonfX4o`0000Cooo]Z1Ol0002BoookJP00WooonfX4
o`0000Cooo]Z1Ol0001aoookJPGo0000OooonfX4o`0000Cooo]Z1Ol0002BoookJP00WooonfX4o`00
00Cooo]Z1Ol0001aoookJPGo0000OooonfX4o`0000Cooo]Z1Ol0002BoookJP00WooonfX4o`0000Go
oo]Z1?l0001aoookJPGo0000OooonfX4o`0000Gooo]Z1?l0002BoookJP00WooonfX4o`0000Gooo]Z
1?l0001aoookJPGo0000OooonfX4o`0000Gooo]Z1?l0002BoookJP00WooonfX4o`0000Gooo]Z1Ol0
0003oookJPCo0000JOoonfX5o`0007oooo]Z1?l00005oookJPCo00001?oonfX4o`0008[ooo]Z002O
oookJPCo00001OoonfX5o`000003oookJ_l0003o000000Co0000JOoonfX5o`0007oooo]Z1?l00005
oookJPGo000000?ooo]Zo`000?l000001Ol00029oookJP00WooonfX4o`0000Gooo]Z1Ol000000ooo
nf[o0000o`000005o`0006Sooo]Z1Ol0001ooookJPCo00001OoonfX5o`000003oookJ_l0003o0000
00Ko0000R?oonfX009oooo]Z1?l00006oookJPgo0000IooonfX5o`0007oooo]Z1?l00005oookJPko
0000R?oonfX009oooo]Z1?l00006oookJPgo0000IooonfX5o`0007oooo]Z1?l00006oookJPgo0000
R?oonfX009oooo]Z1?l00006oookJPgo0000IooonfX5o`0007oooo]Z1?l00006oookJPgo0000R?oo
nfX009oooo]Z1?l00006oookJPSo000000?ooo]Zo`000?l000000ol0001VoookJPGo0000OooonfX4
o`0000Kooo]Z2?l000000ooonf[o0000o`000003o`0008Oooo]Z002OoookJPCo00001_oonfX7o`00
00;ooo]Z1Ol0001VoookJPGo0000OooonfX4o`0000Kooo]Z1ol00002oookJPGo0000QooonfX009oo
oo]Z1?l00007oookJPKo00000_oonfX5o`0006Kooo]Z1Ol0001ooookJPCo00001ooonfX6o`0000;o
oo]Z1Ol00027oookJP00W_oonfX5o`00013ooo]Z1Ol0001UoookJPGo0000OooonfX4o`00013ooo]Z
1Ol00026oookJP00W_oonfX5o`00013ooo]Z1Ol0001UoookJPGo0000O_oonfX5o`00013ooo]Z1Ol0
0026oookJP00W_oonfX5o`00013ooo]Z1Ol00017oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:
oookJPGo0000O_oonfX5o`00013ooo]Z1Ol00026oookJP00W_oonfX4o`0001;ooo]Z1Ol00015oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000O_oonfX5o`00017ooo]Z1Ol00025oook
JP00W_oonfX4o`0001;ooo]Z1Ol00015oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0007kooo]Z1?l0000B
oookJPGo0000QOoonfX009kooo]Z1?l0000BoookJPGo0000>?oonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000O_oonfX4o`0001;ooo]Z1Ol00025oook
JP00W_oonfX4o`0001?ooo]Z1?l0000hoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2?oonfX6o`0007gooo]Z1?l0000CoookJPGo0000Q?oonfX009kooo]Z1?l0000CoookJPGo0000
@ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0007kooo]Z1?l0000CoookJPGo0000
Q?oonfX009kooo]Z1?l0000CoookJPGo0000@ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z1Ol0001noookJPCo00004ooonfX5o`0008Cooo]Z002NoookJPCo00004ooonfX6
o`0004;ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001noookJPCo00005?oonfX5
o`0008?ooo]Z002NoookJPCo00005?oonfX5o`0000;ooo]Z1Ol0000koookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007l:oookJPGo0000O_oonfX4o`0001Cooo]Z1Ol00002oookJPGo0000O?oonfX009ko
oo]Z1?l0000DoookJPgo0000>_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0007ko
oo]Z1?l0000DoookJPgo0000NooonfX009kooo]Z1?l0000EoookJPgo0000>_oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000OOoonfX5o`0001Gooo]Z3?l0001koookJP00
W_oonfX4o`0001Gooo]Z3Ol0000joookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001moookJPGo0000
5OoonfX=o`0007[ooo]Z002NoookJPCo00005_oonfX=o`0003[ooo]Z1Ol007l:oookJPOo001o2?oo
nfX5o`0007gooo]Z1Ol0000FoookJPco0000N_oonfX009kooo]Z1?l0000GoookJPGo00000_oonfX5
o`0005Sooo]Z1Ol0001moookJPCo00006?oonfX<o`0007Wooo]Z002NoookJPCo00007_oonfX6o`00
05Oooo]Z1Ol0001moookJPCo00007ooonfX5o`0007Wooo]Z002NoookJPCo00007ooonfX5o`0005Oo
oo]Z1Ol0001moookJPCo00007ooonfX6o`0007Sooo]Z002NoookJPCo00007ooonfX5o`0005Oooo]Z
1Ol0001moookJPCo00008?oonfX5o`0007Sooo]Z002NoookJPCo00008?oonfX5o`0005Kooo]Z1Ol0
001moookJPCo00008?oonfX5o`0007Sooo]Z002NoookJPCo00008?oonfX5o`0005Kooo]Z1Ol0001m
oookJPCo00008OoonfX5o`0007Oooo]Z002NoookJPCo00008?oonfX6o`0005Gooo]Z1Ol0001moook
JPCo00008OoonfX5o`0007Oooo]Z002MoookJPGo00008OoonfX5o`0005Gooo]Z1Ol0001moookJPCo
00008OoonfX6o`0007Kooo]Z002MoookJPGo00008OoonfX6o`0005Cooo]Z1Ol0001moookJPCo0000
8_oonfX6o`0007Gooo]Z002MoookJPGo00008_oonfX=o`0004cooo]Z1Ol0001moookJPCo00008_oo
nfX>o`0006gooo]Z002MoookJPCo00008ooonfX>o`0004_ooo]Z1Ol0001moookJPCo00008ooonfX>
o`0006cooo]Z002MoookJPCo00009?oonfX=o`0004_ooo]Z1Ol0001moookJPCo00009?oonfX=o`00
06cooo]Z000RoookJP?o001oMOoonfX3o`00O`Co00000_oonfX3o`00O`?ooo]Z1Ol007lHoookJPco
0000BooonfX5o`0007Cooo]Z1Ol007l4oookJPCo00000_oonfX5o`00Oakooo]Z3?l0001<oookJP?o
001o7OoonfX002;ooo]Z0ol007mdoookJPCo001o1?l00002oookJP?o001o0_oonfX7o`00OaSooo]Z
1Ol00002oookJPGo0000B_oonfX5o`0007?ooo]Z1ol007l3oookJPCo000000?ooo]Zo`00Ool007l0
1Ol007lNoookJPKo000000?ooo]Zo`000?l000000ol0001;oookJP?o001o7OoonfX002;ooo]Z0ol0
07mdoookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007lOoookJPKo0000BOoonfX5o`0007?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJPCo00001?l007l01?oonf[o001oo`00Ool007lUoookJPKo0000B_oonfX3o`00
Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o0_oonfX4o`0000Ko
oo]Z0ol007l3oookJP?o001o7_oonfX7o`0004Sooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;o
oo]Z1?l00003o`00O`?ooo]Z0ol007lToookJPOo0000BOoonfX3o`00Oagooo]Z000CoookJP[o001o
1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o0_oonfX4o`0000cooo]Z0ol007lOoookJPKo0000
B?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`0000Kooo]Z0ol007lUoookJPKo0000
BOoonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`;ooo]Z1?l0000<oookJP?o001o8?oo
nfX6o`0004Oooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000?o00001_oo
nfX3o`00ObKooo]Z1_l00018oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4
o`0000Oooo]Z0_l007l2oookJPCo001o8OoonfX6o`000003oookJ_l0003o000000Co0000?ooonfX5
o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000ol000000ooonf[o001oo`00O`02
oookJPCo001o9ooonfX6o`0000;ooo]Z1Ol00010oookJP?o001o7OoonfX002;ooo]Z0ol007mcoook
JP?o001o0_oonfX4o`0000Oooo]Z1ol007lRoookJPko0000?_oonfX5o`0007;ooo]Z0ol007l3oook
JP?o001o00?ooo]Zo`000?l000000ol000000ooonf[o001oo`00O`05o`00ObSooo]Z3ol0000noook
JP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4o`0000Oooo]Z1_l007lToookJPoo
0000??oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJPKo
001o:_oonfX>o`0003kooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l2oookJPCo0000
1ooonfX2o`00ObSooo]Z3ol0000loookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000
o`000002o`0000;ooo]Z0_l007l_oookJPko0000>_oonfX6o`00Oagooo]Z000OoookJPKo001oM?oo
nfX3o`00O`03oookJ_l0003o000000;o00001ooonfX2o`00Ob[ooo]Z3_l0000koookJPGo0000Looo
nfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l00002oookJP;o001o;ooonfX?o`0003Wooo]Z
1_l007lMoookJP008OoonfX4o`00OgCooo]Z1?l007l4o`0000Sooo]Z1ol007l/oookJPOo0000>_oo
nfX5o`0007?ooo]Z1ol007l2oookJPCo00000ooonfX7o`00Oc;ooo]Z1ol0000joookJPCo001o7Ooo
nfX002;ooo]Z0ol007meoookJP?o001o1?l00008oookJPOo001o;OoonfX6o`0003[ooo]Z1Ol0001d
oookJPGo001o0ooonfX4o`0000?ooo]Z1ol007lcoookJPOo0000>_oonfX3o`00Oagooo]Z002Moook
JPCo0000?OoonfX@o`0002oooo]Z1Ol0001loookJPCo0000?_oonfX@o`00053ooo]Z002LoookJPGo
0000?_oonfX@o`0002kooo]Z1Ol0001loookJPCo0000?ooonfX@o`0004oooo]Z002LoookJPGo0000
?_oonfXAo`0002gooo]Z1Ol0001loookJPCo0000@?oonfX@o`0004kooo]Z002LoookJPGo0000?ooo
nfXAo`0000Cooo]Z1_l0000RoookJPGo0000O?oonfX4o`00043ooo]Z4Ol00004oookJPKo0000@ooo
nfX009cooo]Z1?l00012oookJPKo00000_oonfX8o`000003oookJ_l0003o000000So00008?oonfX5
o`0007cooo]Z1?l00011oookJPOo00000ooonfX7o`000003oookJ_l0003o000000So0000@OoonfX0
09cooo]Z1?l0001<oookJQ;o00001OoonfX7o`0001?ooo]Z1Ol0001loookJPCo0000C?oonfXBo`00
00Gooo]Z1ol0000doookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo0000
9Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?
oookJP003_oonf[oo`000?oo00009Ol0000?oookJP007OoonfX00ol0003ooo]ZoookJP03oookJPWo
00001OoonfX:o`0000?ooo]Z4Ol0001=oookJPCo0000J_oonfX8o`0000Gooo]Z2ol00003oookJPWo
00001OoonfX9o`0000;ooo]Z4ol0001=oookJPCo0000JOoonfX9o`0000Gooo]Z2Ol0000NoookJP00
9OoonfX5o`0000Sooo]Z1ol00005oookJQ;o0000C?oonfX4o`0007gooo]Z1Ol00005oookJPGo0000
2?oonfX8o`0000Cooo]Z4_l0001<oookJPCo0000W_oonfX003oooo]Z2_l000000ooonf[o0000o`00
0005o`0000;ooo]Z2?l00011oookJPCo0000OOoonfX5o`0001oooo]Z2_l000000ooonf[o0000o`00
0005o`0000?ooo]Z1_l00012oookJPCo0000W_oonfX0047ooo]Z1_l00004oookJQ3o0000@OoonfX4
o`0007gooo]Z1Ol0000QoookJPKo00001?oonfXAo`00043ooo]Z1?l0002NoookJP00C?oonfX@o`00
043ooo]Z1?l0001moookJPGo0000;?oonfXAo`0003kooo]Z1Ol0002NoookJP00COoonfX@o`0003oo
oo]Z1?l0001moookJPGo0000;OoonfX@o`0003kooo]Z1Ol0002NoookJP00C_oonfX8o`000003oook
J_l0003o000000Go0000?_oonfX4o`0007gooo]Z1Ol0000^oookJQ3o0000?OoonfX5o`0009kooo]Z
001@oookJPCo00001?oonfX7o`0003gooo]Z1?l0001moookJPGo0000<?oonfX5o`0000Cooo]Z1Ol0
000moookJPCo0000WooonfX005Wooo]Z1_l0000moookJPCo0000OOoonfX5o`0003Wooo]Z1_l0000l
oookJPCo0000WooonfX005[ooo]Z3_l0000doookJPCo0000OOoonfX5o`0003[ooo]Z3ol0000boook
JPCo0000WooonfX005_ooo]Z3_l0000boookJPGo0000OOoonfX5o`0003[ooo]Z3ol0000boookJPCo
0000WooonfX005_ooo]Z3ol0000aoookJPGo0000OOoonfX5o`0003_ooo]Z3ol0000aoookJPCo0000
WooonfX005cooo]Z3ol0000`oookJPGo0000OOoonfX5o`0003cooo]Z3_l0000aoookJPCo0000Wooo
nfX005kooo]Z1_l000000ooonf[o0000o`000004o`00033ooo]Z1?l0001noookJPGo0000?OoonfX6
o`0000;ooo]Z1_l0000`oookJPCo0000WooonfX006Kooo]Z1_l0000_oookJPCo0000O_oonfX5o`00
04Kooo]Z1_l0000_oookJPCo0000WooonfX006Oooo]Z1Ol0000_oookJPCo0000O_oonfX5o`0004Ko
oo]Z1_l0000_oookJPCo0000WooonfX006Oooo]Z1Ol0000_oookJPCo0000O_oonfX5o`0004Oooo]Z
1_l0000^oookJPCo0000WooonfX006Sooo]Z1_l0000]oookJPCo0000O_oonfX5o`0004Sooo]Z1_l0
000]oookJPCo0000WooonfX006Sooo]Z1ol000000ooonf[o0000o`000003o`0002Kooo]Z1?l0001n
oookJPGo0000B?oonfX6o`0000;ooo]Z1Ol0000VoookJPCo0000WooonfX006Sooo]Z3_l0000Uoook
JPCo0000O_oonfX5o`0004Wooo]Z3Ol0000UoookJPCo0000WooonfX006Wooo]Z3_l0000ToookJPCo
0000O_oonfX5o`0004[ooo]Z3Ol0000ToookJPCo0000WooonfX006_ooo]Z3Ol0000SoookJPCo0000
O_oonfX5o`0004[ooo]Z3_l0000SoookJPCo0000WooonfX006_ooo]Z3Ol0000SoookJPCo0000O_oo
nfX5o`0004_ooo]Z3Ol0000SoookJPCo0000WooonfX007?ooo]Z1_l0000RoookJPCo0000O_oonfX5
o`0005?ooo]Z1Ol0000RoookJPGo0000WooonfX007Cooo]Z1Ol0000RoookJPCo0000O_oonfX5o`00
05Cooo]Z1Ol0000QoookJPGo0000WooonfX007Cooo]Z1Ol0000RoookJPCo0000O_oonfX5o`0005Co
oo]Z1Ol0000QoookJPGo0000WooonfX007Gooo]Z1Ol0000QoookJPCo0000O_oonfX5o`0005Cooo]Z
1_l0000PoookJPCo0000X?oonfX007Gooo]Z1Ol0000PoookJPGo0000O_oonfX5o`0005Gooo]Z1Ol0
000PoookJPCo0000X?oonfX007Gooo]Z1Ol0000PoookJPGo0000O_oonfX5o`0005Gooo]Z1_l0000O
oookJPCo0000X?oonfX007Kooo]Z1Ol0000OoookJPGo0000O_oonfX5o`0005Kooo]Z1Ol0000Ooook
JPCo0000X?oonfX007Kooo]Z1Ol0000OoookJPCo0000OooonfX5o`0005Kooo]Z1Ol0000OoookJPCo
0000X?oonfX007Kooo]Z1_l00002oookJPGo00005ooonfX4o`0007oooo]Z1Ol0001GoookJPGo0000
0_oonfX5o`0001Oooo]Z1?l0002PoookJP00MooonfX=o`0001Kooo]Z1?l0001ooookJPGo0000Eooo
nfX=o`0001Kooo]Z1?l0002PoookJP00MooonfX>o`0001Gooo]Z1?l0001ooookJPGo0000EooonfX>
o`0001Gooo]Z1?l0002PoookJP00N?oonfX=o`0001Gooo]Z1?l0001ooookJPGo0000F?oonfX=o`00
01Gooo]Z1?l0002PoookJP00NOoonfX<o`0001Gooo]Z1?l0001QoookJPGo001o1?oonfX3o`00O`?o
oo]Z1Ol007l:oookJPGo0000FOoonfX<o`0001Gooo]Z1?l0002PoookJP00N_oonfX6o`000003oook
J_l0003o000000?o00005?oonfX4o`00063ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z
1Ol0001JoookJPKo000000?ooo]Zo`000?l000000ol0000DoookJPCo0000X?oonfX0087ooo]Z1Ol0
000DoookJPCo0000H?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001o
o`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001QoookJPKo00004ooonfX4o`000:3o
oo]Z0021oookJPKo00004ooonfX4o`0005oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l8oookJPGo0000HOoonfX6o`0001?ooo]Z1?l0002PoookJP00P_oonfX5o`0001?ooo]Z1?l0
001OoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000HOoonfX5o`0001?ooo]Z1?l0
002PoookJP00P_oonfX5o`0001?ooo]Z1?l0001OoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8
oookJPGo0000HooonfX5o`0001;ooo]Z1?l0002PoookJP00PooonfX5o`0001;ooo]Z1?l0001Ooook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0006?ooo]Z1Ol0000Boook
JPCo0000X?oonfX008?ooo]Z1Ol0000AoookJPGo0000GooonfX3o`00O`?ooo]Z0ol007l7oookJPOo
001o2OoonfX5o`0006?ooo]Z1Ol0000AoookJPGo0000X?oonfX008?ooo]Z1Ol0000AoookJPGo0000
GooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0006Cooo]Z1?l0000AoookJPGo0000
X?oonfX008Cooo]Z1Ol0000@oookJPGo0000GooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oo
nfX5o`0006Cooo]Z1?l0000AoookJPGo0000X?oonfX008Cooo]Z1Ol0000@oookJPCo0000HOoonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000I?oonfX5o`00013ooo]Z1?l0
002QoookJP00Q?oonfX5o`00013ooo]Z1?l0001QoookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001T
oookJPGo00004?oonfX4o`000:7ooo]Z0025oookJPCo00000ooonfX6o`0000Oooo]Z1?l0001Roook
JPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001ToookJPGo00000ooonfX6o`0000Oooo]Z1?l0002Qoook
JP00QOoonfX4o`0000;ooo]Z1ol00007oookJPCo0000P?oonfX5o`0006Gooo]Z1Ol00002oookJPKo
00001ooonfX4o`000:7ooo]Z0025oookJPGo000000?ooo]Zo`000?l000001_l00006oookJPCo0000
P?oonfX5o`0006Gooo]Z1Ol000000ooonf[o0000o`000006o`0000Kooo]Z1?l0002QoookJP00QOoo
nfX>o`0000Kooo]Z1?l00020oookJPGo0000IOoonfX>o`0000Kooo]Z1?l0002QoookJP00QOoonfX>
o`0000Kooo]Z1?l00020oookJPGo0000I_oonfX>o`0000Gooo]Z1?l0002QoookJP00Q_oonfX=o`00
00Kooo]Z1?l00020oookJPGo0000I_oonfX>o`0000Gooo]Z1?l0002QoookJP00QooonfX7o`000003
oookJ_l0003o000000?o00001OoonfX4o`00083ooo]Z1Ol0001WoookJPOo000000?ooo]Zo`000?l0
00000ol00005oookJPCo0000XOoonfX008Oooo]Z1_l00002oookJPGo00001OoonfX4o`00083ooo]Z
1Ol0001XoookJPKo00000_oonfX4o`0000Gooo]Z1?l0002QoookJP00R?oonfX4o`0000?ooo]Z1Ol0
0005oookJPCo0000P?oonfX5o`0006Sooo]Z1Ol00003oookJPCo00001OoonfX4o`000:7ooo]Z002@
oookJPCo00001OoonfX4o`00083ooo]Z1Ol0001`oookJPGo00001?oonfX4o`000:7ooo]Z002@oook
JPCo00001OoonfX4o`00083ooo]Z1Ol0001`oookJPGo00001?oonfX4o`000:7ooo]Z002@oookJPCo
00001OoonfX4o`00083ooo]Z1Ol0001`oookJPGo00001?oonfX4o`000:7ooo]Z002@oookJPGo0000
1?oonfX4o`00083ooo]Z1Ol0001aoookJPCo00001?oonfX4o`000:7ooo]Z002@oookJPGo00001?oo
nfX4o`00083ooo]Z1Ol0001aoookJPCo00001?oonfX4o`000:7ooo]Z002@oookJPGo00001?oonfX4
o`00083ooo]Z1Ol0001aoookJPCo00001?oonfX4o`000:7ooo]Z002AoookJPCo00001?oonfX4o`00
083ooo]Z1Ol0001aoookJPCo00001?oonfX4o`000:7ooo]Z002AoookJPCo00001?oonfX4o`00083o
oo]Z1Ol0001aoookJPCo00001?oonfX4o`000:7ooo]Z002AoookJPCo00001?oonfX4o`00083ooo]Z
1Ol0001aoookJPGo00000ooonfX4o`000:7ooo]Z002AoookJPGo00000_oonfX5o`00083ooo]Z1Ol0
001aoookJPGo00000ooonfX4o`000:7ooo]Z002AoookJPGo00000_oonfX5o`00083ooo]Z1Ol0001a
oookJPGo00000ooonfX4o`000:7ooo]Z002AoookJPGo00000_oonfX5o`00083ooo]Z1Ol0001boook
JPCo00000_oonfX5o`000:7ooo]Z002BoookJPCo00000_oonfX4o`00087ooo]Z1Ol0001boookJPCo
00000_oonfX5o`000:7ooo]Z002BoookJPCo00000_oonfX4o`00087ooo]Z1Ol0001boookJPCo0000
0_oonfX5o`000:7ooo]Z002BoookJPGo000000?ooo]Zo`000?l000000_l00021oookJPGo0000L_oo
nfX4o`0000;ooo]Z1?l0002RoookJP00T_oonfX5o`000003oookJ_l0003o000000;o0000POoonfX5
o`0007;ooo]Z1Ol000000ooonf[o0000o`000002o`000:;ooo]Z002BoookJPGo000000?ooo]Zo`00
0?l000000_l00021oookJPGo0000L_oonfX5o`000003oookJ_l0003o000000;o0000X_oonfX009?o
oo]Z2Ol00021oookJPGo0000L_oonfX:o`000:;ooo]Z002CoookJPWo0000POoonfX5o`0007?ooo]Z
2Ol0002RoookJP00TooonfX9o`00087ooo]Z1Ol0001coookJPWo0000X_oonfX009?ooo]Z2?l00022
oookJPGo0000LooonfX8o`000:?ooo]Z002CoookJPSo0000MOoonfX3o`00O`[ooo]Z1Ol0001coook
JPSo0000XooonfX009?ooo]Z2?l0001eoookJP?o001o2_oonfX5o`0007?ooo]Z2?l0002SoookJP00
TooonfX8o`0007Gooo]Z0ol007l:oookJPGo0000M?oonfX7o`000:?ooo]Z002CoookJPSo0000MOoo
nfX3o`00O`[ooo]Z1Ol0001doookJPOo0000XooonfX009Cooo]Z1ol0001eoookJP?o001o2_oonfX6
o`0007?ooo]Z1ol0002SoookJP00U?oonfX7o`0007Gooo]Z0ol007l:oookJPGo0000M?oonfX7o`00
0:?ooo]Z002DoookJPOo0000MOoonfX3o`00O`[ooo]Z1Ol0001doookJPOo0000XooonfX009Cooo]Z
1_l0001foookJP?o001o2_oonfX5o`0007Gooo]Z1Ol0002ToookJP00UOoonfX4o`0007Oooo]Z0ol0
07l:oookJPGo0000MOoonfX5o`000:Cooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfXO
oookJP00oooonfX>oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4?oonfX4o`00O`[o
oo]Z1Ol0003ooookJQoooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2
oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXNoook
JP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l007l:
oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoook
JP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00oooonfX1oookJPCo001o
2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooo
nfXOoookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4o`00
O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oookJPKo0000oooonfXNoookJP00
oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z1Ol0
003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oook
JP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z
3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z003o
oookJPoooo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30977 L
.02605 .31039 L
.02729 .31098 L
.02846 .31136 L
.02954 .31153 L
.03053 .31151 L
.03163 .3113 L
.03279 .31089 L
.03523 .30954 L
.03658 .30867 L
.03786 .30789 L
.03905 .30728 L
.04035 .30679 L
.04152 .30658 L
.04262 .30658 L
.04385 .30682 L
.04501 .30726 L
.04606 .3078 L
.04718 .3085 L
.0495 .31004 L
.05073 .31079 L
.05205 .31141 L
.05276 .31166 L
.05341 .31181 L
.05468 .31191 L
.05537 .31185 L
.05611 .31171 L
.05681 .31149 L
.05746 .31123 L
.05988 .30991 L
.06244 .30838 L
.06371 .30779 L
.06434 .30757 L
.06504 .30739 L
.06627 .30728 L
.06742 .30741 L
.06811 .3076 L
.06877 .30786 L
.07001 .3085 L
.07277 .31047 L
.07504 .31211 L
.07617 .31278 L
.07743 .31332 L
.07808 .3135 L
.07878 .31361 L
.08005 .3136 L
.08132 .31332 L
.08247 .31287 L
.0851 .31145 L
Mistroke
.08654 .31066 L
.08725 .31033 L
.0879 .31006 L
.08867 .30982 L
.08951 .30967 L
.09022 .30964 L
.09097 .3097 L
.09167 .30986 L
.09233 .31008 L
.09304 .31042 L
.09381 .31088 L
.09653 .31306 L
.09941 .31562 L
.10059 .31649 L
.10187 .3172 L
.1026 .31749 L
.10327 .31766 L
.10458 .31776 L
.10581 .31759 L
.10696 .31722 L
.10821 .31666 L
.10955 .31598 L
.11096 .31529 L
.11165 .31501 L
.11229 .3148 L
.11349 .31457 L
.11478 .31462 L
.11542 .31476 L
.11611 .31501 L
.11735 .31571 L
.1181 .31628 L
.11882 .31691 L
.12017 .31827 L
.12293 .32137 L
.12444 .32292 L
.12586 .32411 L
.127 .32481 L
.12824 .32525 L
.12891 .32537 L
.12961 .32539 L
.13087 .32521 L
.13201 .32485 L
.13308 .32441 L
.13424 .32389 L
.1355 .32338 L
.13621 .32316 L
.13686 .32301 L
.13816 .32295 L
.13933 .3232 L
.14057 .32382 L
Mistroke
.14121 .32428 L
.1419 .32489 L
.14315 .32622 L
.14599 .33007 L
.14853 .33361 L
.14993 .33524 L
.15124 .33642 L
.15247 .33716 L
.15316 .33741 L
.15379 .33755 L
.15492 .33758 L
.15611 .33736 L
.15742 .33691 L
.15883 .33635 L
.15951 .3361 L
.16016 .3359 L
.16137 .3357 L
.16207 .33571 L
.16281 .33585 L
.16344 .33608 L
.16414 .33647 L
.16488 .33704 L
.16569 .33783 L
.16714 .33969 L
.17225 .34875 L
.17349 .35084 L
.17482 .35273 L
.17558 .35362 L
.17628 .35428 L
.17697 .35479 L
.17763 .35515 L
.17879 .35547 L
.18003 .35543 L
.18108 .35516 L
.18224 .35471 L
.18349 .35418 L
.18417 .35393 L
.18482 .35375 L
.18608 .35365 L
.18724 .35394 L
.18849 .35475 L
.18919 .35546 L
.18984 .35628 L
.19229 .36065 L
.19686 .37173 L
.19801 .3743 L
.19924 .37665 L
.19994 .37777 L
.20059 .37861 L
.20184 .37978 L
Mistroke
.20314 .38031 L
.20387 .38032 L
.20454 .38019 L
.20578 .37963 L
.2071 .37879 L
.20821 .37806 L
.20928 .37751 L
.2105 .37726 L
.21162 .37752 L
.21267 .37831 L
.21364 .37956 L
.21471 .38152 L
.21585 .38427 L
.22055 .40013 L
.22178 .40441 L
.22311 .40841 L
.22436 .41138 L
.2255 .41324 L
.22681 .41426 L
.22805 .41415 L
.22875 .41367 L
.2294 .413 L
.23086 .41084 L
.23208 .4087 L
.2334 .4065 L
.23464 .40497 L
.23578 .4044 L
.23703 .40503 L
.23834 .40737 L
.23904 .40939 L
.2397 .41176 L
.24117 .4188 L
.24412 .43799 L
.24557 .44829 L
.2469 .45704 L
.24809 .46341 L
.24935 .4679 L
.25062 .46931 L
.25134 .46849 L
.25201 .46653 L
.25318 .46025 L
.25425 .45117 L
.25548 .43671 L
.25665 .41921 L
.26212 .30397 L
.2645 .24987 L
.26707 .2002 L
.26833 .18133 L
.26901 .17278 L
.26965 .16597 L
Mistroke
.27078 .15675 L
.27202 .15072 L
.2732 .14872 L
.27427 .14972 L
.27551 .1537 L
.27668 .15965 L
.27926 .17696 L
.28199 .19554 L
.28312 .20178 L
.28433 .20711 L
.28503 .20945 L
.28566 .21113 L
.28691 .21314 L
.28797 .21363 L
.28896 .21323 L
.29005 .21206 L
.29121 .21025 L
.29337 .2065 L
.2946 .20482 L
.29572 .2039 L
.29698 .20377 L
.29761 .20411 L
.29831 .2048 L
.29957 .2069 L
.30075 .20975 L
.30531 .2253 L
.30772 .23313 L
.30895 .23619 L
.30965 .23761 L
.3103 .23868 L
.311 .23957 L
.31175 .24025 L
.31242 .24061 L
.31312 .24077 L
.31437 .24058 L
.31507 .24027 L
.31573 .23989 L
.31691 .23911 L
.31819 .23831 L
.3194 .23781 L
.32051 .23771 L
.32181 .23815 L
.32247 .23864 L
.32319 .23938 L
.32445 .24117 L
.32562 .24336 L
.3302 .25436 L
.3313 .2569 L
.33246 .25929 L
.33354 .26114 L
Mistroke
.33456 .26251 L
.33582 .26367 L
.33696 .26424 L
.33822 .26439 L
.33893 .26429 L
.33958 .26412 L
.34071 .2637 L
.34194 .26317 L
.3431 .26276 L
.34417 .26255 L
.34536 .26262 L
.34663 .26311 L
.34769 .2639 L
.34887 .26515 L
.35012 .26689 L
.35147 .26913 L
.35391 .27365 L
.35622 .27767 L
.35748 .27945 L
.35865 .28075 L
.35966 .28155 L
.36073 .28209 L
.36192 .28234 L
.363 .28227 L
.36429 .28194 L
.36494 .2817 L
.36565 .28142 L
.36693 .28092 L
.3681 .28058 L
.36881 .28046 L
.36948 .28044 L
.37019 .28051 L
.37096 .28072 L
.37163 .28102 L
.37234 .28145 L
.37363 .28254 L
.37851 .28897 L
.3798 .29074 L
.38118 .29241 L
.38248 .29366 L
.38366 .29447 L
.38498 .29497 L
.38623 .29509 L
.38693 .29502 L
.38758 .29488 L
.38829 .29466 L
.38904 .29437 L
.39142 .29333 L
.3921 .29307 L
.39276 .29287 L
Mistroke
.39398 .29266 L
.39529 .29272 L
.39603 .29291 L
.39672 .29319 L
.39796 .29393 L
.39928 .29502 L
.40209 .29802 L
.40356 .29968 L
.40512 .30125 L
.40647 .30233 L
.40724 .3028 L
.40796 .30312 L
.40922 .30345 L
.40992 .30348 L
.41057 .30343 L
.41183 .30314 L
.41255 .30287 L
.41321 .30258 L
.4157 .30132 L
.41677 .30085 L
.41792 .30047 L
.41918 .30027 L
.42036 .30034 L
.42162 .30069 L
.42225 .30098 L
.42294 .30137 L
.42531 .30318 L
.42784 .30547 L
.42917 .30657 L
.4299 .30709 L
.43058 .30751 L
.43182 .30808 L
.43247 .30826 L
.43318 .30838 L
.43443 .30835 L
.43557 .30809 L
.43676 .30762 L
.43786 .30706 L
.44035 .30565 L
.44149 .3051 L
.44255 .3047 L
.44378 .30444 L
.4449 .30441 L
.44611 .30463 L
.44681 .30487 L
.44745 .30516 L
.44875 .30591 L
.45014 .30689 L
.45245 .30863 L
.45367 .30945 L
Mistroke
.45496 .31014 L
.45569 .31043 L
.45648 .31064 L
.45721 .31074 L
.45789 .31075 L
.45858 .31067 L
.45922 .31054 L
.45992 .31031 L
.46066 .31001 L
.46332 .3085 L
.46464 .3077 L
.46584 .30704 L
.46701 .30654 L
.46825 .30621 L
.46949 .30612 L
.47019 .30619 L
.47085 .30632 L
.472 .30672 L
.47305 .30723 L
.4754 .30872 L
.47791 .31032 L
.47859 .31068 L
.47932 .311 L
.48064 .31138 L
.48128 .31146 L
.48198 .31148 L
.48325 .3113 L
.48448 .31088 L
.4856 .31034 L
.48784 .30897 L
.48907 .30819 L
.49023 .30753 L
.49132 .30703 L
.49249 .30666 L
.49356 .3065 L
.49455 .30653 L
.49559 .30673 L
.49673 .30714 L
.49793 .30774 L
.49905 .30841 L
.50143 .30993 L
.50274 .31065 L
.50398 .31117 L
.50463 .31136 L
.50533 .31149 L
.50655 .31152 L
.5078 .31131 L
.50894 .3109 L
.5102 .31028 L
.51157 .30944 L
Mistroke
.51303 .30851 L
.51436 .30772 L
.51562 .30711 L
.51682 .30672 L
.51808 .30655 L
.5188 .30658 L
.51946 .30668 L
.52056 .30699 L
.52177 .30754 L
.52422 .30906 L
.52646 .31052 L
.52768 .31117 L
.52882 .31162 L
.53005 .31188 L
.53071 .31191 L
.5314 .31187 L
.53265 .31161 L
.53378 .31118 L
.53805 .30871 L
.53922 .30809 L
.54047 .30759 L
.54166 .30732 L
.54275 .30729 L
.54394 .30749 L
.54523 .30798 L
.54646 .30866 L
.54759 .30944 L
.55029 .31146 L
.55146 .31226 L
.55272 .31296 L
.55392 .31341 L
.55502 .31361 L
.55607 .31361 L
.55718 .31341 L
.55835 .31301 L
.55945 .31249 L
.56193 .31109 L
.56322 .31042 L
.5639 .31013 L
.56463 .30989 L
.56526 .30974 L
.56596 .30965 L
.56718 .3097 L
.56837 .31003 L
.56965 .31066 L
.57086 .31149 L
.57197 .3124 L
.57469 .31485 L
.57601 .31594 L
.57721 .31676 L
Mistroke
.57849 .31738 L
.57919 .3176 L
.57985 .31773 L
.58056 .31777 L
.58123 .31773 L
.58195 .3176 L
.58272 .31737 L
.58505 .31633 L
.58627 .31571 L
.58758 .31511 L
.58871 .31474 L
.58997 .31455 L
.59111 .31464 L
.59218 .31497 L
.59283 .31528 L
.59351 .3157 L
.59474 .31666 L
.59749 .31953 L
.59983 .32213 L
.60112 .32337 L
.60233 .32431 L
.60347 .32493 L
.6047 .32531 L
.60583 .32539 L
.60686 .32525 L
.60784 .32498 L
.60891 .32457 L
.61108 .32361 L
.61233 .32318 L
.61346 .32296 L
.61478 .32301 L
.61603 .32341 L
.61717 .32411 L
.61824 .32503 L
.62066 .32791 L
.62313 .33144 L
.62574 .33483 L
.6271 .33616 L
.62788 .33673 L
.6286 .33713 L
.62987 .33753 L
.63058 .3376 L
.63123 .33757 L
.63355 .33693 L
.63481 .33643 L
.636 .336 L
.63729 .33572 L
.63797 .33569 L
.6387 .33578 L
.64 .33627 L
Mistroke
.64119 .33714 L
.64234 .33836 L
.64342 .33981 L
.64585 .34394 L
.64842 .3487 L
.64954 .35061 L
.65075 .3524 L
.65192 .35377 L
.653 .35469 L
.65404 .35524 L
.65513 .35548 L
.65628 .35542 L
.65735 .35513 L
.65853 .35466 L
.6598 .35413 L
.66049 .35389 L
.66114 .35373 L
.66235 .35366 L
.66366 .35405 L
.66439 .35452 L
.66506 .35512 L
.6662 .35651 L
.66744 .35856 L
.66994 .36403 L
.6727 .3709 L
.67422 .37435 L
.67566 .37704 L
.67631 .37802 L
.677 .37887 L
.67775 .37958 L
.67845 .38002 L
.67966 .38034 L
.68034 .38028 L
.68099 .3801 L
.68223 .37948 L
.68358 .37859 L
.68477 .37784 L
.68605 .37733 L
.6873 .37734 L
.68844 .37793 L
.68959 .3792 L
.69067 .38104 L
.69194 .38399 L
.69328 .38792 L
.69568 .39629 L
.69701 .40111 L
.69846 .40596 L
.69974 .40955 L
.70044 .41115 L
.70109 .41237 L
Mistroke
.70232 .41387 L
.70297 .41425 L
.70367 .41433 L
.70491 .4137 L
.70605 .4124 L
.70839 .40849 L
.70953 .40659 L
.71056 .40523 L
.71171 .40445 L
.71293 .40475 L
.71356 .40546 L
.71425 .40672 L
.71551 .41034 L
.71683 .41598 L
.71822 .4238 L
.72072 .44091 L
.72289 .4558 L
.72411 .4626 L
.72523 .46703 L
.72626 .46913 L
.72739 .46875 L
.72846 .46548 L
.72945 .45972 L
.7307 .44843 L
.73189 .43379 L
.7341 .39687 L
.73905 .28677 L
.7413 .23697 L
.74371 .19295 L
.7451 .17398 L
.74636 .16129 L
.74763 .15303 L
.74883 .14924 L
.75008 .14908 L
.75071 .15029 L
.7514 .1525 L
.75263 .15828 L
.75378 .1653 L
.7564 .18373 L
.75783 .19333 L
.75915 .20099 L
.76023 .20596 L
.76137 .20991 L
.76264 .2126 L
.7638 .21358 L
.76485 .21343 L
.76599 .21239 L
.76706 .21081 L
.76805 .20911 L
.76912 .20723 L
Mistroke
.77027 .20546 L
.77153 .20413 L
.77271 .20369 L
.77403 .2043 L
.77528 .20598 L
.77641 .20837 L
.77764 .21178 L
.78214 .22757 L
.78338 .23157 L
.78468 .23514 L
.78579 .23752 L
.78701 .23937 L
.78771 .24007 L
.78835 .24049 L
.78908 .24074 L
.78978 .24076 L
.79101 .2404 L
.79171 .24002 L
.79235 .23962 L
.79361 .23878 L
.79479 .23811 L
.79602 .23772 L
.79667 .2377 L
.79737 .23786 L
.79805 .23818 L
.79877 .23874 L
.80006 .24027 L
.80085 .24154 L
.8016 .24293 L
.80299 .24596 L
.80578 .25285 L
.807 .25579 L
.80834 .25868 L
.80947 .26072 L
.81068 .26242 L
.81196 .26364 L
.81316 .26424 L
.81383 .26437 L
.81456 .26438 L
.81524 .26426 L
.81588 .26408 L
.81709 .26362 L
.81837 .26308 L
.81951 .2627 L
.82075 .26254 L
.82205 .26276 L
.82326 .26339 L
.82439 .26439 L
.82542 .26562 L
.82774 .26927 L
Mistroke
.83009 .27364 L
.83259 .27794 L
.83389 .27972 L
.83458 .28049 L
.83532 .28117 L
.83662 .28198 L
.83784 .28231 L
.83905 .28229 L
.84036 .28198 L
.8416 .28152 L
.84275 .28106 L
.8439 .28068 L
.84493 .28047 L
.84612 .28047 L
.84724 .28075 L
.84833 .28131 L
.84947 .2822 L
.85044 .28319 L
.85151 .28448 L
.85612 .29091 L
.85734 .29238 L
.85864 .29363 L
.85932 .29414 L
.86007 .29457 L
.86138 .29502 L
.86262 .29508 L
.86331 .29499 L
.86395 .29483 L
.86512 .29442 L
.86635 .29388 L
.86747 .29339 L
.86866 .29295 L
.86979 .2927 L
.87081 .29265 L
.87201 .29284 L
.87331 .29339 L
.87454 .29422 L
.87567 .29521 L
.87821 .29794 L
.87961 .29952 L
.88093 .30089 L
.88216 .30196 L
.88281 .30243 L
.8835 .30283 L
.88472 .30331 L
.88585 .30348 L
.8871 .30338 L
.88828 .30305 L
.88957 .30249 L
.89097 .30179 L
Mistroke
.8924 .30109 L
.89318 .30076 L
.89391 .30052 L
.89519 .30028 L
.89587 .30027 L
.8966 .30035 L
.89783 .3007 L
.89853 .30102 L
.89918 .3014 L
.90192 .30356 L
.90444 .30582 L
.90568 .3068 L
.90683 .30754 L
.90748 .30787 L
.90816 .30813 L
.90893 .30832 L
.90962 .30839 L
.91094 .3083 L
.91218 .30794 L
.91288 .30765 L
.91361 .30729 L
.91494 .30656 L
.9165 .30568 L
.91718 .30533 L
.91792 .30499 L
.91916 .30458 L
.92032 .30441 L
.92097 .30441 L
.92166 .30449 L
.92289 .30483 L
.92403 .30536 L
.9251 .30601 L
.92753 .3078 L
.93 .30954 L
.93125 .31018 L
.93195 .31045 L
.9326 .31063 L
.93333 .31073 L
.93398 .31075 L
.93474 .31068 L
.93546 .31052 L
.93671 .31007 L
.93807 .30937 L
.94027 .30803 L
.94148 .30733 L
.94263 .30676 L
.9437 .30638 L
.94486 .30615 L
.94591 .30614 L
.94689 .30629 L
Mistroke
.94816 .30671 L
.94936 .3073 L
.95159 .30872 L
.95403 .31028 L
.95525 .31089 L
.95594 .31115 L
.95659 .31133 L
.95783 .31148 L
.95896 .31139 L
.96027 .31104 L
.9615 .31049 L
.96369 .30919 L
.96602 .30775 L
.96722 .30714 L
.96791 .30688 L
.96855 .30669 L
.96968 .30651 L
.97089 .30655 L
.97157 .30668 L
.97231 .3069 L
.97301 .30718 L
.97366 .30749 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00X_oonfX4o`0006[ooo]Z0ol007l:oookJPGo0000P_oonfX5o`0009Oooo]Z
002QoookJPKo0000JOoonfX3o`00O`[ooo]Z1Ol00022oookJPGo0000UooonfX00:7ooo]Z1_l0001Y
oookJP?o001o2_oonfX5o`00087ooo]Z1_l0002GoookJP00XOoonfX6o`0005Wooo]Z2_l007l6oook
JP?o001o2_oonfX5o`00087ooo]Z1_l0002GoookJP00XOoonfX6o`0005Wooo]Z2_l007l6oookJP?o
001o2_oonfX6o`00083ooo]Z1ol0002FoookJP00XOoonfX7o`0006Sooo]Z0ol007l:oookJPGo0000
POoonfX7o`0009Kooo]Z002QoookJPOo0000J?oonfX3o`00O`[ooo]Z1Ol00021oookJPOo0000U_oo
nfX00:7ooo]Z1ol0001XoookJP?o001o2_oonfX5o`00087ooo]Z1ol0002FoookJP00X?oonfX8o`00
06Sooo]Z0ol007l:oookJPGo0000POoonfX8o`0009Gooo]Z002PoookJPSo0000IOoonfX6o`00O`[o
oo]Z1Ol00021oookJPSo0000UOoonfX00:3ooo]Z2?l0001UoookJPKo001o2_oonfX5o`00087ooo]Z
2?l0002EoookJP00X?oonfX9o`0006Kooo]Z1?l007l:oookJPGo0000P?oonfX9o`0009Gooo]Z002P
oookJPWo0000IooonfX3o`00O`[ooo]Z1Ol00020oookJPWo0000UOoonfX00:3ooo]Z2Ol0001doook
JPGo0000P?oonfX9o`0009Gooo]Z002PoookJPCo000000?ooo]Zo`000?l000000_l0001doookJPGo
0000P?oonfX4o`000003oookJ_l0003o000000;o0000UOoonfX00:3ooo]Z1?l000000ooonf[o0000
o`000002o`0007Cooo]Z1Ol00020oookJPCo000000?ooo]Zo`000?l000000ol0002DoookJP00Wooo
nfX5o`000003oookJ_l0003o000000;o0000M?oonfX5o`00083ooo]Z1?l000000ooonf[o0000o`00
0003o`0009Cooo]Z002OoookJPGo000000?ooo]Zo`000?l000000_l0001doookJPGo0000P?oonfX4
o`000003oookJ_l0003o000000?o0000U?oonfX009oooo]Z1Ol000000ooonf[o0000o`000002o`00
07Cooo]Z1Ol00020oookJPCo00000_oonfX4o`0009Cooo]Z002OoookJPCo00000_oonfX5o`0007?o
oo]Z1Ol00020oookJPCo00000_oonfX4o`0009Cooo]Z002OoookJPCo00000_oonfX5o`0007?ooo]Z
1Ol0001ooookJPGo00000_oonfX4o`0009Cooo]Z002OoookJPCo00000_oonfX5o`0007?ooo]Z1Ol0
001ooookJPGo00000_oonfX4o`0009Cooo]Z002OoookJPCo00000ooonfX4o`0007?ooo]Z1Ol0001o
oookJPGo00000_oonfX5o`0009?ooo]Z002OoookJPCo00000ooonfX4o`0007?ooo]Z1Ol0001ooook
JPCo00000ooonfX5o`0009?ooo]Z002OoookJPCo00000ooonfX5o`0007;ooo]Z1Ol0001ooookJPCo
00000ooonfX5o`0009?ooo]Z002OoookJPCo00000ooonfX5o`0007;ooo]Z1Ol0001ooookJPCo0000
1?oonfX4o`0009?ooo]Z002OoookJPCo00000ooonfX5o`0007;ooo]Z1Ol0001ooookJPCo00001?oo
nfX4o`0009?ooo]Z002OoookJPCo00001?oonfX4o`0007;ooo]Z1Ol0001ooookJPCo00001?oonfX4
o`0009?ooo]Z002OoookJPCo00001?oonfX4o`0007;ooo]Z1Ol0001ooookJPCo00001?oonfX4o`00
09?ooo]Z002OoookJPCo00001?oonfX4o`0007;ooo]Z1Ol0001ooookJPCo00001?oonfX4o`0009?o
oo]Z002OoookJPCo00001?oonfX4o`0000?ooo]Z1Ol0001ZoookJPGo0000OooonfX4o`0000Cooo]Z
1Ol00002oookJPKo0000R_oonfX009oooo]Z1?l00004oookJPGo000000?ooo]Zo`000?l000001Ol0
001YoookJPGo0000OooonfX4o`0000Cooo]Z1Ol000000ooonf[o0000o`000005o`0008[ooo]Z002O
oookJPCo00001?oonfX5o`000003oookJ_l0003o000000Go0000JOoonfX5o`0007oooo]Z1?l00004
oookJPGo000000?ooo]Zo`000?l000001_l00029oookJP00WooonfX4o`0000Cooo]Z3_l0001Xoook
JPGo0000OooonfX4o`0000Gooo]Z3Ol00029oookJP00WooonfX4o`0000Gooo]Z3Ol0001XoookJPGo
0000OooonfX4o`0000Gooo]Z3Ol00029oookJP00WooonfX4o`0000Gooo]Z3Ol0001XoookJPGo0000
OooonfX4o`0000Gooo]Z3Ol00029oookJP00W_oonfX5o`0000Kooo]Z1ol000000ooonf[o0000o`00
0003o`0006Oooo]Z1Ol0001ooookJPCo00001_oonfX7o`000003oookJ_l0003o000000?o0000R?oo
nfX009kooo]Z1Ol00006oookJPOo000000?ooo]Zo`000?l000000ol0001WoookJPGo0000O_oonfX5
o`0000Kooo]Z1ol000000ooonf[o0000o`000003o`0008Sooo]Z002NoookJPGo00001ooonfX5o`00
00;ooo]Z1Ol0001WoookJPGo0000O_oonfX5o`0000Kooo]Z1_l00002oookJPGo0000R?oonfX009ko
oo]Z1?l0000@oookJPCo0000IooonfX5o`0007kooo]Z1Ol0000?oookJPGo0000QooonfX009kooo]Z
1?l0000@oookJPCo0000IooonfX5o`0007kooo]Z1?l0000@oookJPGo0000QooonfX009kooo]Z1?l0
000@oookJPGo0000I_oonfX5o`0007kooo]Z1?l0000@oookJPGo0000QooonfX009kooo]Z1?l0000@
oookJPGo0000B?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0007kooo]Z1?l0000A
oookJPGo0000Q_oonfX009kooo]Z1?l0000@oookJPGo0000AooonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o2OoonfX5o`0007kooo]Z1?l0000AoookJPGo0000Q_oonfX009kooo]Z1?l0000AoookJPGo
0000A_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001noookJPCo00004OoonfX5o`0008Kooo]Z002Noook
JPCo00004OoonfX5o`0003Wooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o2?oonfX5o`0007kooo]Z1?l0000BoookJPGo0000QOoonfX009kooo]Z1?l0000AoookJPKo
0000>?oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001moookJPCo
00004_oonfX5o`0008Gooo]Z002NoookJPCo00004_oonfX5o`0004Cooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Sooo]Z1Ol0001noookJPCo00004_oonfX5o`0008Gooo]Z002NoookJPCo00004_oo
nfX6o`000003oookJ_l0003o000000?o0000?OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z1Ol0001noookJPCo00004ooonfX5o`000003oookJ_l0003o000000?o0000O_oo
nfX009gooo]Z1Ol0000CoookJPco0000??oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5
o`0007kooo]Z1?l0000CoookJPco0000OOoonfX009gooo]Z1Ol0000CoookJPgo0000>ooonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0007kooo]Z1?l0000CoookJPgo0000O?oonfX009go
oo]Z1Ol0000CoookJPgo0000>ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0007ko
oo]Z1?l0000DoookJPco0000O?oonfX009gooo]Z1?l0000EoookJPco0000??oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000O_oonfX4o`0001Gooo]Z2ol0001loookJP00
WOoonfX4o`0001Kooo]Z1_l000000ooonf[o0000o`000003o`0003_ooo]Z1ol007l9oookJPOo001o
2?oonfX5o`0007kooo]Z1?l0000EoookJPKo000000?ooo]Zo`000?l000000ol0001koookJP00WOoo
nfX4o`0001gooo]Z1Ol0000loookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001noookJPCo00007?oo
nfX5o`0007_ooo]Z002MoookJPCo00007OoonfX6o`0005Wooo]Z1Ol0001noookJPCo00007?oonfX6
o`0007[ooo]Z002MoookJPCo00007_oonfX5o`0005Wooo]Z1Ol0001noookJPCo00007OoonfX5o`00
07[ooo]Z002MoookJPCo00007_oonfX6o`0005Sooo]Z1Ol0001noookJPCo00007OoonfX6o`0007Wo
oo]Z002MoookJPCo00007ooonfX5o`0005Sooo]Z1Ol0001noookJPCo00007_oonfX5o`0007Wooo]Z
002MoookJPCo00007ooonfX6o`0005Oooo]Z1Ol0001noookJPCo00007_oonfX5o`0007Wooo]Z002M
oookJPCo00008?oonfX5o`0005Oooo]Z1Ol0001noookJPCo00007ooonfX5o`0007Sooo]Z002Moook
JPCo00008?oonfX6o`0005Kooo]Z1Ol0001noookJPCo00007ooonfX6o`0007Oooo]Z002MoookJPCo
00008OoonfX<o`0004oooo]Z1Ol0001moookJPGo00007ooonfX=o`00073ooo]Z002MoookJPCo0000
8OoonfX=o`0004kooo]Z1Ol0001moookJPGo00008?oonfX=o`0006oooo]Z002MoookJPCo00008_oo
nfX=o`0004gooo]Z1Ol0001moookJPGo00008OoonfX=o`0006kooo]Z002MoookJPCo00008_oonfX>
o`0004cooo]Z1Ol0001moookJPCo00008_oonfX>o`0006gooo]Z002MoookJPCo00009?oonfX<o`00
04cooo]Z1Ol0001moookJPCo00009?oonfX5o`000003oookJ_l0003o000000Co0000KOoonfX002;o
oo]Z0ol007meoookJP?o001o1?l00002oookJP?o001o0ooonfX5o`00Oakooo]Z1_l0001;oookJPGo
0000M?oonfX5o`00O`Cooo]Z1?l00002oookJPGo001o8ooonfX7o`0004cooo]Z0ol007lMoookJP00
8_oonfX3o`00OgCooo]Z1?l007l4o`0000;ooo]Z0ol007l2oookJPOo001o7_oonfX5o`0004_ooo]Z
1Ol0001coookJPOo001o0ooonfX4o`000003oookJ_l007oo001o00Go001o9?oonfX5o`0004cooo]Z
0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Oakooo]Z1Ol0001;oookJPGo0000
LooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1?l00004o`00O`04oookJ_l007oo001oo`00
ObCooo]Z1Ol0001<oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l00ooonf[o0000o`000003o`0000Kooo]Z0ol007l3oookJP?o001o7_oonfX5o`0004[o
oo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00003o`00O`?ooo]Z0ol007lToookJPGo
0000BooonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o
00?ooo]Zo`000?l000000ol0000<oookJP?o001o7_oonfX6o`0004Wooo]Z1Ol0001boookJP?o001o
0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o9?oonfX6o`0004[ooo]Z0ol007lMoookJP008_oo
nfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000003o`0000cooo]Z0ol007lNoookJPko0000@Ooo
nfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`0000Kooo]Z0ol007lToookJPko0000@_oo
nfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001o
oookJ_oonfX01OoonfX2o`00O`;ooo]Z1?l007lOoookJPko0000@?oonfX5o`0007;ooo]Z0ol007l3
oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o00;ooo]Z1?l007lUoookJPko0000@OoonfX3
o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooook
J_oonfX01OoonfX7o`00Ob7ooo]Z3Ol00010oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oook
JPCo000000?ooo]Zo`00Ool007l01Ol007lWoookJPgo0000@OoonfX3o`00Oagooo]Z000RoookJP?o
001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX6o`00Ob;o
oo]Z3_l0000ooookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Zo`00Ool0
07l01?l007lXoookJPko0000@?oonfX3o`00Oagooo]Z000OoookJPKo001oLooonfX3o`00O`03oook
J_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX2o`00ObSooo]Z1Ol00002oookJPKo0000
?_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o02kooo]Z
1Ol00002oookJPKo0000??oonfX6o`00Oagooo]Z000OoookJPKo001oM?oonfX3o`00O`Co00002?oo
nfX2o`00Oboooo]Z1ol0000moookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
1?l000000ooonf[o001oo`00O`0eoookJPOo0000>ooonfX6o`00Oagooo]Z000QoookJPCo001oM?oo
nfX3o`00O`Co00002OoonfX7o`00Ob[ooo]Z1ol00002oookJPKo0000=?oonfX5o`0007?ooo]Z1ol0
07l3oookJPCo00000_oonfX7o`00Oc3ooo]Z1ol00002oookJPKo0000=?oonfX4o`00Oagooo]Z000R
oookJP?o001oMOoonfX2o`00O`Co00002OoonfX7o`00Ob_ooo]Z3ol0000coookJPGo0000M?oonfX5
o`00O`Cooo]Z1?l00002oookJPOo001o<OoonfX?o`0003Cooo]Z0ol007lMoookJP00W?oonfX4o`00
03cooo]Z3ol0000boookJPGo0000OOoonfX4o`0003_ooo]Z3ol0001CoookJP00W?oonfX4o`0003go
oo]Z3ol0000aoookJPGo0000OOoonfX4o`0003cooo]Z3ol0001BoookJP00W?oonfX4o`0003gooo]Z
4?l00004oookJPGo00009ooonfX5o`0007gooo]Z1?l0000loookJQ3o00000ooonfX6o`0004Sooo]Z
002LoookJPCo0000AooonfX7o`000003oookJ_l0003o000000Oo00009OoonfX5o`0007gooo]Z1?l0
0016oookJQ7o0000A_oonfX009cooo]Z1?l00018oookJQ7o00009?oonfX5o`0007gooo]Z1?l00017
oookJQ7o0000AOoonfX009cooo]Z1?l00019oookJQ7o00000_oonfX9o`0000Oooo]Z1Ol0000<oook
JPGo0000OOoonfX4o`0004Sooo]Z4Ol00003oookJPWo00001_oonfX5o`0002gooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`00
00oooo]Z000LoookJPSo00001OoonfX9o`0000?ooo]Z7Ol0001:oookJPCo0000IOoonfX7o`0000Go
oo]Z2?l00004oookJP[o00001?oonfX9o`0000Cooo]Z7?l0001:oookJPCo0000IOoonfX7o`0000Go
oo]Z2?l00006oookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPGo00001ooonfX8o`0000?ooo]Z
4Ol00019oookJPCo0000OOoonfX5o`0000_ooo]Z1Ol00007oookJPSo00000ooonfXAo`0004Wooo]Z
1?l0002NoookJP00>OoonfX4o`0000Kooo]Z4Ol00018oookJPCo0000OOoonfX5o`0001Wooo]Z1?l0
0006oookJQ7o0000B?oonfX4o`0009kooo]Z0014oookJPWo000000?ooo]Zo`000?l000001Ol00017
oookJPCo0000OOoonfX5o`0002Cooo]Z4Ol00017oookJPCo0000W_oonfX004Kooo]Z1Ol00004oook
JQ3o0000??oonfX5o`0007gooo]Z1Ol0000VoookJPKo00000ooonfX@o`0003gooo]Z1?l0002Noook
JP00D?oonfX@o`0003_ooo]Z1Ol0001moookJPGo0000<?oonfX?o`0003gooo]Z1?l0002NoookJP00
DOoonfX?o`0003_ooo]Z1Ol0001moookJPGo0000<OoonfX?o`0003cooo]Z1?l0002NoookJP00DOoo
nfX@o`0003[ooo]Z1?l0001noookJPGo0000<_oonfX?o`0003_ooo]Z1?l0002NoookJP00DooonfX7
o`000003oookJ_l0003o000000Go0000>OoonfX4o`0007kooo]Z1Ol0000coookJPKo00000_oonfX7
o`0003[ooo]Z1?l0002NoookJP00G?oonfX7o`0003Sooo]Z1?l0001noookJPGo0000??oonfX6o`00
03[ooo]Z1?l0002NoookJP00GOoonfX6o`0000;ooo]Z1Ol0000aoookJPCo0000O_oonfX5o`0003go
oo]Z1_l00003oookJPCo0000<_oonfX4o`0009kooo]Z001NoookJPgo0000<?oonfX4o`0007kooo]Z
1Ol0000noookJPko0000<?oonfX4o`0009kooo]Z001OoookJPgo0000;ooonfX4o`0007kooo]Z1Ol0
000noookJPko0000<?oonfX4o`0009kooo]Z001OoookJPko0000;_oonfX4o`0007kooo]Z1Ol0000o
oookJPko0000;ooonfX4o`0009kooo]Z001PoookJPgo0000;_oonfX4o`0007kooo]Z1Ol00010oook
JPgo0000;ooonfX4o`0009kooo]Z001RoookJPCo00000_oonfX6o`0002gooo]Z1?l0001noookJPGo
0000@_oonfX4o`0000;ooo]Z1_l0000]oookJPGo0000W_oonfX006Wooo]Z1Ol0000]oookJPCo0000
O_oonfX5o`0004Wooo]Z1Ol0000]oookJPGo0000W_oonfX006Wooo]Z1Ol0000]oookJPCo0000O_oo
nfX5o`0004Wooo]Z1_l0000/oookJPGo0000W_oonfX006[ooo]Z1Ol0000/oookJPCo0000O_oonfX5
o`0004[ooo]Z1Ol0000/oookJPCo0000WooonfX006[ooo]Z1_l0000[oookJPCo0000O_oonfX5o`00
04[ooo]Z1_l0000[oookJPCo0000WooonfX006[ooo]Z1ol000000ooonf[o0000o`000004o`0002?o
oo]Z1?l0001noookJPGo0000BooonfX6o`000003oookJ_l0003o000000Co00008ooonfX4o`0009oo
oo]Z001[oookJPko00008_oonfX4o`0007kooo]Z1Ol0001;oookJPgo00008ooonfX4o`0009oooo]Z
001/oookJPgo00008_oonfX4o`0007kooo]Z1Ol0001<oookJPgo00008_oonfX4o`0009oooo]Z001]
oookJPco00008_oonfX4o`0007kooo]Z1Ol0001=oookJPgo00008OoonfX4o`0009oooo]Z001^oook
JPco00008OoonfX4o`0007kooo]Z1Ol0001>oookJPco00008OoonfX4o`0009oooo]Z001eoookJPGo
00008?oonfX5o`0007kooo]Z1Ol0001EoookJPKo00008?oonfX4o`0009oooo]Z001eoookJPKo0000
7ooonfX5o`0007kooo]Z1Ol0001FoookJPGo00008?oonfX4o`0009oooo]Z001foookJPGo00007ooo
nfX5o`0007kooo]Z1Ol0001FoookJPGo00008?oonfX4o`0009oooo]Z001foookJPKo00007_oonfX4
o`0007oooo]Z1Ol0001GoookJPGo00007ooonfX4o`0009oooo]Z001goookJPGo00007_oonfX4o`00
07oooo]Z1Ol0001GoookJPGo00007ooonfX4o`0009oooo]Z001goookJPKo00007OoonfX4o`0007oo
oo]Z1Ol0001GoookJPKo00007_oonfX4o`0009oooo]Z001hoookJPGo00007OoonfX4o`0007oooo]Z
1Ol0001HoookJPGo00007_oonfX4o`0009oooo]Z001hoookJPGo00007OoonfX4o`0007oooo]Z1Ol0
001HoookJPGo00007_oonfX4o`0009oooo]Z001ioookJPGo000000?ooo]Zo`000?l000001?l0000E
oookJPCo0000OooonfX5o`0005Wooo]Z3?l0000FoookJPCo0000WooonfX007Wooo]Z3Ol0000Doook
JPCo0000OooonfX5o`0005Wooo]Z3Ol0000EoookJPCo0000WooonfX007Wooo]Z3Ol0000DoookJPCo
0000HOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0005Wooo]Z3Ol0000DoookJPGo
0000WooonfX007[ooo]Z3?l0000DoookJPCo0000H?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
2OoonfX5o`0005[ooo]Z3?l0000DoookJPGo0000WooonfX007_ooo]Z3?l0000CoookJPCo0000H?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Wooo]Z1Ol0001KoookJPco00004ooonfX5o`0009oooo]Z001loookJPGo0000
00?ooo]Zo`000?l000000ol0000CoookJPCo0000GooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`Sooo]Z1Ol0001LoookJPGo000000?ooo]Zo`000?l000000ol0000CoookJPCo0000
X?oonfX008;ooo]Z1_l0000BoookJPCo0000GooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oo
nfX6o`00067ooo]Z1_l0000BoookJPCo0000X?oonfX008?ooo]Z1Ol0000BoookJPCo0000GooonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0006?ooo]Z1Ol0000BoookJPCo0000X?oonfX0
08?ooo]Z1Ol0000BoookJPCo0000GooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00
O`Sooo]Z1Ol0001SoookJPGo00004_oonfX4o`000:3ooo]Z0024oookJPGo00004OoonfX4o`0005oo
oo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001ToookJPGo00004OoonfX4o`000:3o
oo]Z0024oookJPGo00004OoonfX4o`0005oooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z
1Ol0001ToookJPGo00004OoonfX4o`000:3ooo]Z0024oookJPGo00004OoonfX4o`0005oooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001ToookJPGo00004OoonfX4o`000:3ooo]Z0025
oookJPGo00004?oonfX4o`00063ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oo
nfX5o`0006Gooo]Z1Ol0000@oookJPCo0000X?oonfX008Gooo]Z1Ol0000?oookJPGo0000H?oonfX7
o`00O`Wooo]Z1ol007l8oookJPGo0000IOoonfX5o`00013ooo]Z1?l0002PoookJP00QOoonfX5o`00
00oooo]Z1Ol0001QoookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001UoookJPGo00004?oonfX4o`00
0:3ooo]Z0026oookJPCo00000ooonfX5o`0000Oooo]Z1Ol0001ooookJPGo0000I_oonfX5o`0000;o
oo]Z1_l00007oookJPCo0000X?oonfX008Kooo]Z1?l00003oookJPKo00001_oonfX4o`00083ooo]Z
1Ol0001VoookJPGo00000_oonfX6o`0000Oooo]Z1?l0002PoookJP00Q_oonfX5o`000003oookJ_l0
003o000000Ko00001OoonfX4o`00083ooo]Z1Ol0001VoookJPGo000000?ooo]Zo`000?l000001Ol0
0007oookJPCo0000X?oonfX008Kooo]Z3_l00005oookJPCo0000P?oonfX5o`0006Oooo]Z3Ol00006
oookJPCo0000X?oonfX008Kooo]Z3_l00005oookJPCo0000P?oonfX5o`0006Oooo]Z3Ol00006oook
JPCo0000X?oonfX008Oooo]Z3Ol00005oookJPCo0000P?oonfX5o`0006Oooo]Z3_l00005oookJPCo
0000X?oonfX008Oooo]Z2?l000000ooonf[o0000o`000002o`0000Gooo]Z1?l00020oookJPGo0000
IooonfX>o`0000Gooo]Z1?l0002PoookJP00R?oonfX6o`0000;ooo]Z1Ol00004oookJPCo0000P?oo
nfX5o`0006Sooo]Z1ol000000ooonf[o0000o`000003o`0000Cooo]Z1Ol0002PoookJP00R?oonfX6
o`0000;ooo]Z1Ol00004oookJPCo0000P?oonfX5o`0006Wooo]Z1Ol00003oookJPCo00001?oonfX5
o`000:3ooo]Z002@oookJPGo00001?oonfX4o`00083ooo]Z1Ol0001aoookJPCo00001?oonfX5o`00
0:3ooo]Z002AoookJPCo00001?oonfX4o`00083ooo]Z1Ol0001aoookJPCo00001?oonfX4o`000:7o
oo]Z002AoookJPCo00001?oonfX4o`00083ooo]Z1Ol0001aoookJPCo00001?oonfX4o`000:7ooo]Z
002AoookJPCo00001?oonfX4o`00083ooo]Z1Ol0001aoookJPCo00001?oonfX4o`000:7ooo]Z002A
oookJPCo00000ooonfX5o`00083ooo]Z1Ol0001aoookJPGo00000ooonfX4o`000:7ooo]Z002Aoook
JPGo00000_oonfX5o`00083ooo]Z1Ol0001aoookJPGo00000ooonfX4o`000:7ooo]Z002AoookJPGo
00000_oonfX5o`00083ooo]Z1Ol0001aoookJPGo00000ooonfX4o`000:7ooo]Z002AoookJPGo0000
0_oonfX4o`00087ooo]Z1Ol0001boookJPCo00000ooonfX4o`000:7ooo]Z002BoookJPCo00000_oo
nfX4o`00087ooo]Z1Ol0001boookJPCo00000ooonfX4o`000:7ooo]Z002BoookJPCo00000_oonfX4
o`00087ooo]Z1Ol0001boookJPGo00000_oonfX4o`000:7ooo]Z002BoookJPCo00000_oonfX4o`00
087ooo]Z1Ol0001boookJPGo00000_oonfX4o`000:7ooo]Z002BoookJPCo00000_oonfX4o`00087o
oo]Z1Ol0001boookJPGo00000_oonfX4o`000:7ooo]Z002BoookJPCo00000_oonfX4o`00087ooo]Z
1Ol0001coookJPCo000000?ooo]Zo`000?l000000ol0002QoookJP00T_oonfX5o`000003oookJ_l0
003o000000;o0000POoonfX5o`0007?ooo]Z1?l000000ooonf[o0000o`000003o`000:7ooo]Z002B
oookJPGo000000?ooo]Zo`000?l000000_l00021oookJPGo0000LooonfX4o`000003oookJ_l0003o
000000?o0000XOoonfX009;ooo]Z1Ol000000ooonf[o0000o`000002o`00087ooo]Z1Ol0001coook
JPCo000000?ooo]Zo`000?l000000_l0002RoookJP00TooonfX4o`000003oookJ_l0003o000000;o
0000POoonfX5o`0007?ooo]Z2Ol0002RoookJP00TooonfX4o`000003oookJ_l0003o000000;o0000
POoonfX5o`0007?ooo]Z2Ol0002RoookJP00TooonfX9o`00087ooo]Z1Ol0001coookJPWo0000X_oo
nfX009?ooo]Z2Ol00021oookJPGo0000M?oonfX8o`000:;ooo]Z002CoookJPWo0000M?oonfX3o`00
O`[ooo]Z1Ol0001doookJPSo0000X_oonfX009Cooo]Z2?l0001doookJP?o001o2_oonfX5o`0007Co
oo]Z2?l0002RoookJP00U?oonfX7o`0007Gooo]Z0ol007l:oookJPGo0000M?oonfX7o`000:?ooo]Z
002DoookJPOo0000MOoonfX3o`00O`[ooo]Z1Ol0001doookJPOo0000XooonfX009Cooo]Z1ol0001e
oookJP?o001o2_oonfX6o`0007?ooo]Z1ol0002SoookJP00U?oonfX7o`0007Gooo]Z0ol007l:oook
JPGo0000M?oonfX7o`000:?ooo]Z002DoookJPOo0000MOoonfX3o`00O`[ooo]Z1Ol0001doookJPOo
0000XooonfX009Cooo]Z1ol0001eoookJP?o001o2_oonfX5o`0007Gooo]Z1_l0002SoookJP00UOoo
nfX5o`0007Kooo]Z0ol007l:oookJPGo0000MOoonfX6o`000:?ooo]Z002FoookJPCo0000LooonfX6
o`00O`[ooo]Z1Ol0001foookJPCo0000Y?oonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooook
JQoooo]Z003ooookJQ3ooo]Z1?l007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8
oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oook
JP?o001o2?oonfX6o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo
0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oook
JP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooo
nfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003o
oookJQoooo]Z003ooookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo
001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003ooookJQ;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/
oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?o
oo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooo
nfX>oookJPOo001ooooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.06244 .3118 L
.06361 .31216 L
.06484 .31228 L
.06548 .31223 L
.06619 .3121 L
.06744 .31168 L
.06861 .31111 L
.06988 .31038 L
.07216 .30906 L
.07286 .30872 L
.07362 .30843 L
.07434 .30823 L
.075 .30812 L
.07626 .30813 L
.07696 .30827 L
.0776 .30847 L
.07883 .30906 L
.08015 .30993 L
.08255 .31183 L
.08405 .31298 L
.08544 .31385 L
.08614 .31419 L
.0869 .31445 L
.08773 .31463 L
.08849 .31468 L
.08919 .31463 L
.08984 .3145 L
.09055 .31429 L
.0913 .314 L
.09396 .3126 L
.09521 .31195 L
.09587 .31166 L
.09656 .31141 L
.09784 .31115 L
.09901 .31117 L
.09967 .3113 L
.10039 .31155 L
.10167 .31224 L
.10245 .3128 L
.10319 .31341 L
.10458 .31469 L
.10706 .31707 L
.10827 .31807 L
.10938 .3188 L
.11054 .31932 L
.1118 .31959 L
.11245 .3196 L
.11316 .31952 L
.11446 .31917 L
Mistroke
.11566 .31867 L
.11675 .31814 L
.11792 .31758 L
.11919 .31708 L
.12036 .31681 L
.12144 .31679 L
.12248 .317 L
.12357 .31749 L
.12868 .32256 L
.12989 .32402 L
.13119 .32543 L
.13239 .32652 L
.13351 .32729 L
.13478 .32782 L
.13545 .32795 L
.13618 .32799 L
.13692 .32792 L
.13769 .32774 L
.13836 .32753 L
.13908 .32725 L
.14045 .32666 L
.14174 .32616 L
.1429 .32587 L
.14415 .32584 L
.1454 .32616 L
.14672 .32694 L
.14785 .32796 L
.14909 .3294 L
.15163 .33308 L
.15435 .33707 L
.15567 .33863 L
.15691 .33974 L
.15803 .3404 L
.15925 .34074 L
.1604 .34073 L
.16163 .34046 L
.16267 .34009 L
.16383 .33963 L
.16498 .33924 L
.1662 .33902 L
.16724 .3391 L
.16838 .33951 L
.16961 .3404 L
.17092 .34187 L
.17216 .34371 L
.17329 .34568 L
.18218 .35873 L
.20295 .38101 L
.20403 .38238 L
.20521 .38326 L
Mistroke
.20632 .38354 L
.20735 .38336 L
.20855 .38277 L
.20982 .38188 L
.21091 .38111 L
.21208 .3805 L
.21281 .38032 L
.21348 .38035 L
.2148 .38104 L
.216 .38252 L
.21727 .38502 L
.21847 .38821 L
.21958 .39181 L
.22213 .4012 L
.22329 .40548 L
.22455 .40968 L
.22566 .41273 L
.22684 .41511 L
.2279 .41636 L
.22907 .41675 L
.23014 .41623 L
.23113 .4151 L
.23232 .41319 L
.23356 .41083 L
.23463 .40887 L
.23578 .40722 L
.23702 .40639 L
.23817 .40686 L
.23888 .40786 L
.23954 .40933 L
.24079 .41354 L
.24193 .41902 L
.24319 .42662 L
.24573 .44494 L
.24695 .45375 L
.2481 .4611 L
.24914 .46624 L
.25028 .46963 L
.25092 .4703 L
.25161 .46987 L
.25284 .46582 L
.25358 .46118 L
.25428 .45526 L
.25559 .44013 L
.25684 .42096 L
.25798 .39967 L
.26056 .34198 L
.26528 .2297 L
.26664 .20297 L
.26792 .18204 L
Mistroke
.26908 .16737 L
.27033 .1561 L
.27142 .15021 L
.27263 .14775 L
.27389 .14917 L
.27506 .15357 L
.27616 .15968 L
.27717 .16643 L
.27944 .18313 L
.28071 .19197 L
.28206 .19999 L
.28334 .20576 L
.2845 .20929 L
.28522 .21065 L
.28587 .21138 L
.28659 .21166 L
.28735 .21142 L
.28863 .21003 L
.28936 .20885 L
.29004 .20761 L
.29123 .20533 L
.29254 .20313 L
.29376 .20173 L
.2949 .20128 L
.29623 .20196 L
.29689 .20281 L
.29763 .20414 L
.29891 .20732 L
.30012 .21114 L
.30258 .22023 L
.30393 .2252 L
.30521 .22942 L
.3064 .23267 L
.30769 .23532 L
.30886 .23686 L
.30994 .23758 L
.31109 .2377 L
.31234 .23725 L
.31366 .2364 L
.31489 .23551 L
.31558 .23508 L
.31625 .23475 L
.31749 .2345 L
.31819 .23461 L
.31883 .2349 L
.31954 .23543 L
.32029 .23624 L
.33879 .25945 L
.3491 .26962 L
.36024 .27831 L
Mistroke
.36138 .27785 L
.36262 .27745 L
.3638 .27727 L
.36488 .27735 L
.36615 .27782 L
.36679 .27822 L
.36749 .27878 L
.36871 .28004 L
.36986 .28151 L
.37249 .28543 L
.37387 .28748 L
.37532 .28937 L
.37659 .29069 L
.37731 .29126 L
.37798 .29167 L
.37916 .29211 L
.38042 .29221 L
.38107 .29213 L
.38176 .29197 L
.383 .29152 L
.38445 .2909 L
.38516 .29061 L
.3858 .29039 L
.38697 .29011 L
.38822 .29007 L
.38888 .29018 L
.38959 .29041 L
.39088 .29111 L
.39202 .29202 L
.39327 .29329 L
.39582 .2963 L
.39804 .2988 L
.39916 .2998 L
.40038 .30062 L
.40107 .30094 L
.4018 .30115 L
.40311 .30125 L
.40442 .30102 L
.40561 .30058 L
.40831 .29929 L
.40905 .29897 L
.40984 .2987 L
.41051 .29854 L
.41125 .29844 L
.41255 .29852 L
.41329 .29872 L
.41396 .29899 L
.41526 .29976 L
.4165 .30074 L
.41888 .303 L
Mistroke
.42146 .30531 L
.42212 .30578 L
.42281 .30619 L
.42405 .30671 L
.42521 .3069 L
.42649 .30681 L
.42763 .30649 L
.42885 .30596 L
.43105 .30477 L
.43236 .3041 L
.43306 .30382 L
.4338 .30358 L
.43444 .30344 L
.43515 .30336 L
.4364 .30346 L
.43761 .30382 L
.43891 .30449 L
.44127 .30622 L
.44369 .30813 L
.44487 .30891 L
.44594 .30946 L
.44708 .30982 L
.44829 .30995 L
.44962 .30977 L
.45086 .30935 L
.45306 .30818 L
.45426 .30745 L
.45541 .30681 L
.45647 .30631 L
.45763 .30593 L
.45868 .30577 L
.45966 .30579 L
.46084 .30604 L
.4619 .30647 L
.46313 .30715 L
.46429 .30791 L
.46558 .30882 L
.46695 .30973 L
.46821 .31044 L
.46939 .31091 L
.47053 .31115 L
.47175 .31114 L
.47244 .31102 L
.4731 .31084 L
.47433 .31032 L
.47693 .30878 L
.47835 .30791 L
.47968 .30722 L
.48073 .30682 L
.48187 .30658 L
Mistroke
.48313 .30658 L
.48428 .30681 L
.48532 .3072 L
.48645 .30778 L
.48853 .30909 L
.48977 .30988 L
.49094 .31053 L
.49158 .31083 L
.49228 .31109 L
.49351 .31137 L
.49468 .31139 L
.49592 .31116 L
.49697 .31077 L
.49813 .31018 L
.50064 .3086 L
.50196 .30781 L
.50269 .30743 L
.50337 .30713 L
.50459 .30675 L
.50524 .30665 L
.50594 .30663 L
.50719 .30679 L
.50833 .30716 L
.51065 .30842 L
.51314 .31001 L
.51435 .31068 L
.51549 .31115 L
.51651 .31141 L
.51763 .31149 L
.51885 .31133 L
.52015 .31089 L
.52126 .31035 L
.52249 .30962 L
.52391 .30872 L
.52527 .30792 L
.52648 .30735 L
.52717 .30711 L
.52781 .30696 L
.5291 .30686 L
.52982 .30694 L
.53048 .30709 L
.53119 .30733 L
.53196 .30768 L
.53335 .30849 L
.53585 .31022 L
.53723 .3111 L
.53853 .31176 L
.53977 .31215 L
.54047 .31226 L
.54111 .31228 L
Mistroke
.54225 .31213 L
.54346 .31175 L
.54458 .31123 L
.54564 .31064 L
.54805 .30922 L
.54933 .30861 L
.54997 .30837 L
.55067 .30819 L
.55192 .30809 L
.55308 .30825 L
.55378 .30847 L
.55445 .30876 L
.5557 .30948 L
.55849 .31163 L
.56105 .31352 L
.56234 .31419 L
.56307 .31445 L
.56376 .31461 L
.56498 .31467 L
.5661 .31449 L
.56738 .31404 L
.56861 .31345 L
.57115 .31208 L
.57188 .31174 L
.57257 .31147 L
.57385 .31117 L
.57459 .31112 L
.57528 .31118 L
.57603 .31135 L
.57682 .31165 L
.57813 .31242 L
.57956 .31357 L
.58209 .31598 L
.58342 .31722 L
.58483 .31833 L
.58606 .31905 L
.58676 .31933 L
.58742 .31951 L
.58857 .3196 L
.58981 .31943 L
.591 .31904 L
.59231 .31845 L
.59345 .31788 L
.59468 .31733 L
.59589 .31694 L
.59699 .31678 L
.59809 .31686 L
.59913 .31718 L
.6044 .32199 L
.60697 .325 L
Mistroke
.60809 .32611 L
.60931 .32705 L
.61058 .32769 L
.61179 .32797 L
.61245 .32798 L
.61316 .32791 L
.61444 .32757 L
.61715 .32645 L
.61789 .32617 L
.61867 .32595 L
.61934 .32584 L
.62007 .32582 L
.6213 .32605 L
.62262 .32673 L
.62386 .32777 L
.62499 .32904 L
.62961 .33578 L
.63087 .33749 L
.63221 .33898 L
.63291 .33959 L
.63368 .34012 L
.63437 .34046 L
.63503 .34066 L
.63632 .34076 L
.63749 .34055 L
.63814 .34035 L
.63885 .34009 L
.64014 .33958 L
.6414 .33918 L
.64258 .33902 L
.64364 .33914 L
.64478 .33963 L
.64604 .34063 L
.64736 .34221 L
.64973 .34614 L
.65861 .3588 L
.67829 .37957 L
.69663 .39486 L
.69907 .40401 L
.7004 .40863 L
.70165 .41225 L
.70236 .41388 L
.703 .41506 L
.70372 .41602 L
.70449 .41661 L
.70577 .4166 L
.70641 .41616 L
.70711 .41539 L
.70841 .41335 L
.7096 .41113 L
Mistroke
.71087 .40879 L
.71154 .40776 L
.71225 .40693 L
.71353 .40639 L
.7147 .40727 L
.71581 .40954 L
.71702 .41373 L
.71826 .41982 L
.71944 .42706 L
.72165 .44297 L
.7229 .45212 L
.72423 .46074 L
.72537 .46637 L
.72662 .46988 L
.72769 .47003 L
.72883 .46676 L
.72992 .46008 L
.73091 .45075 L
.732 .43707 L
.73319 .4181 L
.73559 .36923 L
.73812 .30844 L
.74086 .24291 L
.74212 .21637 L
.74345 .19222 L
.74461 .17529 L
.74585 .16157 L
.74704 .15284 L
.74814 .14865 L
.74924 .1478 L
.75028 .14976 L
.7515 .15477 L
.75262 .16139 L
.75517 .17979 L
.75649 .18923 L
.75791 .19813 L
.75857 .20156 L
.75926 .20467 L
.76049 .20879 L
.76168 .21101 L
.76279 .21166 L
.76401 .21104 L
.76531 .20926 L
.7667 .2067 L
.76821 .20393 L
.76891 .20287 L
.76964 .20201 L
.77096 .20128 L
.77223 .20178 L
.77341 .20335 L
Mistroke
.77471 .20624 L
.77611 .21047 L
.78075 .22734 L
.78208 .23137 L
.78334 .23433 L
.78447 .23619 L
.78569 .23736 L
.78635 .23765 L
.78706 .23772 L
.78781 .23757 L
.78852 .23726 L
.78977 .23645 L
.79112 .23549 L
.79177 .23508 L
.79247 .23474 L
.79376 .2345 L
.79501 .23489 L
.79617 .23587 L
.81727 .25917 L
.82644 .27185 L
.82867 .2756 L
.82992 .27716 L
.83106 .27817 L
.8317 .27857 L
.8324 .27885 L
.83367 .27901 L
.83494 .27882 L
.83611 .27843 L
.83729 .27796 L
.83856 .27752 L
.83929 .27735 L
.83996 .27727 L
.84126 .2774 L
.84196 .27763 L
.8426 .27797 L
.84331 .27846 L
.84406 .27913 L
.84672 .28246 L
.849 .28591 L
.8514 .28924 L
.85266 .29057 L
.85337 .29116 L
.85404 .2916 L
.85521 .29208 L
.85647 .29222 L
.85721 .29214 L
.85802 .29195 L
.85879 .29169 L
.8595 .2914 L
.86081 .29083 L
Mistroke
.86151 .29055 L
.86226 .2903 L
.86297 .29014 L
.86362 .29006 L
.86491 .29014 L
.86556 .29032 L
.86628 .29063 L
.86702 .29108 L
.86772 .2916 L
.87047 .29444 L
.87307 .29755 L
.8742 .29877 L
.8754 .29984 L
.87672 .3007 L
.87793 .30114 L
.87909 .30126 L
.88033 .30109 L
.8815 .30071 L
.88257 .30023 L
.88386 .2996 L
.88456 .29926 L
.88523 .29898 L
.88652 .29858 L
.88769 .29843 L
.88892 .29856 L
.88961 .29877 L
.89025 .29904 L
.89089 .2994 L
.8916 .29987 L
.89304 .30105 L
.89568 .30359 L
.89684 .30465 L
.89812 .30565 L
.89934 .30636 L
.90063 .3068 L
.90131 .3069 L
.90204 .3069 L
.90273 .3068 L
.90337 .30664 L
.90452 .3062 L
.90579 .30557 L
.90713 .30483 L
.90834 .3042 L
.90954 .30371 L
.91067 .30343 L
.91187 .30337 L
.91316 .3036 L
.9143 .30405 L
.9155 .30475 L
.91765 .30637 L
Mistroke
.92014 .30831 L
.92085 .30879 L
.92153 .30917 L
.9228 .3097 L
.924 .30993 L
.92511 .30991 L
.92633 .30963 L
.92762 .30909 L
.93012 .30765 L
.93144 .30689 L
.93282 .30624 L
.93356 .306 L
.93437 .30582 L
.9351 .30576 L
.93579 .30578 L
.93649 .3059 L
.93713 .30608 L
.93788 .30637 L
.93857 .30671 L
.94094 .30823 L
.94224 .30914 L
.94348 .30994 L
.94462 .31054 L
.94588 .31099 L
.94701 .31117 L
.94807 .31113 L
.94929 .31084 L
.95039 .31039 L
.95286 .30895 L
.9542 .30811 L
.95561 .30734 L
.95681 .30685 L
.95813 .30657 L
.95925 .30657 L
.96044 .30681 L
.96157 .30723 L
.9626 .30776 L
.96491 .30922 L
.96614 .30998 L
.96743 .31068 L
.96854 .31112 L
.96977 .31138 L
.97088 .31139 L
.97193 .31121 L
.973 .31084 L
.97398 .31037 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00X_oonfX4o`0006[ooo]Z0ol007l:oookJPGo0000POoonfX5o`0009Sooo]Z
002QoookJPGo0000J_oonfX3o`00O`[ooo]Z1Ol00021oookJPKo0000UooonfX00:7ooo]Z1_l0001Y
oookJP?o001o2_oonfX5o`00087ooo]Z1_l0002GoookJP00XOoonfX6o`0005Wooo]Z2_l007l6oook
JP?o001o2_oonfX5o`00087ooo]Z1_l0002GoookJP00XOoonfX6o`0005Wooo]Z2_l007l6oookJP?o
001o2_oonfX6o`00083ooo]Z1_l0002GoookJP00XOoonfX7o`0006Sooo]Z0ol007l:oookJPGo0000
P?oonfX7o`0009Oooo]Z002QoookJPOo0000J?oonfX3o`00O`[ooo]Z1Ol00020oookJPSo0000U_oo
nfX00:7ooo]Z1ol0001XoookJP?o001o2_oonfX5o`00083ooo]Z2?l0002FoookJP00X?oonfX8o`00
06Sooo]Z0ol007l:oookJPGo0000P?oonfX8o`0009Kooo]Z002PoookJPSo0000IOoonfX6o`00O`[o
oo]Z1Ol00020oookJPSo0000U_oonfX00:3ooo]Z2?l0001UoookJPKo001o2_oonfX5o`00083ooo]Z
2?l0002FoookJP00X?oonfX8o`0006Oooo]Z1?l007l:oookJPGo0000P?oonfX8o`0009Kooo]Z002P
oookJPSo0000J?oonfX3o`00O`[ooo]Z1Ol00020oookJPSo0000U_oonfX00:3ooo]Z2?l0001eoook
JPGo0000P?oonfX9o`0009Gooo]Z002PoookJPSo0000MOoonfX5o`00083ooo]Z2Ol0002EoookJP00
WooonfX:o`0007Cooo]Z1Ol00020oookJPWo0000UOoonfX009oooo]Z2_l0001doookJPGo0000P?oo
nfX4o`000003oookJ_l0003o000000;o0000UOoonfX009oooo]Z2_l0001doookJPGo0000P?oonfX4
o`000003oookJ_l0003o000000;o0000UOoonfX009oooo]Z1?l00002oookJPCo0000M?oonfX5o`00
083ooo]Z1?l000000ooonf[o0000o`000002o`0009Gooo]Z002OoookJPCo00000_oonfX4o`0007Co
oo]Z1Ol00020oookJPCo000000?ooo]Zo`000?l000000_l0002EoookJP00WooonfX4o`0000;ooo]Z
1?l0001doookJPGo0000OooonfX5o`000003oookJ_l0003o000000?o0000U?oonfX009oooo]Z1?l0
0002oookJPCo0000M?oonfX5o`0007oooo]Z1Ol000000ooonf[o0000o`000003o`0009Cooo]Z002O
oookJPCo00000_oonfX5o`0007?ooo]Z1Ol0001ooookJPGo000000?ooo]Zo`000?l000000ol0002D
oookJP00WooonfX4o`0000;ooo]Z1Ol0001coookJPGo0000OooonfX4o`0000?ooo]Z1?l0002Doook
JP00WooonfX4o`0000;ooo]Z1Ol0001coookJPGo0000OooonfX4o`0000?ooo]Z1?l0002DoookJP00
WooonfX4o`0000?ooo]Z1?l0001coookJPGo0000OooonfX4o`0000?ooo]Z1Ol0002CoookJP00Wooo
nfX4o`0000?ooo]Z1?l0001coookJPGo0000OooonfX4o`0000?ooo]Z1Ol0002CoookJP00WooonfX4
o`0000?ooo]Z1Ol0001boookJPGo0000OooonfX4o`0000?ooo]Z1Ol0002CoookJP00WooonfX4o`00
00?ooo]Z1Ol0001boookJPGo0000OooonfX4o`0000Cooo]Z1?l0002CoookJP00WooonfX4o`0000?o
oo]Z1Ol00002oookJPKo0000J_oonfX5o`0007oooo]Z1?l00004oookJPCo00000_oonfX6o`0008_o
oo]Z002OoookJPCo00001?oonfX5o`000003oookJ_l0003o000000Co0000J_oonfX5o`0007oooo]Z
1?l00004oookJPco0000RooonfX009oooo]Z1?l00004oookJPco0000J_oonfX5o`0007kooo]Z1Ol0
0004oookJPgo0000R_oonfX009oooo]Z1?l00004oookJPgo0000JOoonfX5o`0007kooo]Z1Ol00004
oookJPgo0000R_oonfX009oooo]Z1?l00005oookJPco0000JOoonfX5o`0007kooo]Z1Ol00005oook
JPgo0000ROoonfX009oooo]Z1?l00005oookJPgo0000J?oonfX5o`0007kooo]Z1?l00006oookJPgo
0000ROoonfX009oooo]Z1?l00005oookJPOo000000?ooo]Zo`000?l000000ol0001XoookJPGo0000
O_oonfX4o`0000Kooo]Z3Ol00029oookJP00WooonfX4o`0000Gooo]Z1ol000000ooonf[o0000o`00
0003o`0006Sooo]Z1Ol0001noookJPCo00001_oonfX7o`0000;ooo]Z1?l00029oookJP00WooonfX4
o`0000Kooo]Z1Ol00003oookJPGo0000IooonfX5o`0007kooo]Z1?l00007oookJPGo00000ooonfX5
o`0008Sooo]Z002NoookJPGo00003_oonfX5o`0006Oooo]Z1Ol0001noookJPCo00003ooonfX5o`00
08Sooo]Z002NoookJPGo00003_oonfX5o`0006Oooo]Z1Ol0001noookJPCo00003ooonfX5o`0008So
oo]Z002NoookJPGo00003ooonfX4o`0006Oooo]Z1Ol0001noookJPCo00004?oonfX4o`0008Sooo]Z
002NoookJPCo00004?oonfX5o`0006Kooo]Z1Ol0001noookJPCo00004?oonfX4o`0008Sooo]Z002N
oookJPCo00004?oonfX5o`0004Sooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001n
oookJPCo00004?oonfX5o`0008Oooo]Z002NoookJPCo00004?oonfX5o`0004Oooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001noookJPCo00004?oonfX5o`0008Oooo]Z002NoookJPCo
00004OoonfX4o`0004Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000O_oonfX4o`00013ooo]Z1Ol00027
oookJP00W_oonfX4o`00017ooo]Z1?l0000joookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001noookJPCo00004OoonfX5o`0008Kooo]Z002NoookJPCo
00004OoonfX5o`0003Wooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo
0000OOoonfX4o`00017ooo]Z1Ol00026oookJP00W_oonfX4o`00017ooo]Z3?l0000noookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000O_oonfX4o`00017ooo]Z3Ol0001noookJP00W_oo
nfX4o`00017ooo]Z3Ol0000moookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oo
nfX5o`0007kooo]Z1?l0000BoookJPco0000O_oonfX009kooo]Z1?l0000BoookJPco0000?OoonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`0007kooo]Z1?l0000BoookJPgo0000OOoonfX0
09kooo]Z1?l0000CoookJPco0000??oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`00
07kooo]Z1?l0000CoookJPgo0000O?oonfX009kooo]Z1?l0000CoookJPgo0000>ooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o3_oonfX5o`0007kooo]Z1?l0000CoookJPko0000NooonfX009kooo]Z
1?l0000JoookJPOo0000>ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo
0000O_oonfX4o`0001_ooo]Z1ol0001joookJP00W_oonfX4o`0001_ooo]Z1ol0000joookJPOo001o
2OoonfX7o`00O`Sooo]Z1Ol0001noookJPCo00007?oonfX7o`0007Wooo]Z002NoookJPCo00007?oo
nfX7o`0003[ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0007kooo]Z1?l0000MoookJPOo0000N?oo
nfX009gooo]Z1Ol0000MoookJPKo0000F?oonfX5o`0007kooo]Z1?l0000NoookJPKo0000N?oonfX0
09gooo]Z1Ol0000NoookJPKo0000EooonfX5o`0007kooo]Z1?l0000OoookJPKo0000MooonfX009go
oo]Z1Ol0000OoookJPKo0000E_oonfX5o`0007kooo]Z1?l0000PoookJPKo0000M_oonfX009gooo]Z
1?l0000PoookJPOo0000EOoonfX5o`0007kooo]Z1?l0000PoookJPOo0000MOoonfX009gooo]Z1?l0
000QoookJPOo0000E?oonfX5o`0007kooo]Z1?l0000QoookJPOo0000M?oonfX009gooo]Z1?l0000R
oookJPOo0000DooonfX5o`0007kooo]Z1?l0000RoookJPOo0000LooonfX009gooo]Z1?l0000Soook
JPKo0000DooonfX5o`0007gooo]Z1Ol0000SoookJPKo0000LooonfX009gooo]Z1?l0000ToookJPKo
0000D_oonfX5o`0007gooo]Z1Ol0000ToookJPKo0000L_oonfX009gooo]Z1?l0000UoookJPKo0000
DOoonfX5o`0007gooo]Z1Ol0000UoookJPKo0000LOoonfX009gooo]Z1?l0000UoookJPOo0000D?oo
nfX5o`0007gooo]Z1?l0000VoookJPOo0000L?oonfX009gooo]Z1?l0000VoookJPOo0000CooonfX5
o`0007gooo]Z1?l0000WoookJPKo0000L?oonfX009gooo]Z1?l0000WoookJPSo0000COoonfX5o`00
07gooo]Z1?l0000XoookJPKo0000KooonfX002;ooo]Z0ol007meoookJP?o001o1?l00002oookJP?o
001o0ooonfX5o`00Oa_ooo]Z2?l0001<oookJPGo0000M?oonfX5o`00O`Cooo]Z1?l00002oookJPGo
001o8_oonfX6o`0004kooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z1?l007l4o`0000;ooo]Z
0ol007l2oookJPOo001o6ooonfX9o`0004[ooo]Z1Ol0001coookJPOo001o0ooonfX4o`000003oook
J_l007oo001o00Go001o8OoonfX6o`0004kooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol0
07l00ooonf[o0000o`000002o`0000;ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00Oacooo]Z2Ol00019oookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z1?l00004o`00O`04oookJ_l007oo001oo`00Ob;ooo]Z1_l0001=oookJP?o001o7OoonfX001?o
oo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l2oookJPCo00001_oonfX3o`00O`?o
oo]Z0ol007lMoookJPco0000A?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`0000?o
001o0ooonfX3o`00Ob;ooo]Z3Ol00015oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001o
IooonfX:o`00O`;ooo]Z0ol007l2oookJPCo00003?oonfX3o`00Oakooo]Z3?l00013oookJPGo0000
L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00001_oonfX3o`00Ob;ooo]Z3Ol00015oookJP?o001o
7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4o`0000cooo]Z0ol007lPoookJP[o0000@ooo
nfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`0000Kooo]Z0ol007lSoookJPgo0000A?oo
nfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`;ooo]Z1?l00007oookJP;o001o0_oonfX4
o`00Ob7ooo]Z2_l00012oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Z
o`00Ool007l00_oonfX4o`00ObCooo]Z3Ol00013oookJP?o001o7OoonfX002;ooo]Z0ol007mcoook
JP?o001o0_oonfX4o`0000Oooo]Z1ol007lVoookJPOo0000@OoonfX5o`0007;ooo]Z0ol007l3oook
JP?o001o0_oonfX4o`000003oookJ_l007oo001o00Go001o9_oonfX<o`0004?ooo]Z0ol007lMoook
JP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000003o`0000Oooo]Z1_l007lXoookJPOo
0000@?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o00Co
001o;_oonfX6o`0004;ooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l00ooonf[o0000
o`000003o`0000Oooo]Z0_l007l]oookJPKo0000@?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o
0_oonfX4o`000003oookJ_l007oo001o03?ooo]Z1_l0000noookJPKo001o7OoonfX001oooo]Z1_l0
07mdoookJP?o001o1Ol00007oookJP;o001o;_oonfX>o`0003Oooo]Z1Ol0001coookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX4o`000003oookJ_l007oo001o03?ooo]Z3ol0000eoookJPKo001o
7OoonfX0027ooo]Z1?l007mdoookJP?o001o1?l00009oookJPOo001o:OoonfX=o`0003Oooo]Z1Ol0
001coookJPOo001o0ooonfX4o`0000;ooo]Z1ol007l^oookJPoo0000=_oonfX4o`00Oagooo]Z000R
oookJP?o001oMOoonfX2o`00O`Co00002OoonfX7o`00ObWooo]Z3ol0000eoookJPGo0000M?oonfX5
o`00O`?ooo]Z1Ol00002oookJPOo001o;ooonfX?o`0003Kooo]Z0ol007lMoookJP00W?oonfX4o`00
03[ooo]Z3ol0000doookJPGo0000O?oonfX5o`0003Wooo]Z3_l0001FoookJP00W?oonfX4o`0003_o
oo]Z3ol00002oookJPKo0000:ooonfX5o`0007cooo]Z1Ol0000joookJPKo000000?ooo]Zo`000?l0
00001_l00002oookJPKo0000C?oonfX009cooo]Z1?l00013oookJQ3o0000:_oonfX5o`0007cooo]Z
1?l00014oookJPoo0000BooonfX009cooo]Z1?l00015oookJPoo0000:OoonfX5o`0007cooo]Z1?l0
0014oookJQ3o0000B_oonfX009cooo]Z1?l00016oookJPoo00000ooonfX7o`0001kooo]Z1Ol0001l
oookJPCo0000AOoonfX@o`0000?ooo]Z2?l0000noookJP00W?oonfX4o`0004Kooo]Z6_l00006oook
JPKo00004OoonfX5o`0007cooo]Z1?l00016oookJQ[o00001_oonfX6o`0003;ooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`00
00oooo]Z000MoookJP04o`000?oonf[ooo]ZoookJQOo000000?ooo]Zo`000?l000004Ol00003oook
JPGo0000B?oonfX4o`00067ooo]Z1?l00007oookJPOo00001OoonfX:o`0000;ooo]Z2Ol00003oook
JP[o00000ooonfXAo`0000?ooo]Z1_l00017oookJPCo0000HOoonfX4o`0000Kooo]Z2?l00005oook
JPSo00007_oonfX002cooo]Z2_l00005oookJQ_o0000A_oonfX4o`0007gooo]Z1Ol0000@oookJPOo
00001OoonfXJo`0004Kooo]Z1?l0002NoookJP00??oonfX8o`0000?ooo]Z4?l00015oookJPCo0000
OOoonfX5o`0001gooo]Z1ol00002oookJQ7o0000AOoonfX4o`0009kooo]Z0018oookJQ3o0000A?oo
nfX4o`0007gooo]Z1Ol0000WoookJQ7o0000A?oonfX4o`0009kooo]Z0019oookJPoo0000A?oonfX4
o`0007gooo]Z1Ol0000YoookJPoo0000A?oonfX4o`0009kooo]Z001:oookJPKo00000ooonfX6o`00
00;ooo]Z1_l0000joookJPGo0000OOoonfX5o`0002[ooo]Z1_l00003oookJPko0000>ooonfX4o`00
09kooo]Z001DoookJPko0000>OoonfX5o`0007gooo]Z1Ol0000doookJPko0000>_oonfX4o`0009ko
oo]Z001DoookJPoo0000>?oonfX5o`0007gooo]Z1Ol0000doookJPoo0000>OoonfX4o`0009kooo]Z
001EoookJPko0000>?oonfX4o`0007kooo]Z1Ol0000eoookJPko0000>OoonfX4o`0009kooo]Z001F
oookJPko0000=ooonfX4o`0007kooo]Z1Ol0000foookJPko0000>?oonfX4o`0009kooo]Z001Ooook
JPKo0000=_oonfX4o`0007kooo]Z1Ol0000ooookJPGo0000>?oonfX4o`0009kooo]Z001OoookJPOo
0000=OoonfX4o`0007kooo]Z1Ol0000ooookJPOo0000=_oonfX4o`0009kooo]Z001PoookJPKo0000
00?ooo]Zo`000?l000001?l0000^oookJPCo0000O_oonfX5o`00043ooo]Z1ol000000ooonf[o0000
o`000003o`0002oooo]Z1?l0002NoookJP00HOoonfX=o`0002gooo]Z1?l0001noookJPGo0000@?oo
nfX>o`0002gooo]Z1Ol0002NoookJP00H_oonfX=o`0002cooo]Z1?l0001noookJPGo0000@OoonfX>
o`0002cooo]Z1Ol0002NoookJP00H_oonfX=o`0002cooo]Z1?l0001noookJPGo0000@ooonfX<o`00
02cooo]Z1Ol0002NoookJP00HooonfX=o`0002_ooo]Z1?l0001noookJPGo0000@ooonfX=o`0002_o
oo]Z1?l0002OoookJP00JooonfX5o`0002_ooo]Z1?l0001noookJPGo0000BooonfX5o`0002_ooo]Z
1?l0002OoookJP00JooonfX6o`0002[ooo]Z1?l0001noookJPGo0000BooonfX6o`0002[ooo]Z1?l0
002OoookJP00K?oonfX6o`0002Wooo]Z1?l0001noookJPGo0000C?oonfX6o`0002Wooo]Z1?l0002O
oookJP00K?oonfX7o`0002Sooo]Z1?l0001noookJPGo0000C?oonfX7o`0002Sooo]Z1?l0002Ooook
JP00KOoonfX6o`0002Sooo]Z1?l0001noookJPGo0000COoonfX6o`0002Sooo]Z1?l0002OoookJP00
K_oonfX6o`0002Oooo]Z1?l0001noookJPGo0000C_oonfX6o`0002Oooo]Z1?l0002OoookJP00Kooo
nfX6o`0002Kooo]Z1?l0001noookJPGo0000CooonfX6o`0002Kooo]Z1?l0002OoookJP00KooonfX6
o`0002Kooo]Z1?l0001noookJPGo0000CooonfX7o`0002Gooo]Z1?l0002OoookJP00L?oonfX6o`00
02Gooo]Z1?l0001noookJPGo0000D?oonfX7o`0002Cooo]Z1?l0002OoookJP00LOoonfX6o`0002Co
oo]Z1?l0001noookJPGo0000DOoonfX7o`0002?ooo]Z1?l0002OoookJP00LOoonfX7o`0002?ooo]Z
1?l0001noookJPGo0000D_oonfX7o`0002;ooo]Z1?l0002OoookJP00L_oonfX7o`0002;ooo]Z1?l0
001noookJPGo0000DooonfX7o`00027ooo]Z1?l0002OoookJP00LooonfX7o`00027ooo]Z1?l0001n
oookJPGo0000E?oonfX7o`00023ooo]Z1?l0002OoookJP00M?oonfX7o`0001oooo]Z1Ol0001noook
JPGo0000EOoonfX7o`0001oooo]Z1?l0002OoookJP00MOoonfX7o`0001kooo]Z1Ol0001noookJPGo
0000E_oonfX7o`0001kooo]Z1?l0002OoookJP00M_oonfX7o`0001gooo]Z1Ol0001noookJPGo0000
EooonfX7o`0001gooo]Z1?l0002OoookJP00MooonfX7o`0001cooo]Z1?l0001ooookJPGo0000F?oo
nfX7o`0001cooo]Z1?l0002OoookJP00N?oonfX7o`0001_ooo]Z1?l0001ooookJPGo0000FOoonfX8
o`0001[ooo]Z1?l0002OoookJP00NOoonfX=o`0001Cooo]Z1?l0001QoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPGo0000F_oonfX8o`0001Wooo]Z1?l0002OoookJP00N_oonfX=o`0001?o
oo]Z1?l0001PoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000FooonfX8o`0001Oo
oo]Z1Ol0002OoookJP00NooonfX=o`0001;ooo]Z1?l0001PoookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`00
05cooo]Z2?l0000FoookJPGo0000WooonfX007cooo]Z3?l0000BoookJPCo0000GooonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001NoookJPOo00005OoonfX5o`0009oo
oo]Z001moookJP_o00004_oonfX4o`0005oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z
1_l0001NoookJPOo00005?oonfX4o`000:3ooo]Z0024oookJPCo00004_oonfX4o`0005oooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001PoookJPOo00004ooonfX4o`000:3ooo]Z0024
oookJPGo00004OoonfX4o`0005oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8
oookJPGo0000HOoonfX7o`0001;ooo]Z1?l0002PoookJP00Q?oonfX5o`00017ooo]Z1?l0001Ooook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000H_oonfX7o`00017ooo]Z1?l0002Poook
JP00Q?oonfX5o`00017ooo]Z1?l0001OoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo
0000HooonfX7o`00013ooo]Z1?l0002PoookJP00QOoonfX5o`00013ooo]Z1?l0001OoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000I?oonfX6o`00013ooo]Z1?l0002PoookJP00QOoo
nfX5o`00013ooo]Z1?l0001PoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z
1Ol0001UoookJPGo00004?oonfX4o`000:3ooo]Z0025oookJPGo00004?oonfX4o`00063ooo]Z1ol0
07l9oookJPOo001o2?oonfX5o`0006Kooo]Z1Ol0000?oookJPCo0000X?oonfX008Kooo]Z1?l0000@
oookJPCo0000HOoonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000I_oonfX5o`0000oooo]Z1?l0002P
oookJP00Q_oonfX5o`0000oooo]Z1?l0001ooookJPGo0000I_oonfX5o`0000oooo]Z1?l0002Poook
JP00Q_oonfX5o`0000?ooo]Z1Ol00007oookJPCo0000OooonfX5o`0006Oooo]Z1?l00003oookJPGo
00001_oonfX5o`000:3ooo]Z0026oookJPKo000000?ooo]Zo`000?l000001Ol00006oookJPCo0000
OooonfX5o`0006Oooo]Z1Ol000000ooonf[o0000o`000004o`0000Kooo]Z1Ol0002PoookJP00Qooo
nfX5o`000003oookJ_l0003o000000Go00001_oonfX4o`0007oooo]Z1Ol0001WoookJPGo000000?o
oo]Zo`000?l000001Ol00005oookJPGo0000X?oonfX008Oooo]Z3_l00004oookJPGo0000OooonfX5
o`0006Oooo]Z1Ol000000ooonf[o0000o`000005o`0000Gooo]Z1?l0002QoookJP00R?oonfX=o`00
00Cooo]Z1Ol0001ooookJPGo0000J?oonfX=o`0000Cooo]Z1?l0002QoookJP00R?oonfX=o`0000Co
oo]Z1Ol0001ooookJPGo0000J?oonfX=o`0000Cooo]Z1?l0002QoookJP00R?oonfX8o`000003oook
J_l0003o000000;o00001?oonfX4o`00083ooo]Z1Ol0001XoookJPgo00001?oonfX4o`000:7ooo]Z
0028oookJPSo000000?ooo]Zo`000?l000000_l00004oookJPCo0000P?oonfX5o`0006Wooo]Z1ol0
00000ooonf[o0000o`000002o`0000Cooo]Z1?l0002QoookJP00ROoonfX6o`0000;ooo]Z1?l00004
oookJPCo0000P?oonfX5o`0006Wooo]Z1_l00002oookJPCo00001?oonfX4o`000:7ooo]Z002Aoook
JPCo00001?oonfX4o`00083ooo]Z1Ol0001aoookJPCo00001?oonfX4o`000:7ooo]Z002AoookJPGo
00000ooonfX4o`00083ooo]Z1Ol0001aoookJPGo00000ooonfX4o`000:7ooo]Z002AoookJPGo0000
0ooonfX4o`00083ooo]Z1Ol0001aoookJPGo00000ooonfX4o`000:7ooo]Z002AoookJPGo00000ooo
nfX4o`00083ooo]Z1Ol0001aoookJPGo00000ooonfX4o`000:7ooo]Z002BoookJPCo00000ooonfX4
o`00083ooo]Z1Ol0001boookJPCo00000ooonfX4o`000:7ooo]Z002BoookJPCo00000ooonfX4o`00
083ooo]Z1Ol0001boookJPCo00000ooonfX4o`000:7ooo]Z002BoookJPCo00000ooonfX4o`00083o
oo]Z1Ol0001boookJPCo00000ooonfX4o`000:7ooo]Z002BoookJPCo00000ooonfX4o`00083ooo]Z
1Ol0001boookJPGo00000_oonfX4o`000:7ooo]Z002BoookJPGo00000_oonfX4o`00083ooo]Z1Ol0
001boookJPGo00000_oonfX4o`000:7ooo]Z002BoookJPGo00000_oonfX4o`00083ooo]Z1Ol0001b
oookJPGo00000_oonfX4o`000:7ooo]Z002BoookJPGo00000_oonfX4o`00083ooo]Z1Ol0001coook
JPCo00000_oonfX4o`000:7ooo]Z002CoookJPCo00000_oonfX4o`00083ooo]Z1Ol0001coookJPCo
00000_oonfX4o`000:7ooo]Z002CoookJPCo00000_oonfX4o`00083ooo]Z1Ol0001coookJPCo0000
00?ooo]Zo`000?l000000ol0002QoookJP00TooonfX4o`0000;ooo]Z1?l00020oookJPGo0000Looo
nfX4o`000003oookJ_l0003o000000?o0000XOoonfX009?ooo]Z1?l000000ooonf[o0000o`000003
o`00083ooo]Z1Ol0001coookJP[o0000XOoonfX009?ooo]Z2_l00020oookJPGo0000LooonfX9o`00
0:;ooo]Z002CoookJP[o0000P?oonfX5o`0007?ooo]Z2Ol0002RoookJP00TooonfX9o`00087ooo]Z
1Ol0001doookJPSo0000X_oonfX009Cooo]Z2?l00021oookJPGo0000M?oonfX8o`000:;ooo]Z002D
oookJPSo0000M?oonfX3o`00O`[ooo]Z1Ol0001doookJPSo0000X_oonfX009Cooo]Z2?l0001doook
JP?o001o2_oonfX5o`0007Cooo]Z2?l0002RoookJP00U?oonfX8o`0007Cooo]Z0ol007l:oookJPGo
0000M?oonfX8o`000:;ooo]Z002DoookJPOo0000MOoonfX3o`00O`[ooo]Z1Ol0001eoookJPOo0000
X_oonfX009Cooo]Z1ol0001eoookJP?o001o2_oonfX6o`0007Cooo]Z1ol0002RoookJP00U?oonfX7
o`0007Gooo]Z0ol007l:oookJPGo0000MOoonfX7o`000:;ooo]Z002EoookJPKo0000MOoonfX3o`00
O`[ooo]Z1Ol0001eoookJPOo0000X_oonfX009Gooo]Z1_l0001eoookJP?o001o2_oonfX5o`0007Go
oo]Z1_l0002SoookJP00UOoonfX6o`0007Gooo]Z0ol007l:oookJPGo0000MOoonfX6o`000:?ooo]Z
002FoookJPCo0000LooonfX6o`00O`[ooo]Z1Ol0001foookJPCo0000Y?oonfX00?oooo]Z3_oonfX6
o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQ3ooo]Z1?l007l:oookJPGo0000oooonfXOoook
JP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00
O`kooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX2o`00O`;o
oo]Z1?l007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooo
nfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oook
JP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo
0000oooonfXOoookJP00oooonfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo
0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3Ooo
nfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1?l007l<oookJPGo0000oooonfXO
oookJP00oooonfX?oookJPGo001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wo
oo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00oooo
nfXCoookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX0
0?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o
001ooooonfX/oookJP00oooonfX>oookJPOo001ooooonfX]oookJP00oooonfX?oookJPGo001ooooo
nfX^oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30976 L
.02605 .31038 L
.02729 .31092 L
.02846 .31123 L
.02954 .3113 L
.03053 .31118 L
.03163 .31085 L
.03279 .31031 L
.03504 .30893 L
.03628 .30815 L
.03746 .30751 L
.03813 .30722 L
.03885 .30698 L
.04012 .30678 L
.04142 .30687 L
.04262 .30723 L
.04386 .30783 L
.04521 .30865 L
.04765 .31025 L
.04881 .31088 L
.05003 .31135 L
.05107 .31155 L
.05221 .31155 L
.0529 .31144 L
.05355 .31126 L
.05477 .31074 L
.05751 .30913 L
.05865 .30845 L
.05987 .30785 L
.06051 .30761 L
.06121 .30743 L
.06244 .30732 L
.06371 .30751 L
.06443 .30775 L
.0651 .30805 L
.06646 .30885 L
.0679 .30988 L
.0703 .31158 L
.07096 .31196 L
.07165 .31231 L
.0729 .31273 L
.07365 .31285 L
.07435 .31286 L
.07512 .31277 L
.07594 .31255 L
.07671 .31226 L
.07744 .31192 L
.07881 .31116 L
.08005 .31043 L
Mistroke
.08138 .30975 L
.08214 .30944 L
.08283 .30924 L
.08352 .30911 L
.08418 .30908 L
.08536 .30925 L
.08666 .30975 L
.08732 .31012 L
.08802 .31059 L
.08929 .31158 L
.09154 .3135 L
.09273 .31442 L
.09398 .31521 L
.09469 .31554 L
.09547 .31578 L
.09617 .31591 L
.09683 .31593 L
.09813 .31573 L
.09886 .3155 L
.09953 .31523 L
.10218 .31387 L
.10343 .31329 L
.10458 .31292 L
.10576 .31277 L
.10703 .31294 L
.10815 .31339 L
.10934 .31414 L
.11059 .31519 L
.11175 .31634 L
.11441 .31905 L
.11559 .32008 L
.11671 .32083 L
.11772 .3213 L
.11881 .32155 L
.12 .32154 L
.12127 .32125 L
.12235 .32082 L
.12354 .32027 L
.12485 .31968 L
.12556 .31941 L
.12622 .31922 L
.12739 .31908 L
.12868 .31926 L
.1294 .31954 L
.13008 .31992 L
.13136 .32093 L
.13273 .32237 L
.13422 .3242 L
.13676 .32738 L
.13814 .32883 L
Mistroke
.13944 .32983 L
.14054 .33037 L
.14173 .33062 L
.14305 .33052 L
.14426 .33018 L
.14544 .32971 L
.14671 .32919 L
.14792 .32881 L
.14903 .32868 L
.15032 .32888 L
.15098 .32915 L
.15169 .32958 L
.15294 .33068 L
.15411 .33207 L
.15636 .33543 L
.15881 .33931 L
.15993 .34085 L
.16112 .3422 L
.16214 .34304 L
.16326 .34363 L
.16456 .34387 L
.16529 .34383 L
.16596 .34369 L
.16719 .34328 L
.16849 .34276 L
.16967 .34238 L
.17077 .34224 L
.17198 .34241 L
.17326 .3431 L
.17398 .34373 L
.17465 .34447 L
.17615 .34666 L
.17888 .35191 L
.18155 .35719 L
.18271 .35909 L
.18398 .36068 L
.18523 .36168 L
.18639 .36211 L
.18749 .36213 L
.18866 .36181 L
.18991 .36127 L
.19056 .36097 L
.19125 .36068 L
.19252 .36035 L
.19369 .36044 L
.19486 .36103 L
.19596 .36212 L
.19716 .36393 L
.19845 .36651 L
.20276 .37778 L
Mistroke
.20406 .38092 L
.20543 .38363 L
.20614 .38471 L
.20693 .38562 L
.20765 .38616 L
.20832 .38645 L
.20964 .38641 L
.21085 .38583 L
.21152 .38536 L
.21224 .38479 L
.21293 .38426 L
.21357 .38381 L
.21487 .38321 L
.21604 .38325 L
.2173 .38414 L
.21802 .38508 L
.21867 .38624 L
.21977 .38881 L
.22097 .39244 L
.22341 .40149 L
.22592 .4109 L
.2266 .41308 L
.22733 .41508 L
.22864 .4177 L
.22986 .41886 L
.231 .41883 L
.23226 .41767 L
.23296 .41659 L
.23361 .41542 L
.23474 .41312 L
.23595 .41072 L
.2371 .40899 L
.23814 .40822 L
.23931 .40865 L
.24042 .41058 L
.24161 .41448 L
.24291 .42083 L
.24564 .4397 L
.24819 .45873 L
.24948 .46611 L
.2502 .469 L
.25086 .47065 L
.25157 .47121 L
.25236 .47015 L
.2531 .46741 L
.25379 .46326 L
.2551 .45087 L
.25634 .43386 L
.25865 .38955 L
.26382 .2601 L
Mistroke
.26607 .2093 L
.26731 .18675 L
.26849 .16986 L
.26915 .16235 L
.26987 .1559 L
.27113 .14884 L
.27242 .14683 L
.2736 .149 L
.27483 .15449 L
.27599 .1618 L
.27861 .1817 L
.27986 .19069 L
.28117 .1987 L
.28186 .2021 L
.28261 .20512 L
.28393 .20858 L
.28518 .20982 L
.28636 .20941 L
.28742 .20807 L
.28856 .20596 L
.2898 .20341 L
.29097 .20125 L
.29218 .19965 L
.29282 .19919 L
.29351 .19905 L
.29475 .1998 L
.29593 .2017 L
.29699 .20432 L
.29814 .20798 L
.30241 .22415 L
.30354 .22782 L
.30474 .23094 L
.30604 .23332 L
.30724 .23453 L
.30837 .23489 L
.30941 .23467 L
.31056 .23401 L
.31179 .23306 L
.31244 .23257 L
.31313 .2321 L
.31388 .23172 L
.31458 .23153 L
.31583 .2317 L
.31655 .23213 L
.31722 .23276 L
.31846 .23453 L
.31959 .23676 L
.32215 .24321 L
.32464 .24984 L
.32601 .25291 L
Mistroke
.3273 .25517 L
.32803 .25613 L
.32883 .25691 L
.32955 .25738 L
.33021 .25762 L
.33153 .25765 L
.33219 .25748 L
.33292 .25721 L
.33423 .25661 L
.33547 .25611 L
.33616 .25593 L
.3369 .25587 L
.33821 .25616 L
.33945 .257 L
.34077 .25849 L
.3419 .26022 L
.34315 .2625 L
.3457 .2677 L
.34807 .27204 L
.34926 .27368 L
.35054 .27493 L
.35127 .27538 L
.35196 .27566 L
.35324 .27579 L
.35437 .27559 L
.35556 .27518 L
.35658 .27477 L
.35769 .27439 L
.35887 .27417 L
.35998 .27424 L
.3613 .27475 L
.3625 .27566 L
.38336 .2877 L
.40239 .29684 L
.40368 .29651 L
.40441 .29645 L
.40507 .29649 L
.4063 .29682 L
.4076 .29751 L
.40832 .29804 L
.40899 .2986 L
.41051 .30008 L
.41315 .30277 L
.41445 .30387 L
.41567 .30465 L
.41677 .30509 L
.41797 .30526 L
.41927 .30511 L
.41993 .30492 L
.42065 .30464 L
Mistroke
.42313 .30337 L
.42433 .30278 L
.42561 .30232 L
.42634 .30216 L
.42701 .3021 L
.42832 .30224 L
.42954 .30268 L
.43086 .30345 L
.43325 .30537 L
.4356 .30731 L
.43678 .30809 L
.43808 .30868 L
.43918 .30892 L
.44037 .30891 L
.44149 .30865 L
.44252 .30825 L
.445 .30687 L
.44637 .30612 L
.44765 .30555 L
.44831 .30535 L
.44903 .30521 L
.44982 .30517 L
.45055 .30523 L
.45186 .3056 L
.45251 .30589 L
.45323 .30629 L
.4556 .30793 L
.45811 .30966 L
.45941 .3103 L
.46016 .31054 L
.46085 .31068 L
.46208 .31069 L
.46339 .31039 L
.46407 .31013 L
.4648 .30977 L
.46615 .309 L
.46867 .30748 L
.46992 .3069 L
.47062 .30667 L
.47125 .30653 L
.47249 .30646 L
.47365 .30665 L
.47479 .30706 L
.47599 .30768 L
.47814 .30908 L
.47925 .3098 L
.48045 .31047 L
.48176 .311 L
.48298 .31124 L
.48366 .31126 L
Mistroke
.48438 .31118 L
.48568 .31081 L
.4864 .3105 L
.48707 .31015 L
.48861 .30921 L
.48997 .30834 L
.49139 .30754 L
.49261 .30704 L
.4933 .30685 L
.49394 .30675 L
.49516 .30678 L
.49627 .30702 L
.49754 .30755 L
.49875 .30822 L
.50142 .30992 L
.50273 .31062 L
.50393 .31107 L
.50507 .31128 L
.50616 .31127 L
.50731 .31102 L
.50856 .31052 L
.50985 .30981 L
.51121 .30894 L
.51249 .30814 L
.51366 .30751 L
.5143 .30723 L
.515 .30699 L
.51571 .30684 L
.51645 .30677 L
.5171 .3068 L
.5178 .30692 L
.51907 .30734 L
.52039 .30802 L
.52163 .3088 L
.52274 .30954 L
.52396 .31032 L
.52504 .31089 L
.52619 .31134 L
.52742 .31157 L
.52856 .31153 L
.5297 .31127 L
.53078 .31083 L
.53281 .30968 L
.53503 .30834 L
.53628 .30776 L
.53741 .30743 L
.53805 .30734 L
.53874 .30732 L
.54001 .30754 L
.54126 .30803 L
Mistroke
.54242 .3087 L
.54483 .31043 L
.54602 .31127 L
.54712 .31195 L
.54838 .31252 L
.54904 .31272 L
.54975 .31284 L
.55089 .31283 L
.55215 .31255 L
.55333 .31207 L
.55441 .3115 L
.55557 .31082 L
.55684 .31011 L
.55788 .30961 L
.55898 .30925 L
.56015 .30908 L
.56124 .30918 L
.56192 .30935 L
.56263 .30964 L
.56391 .31038 L
.56681 .31272 L
.56812 .31382 L
.56952 .31483 L
.57021 .31523 L
.57085 .31552 L
.57207 .31587 L
.57323 .31592 L
.57431 .31574 L
.57549 .31533 L
.57675 .31472 L
.57794 .31409 L
.57921 .31346 L
.57994 .31316 L
.5806 .31296 L
.5819 .31277 L
.58255 .31281 L
.58325 .31295 L
.58452 .31348 L
.58521 .31391 L
.58595 .31447 L
.58728 .31567 L
.58965 .31812 L
.5909 .31933 L
.59221 .3204 L
.59289 .32083 L
.59364 .32119 L
.59495 .32155 L
.59559 .32158 L
.59628 .32153 L
.59751 .32123 L
Mistroke
.59827 .32094 L
.59909 .32058 L
.60057 .31988 L
.60128 .31958 L
.60202 .31932 L
.60265 .31917 L
.60335 .31908 L
.604 .3191 L
.6047 .31922 L
.60598 .31975 L
.60723 .32064 L
.60838 .32177 L
.61095 .32489 L
.61231 .32663 L
.61378 .32829 L
.61505 .32943 L
.61622 .33015 L
.61733 .33054 L
.61851 .33062 L
.61975 .3304 L
.62091 .33001 L
.62218 .32948 L
.62288 .3292 L
.62353 .32897 L
.62478 .3287 L
.62544 .32868 L
.62615 .32878 L
.62742 .32928 L
.62857 .33013 L
.62927 .33082 L
.62991 .33157 L
.63137 .33359 L
.63404 .33783 L
.63523 .33964 L
.63651 .34133 L
.63772 .34258 L
.63884 .34336 L
.64015 .34382 L
.64081 .34387 L
.64153 .34382 L
.64279 .3435 L
.64396 .34305 L
.64512 .34261 L
.64637 .34228 L
.64756 .34227 L
.64865 .34261 L
.64964 .34325 L
.65073 .34434 L
.65186 .34589 L
.65293 .34768 L
Mistroke
.66254 .36211 L
.70124 .40785 L
.7213 .43564 L
.7238 .45474 L
.72504 .46279 L
.72617 .46824 L
.72748 .47115 L
.72817 .47089 L
.7289 .46908 L
.73008 .46252 L
.73138 .44986 L
.73212 .44002 L
.7328 .42944 L
.73433 .40054 L
.73709 .3351 L
.73988 .26345 L
.74109 .23447 L
.7424 .20662 L
.74368 .18385 L
.74486 .16757 L
.74599 .15643 L
.74718 .14937 L
.74844 .14682 L
.74961 .14845 L
.7509 .15383 L
.75162 .15808 L
.75228 .16252 L
.75459 .18006 L
.75585 .18934 L
.75704 .19689 L
.75804 .20207 L
.75913 .20619 L
.76033 .20893 L
.76143 .20983 L
.76269 .20928 L
.76339 .20839 L
.76405 .2073 L
.76654 .20233 L
.76727 .20106 L
.76795 .2001 L
.76923 .19911 L
.76995 .1991 L
.7706 .19947 L
.77133 .2003 L
.77209 .20165 L
.77329 .20465 L
.77458 .20884 L
.7769 .21775 L
.77941 .22682 L
.78009 .22885 L
Mistroke
.78083 .23073 L
.78149 .2321 L
.78217 .23324 L
.78281 .23402 L
.78351 .23458 L
.78473 .23489 L
.78541 .23474 L
.78614 .2344 L
.78745 .23348 L
.78877 .23246 L
.79001 .23174 L
.79113 .23151 L
.79234 .23186 L
.79303 .23238 L
.79367 .23308 L
.79438 .23408 L
.79513 .23542 L
.79809 .24254 L
.80085 .24987 L
.80219 .25288 L
.8034 .25504 L
.80465 .25659 L
.80534 .25714 L
.80598 .25748 L
.80668 .25767 L
.80733 .25769 L
.80804 .25758 L
.80879 .25734 L
.81007 .25677 L
.81077 .25645 L
.81144 .25618 L
.81273 .25588 L
.81391 .25599 L
.81505 .25653 L
.81611 .25745 L
.81726 .25891 L
.81849 .26092 L
.82094 .26576 L
.82352 .27081 L
.82465 .27263 L
.82586 .27414 L
.82655 .27479 L
.82719 .27523 L
.82842 .27572 L
.82953 .27578 L
.83073 .27554 L
.83186 .27513 L
.83291 .27472 L
.83412 .27433 L
.83525 .27416 L
Mistroke
.83649 .27432 L
.83718 .27459 L
.83782 .27496 L
.8391 .27605 L
.84049 .27773 L
.84302 .28159 L
.84539 .28528 L
.84655 .28679 L
.84762 .2879 L
.84873 .28873 L
.84994 .28923 L
.85119 .28935 L
.85251 .28911 L
.85356 .28874 L
.85468 .28827 L
.85565 .28788 L
.85671 .28756 L
.85794 .28741 L
.85911 .28756 L
.86025 .28802 L
.8613 .28873 L
.86255 .28989 L
.86374 .29124 L
.86596 .29407 L
.86722 .29561 L
.86856 .29703 L
.86983 .29805 L
.87097 .29865 L
.87205 .29892 L
.8732 .29892 L
.8743 .29867 L
.87531 .29829 L
.87759 .29724 L
.87887 .29675 L
.88003 .29649 L
.8813 .2965 L
.88251 .29682 L
.88361 .29739 L
.88481 .29829 L
.88731 .30071 L
.88873 .30218 L
.89006 .30342 L
.89135 .30436 L
.89207 .30476 L
.89273 .30502 L
.89339 .30519 L
.89411 .30526 L
.89487 .30522 L
.89557 .30508 L
.89686 .30463 L
Mistroke
.89803 .30406 L
.89939 .30334 L
.90066 .30272 L
.90177 .30233 L
.90297 .30211 L
.90365 .30211 L
.90429 .3022 L
.90551 .30258 L
.90678 .30327 L
.90796 .30413 L
.91064 .3064 L
.91185 .30735 L
.91298 .30809 L
.914 .30858 L
.9151 .30888 L
.9163 .30894 L
.91757 .30869 L
.91866 .30827 L
.91985 .30766 L
.92113 .30692 L
.92252 .30614 L
.92383 .30556 L
.92504 .30524 L
.92572 .30517 L
.92646 .3052 L
.92723 .30534 L
.92796 .30556 L
.92923 .30618 L
.93061 .30706 L
.93316 .30893 L
.93455 .3098 L
.93585 .31039 L
.93696 .31066 L
.93814 .3107 L
.93945 .31043 L
.94064 .30995 L
.94288 .30867 L
.94496 .30743 L
.94601 .30694 L
.94714 .30659 L
.94839 .30645 L
.94953 .30658 L
.95057 .30689 L
.95154 .30733 L
.95373 .30868 L
.95565 .30992 L
.95665 .31048 L
.95771 .31093 L
.95886 .31121 L
.95991 .31125 L
Mistroke
.96089 .31112 L
.96197 .31077 L
.96314 .31021 L
.9644 .30946 L
.96667 .30803 L
.9679 .30739 L
.96859 .30711 L
.96923 .30691 L
.97041 .30674 L
.97166 .30682 L
.97277 .30713 L
.97381 .30759 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00X_oonfX4o`0007Oo
oo]Z1Ol00022oookJPCo0000V?oonfX00:7ooo]Z1Ol0001ZoookJP?o001o2_oonfX5o`0008;ooo]Z
1?l0002HoookJP00XOoonfX5o`0006[ooo]Z0ol007l:oookJPGo0000POoonfX5o`0009Sooo]Z002Q
oookJPKo0000JOoonfX3o`00O`[ooo]Z1Ol00021oookJPKo0000UooonfX00:3ooo]Z1ol0001Ioook
JP[o001o1_oonfX3o`00O`[ooo]Z1Ol00020oookJPOo0000UooonfX00:3ooo]Z1ol0001IoookJP[o
001o1_oonfX3o`00O`[ooo]Z1_l0001ooookJPOo0000UooonfX00:3ooo]Z1ol0001YoookJP?o001o
2_oonfX5o`00083ooo]Z1ol0002GoookJP00X?oonfX8o`0006Sooo]Z0ol007l:oookJPGo0000P?oo
nfX7o`0009Oooo]Z002PoookJPSo0000J?oonfX3o`00O`[ooo]Z1Ol00020oookJPSo0000U_oonfX0
0:3ooo]Z2?l0001XoookJP?o001o2_oonfX5o`00083ooo]Z2?l0002FoookJP00X?oonfX8o`0006Go
oo]Z1_l007l:oookJPGo0000P?oonfX8o`0009Kooo]Z002PoookJPSo0000IOoonfX6o`00O`[ooo]Z
1Ol00020oookJPSo0000U_oonfX00:3ooo]Z2?l0001WoookJPCo001o2_oonfX5o`00083ooo]Z2?l0
002FoookJP00X?oonfX8o`0006Sooo]Z0ol007l:oookJPGo0000P?oonfX8o`0009Kooo]Z002Poook
JPWo0000M?oonfX5o`00083ooo]Z2Ol0002EoookJP00X?oonfX9o`0007Cooo]Z1Ol00020oookJPWo
0000UOoonfX00:3ooo]Z2Ol0001doookJPGo0000OooonfX:o`0009Gooo]Z002PoookJPCo000000?o
oo]Zo`000?l000000_l0001doookJPGo0000OooonfX5o`000003oookJ_l0003o000000;o0000UOoo
nfX009oooo]Z1Ol000000ooonf[o0000o`000002o`0007Cooo]Z1Ol0001ooookJPGo000000?ooo]Z
o`000?l000000_l0002EoookJP00WooonfX5o`000003oookJ_l0003o000000;o0000M?oonfX5o`00
07oooo]Z1?l00002oookJPCo0000UOoonfX009oooo]Z1Ol000000ooonf[o0000o`000002o`0007Co
oo]Z1Ol0001ooookJPCo00000_oonfX4o`0009Gooo]Z002OoookJPCo00000_oonfX4o`0007Cooo]Z
1Ol0001ooookJPCo00000_oonfX5o`0009Cooo]Z002OoookJPCo00000_oonfX5o`0007?ooo]Z1Ol0
001ooookJPCo00000_oonfX5o`0009Cooo]Z002OoookJPCo00000_oonfX5o`0007?ooo]Z1Ol0001o
oookJPCo00000_oonfX5o`0009Cooo]Z002OoookJPCo00000_oonfX5o`0007?ooo]Z1Ol0001ooook
JPCo00000ooonfX4o`0009Cooo]Z002OoookJPCo00000ooonfX4o`0007?ooo]Z1Ol0001ooookJPCo
00000ooonfX4o`0009Cooo]Z002OoookJPCo00000ooonfX4o`0007?ooo]Z1Ol0001ooookJPCo0000
0ooonfX4o`0009Cooo]Z002OoookJPCo00000ooonfX4o`0007?ooo]Z1Ol0001noookJPGo00000ooo
nfX4o`0009Cooo]Z002OoookJPCo00000ooonfX4o`0000?ooo]Z1?l0001/oookJPGo0000O_oonfX5
o`0000?ooo]Z1?l00003oookJPCo0000SOoonfX009kooo]Z1Ol00003oookJPCo00000_oonfX6o`00
06_ooo]Z1Ol0001noookJPGo00000ooonfX5o`000003oookJ_l0003o000000Co0000S?oonfX009ko
oo]Z1Ol00003oookJPGo000000?ooo]Zo`000?l000001?l0001[oookJPGo0000O_oonfX4o`0000Co
oo]Z3?l0002<oookJP00W_oonfX5o`0000?ooo]Z3Ol0001ZoookJPGo0000O_oonfX4o`0000Cooo]Z
3Ol0002;oookJP00W_oonfX4o`0000Cooo]Z3Ol0001ZoookJPGo0000O_oonfX4o`0000Gooo]Z3?l0
002;oookJP00W_oonfX4o`0000Gooo]Z3Ol0001YoookJPGo0000O_oonfX4o`0000Gooo]Z3Ol0002:
oookJP00W_oonfX4o`0000Gooo]Z3Ol0001YoookJPGo0000O_oonfX4o`0000Gooo]Z3Ol0002:oook
JP00W_oonfX4o`0000Gooo]Z1ol000000ooonf[o0000o`000003o`0006Wooo]Z1Ol0001noookJPCo
00001OoonfX7o`000003oookJ_l0003o000000?o0000R_oonfX009kooo]Z1?l00005oookJPOo0000
0_oonfX5o`0006Sooo]Z1Ol0001noookJPCo00001OoonfX7o`0000;ooo]Z1?l0002:oookJP00W_oo
nfX4o`0000Kooo]Z1Ol00003oookJPGo0000J?oonfX5o`0007kooo]Z1?l00006oookJPGo00000ooo
nfX5o`0008Wooo]Z002NoookJPCo00003_oonfX5o`0006Sooo]Z1Ol0001noookJPCo00003_oonfX5
o`0008Wooo]Z002NoookJPCo00003ooonfX4o`0006Sooo]Z1Ol0001noookJPCo00003_oonfX5o`00
08Wooo]Z002NoookJPCo00003ooonfX4o`0006Sooo]Z1Ol0001noookJPCo00003ooonfX4o`0008Wo
oo]Z002NoookJPCo00003ooonfX5o`0006Oooo]Z1Ol0001noookJPCo00003ooonfX4o`0008Wooo]Z
002NoookJPCo00003ooonfX5o`0006Oooo]Z1Ol0001noookJPCo00003ooonfX5o`0008Sooo]Z002N
oookJPCo00003ooonfX5o`0004Wooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001n
oookJPCo00003ooonfX5o`0008Sooo]Z002NoookJPCo00004?oonfX5o`0004Oooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001noookJPCo00003ooonfX5o`0008Sooo]Z002NoookJPCo
00004?oonfX5o`0004Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000O_oonfX4o`00013ooo]Z1Ol00027
oookJP00W_oonfX4o`00013ooo]Z1Ol000000ooonf[o0000o`000004o`0003?ooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0007kooo]Z1?l0000@oook
JPco0000P?oonfX009kooo]Z1?l0000AoookJP_o0000<ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Sooo]Z1_l0001moookJPCo00004?oonfX=o`0007oooo]Z002NoookJPCo0000
4OoonfX<o`0003kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001noookJPCo0000
4OoonfX<o`0007oooo]Z002MoookJPGo00004OoonfX<o`0003kooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l8oookJPGo0000O_oonfX4o`00017ooo]Z3?l0001ooookJP00WOoonfX5
o`0001;ooo]Z2ol0000noookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000O_oonfX4
o`0001;ooo]Z3?l0001noookJP00WOoonfX5o`0001?ooo]Z1Ol000000ooonf[o0000o`000003o`00
03gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001noookJPCo00004ooonfX5o`00
0003oookJ_l0003o000000?o0000O_oonfX009gooo]Z1?l0000JoookJPKo0000??oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o3_oonfX5o`0007kooo]Z1?l0000IoookJPKo0000OOoonfX009gooo]Z
1?l0000JoookJPKo0000?OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo
0000O_oonfX4o`0001[ooo]Z1Ol0001moookJP00WOoonfX4o`0001_ooo]Z1Ol0000moookJPOo001o
2OoonfX7o`00O`Sooo]Z1Ol0001noookJPCo00006_oonfX5o`0007gooo]Z002MoookJPCo00007?oo
nfX5o`0003gooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0007kooo]Z1?l0000KoookJPGo0000O?oo
nfX009gooo]Z1?l0000LoookJPGo0000FooonfX5o`0007gooo]Z1Ol0000KoookJPGo0000O?oonfX0
09gooo]Z1?l0000LoookJPGo0000FooonfX5o`0007gooo]Z1Ol0000KoookJPGo0000O?oonfX009go
oo]Z1?l0000MoookJPGo0000F_oonfX5o`0007gooo]Z1Ol0000LoookJPGo0000NooonfX009gooo]Z
1?l0000MoookJP_o0000E?oonfX5o`0007gooo]Z1?l0000MoookJPGo000000?ooo]Zo`000?l00000
0ol0001eoookJP00WOoonfX4o`0001gooo]Z3?l0001CoookJPGo0000OOoonfX4o`0001gooo]Z3?l0
001doookJP00WOoonfX4o`0001kooo]Z3?l0001BoookJPGo0000OOoonfX4o`0001kooo]Z3?l0001c
oookJP00WOoonfX4o`0001kooo]Z3?l0001BoookJPGo0000OOoonfX4o`0001kooo]Z3Ol0001boook
JP00WOoonfX4o`0001oooo]Z3?l0001AoookJPGo0000OOoonfX4o`0001oooo]Z3?l0001boookJP00
WOoonfX4o`0002Kooo]Z1Ol0001AoookJPGo0000OOoonfX4o`0002Kooo]Z1_l0001aoookJP00WOoo
nfX4o`0002Kooo]Z1_l0001@oookJPGo0000OOoonfX4o`0002Oooo]Z1Ol0001aoookJP00WOoonfX4
o`0002Oooo]Z1Ol0001@oookJPGo0000OOoonfX4o`0002Oooo]Z1Ol0001aoookJP00WOoonfX4o`00
02Oooo]Z1_l0001?oookJPGo0000OOoonfX4o`0002Sooo]Z1Ol0001`oookJP008_oonfX3o`00OgGo
oo]Z0ol007l4o`0000;ooo]Z0ol007l3oookJPGo001o6ooonfX6o`0004kooo]Z1Ol0001doookJPGo
001o1?oonfX4o`0000;ooo]Z1Ol007lQoookJPKo0000CooonfX3o`00Oagooo]Z000RoookJP?o001o
M?oonfX4o`00O`Co00000_oonfX3o`00O`;ooo]Z1ol007lJoookJPgo0000AooonfX5o`0007?ooo]Z
1ol007l3oookJPCo000000?ooo]Zo`00Ool007l01Ol007lPoookJPgo0000B?oonfX3o`00Oagooo]Z
000RoookJP?o001oM?oonfX3o`00O`03oookJ_l0003o000000;o00000_oonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o6ooonfX=o`0004Kooo]Z1Ol0001coookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX4o`0000Co001o00Cooo]Zo`00Ool007oo001o8OoonfX=o`00
04Oooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;o
oo]Z1?l00006oookJP?o001o0ooonfX3o`00Oa_ooo]Z3_l00014oookJPGo0000L_oonfX3o`00O`?o
oo]Z0ol007l2oookJPCo00000ol007l3oookJP?o001o8OoonfX=o`0004Kooo]Z0ol007lMoookJP00
4ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1?l0000<oookJP?o001o
6ooonfX@o`0004;ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o
8_oonfX<o`0004Kooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo00003?oo
nfX3o`00Oacooo]Z4Ol00010oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00001_oo
nfX3o`00Ob;ooo]Z3Ol00015oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4
o`0000Oooo]Z0_l007l2oookJPCo001o9?oonfX;o`0003kooo]Z1Ol0001boookJP?o001o0ooonfX3
o`00O`03oookJ_l0003o000000?o000000?ooo]Zo`00Ool007l00_oonfX4o`00Ob[ooo]Z1Ol00015
oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000ol00007oook
JPOo001o9ooonfX;o`0003cooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o0000
00?o000000?ooo]Zo`00Ool007l01Ol007l[oookJPKo0000A?oonfX3o`00Oagooo]Z000RoookJP?o
001oLooonfX3o`00O`03oookJ_l0003o000000?o00001ooonfX6o`00Ob[ooo]Z2ol0000joookJPGo
0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000003o`000003oookJ_l007oo001o00Co
001o;OoonfX6o`000003oookJ_l0003o000000Co0000??oonfX3o`00Oagooo]Z000OoookJPKo001o
LooonfX3o`00O`03oookJ_l0003o000000?o00001ooonfX2o`00Oc3ooo]Z2ol0000hoookJPGo0000
L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l007laoookJPko0000
>?oonfX6o`00Oagooo]Z000OoookJPKo001oM?oonfX3o`00O`Co00002?oonfX2o`00Oc;ooo]Z2ol0
000foookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l00002oookJP;o001o
<_oonfX>o`0003Oooo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol0
07l^oookJP_o0000=?oonfX5o`0007?ooo]Z1ol007l2oookJPCo00000ooonfX7o`00Obgooo]Z3Ol0
000ioookJPCo001o7OoonfX002;ooo]Z0ol007meoookJP;o001o1?l00009oookJPOo001o<?oonfX;
o`0003;ooo]Z1Ol0001doookJPGo001o0ooonfX4o`0000?ooo]Z1ol007l]oookJPko0000>OoonfX3
o`00Oagooo]Z002LoookJPCo0000@_oonfX<o`0002oooo]Z1Ol0001loookJPCo0000?ooonfX7o`00
00;ooo]Z1_l0001@oookJP00W?oonfX4o`0004Cooo]Z3?l0000]oookJPGo0000O?oonfX4o`00043o
oo]Z4?l0001>oookJP00W?oonfX4o`0004Kooo]Z2ol0000/oookJPGo0000O?oonfX4o`00047ooo]Z
3ol0001>oookJP00W?oonfX4o`0004Sooo]Z2Ol00004oookJPGo00008ooonfX5o`0007cooo]Z1?l0
0012oookJQ3o00000ooonfX5o`0004Cooo]Z002LoookJPCo0000BooonfXAo`00027ooo]Z1Ol0001l
oookJPCo0000@ooonfX?o`000003oookJ_l0003o000000Oo0000@_oonfX009cooo]Z1?l0001=oook
JQ3o00000ooonfX7o`0001Kooo]Z1Ol0001loookJPCo0000AOoonfX4o`0000?ooo]Z4Ol00003oook
JPSo0000=_oonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go0000
3ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX0
00kooo]Zool0003oo`0002Go00003ooonfX001cooo]Z2?l00004oookJPSo00001?oonfXKo`0004go
oo]Z1?l0001WoookJPOo00001?oonfX8o`0000?ooo]Z2Ol00004oookJPSo00000ooonfXLo`0004go
oo]Z1?l0001WoookJPOo00001?oonfX8o`0000Gooo]Z00?o0000oookJ_oonfX07?oonfX003Cooo]Z
2?l00004oookJQ3o00000ooonfX4o`0004Gooo]Z1?l0001moookJPGo00005OoonfX7o`0000?ooo]Z
4Ol00003oookJPCo0000A?oonfX5o`0009kooo]Z0010oookJQWo0000@ooonfX4o`0007gooo]Z1Ol0
000PoookJQWo0000@_oonfX5o`0009kooo]Z0011oookJPOo00000ooonfX?o`0004;ooo]Z1?l0001m
oookJPGo00008OoonfX6o`0000?ooo]Z4?l00011oookJPGo0000W_oonfX004cooo]Z3ol00011oook
JPCo0000OOoonfX5o`0002cooo]Z3_l00011oookJPCo0000WooonfX004gooo]Z3_l00011oookJPCo
0000OOoonfX5o`0002cooo]Z3ol00010oookJPCo0000WooonfX004kooo]Z1_l00002oookJPKo0000
?ooonfX5o`0007gooo]Z1Ol0000^oookJPKo00000_oonfX7o`0003kooo]Z1?l0002OoookJP00Eooo
nfX=o`0003Oooo]Z1Ol0001moookJPGo0000=_oonfX?o`0003Kooo]Z1?l0002OoookJP00EooonfX>
o`0003Kooo]Z1Ol0001moookJPGo0000=ooonfX>o`0003Kooo]Z1?l0002OoookJP00F?oonfX>o`00
03Gooo]Z1?l0001noookJPGo0000>?oonfX>o`0003Gooo]Z1?l0002OoookJP00FOoonfX>o`0003Co
oo]Z1?l0001noookJPGo0000>OoonfX=o`0003Gooo]Z1?l0002OoookJP00F_oonfX6o`000003oook
J_l0003o000000Co0000=?oonfX4o`0007kooo]Z1Ol0000koookJPGo000000?ooo]Zo`000?l00000
1?l0000doookJPCo0000WooonfX006;ooo]Z1_l0000coookJPCo0000O_oonfX5o`0004;ooo]Z1_l0
000coookJPCo0000WooonfX006?ooo]Z1_l0000boookJPCo0000O_oonfX5o`0004;ooo]Z1_l0000c
oookJPCo0000WooonfX006?ooo]Z3?l0000/oookJPCo0000O_oonfX5o`0004?ooo]Z3Ol0000[oook
JPCo0000WooonfX006Cooo]Z3Ol0000ZoookJPCo0000O_oonfX5o`0004Cooo]Z3Ol0000ZoookJPCo
0000WooonfX006Gooo]Z3?l0000ZoookJPCo0000O_oonfX5o`0004Cooo]Z3Ol0000ZoookJPCo0000
WooonfX006Gooo]Z3?l0000ZoookJPCo0000O_oonfX5o`0004Gooo]Z3Ol0000YoookJPCo0000Wooo
nfX006Oooo]Z2ol0000YoookJPCo0000O_oonfX5o`0004Kooo]Z3?l0000YoookJPCo0000WooonfX0
06gooo]Z1_l0000XoookJPCo0000O_oonfX5o`0004gooo]Z1_l0000XoookJPCo0000WooonfX006go
oo]Z1_l0000XoookJPCo0000O_oonfX5o`0004kooo]Z1_l0000WoookJPCo0000WooonfX006kooo]Z
1_l0000WoookJPCo0000O_oonfX5o`0004kooo]Z1_l0000WoookJPCo0000WooonfX006oooo]Z1Ol0
000WoookJPCo0000O_oonfX5o`0004oooo]Z1_l0000VoookJPCo0000WooonfX006oooo]Z1_l0000V
oookJPCo0000O_oonfX5o`00053ooo]Z1Ol0000VoookJPCo0000WooonfX0073ooo]Z3?l0000Ooook
JPCo0000O_oonfX5o`00053ooo]Z1_l0000UoookJPCo0000WooonfX0073ooo]Z3?l0000OoookJPCo
0000O_oonfX5o`00057ooo]Z1_l0000ToookJPCo0000WooonfX0077ooo]Z3?l0000NoookJPCo0000
O_oonfX5o`00057ooo]Z1_l0000ToookJPCo0000WooonfX007;ooo]Z3?l0000MoookJPCo0000O_oo
nfX5o`0005;ooo]Z1_l0000SoookJPCo0000WooonfX007;ooo]Z3?l0000MoookJPCo0000O_oonfX5
o`0005?ooo]Z1_l0000RoookJPCo0000WooonfX007Wooo]Z1_l0000KoookJPGo0000O_oonfX5o`00
05?ooo]Z1ol0000PoookJPGo0000WooonfX007[ooo]Z1Ol0000KoookJPGo0000O_oonfX5o`0005Co
oo]Z1ol0000OoookJPGo0000WooonfX007[ooo]Z1Ol0000KoookJPGo0000O_oonfX5o`0005Gooo]Z
1ol0000NoookJPGo0000WooonfX007_ooo]Z1Ol0000JoookJPCo0000OooonfX5o`0005Kooo]Z1_l0
000NoookJPCo0000X?oonfX007_ooo]Z1Ol0000JoookJPCo0000OooonfX5o`0005Oooo]Z1_l0000M
oookJPCo0000X?oonfX007_ooo]Z1Ol0000JoookJPCo0000OooonfX5o`0005Sooo]Z1_l0000Loook
JPCo0000X?oonfX007cooo]Z1Ol0000IoookJPCo0000HOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o2_oonfX5o`0005Sooo]Z1ol0000KoookJPCo0000X?oonfX007cooo]Z1Ol000000ooonf[o0000
o`000003o`0001?ooo]Z1?l0001PoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000
FOoonfX7o`0001[ooo]Z1?l0002PoookJP00O?oonfX<o`0001;ooo]Z1?l0001PoookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2OoonfX5o`0005[ooo]Z1ol0000IoookJPCo0000X?oonfX007gooo]Z3?l0000AoookJPCo0000
GooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001KoookJPOo0000
6?oonfX4o`000:3ooo]Z001moookJPco00004OoonfX4o`0005oooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Sooo]Z1_l0001KoookJPKo00006?oonfX4o`000:3ooo]Z001noookJP_o00004OoonfX4
o`0005oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001MoookJPKo00005ooonfX4
o`000:3ooo]Z001noookJPKo000000?ooo]Zo`000?l000000ol0000@oookJPCo0000GooonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001NoookJPKo00005_oonfX4o`00
0:3ooo]Z0025oookJPGo00004?oonfX4o`0005oooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wo
oo]Z1Ol0001NoookJPOo00005OoonfX4o`000:3ooo]Z0025oookJPGo00004?oonfX4o`0005oooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001OoookJPOo00005?oonfX4o`000:3ooo]Z
0026oookJPGo00003ooonfX4o`0005oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0
001PoookJPOo00004ooonfX4o`000:3ooo]Z0026oookJPGo00003ooonfX4o`00063ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`00067ooo]Z1_l0000CoookJPCo0000X?oo
nfX008Kooo]Z1Ol0000?oookJPCo0000H?oonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000H_oonfX6
o`0001;ooo]Z1?l0002PoookJP00QooonfX4o`0000oooo]Z1?l0001QoookJPGo001o2_oonfX7o`00
O`Sooo]Z1Ol0001SoookJPKo00004OoonfX4o`000:3ooo]Z0027oookJPCo00003ooonfX4o`0007oo
oo]Z1Ol0001SoookJPOo00004?oonfX4o`000:3ooo]Z0027oookJPGo00003_oonfX4o`0007oooo]Z
1Ol0001ToookJPOo00003ooonfX4o`000:3ooo]Z0027oookJPGo00000ooonfX5o`0000Kooo]Z1?l0
001ooookJPGo0000IOoonfX7o`0000kooo]Z1?l0002PoookJP00QooonfX5o`0000;ooo]Z1_l00006
oookJPCo0000OooonfX5o`0006Kooo]Z1_l0000>oookJPCo0000X?oonfX008Sooo]Z3?l00006oook
JPCo0000OooonfX5o`0006Oooo]Z1_l0000=oookJPCo0000X?oonfX008Sooo]Z3Ol00004oookJPGo
0000OooonfX5o`0006Sooo]Z1_l0000<oookJPCo0000X?oonfX008Sooo]Z3Ol00004oookJPGo0000
OooonfX5o`0006Sooo]Z1ol0000:oookJPGo0000X?oonfX008Wooo]Z3?l00004oookJPGo0000Oooo
nfX5o`0006Wooo]Z1_l0000:oookJPGo0000X?oonfX008Wooo]Z3Ol00003oookJPCo0000P?oonfX5
o`0006[ooo]Z1_l00009oookJPGo0000X?oonfX008Wooo]Z3Ol00003oookJPCo0000P?oonfX5o`00
06_ooo]Z1_l00008oookJPCo0000XOoonfX008[ooo]Z1_l000000ooonf[o0000o`000003o`0000?o
oo]Z1?l00020oookJPGo0000JooonfX7o`0000Oooo]Z1?l0002QoookJP00RooonfX4o`0000?ooo]Z
1?l00003oookJPCo0000P?oonfX5o`0006cooo]Z1_l00007oookJPCo0000XOoonfX009;ooo]Z1?l0
0003oookJPCo0000P?oonfX5o`0006gooo]Z1_l00006oookJPCo0000XOoonfX009;ooo]Z1?l00003
oookJPCo0000P?oonfX5o`0006kooo]Z1_l00005oookJPCo0000XOoonfX009;ooo]Z1?l00003oook
JPCo0000P?oonfX5o`0006kooo]Z1_l00005oookJPCo0000XOoonfX009;ooo]Z1Ol00002oookJPCo
0000P?oonfX5o`0006oooo]Z1_l00004oookJPCo0000XOoonfX009;ooo]Z1Ol00002oookJPCo0000
P?oonfX5o`00073ooo]Z1_l00003oookJPCo0000XOoonfX009;ooo]Z1Ol00002oookJPCo0000P?oo
nfX5o`00073ooo]Z1ol00002oookJPCo0000XOoonfX009?ooo]Z1?l00002oookJPCo0000P?oonfX5
o`00077ooo]Z1_l00002oookJPCo0000XOoonfX009?ooo]Z1?l00002oookJPCo0000P?oonfX5o`00
07;ooo]Z1Ol00002oookJPCo0000XOoonfX009?ooo]Z1?l00002oookJPCo0000P?oonfX5o`0007?o
oo]Z1?l00002oookJPCo0000XOoonfX009?ooo]Z1?l000000ooonf[o0000o`000003o`00083ooo]Z
1Ol0001coookJPCo00000_oonfX4o`000:7ooo]Z002CoookJP[o0000P?oonfX5o`0007?ooo]Z1?l0
00000ooonf[o0000o`000003o`000:7ooo]Z002CoookJP[o0000P?oonfX5o`0007?ooo]Z2_l0002Q
oookJP00TooonfX9o`00087ooo]Z1Ol0001coookJP[o0000XOoonfX009Cooo]Z2?l00021oookJPGo
0000LooonfX9o`000:;ooo]Z002DoookJPSo0000POoonfX5o`0007Cooo]Z2?l0002RoookJP00U?oo
nfX8o`00087ooo]Z1Ol0001doookJPSo0000X_oonfX009Cooo]Z2?l00021oookJPGo0000M?oonfX8
o`000:;ooo]Z002DoookJPSo0000M?oonfX3o`00O`[ooo]Z1Ol0001doookJPSo0000X_oonfX009Go
oo]Z1ol0001doookJP?o001o2_oonfX5o`0007Cooo]Z2?l0002RoookJP00UOoonfX7o`0007Cooo]Z
0ol007l:oookJPGo0000M?oonfX8o`000:;ooo]Z002EoookJPOo0000M?oonfX3o`00O`[ooo]Z1Ol0
001doookJPSo0000X_oonfX009Gooo]Z1ol0001doookJP?o001o2_oonfX6o`0007Cooo]Z1ol0002R
oookJP00UOoonfX7o`0007Cooo]Z0ol007l:oookJPGo0000MOoonfX7o`000:;ooo]Z002EoookJPOo
0000M?oonfX3o`00O`[ooo]Z1Ol0001eoookJPOo0000X_oonfX009Gooo]Z1ol0001doookJP?o001o
2_oonfX5o`0007Kooo]Z1_l0002RoookJP00UOoonfX6o`0007Gooo]Z0ol007l:oookJPGo0000M_oo
nfX5o`000:?ooo]Z002FoookJPGo0000L_oonfX6o`00O`[ooo]Z1Ol0001foookJPGo0000XooonfX0
09Kooo]Z1?l0001coookJPKo001o2_oonfX5o`0007Kooo]Z1Ol0002SoookJP00oooonfX@oookJPCo
001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z
003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8
oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooook
JQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6
o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooook
JQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z
1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol0
07l8oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0
003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00oooonfX>oook
JPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQko
oo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00
O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00
oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;Ooo
nfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;o
oo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.04262 .3105 L
.04498 .30912 L
.04622 .30834 L
.04754 .30764 L
.04869 .30721 L
.04996 .30701 L
.05112 .3071 L
.0522 .30742 L
.05289 .30772 L
.05355 .30808 L
.05478 .30886 L
.05622 .30986 L
.05756 .31072 L
.05869 .31131 L
.0599 .31172 L
.06058 .31183 L
.06123 .31185 L
.06244 .31168 L
.06371 .31122 L
.06435 .31091 L
.06505 .31053 L
.06745 .30909 L
.0688 .30843 L
.06955 .30816 L
.07024 .30801 L
.07089 .30795 L
.07158 .30797 L
.07286 .30828 L
.07402 .30882 L
.0753 .30965 L
.07789 .31164 L
.07905 .31245 L
.0803 .31314 L
.08147 .31354 L
.08255 .31366 L
.08384 .31351 L
.08456 .31329 L
.08521 .31303 L
.08768 .31171 L
.08906 .31098 L
.08984 .31065 L
.09056 .31042 L
.09188 .31025 L
.09255 .31031 L
.09328 .31048 L
.09404 .31078 L
.09475 .31116 L
.0961 .31212 L
.09912 .31482 L
Mistroke
.10038 .31587 L
.10108 .31635 L
.10173 .31673 L
.10251 .31707 L
.10321 .31727 L
.10387 .31736 L
.10458 .31735 L
.10583 .3171 L
.10696 .31667 L
.10818 .31607 L
.10951 .3154 L
.11074 .31488 L
.11187 .3146 L
.11296 .31457 L
.11411 .31483 L
.11535 .31545 L
.11604 .31595 L
.11667 .31649 L
.11908 .31898 L
.12045 .32049 L
.12192 .32192 L
.12263 .32249 L
.1233 .32293 L
.12456 .32348 L
.12578 .32367 L
.12692 .32355 L
.12816 .32317 L
.12947 .3226 L
.1307 .32205 L
.13138 .32179 L
.13202 .3216 L
.13278 .32146 L
.13348 .32145 L
.13413 .32153 L
.13483 .32175 L
.13612 .32249 L
.13686 .3231 L
.13755 .32379 L
.14044 .32745 L
.14174 .32919 L
.14313 .33086 L
.14444 .3321 L
.14564 .33285 L
.14679 .33322 L
.14804 .33324 L
.14923 .33297 L
.15032 .33257 L
.15161 .33205 L
.15281 .33166 L
.15407 .33151 L
Mistroke
.15473 .33158 L
.15545 .3318 L
.15614 .33215 L
.15678 .33261 L
.15748 .33325 L
.15822 .33409 L
.16085 .33803 L
.16343 .34232 L
.16455 .34394 L
.16579 .34536 L
.16696 .34629 L
.16819 .3468 L
.16884 .34689 L
.16954 .34686 L
.17079 .34656 L
.17195 .34611 L
.17321 .34564 L
.1744 .34536 L
.1755 .3454 L
.17656 .34579 L
.17773 .34669 L
.17895 .34817 L
.1801 .35002 L
.18429 .35868 L
.18547 .36093 L
.18673 .3629 L
.18791 .36424 L
.18899 .36497 L
.19026 .36526 L
.19098 .36519 L
.19164 .36501 L
.19285 .36449 L
.19413 .36387 L
.19536 .36347 L
.19668 .3635 L
.19793 .36416 L
.19906 .3654 L
.19976 .36646 L
.2004 .36763 L
.20185 .37092 L
.20449 .3782 L
.20565 .38141 L
.20691 .38448 L
.2081 .38678 L
.2092 .38827 L
.21018 .38906 L
.21127 .38932 L
.2124 .38901 L
.21346 .38834 L
.21459 .3874 L
Mistroke
.21582 .38642 L
.21699 .38585 L
.21807 .38587 L
.21932 .38676 L
.21995 .38762 L
.22065 .38889 L
.22186 .39193 L
.223 .39561 L
.2254 .40498 L
.22796 .41463 L
.22871 .41687 L
.22943 .41858 L
.23007 .41975 L
.23076 .4206 L
.23142 .421 L
.23212 .42098 L
.23337 .41992 L
.23454 .41797 L
.2358 .41529 L
.23689 .41295 L
.23807 .41089 L
.23879 .41012 L
.23946 .40985 L
.24077 .41088 L
.24197 .41389 L
.24324 .41936 L
.24747 .44984 L
.24863 .45861 L
.24985 .46619 L
.2509 .47048 L
.25204 .47203 L
.25329 .46907 L
.254 .46503 L
.25463 .45978 L
.25588 .44517 L
.25705 .42619 L
.25931 .37742 L
.26176 .31304 L
.26411 .25028 L
.26541 .21928 L
.26664 .19398 L
.26779 .17497 L
.26903 .15964 L
.27017 .15076 L
.27122 .14667 L
.27187 .14599 L
.27258 .14672 L
.27386 .15135 L
.27511 .15894 L
.27626 .16754 L
Mistroke
.27903 .18916 L
.28039 .19769 L
.28162 .20337 L
.28284 .20679 L
.28398 .20812 L
.28519 .20777 L
.28651 .20589 L
.28905 .20049 L
.28975 .19917 L
.2905 .19803 L
.29121 .19731 L
.29186 .19701 L
.29249 .19707 L
.29319 .19757 L
.29391 .19856 L
.29458 .1999 L
.29598 .20383 L
.29747 .20928 L
.29995 .21922 L
.30135 .22426 L
.30266 .22801 L
.30392 .23051 L
.30462 .23141 L
.30526 .23194 L
.30593 .23222 L
.30667 .23221 L
.30736 .23197 L
.30801 .2316 L
.30923 .23063 L
.31054 .22956 L
.31179 .22886 L
.31293 .22874 L
.31417 .22934 L
.31548 .2309 L
.31618 .2321 L
.31683 .23342 L
.31831 .23705 L
.32126 .24527 L
.3227 .24889 L
.32404 .25156 L
.32523 .25324 L
.32649 .25428 L
.32775 .25462 L
.32847 .25456 L
.32914 .25437 L
.33028 .25388 L
.33152 .25328 L
.33269 .25287 L
.33378 .25279 L
.33505 .25319 L
Mistroke
.33576 .25368 L
.3364 .2543 L
.33764 .25594 L
.3388 .25794 L
.34159 .26377 L
.34296 .2666 L
.3442 .26885 L
.34536 .27053 L
.34645 .27168 L
.3476 .27241 L
.34886 .27269 L
.35015 .27253 L
.3508 .27233 L
.35151 .27206 L
.35271 .27159 L
.35397 .27122 L
.35461 .27115 L
.3553 .27118 L
.35653 .27157 L
.35722 .27199 L
.35796 .27261 L
.35929 .27414 L
.36169 .27785 L
.36429 .28214 L
.36554 .28389 L
.36623 .28468 L
.36688 .28529 L
.36801 .28607 L
.36927 .28648 L
.37045 .28648 L
.37153 .28623 L
.37278 .28575 L
.37397 .28527 L
.37502 .28493 L
.37615 .28476 L
.37721 .28485 L
.37817 .28518 L
.37931 .28589 L
.38054 .28702 L
.38276 .28976 L
.38514 .29294 L
.38645 .29445 L
.38769 .29555 L
.38885 .29623 L
.3901 .29657 L
.39124 .29654 L
.39229 .29629 L
.39354 .2958 L
.39471 .29526 L
.39542 .29496 L
Mistroke
.39609 .2947 L
.39736 .2944 L
.3986 .29441 L
.3993 .29456 L
.39995 .29482 L
.40066 .2952 L
.4013 .29564 L
.40274 .29691 L
.40528 .29965 L
.40666 .3011 L
.40795 .30222 L
.40863 .30268 L
.40935 .30307 L
.41016 .30335 L
.41089 .30347 L
.41156 .30347 L
.41228 .30337 L
.41359 .30295 L
.41617 .30169 L
.41685 .30136 L
.41758 .30106 L
.41827 .30085 L
.41891 .30072 L
.42004 .30069 L
.42124 .30095 L
.42247 .30153 L
.42317 .30199 L
.42382 .30248 L
.42627 .30465 L
.42761 .30583 L
.42886 .30675 L
.42952 .30713 L
.43022 .30745 L
.431 .30768 L
.43171 .30777 L
.43235 .30776 L
.43305 .30766 L
.43433 .30724 L
.43564 .3066 L
.43683 .30593 L
.4381 .30524 L
.43877 .30493 L
.43948 .30466 L
.44077 .30439 L
.44194 .30443 L
.44305 .30471 L
.44426 .30528 L
.44665 .30695 L
.4489 .30866 L
.45015 .30941 L
Mistroke
.45085 .30972 L
.4515 .30993 L
.45265 .31009 L
.45387 .30997 L
.45493 .30964 L
.45607 .3091 L
.45814 .30788 L
.45934 .30719 L
.46059 .3066 L
.46167 .30629 L
.46284 .30618 L
.46417 .30638 L
.46538 .30685 L
.46602 .30718 L
.46672 .3076 L
.46814 .30856 L
.46937 .30941 L
.47055 .31012 L
.47119 .31044 L
.4719 .31072 L
.47313 .31099 L
.47435 .31098 L
.47564 .31065 L
.47686 .31011 L
.47796 .30947 L
.48016 .30809 L
.48136 .30745 L
.48247 .30702 L
.48377 .30679 L
.48445 .30679 L
.48518 .30689 L
.48648 .30731 L
.48767 .30791 L
.49036 .30961 L
.49177 .31042 L
.49249 .31074 L
.49328 .311 L
.49395 .31114 L
.49468 .3112 L
.49599 .31104 L
.4973 .31059 L
.4985 .30996 L
.50108 .30833 L
.50231 .30764 L
.50343 .30716 L
.50461 .30688 L
.50588 .30687 L
.50701 .30712 L
.5082 .3076 L
.50945 .30831 L
Mistroke
.51062 .30906 L
.51198 .30992 L
.51327 .31062 L
.51438 .31103 L
.51558 .31125 L
.51667 .3112 L
.51769 .31096 L
.51877 .31052 L
.51998 .30986 L
.52241 .30834 L
.52372 .30764 L
.52438 .30737 L
.5251 .30716 L
.52637 .30701 L
.52756 .30716 L
.52828 .30738 L
.52896 .30767 L
.53024 .30838 L
.5331 .31032 L
.53432 .31104 L
.53561 .31158 L
.53671 .31182 L
.53792 .31181 L
.53922 .3115 L
.53995 .3112 L
.54061 .31088 L
.54314 .30938 L
.54443 .30868 L
.54564 .30819 L
.54674 .30797 L
.54792 .30799 L
.54921 .30834 L
.54986 .30863 L
.55057 .30903 L
.553 .31081 L
.55529 .31248 L
.55657 .31317 L
.55774 .31355 L
.55883 .31366 L
.56001 .31351 L
.56112 .31315 L
.56216 .31266 L
.56446 .31138 L
.56567 .31079 L
.56694 .31038 L
.56762 .31027 L
.56836 .31027 L
.56966 .31054 L
.5703 .31081 L
.57099 .31119 L
Mistroke
.57222 .31207 L
.5751 .31463 L
.57651 .31582 L
.57781 .31667 L
.579 .31716 L
.58025 .31737 L
.58151 .31724 L
.58222 .31704 L
.58289 .31678 L
.58531 .31559 L
.58595 .31528 L
.58664 .31499 L
.58789 .31463 L
.58859 .31456 L
.58923 .31458 L
.58995 .31472 L
.59071 .315 L
.59196 .31575 L
.59266 .31631 L
.59332 .31692 L
.60322 .32353 L
.62176 .33282 L
.64047 .34357 L
.66077 .35927 L
.68209 .38204 L
.70223 .40759 L
.70344 .41223 L
.70476 .41648 L
.70601 .41935 L
.70717 .42078 L
.70788 .42104 L
.70851 .42089 L
.70925 .4203 L
.70995 .41937 L
.71116 .4171 L
.71248 .41421 L
.71374 .4117 L
.71491 .41017 L
.71614 .40997 L
.71679 .41061 L
.71748 .41193 L
.71872 .41602 L
.71989 .42191 L
.72208 .4372 L
.72441 .45559 L
.72568 .46419 L
.72688 .46982 L
.72816 .47204 L
.72885 .47122 L
.72959 .46859 L
Mistroke
.73089 .45912 L
.73209 .44482 L
.73342 .42285 L
.73466 .39723 L
.73746 .32626 L
.7404 .24775 L
.74169 .21721 L
.74311 .1889 L
.74438 .16933 L
.74557 .15642 L
.74682 .14846 L
.74753 .14644 L
.74817 .14601 L
.74887 .14694 L
.74951 .14894 L
.75022 .15224 L
.75098 .15676 L
.75365 .17715 L
.75494 .18711 L
.75633 .1963 L
.75765 .20274 L
.75886 .20645 L
.75996 .208 L
.76116 .20795 L
.76241 .2064 L
.76358 .20409 L
.76474 .20154 L
.766 .19907 L
.76719 .19749 L
.76828 .19699 L
.76927 .19746 L
.77036 .19903 L
.7715 .20175 L
.77256 .20515 L
.77498 .21457 L
.7763 .21984 L
.77755 .22428 L
.77871 .22766 L
.77997 .2303 L
.78112 .23171 L
.78217 .23222 L
.78332 .23208 L
.78458 .23131 L
.78592 .23021 L
.78713 .22928 L
.78783 .22892 L
.78848 .22873 L
.78918 .22875 L
.78993 .22904 L
.79059 .22954 L
Mistroke
.79129 .23034 L
.79255 .23243 L
.79499 .23838 L
.79763 .24576 L
.79885 .24878 L
.80012 .25137 L
.80121 .253 L
.80241 .25412 L
.80356 .25459 L
.80461 .25457 L
.80582 .25418 L
.80697 .25364 L
.80796 .25318 L
.809 .25285 L
.81015 .25281 L
.81121 .25317 L
.81236 .25406 L
.8136 .25559 L
.81477 .25753 L
.81584 .25961 L
.81851 .2653 L
.81977 .26777 L
.82093 .26969 L
.82211 .27118 L
.82339 .27221 L
.82452 .27264 L
.82571 .27266 L
.82696 .27234 L
.82813 .27189 L
.82879 .27163 L
.8295 .27139 L
.83079 .27115 L
.83199 .27128 L
.8331 .27178 L
.83413 .27259 L
.83521 .27379 L
.83746 .27714 L
.83994 .28131 L
.84125 .28326 L
.84196 .28417 L
.84263 .28489 L
.84381 .28585 L
.84509 .28641 L
.84581 .28652 L
.8465 .2865 L
.84777 .28621 L
.84849 .28595 L
.84915 .28568 L
.84987 .28539 L
.85064 .2851 L
Mistroke
.85184 .28481 L
.85296 .28478 L
.85365 .28491 L
.8543 .28515 L
.85552 .2859 L
.8568 .28709 L
.85798 .28849 L
.86067 .29209 L
.86185 .29357 L
.86308 .29488 L
.86414 .29573 L
.86529 .29633 L
.86654 .29659 L
.86724 .29657 L
.86787 .29646 L
.86911 .29606 L
.87028 .29555 L
.87137 .29506 L
.87253 .29463 L
.87352 .29441 L
.8746 .29438 L
.87577 .29466 L
.87703 .29531 L
.87822 .29624 L
.8793 .29729 L
.88174 .29996 L
.88309 .30132 L
.88435 .30237 L
.88507 .30283 L
.88585 .30319 L
.88655 .30339 L
.88721 .30348 L
.8885 .30336 L
.88914 .30319 L
.88986 .30292 L
.89236 .30168 L
.89302 .30137 L
.89374 .30108 L
.89505 .30073 L
.89636 .3007 L
.89758 .301 L
.8987 .30155 L
.89989 .30238 L
.90226 .30446 L
.90446 .30634 L
.90557 .30706 L
.90675 .30757 L
.90807 .30778 L
.90926 .30765 L
.91056 .30722 L
Mistroke
.9113 .30688 L
.91197 .30652 L
.91319 .30583 L
.91453 .30512 L
.91574 .30464 L
.91688 .3044 L
.91808 .30442 L
.91936 .30476 L
.92058 .30536 L
.92171 .3061 L
.92426 .30806 L
.92543 .30888 L
.92652 .30949 L
.92778 .30995 L
.92892 .31009 L
.92998 .30998 L
.9311 .30965 L
.93206 .30921 L
.93311 .30862 L
.93425 .30792 L
.93547 .30722 L
.9365 .30672 L
.93764 .30634 L
.93888 .30618 L
.94004 .30631 L
.9413 .30672 L
.94201 .30707 L
.94265 .30744 L
.94492 .30897 L
.94611 .30975 L
.94739 .31044 L
.94856 .31086 L
.94963 .31102 L
.9507 .31095 L
.95171 .31069 L
.95285 .31021 L
.9539 .30962 L
.95626 .30814 L
.95741 .30752 L
.95865 .30703 L
.95981 .3068 L
.96088 .30681 L
.96212 .3071 L
.96283 .30738 L
.96348 .3077 L
.96595 .30922 L
.96708 .30993 L
.96831 .31058 L
.96901 .31086 L
.96965 .31105 L
Mistroke
.97091 .3112 L
.97214 .31105 L
.97284 .31085 L
.97348 .31059 L
.97479 .3099 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00XOoonfX5o`0007Oo
oo]Z1Ol00021oookJPGo0000V?oonfX00:7ooo]Z1Ol0001ZoookJP?o001o2_oonfX5o`00087ooo]Z
1Ol0002HoookJP00X?oonfX6o`0006[ooo]Z0ol007l:oookJPGo0000POoonfX5o`0009Sooo]Z002P
oookJPKo0000J_oonfX3o`00O`[ooo]Z1Ol00021oookJPKo0000UooonfX00:3ooo]Z1_l0001Joook
JP[o001o1_oonfX3o`00O`[ooo]Z1Ol00020oookJPOo0000UooonfX00:3ooo]Z1_l0001JoookJP[o
001o1_oonfX3o`00O`[ooo]Z1_l0001ooookJPOo0000UooonfX00:3ooo]Z1ol0001YoookJP?o001o
2_oonfX5o`00083ooo]Z1ol0002GoookJP00X?oonfX7o`0006Wooo]Z0ol007l:oookJPGo0000P?oo
nfX7o`0009Oooo]Z002PoookJPOo0000JOoonfX3o`00O`[ooo]Z1Ol00020oookJPOo0000UooonfX0
0:3ooo]Z1ol0001YoookJP?o001o2_oonfX5o`0007oooo]Z2?l0002GoookJP00X?oonfX8o`0006Go
oo]Z1_l007l:oookJPGo0000OooonfX8o`0009Oooo]Z002PoookJPSo0000IOoonfX6o`00O`[ooo]Z
1Ol0001ooookJPSo0000UooonfX009oooo]Z2Ol0001WoookJPCo001o2_oonfX5o`0007oooo]Z2Ol0
002FoookJP00WooonfX9o`0006Sooo]Z0ol007l:oookJPGo0000OooonfX9o`0009Kooo]Z002Ooook
JPWo0000MOoonfX5o`0007oooo]Z2Ol0002FoookJP00WooonfX4o`000003oookJ_l0003o000000;o
0000MOoonfX5o`0007oooo]Z1?l000000ooonf[o0000o`000002o`0009Kooo]Z002OoookJPCo0000
00?ooo]Zo`000?l000000_l0001eoookJPGo0000OooonfX4o`000003oookJ_l0003o000000;o0000
U_oonfX009oooo]Z1?l000000ooonf[o0000o`000002o`0007Gooo]Z1Ol0001ooookJPCo000000?o
oo]Zo`000?l000000_l0002FoookJP00WooonfX4o`000003oookJ_l0003o000000?o0000M?oonfX5
o`0007oooo]Z1?l000000ooonf[o0000o`000002o`0009Kooo]Z002OoookJPCo000000?ooo]Zo`00
0?l000000ol0001doookJPGo0000OooonfX4o`000003oookJ_l0003o000000;o0000U_oonfX009oo
oo]Z1?l000000ooonf[o0000o`000003o`0007Cooo]Z1Ol0001ooookJPCo000000?ooo]Zo`000?l0
00000ol0002EoookJP00WooonfX4o`0000;ooo]Z1?l0001doookJPGo0000OooonfX4o`000003oook
J_l0003o000000?o0000UOoonfX009oooo]Z1?l00002oookJPCo0000M?oonfX5o`0007oooo]Z1?l0
00000ooonf[o0000o`000003o`0009Gooo]Z002OoookJPCo00000_oonfX4o`0007Cooo]Z1Ol0001o
oookJPCo00000_oonfX4o`0009Gooo]Z002OoookJPCo00000_oonfX4o`0007Cooo]Z1Ol0001ooook
JPCo00000_oonfX4o`0009Gooo]Z002OoookJPCo00000_oonfX4o`0007Cooo]Z1Ol0001ooookJPCo
00000_oonfX5o`0009Cooo]Z002OoookJPCo00000_oonfX5o`0007?ooo]Z1Ol0001ooookJPCo0000
0_oonfX5o`0009Cooo]Z002OoookJPCo00000_oonfX5o`0000;ooo]Z1Ol0001/oookJPGo0000Oooo
nfX4o`0000;ooo]Z1Ol00002oookJPCo0000S_oonfX009oooo]Z1?l00002oookJPGo000000?ooo]Z
o`000?l000001?l0001/oookJPGo0000OooonfX4o`0000?ooo]Z1?l000000ooonf[o0000o`000005
o`0008cooo]Z002OoookJPCo00000ooonfX4o`000003oookJ_l0003o000000Go0000JooonfX5o`00
07oooo]Z1?l00003oookJPco0000S?oonfX009oooo]Z1?l00003oookJPco0000JooonfX5o`0007oo
oo]Z1?l00003oookJPco0000S?oonfX009oooo]Z1?l00003oookJPco0000JooonfX5o`0007kooo]Z
1Ol00003oookJPco0000S?oonfX009oooo]Z1?l00003oookJPco0000JooonfX5o`0007kooo]Z1Ol0
0004oookJPco0000RooonfX009kooo]Z1Ol00004oookJPco0000J_oonfX5o`0007kooo]Z1Ol00004
oookJPco0000RooonfX009kooo]Z1Ol00004oookJPco0000J_oonfX5o`0007kooo]Z1?l00005oook
JPco0000RooonfX009kooo]Z1Ol00004oookJPKo000000?ooo]Zo`000?l000000ol0001ZoookJPGo
0000O_oonfX4o`0000Gooo]Z1_l00002oookJPGo0000R_oonfX009kooo]Z1?l00005oookJPKo0000
0_oonfX5o`0006Wooo]Z1Ol0001noookJPCo00001_oonfX5o`0000;ooo]Z1Ol0002:oookJP00W_oo
nfX4o`0000gooo]Z1Ol0001YoookJPGo0000O_oonfX4o`0000gooo]Z1Ol0002:oookJP00W_oonfX4
o`0000gooo]Z1Ol0001YoookJPGo0000O_oonfX4o`0000kooo]Z1?l0002:oookJP00W_oonfX4o`00
00kooo]Z1Ol0001XoookJPGo0000O_oonfX4o`0000kooo]Z1Ol00029oookJP00W_oonfX4o`0000ko
oo]Z1Ol0001XoookJPGo0000O_oonfX4o`0000kooo]Z1Ol00029oookJP00W_oonfX4o`0000kooo]Z
1Ol0001XoookJPGo0000O_oonfX4o`0000kooo]Z1Ol00029oookJP00W_oonfX4o`0000oooo]Z1?l0
001XoookJPGo0000O_oonfX4o`0000oooo]Z1?l00029oookJP00W_oonfX4o`0000oooo]Z1?l0001:
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000O_oonfX4o`0000oooo]Z1?l00029
oookJP00W_oonfX4o`0000oooo]Z1Ol00018oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oook
JPGo0000O_oonfX4o`0000oooo]Z1Ol00028oookJP00W_oonfX4o`0000oooo]Z2ol00012oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2OoonfX5o`0007kooo]Z1?l0000?oookJPco0000POoonfX009kooo]Z1?l0000?oook
JPco0000=?oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000O_oonfX4o`0000oooo]Z3?l00021oookJP00W_oonfX4o`00013ooo]Z3?l0000coookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007cooo]Z1Ol0000@oookJPco
0000P?oonfX009gooo]Z1Ol0000AoookJP_o0000?ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX5o`0007gooo]Z1Ol0000AoookJP_o0000P?oonfX009gooo]Z1Ol0000AoookJPco0000?_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001moookJPGo00004Ooo
nfX<o`0007oooo]Z002MoookJPGo00006?oonfX5o`0003kooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Wooo]Z1Ol0001moookJPCo00006OoonfX5o`0007oooo]Z002MoookJPCo00006OoonfX5o`00
03kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001moookJPCo00006OoonfX5o`00
07oooo]Z002MoookJPCo00006_oonfX5o`0003gooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`ko
oo]Z1Ol0001moookJPCo00006_oonfX4o`0007oooo]Z002MoookJPCo00006_oonfX5o`0003kooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007gooo]Z1?l0000JoookJPGo
0000O_oonfX009gooo]Z1?l0000JoookJPGo0000?_oonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000
OOoonfX4o`0001[ooo]Z1Ol0001noookJP00WOoonfX4o`0001_ooo]Z1Ol0000noookJPGo001o2_oo
nfX7o`00O`Sooo]Z1Ol0001moookJPCo00006_oonfX6o`0007gooo]Z002MoookJPCo00006ooonfX5
o`0005cooo]Z1Ol0001moookJPCo00006ooonfX5o`0007gooo]Z002MoookJPCo00006ooonfX6o`00
05_ooo]Z1Ol0001moookJPCo00006ooonfX6o`0007cooo]Z002MoookJPCo00007?oonfX;o`0005Go
oo]Z1Ol0001moookJPCo00007?oonfX;o`0007Kooo]Z002MoookJPCo00007?oonfX<o`0005Cooo]Z
1Ol0001moookJPCo00007?oonfX<o`0007Gooo]Z002MoookJPCo00007OoonfX<o`0005?ooo]Z1Ol0
001moookJPCo00007OoonfX<o`0007Cooo]Z002MoookJPCo00007OoonfX<o`0005?ooo]Z1Ol0001m
oookJPCo00007OoonfX<o`0007Cooo]Z002MoookJPCo00007ooonfX4o`000003oookJ_l0003o0000
00?o0000DooonfX5o`0007gooo]Z1?l0000OoookJPCo000000?ooo]Zo`000?l000000ol0001doook
JP00WOoonfX4o`0002Gooo]Z1Ol0001BoookJPGo0000OOoonfX4o`0002Gooo]Z1Ol0001coookJP00
WOoonfX4o`0002Gooo]Z1Ol0001BoookJPGo0000OOoonfX4o`0002Gooo]Z1_l0001boookJP00WOoo
nfX4o`0002Gooo]Z1_l0001AoookJPGo0000OOoonfX4o`0002Gooo]Z1_l0001boookJP00WOoonfX4
o`0002Kooo]Z1_l0001@oookJPGo0000OOoonfX4o`0002Kooo]Z1Ol0001boookJP00WOoonfX4o`00
02Kooo]Z1_l0001@oookJPGo0000OOoonfX4o`0002Oooo]Z1Ol0001aoookJP008_oonfX3o`00OgGo
oo]Z0ol007l4o`0000;ooo]Z0ol007l3oookJPGo001o6_oonfX<o`0004Wooo]Z1Ol0001doookJPGo
001o1?oonfX4o`0000;ooo]Z1Ol007lPoookJPco0000B_oonfX3o`00Oagooo]Z000RoookJP?o001o
M?oonfX4o`00O`Co00000_oonfX3o`00O`;ooo]Z1ol007lJoookJPco0000B?oonfX5o`0007?ooo]Z
1ol007l3oookJPCo000000?ooo]Zo`00Ool007l01Ol007lOoookJPgo0000BOoonfX3o`00Oagooo]Z
000RoookJP?o001oM?oonfX3o`00O`03oookJ_l0003o000000;o00000_oonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o6_oonfX<o`0004Sooo]Z1Ol0001coookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX4o`0000Co001o00Cooo]Zo`00Ool007oo001o8?oonfX<o`00
04Wooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;o
oo]Z1?l00006oookJP?o001o0ooonfX3o`00Oa[ooo]Z3?l00017oookJPGo0000L_oonfX3o`00O`?o
oo]Z0ol007l2oookJPCo00000ol007l3oookJP?o001o8?oonfX<o`0004Sooo]Z0ol007lMoookJP00
4ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1?l0000<oookJP?o001o
8OoonfX5o`0004Oooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o
9ooonfX5o`0004Sooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo00003?oo
nfX3o`00Ob7ooo]Z1_l00016oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00001_oo
nfX3o`00ObOooo]Z1_l00017oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Z
o`000?l000000ol00007oookJP;o001o0_oonfX4o`00Ob;ooo]Z1_l00015oookJPGo0000L_oonfX3
o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Zo`00Ool007l00_oonfX4o`00ObSooo]Z1_l00016
oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000ol00007oook
JPOo001o8ooonfX>o`0003gooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooo
nf[o001oo`00O`05o`00ObWooo]Z3Ol0000ooookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o
001o00?ooo]Zo`000?l000000ol00007oookJPKo001o9OoonfX=o`0003gooo]Z1Ol0001boookJP?o
001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`04o`00Ob_ooo]Z3Ol0000noookJP?o
001o7OoonfX001oooo]Z1_l007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]Z
oookJP05oookJP;o001o:_oonfX<o`0003gooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oook
J_l0003o000000?o000000?ooo]Zo`00Ool007l0<?oonfX=o`0003[ooo]Z1_l007lMoookJP007ooo
nfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z0_l007l[oookJPgo0000>ooonfX5o`0007?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l2oookJPGo000000?ooo]Zo`00Ool007l0<?oonfX=o`0003[ooo]Z
1_l007lMoookJP008OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol007lUoookJPKo000000?o
oo]Zo`000?l000001Ol0000joookJPGo0000LooonfX7o`00O`;ooo]Z1Ol00002oookJPOo001o;?oo
nfX<o`0003_ooo]Z1?l007lMoookJP008_oonfX3o`00OgGooo]Z0_l007l4o`0000Wooo]Z1ol007l/
oookJPOo000000?ooo]Zo`000?l000001Ol0000boookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003
oookJPOo001o<ooonfX>o`0003?ooo]Z0ol007lMoookJP00W?oonfX4o`0003gooo]Z3ol0000aoook
JPGo0000O?oonfX4o`0003gooo]Z3ol0001BoookJP00W?oonfX4o`0003oooo]Z3_l0000`oookJPGo
0000O?oonfX4o`0003kooo]Z3ol0001AoookJP00W?oonfX4o`0003oooo]Z3ol0000_oookJPGo0000
O?oonfX4o`0003oooo]Z3ol0001@oookJP00W?oonfX4o`00043ooo]Z6?l0000UoookJPGo0000O?oo
nfX4o`00043ooo]Z6?l00016oookJP00W?oonfX4o`0004Wooo]Z3ol0000UoookJPGo0000O?oonfX4
o`0004Wooo]Z3ol00016oookJP00W?oonfX4o`0004[ooo]Z4?l000000ooonf[o0000o`000006o`00
00Kooo]Z1?l0000@oookJPGo0000O?oonfX4o`0004[ooo]Z3ol00002oookJPWo00001OoonfX4o`00
037ooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z
000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oook
J_oo0000ool0000Uo`0000oooo]Z000MoookJP04o`000?oonf[ooo]ZoookJPSo00001?oonfX8o`00
00?ooo]Z6_l0001:oookJPCo0000HooonfX5o`0000Gooo]Z1ol00005oookJPWo000000?ooo]Zo`00
0?l000001_l00004oookJPSo00000ooonfXKo`0004Wooo]Z1?l0001SoookJPGo00001OoonfX7o`00
00Cooo]Z2?l0000NoookJP00;ooonfX4o`0000Kooo]Z1ol00002oookJQ7o0000BOoonfX4o`0007go
oo]Z1Ol0000?oookJPGo00001OoonfX8o`000003oookJ_l0003o0000013o0000B?oonfX4o`0009ko
oo]Z000koookJPCo00001OoonfX?o`0004Wooo]Z1?l0001moookJPGo00006ooonfX4o`0000Gooo]Z
4Ol00017oookJPCo0000W_oonfX004Cooo]Z6?l00010oookJPCo0000OOoonfX5o`0002Cooo]Z4_l0
0016oookJPCo0000W_oonfX004Kooo]Z1Ol00004oookJPko0000?ooonfX4o`0007gooo]Z1Ol0000V
oookJPCo00001_oonfX8o`0004Cooo]Z1?l0002NoookJP00CooonfX>o`0003oooo]Z1?l0001moook
JPGo0000<OoonfX9o`0004;ooo]Z1?l0002NoookJP00D?oonfX>o`0003kooo]Z1?l0001moookJPGo
0000<_oonfX:o`00043ooo]Z1?l0002NoookJP00DOoonfX6o`000003oookJ_l0003o000000Go0000
?OoonfX4o`0007gooo]Z1Ol0000coookJP_o0000?_oonfX4o`0009kooo]Z001IoookJPOo000000?o
oo]Zo`000?l000000ol0000foookJPCo0000OOoonfX5o`0003Gooo]Z2ol0000loookJPCo0000W_oo
nfX005[ooo]Z3Ol0000eoookJPCo0000OOoonfX5o`0003Oooo]Z2ol0000joookJPCo0000W_oonfX0
05_ooo]Z3Ol0000doookJPCo0000OOoonfX5o`0003Wooo]Z2ol0000hoookJPCo0000W_oonfX005co
oo]Z3?l0000doookJPCo0000OOoonfX5o`0003_ooo]Z2_l0000goookJPCo0000W_oonfX005cooo]Z
3Ol0000coookJPCo0000OOoonfX5o`0003gooo]Z2_l0000eoookJPCo0000W_oonfX006Cooo]Z1_l0
000boookJPCo0000OOoonfX5o`0003oooo]Z2_l0000coookJPCo0000W_oonfX006Cooo]Z1ol0000a
oookJPCo0000OOoonfX5o`00047ooo]Z2Ol0000boookJPCo0000W_oonfX006Gooo]Z1_l0000aoook
JPCo0000OOoonfX5o`0004;ooo]Z2_l0000`oookJPCo0000W_oonfX006Kooo]Z3?l0000YoookJPGo
0000OOoonfX5o`0004Cooo]Z2Ol0000^oookJPGo0000W_oonfX006Oooo]Z3?l0000XoookJPGo0000
OOoonfX5o`0004Kooo]Z2?l0000]oookJPGo0000W_oonfX006Oooo]Z3Ol0000WoookJPGo0000OOoo
nfX5o`0004Oooo]Z2Ol0000[oookJPGo0000W_oonfX006Sooo]Z3?l0000WoookJPCo0000O_oonfX5
o`0004Wooo]Z2?l0000ZoookJPCo0000WooonfX006Wooo]Z1Ol000000ooonf[o0000o`000004o`00
02Kooo]Z1?l0001noookJPGo0000B_oonfX9o`0002Sooo]Z1?l0002OoookJP00L?oonfX5o`0002Ko
oo]Z1?l0001noookJPGo0000BooonfX9o`0002Oooo]Z1?l0002OoookJP00L?oonfX5o`0002Kooo]Z
1?l0001noookJPGo0000COoonfX8o`0002Kooo]Z1?l0002OoookJP00LOoonfX5o`0002Gooo]Z1?l0
001noookJPGo0000C_oonfX8o`0002Gooo]Z1?l0002OoookJP00LOoonfX6o`0002Cooo]Z1?l0001n
oookJPGo0000D?oonfX6o`0002Gooo]Z1?l0002OoookJP00LOoonfX6o`0002Cooo]Z1?l0001noook
JPGo0000DOoonfX6o`0002Cooo]Z1?l0002OoookJP00L_oonfX;o`0001kooo]Z1?l0001noookJPGo
0000D_oonfX6o`0002?ooo]Z1?l0002OoookJP00LooonfX;o`0001gooo]Z1?l0001noookJPGo0000
D_oonfX7o`0002;ooo]Z1?l0002OoookJP00LooonfX<o`0001cooo]Z1?l0001noookJPGo0000Dooo
nfX7o`00027ooo]Z1?l0002OoookJP00M?oonfX;o`0001cooo]Z1?l0001noookJPGo0000E?oonfX7
o`00023ooo]Z1?l0002OoookJP00MOoonfX4o`000003oookJ_l0003o000000?o00007?oonfX4o`00
07kooo]Z1Ol0001EoookJPOo00007ooonfX4o`0009oooo]Z001koookJPCo00007?oonfX4o`0007ko
oo]Z1Ol0001FoookJPOo00007_oonfX4o`0009oooo]Z001koookJPGo00006ooonfX4o`0007kooo]Z
1Ol0001GoookJPOo00007OoonfX4o`0009oooo]Z001koookJPGo00006ooonfX4o`0007kooo]Z1Ol0
001HoookJPOo00007?oonfX4o`0009oooo]Z001koookJPKo00006_oonfX4o`0007kooo]Z1Ol0001I
oookJPOo00006ooonfX4o`0009oooo]Z001loookJPGo00006_oonfX4o`00063ooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001JoookJPOo00006OoonfX5o`0009oooo]Z001loookJPGo
00006_oonfX4o`0005oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001KoookJPOo
00006?oonfX5o`0009oooo]Z001moookJPGo00006OoonfX4o`0005oooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oook
JPGo0000G?oonfX6o`0001Sooo]Z1Ol0002OoookJP00OOoonfX<o`0001;ooo]Z1?l0001NoookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0005gooo]Z1_l0000GoookJPCo
0000X?oonfX007gooo]Z3Ol0000AoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX6o`0005gooo]Z1_l0000FoookJPCo0000X?oonfX007kooo]Z3?l0000AoookJPCo0000G_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0005kooo]Z1ol0000EoookJPCo0000X?oo
nfX007oooo]Z2ol0000@oookJPGo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`Sooo]Z1Ol0001OoookJPOo00005?oonfX4o`000:3ooo]Z001ooookJP_o00004?oonfX5o`00
05kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001PoookJPOo00004ooonfX4o`00
0:3ooo]Z0021oookJPCo000000?ooo]Zo`000?l000000ol0000?oookJPGo0000G_oonfX3o`00O`?o
oo]Z0ol007l7oookJPKo001o2_oonfX5o`00067ooo]Z1ol0000BoookJPCo0000X?oonfX008Kooo]Z
1Ol0000?oookJPCo0000GooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0006;ooo]Z
1_l0000BoookJPCo0000X?oonfX008Kooo]Z1Ol0000?oookJPCo0000H?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000HooonfX6o`00017ooo]Z1?l0002PoookJP00Qooo
nfX5o`0000kooo]Z1?l0001PoookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001ToookJPKo00004?oo
nfX4o`000:3ooo]Z0027oookJPGo00003_oonfX4o`00067ooo]Z1Ol007l:oookJPOo001o2?oonfX5
o`0006Cooo]Z1ol0000?oookJPCo0000X?oonfX008Oooo]Z1Ol0000>oookJPCo0000OooonfX5o`00
06Gooo]Z1ol0000>oookJPCo0000X?oonfX008Sooo]Z1?l0000>oookJPCo0000OooonfX5o`0006Ko
oo]Z1ol0000=oookJPCo0000X?oonfX008Sooo]Z1Ol0000=oookJPCo0000OooonfX5o`0006Oooo]Z
1_l0000=oookJPCo0000X?oonfX008Sooo]Z1Ol00002oookJPKo00001OoonfX4o`0007oooo]Z1Ol0
001XoookJPGo00000_oonfX5o`0000Kooo]Z1?l0002PoookJP00R?oonfX5o`000003oookJ_l0003o
000000Go00001OoonfX4o`0007oooo]Z1Ol0001YoookJPCo00000_oonfX6o`0000Gooo]Z1?l0002P
oookJP00ROoonfX<o`0000Gooo]Z1?l0001ooookJPGo0000JOoonfX4o`000003oookJ_l0003o0000
00Go00001OoonfX4o`000:3ooo]Z0029oookJPco00001?oonfX5o`0007oooo]Z1Ol0001YoookJPgo
00001?oonfX4o`000:3ooo]Z0029oookJPgo00000ooonfX5o`0007oooo]Z1Ol0001YoookJPgo0000
1?oonfX4o`000:3ooo]Z002:oookJPco00000ooonfX5o`0007oooo]Z1Ol0001YoookJPgo00001?oo
nfX4o`000:3ooo]Z002:oookJPco00000ooonfX4o`00083ooo]Z1Ol0001ZoookJPco00001?oonfX4
o`000:3ooo]Z002:oookJPOo000000?ooo]Zo`000?l000000_l00003oookJPCo0000P?oonfX5o`00
06[ooo]Z1ol000000ooonf[o0000o`000002o`0000Cooo]Z1?l0002PoookJP00RooonfX6o`000003
oookJ_l0003o000000;o00000ooonfX4o`00083ooo]Z1Ol0001[oookJPKo000000?ooo]Zo`000?l0
00000_l00004oookJPCo0000X?oonfX008_ooo]Z1Ol00002oookJPCo00000ooonfX4o`00083ooo]Z
1Ol0001[oookJPGo00000_oonfX4o`0000Cooo]Z1?l0002PoookJP00T_oonfX5o`0000;ooo]Z1?l0
0020oookJPGo0000L_oonfX4o`0000Cooo]Z1?l0002PoookJP00T_oonfX5o`0000;ooo]Z1?l00020
oookJPGo0000L_oonfX5o`0000?ooo]Z1?l0002PoookJP00T_oonfX5o`0000;ooo]Z1?l00020oook
JPGo0000L_oonfX5o`0000?ooo]Z1?l0002PoookJP00TooonfX4o`0000;ooo]Z1?l00020oookJPGo
0000L_oonfX5o`0000?ooo]Z1?l0002PoookJP00TooonfX4o`0000;ooo]Z1?l00020oookJPGo0000
LooonfX4o`0000;ooo]Z1Ol0002PoookJP00TooonfX4o`0000;ooo]Z1?l00020oookJPGo0000Looo
nfX4o`0000;ooo]Z1Ol0002PoookJP00TooonfX4o`0000;ooo]Z1?l00020oookJPGo0000LooonfX4
o`0000;ooo]Z1Ol0002PoookJP00TooonfX4o`0000;ooo]Z1?l00020oookJPGo0000LooonfX5o`00
0003oookJ_l0003o000000;o0000XOoonfX009?ooo]Z1Ol000000ooonf[o0000o`000002o`00083o
oo]Z1Ol0001coookJPGo000000?ooo]Zo`000?l000000_l0002QoookJP00TooonfX5o`000003oook
J_l0003o000000;o0000P?oonfX5o`0007?ooo]Z1Ol000000ooonf[o0000o`000002o`000:7ooo]Z
002CoookJPGo000000?ooo]Zo`000?l000000_l00020oookJPGo0000M?oonfX4o`000003oookJ_l0
003o000000;o0000XOoonfX009Cooo]Z1?l000000ooonf[o0000o`000002o`00083ooo]Z1Ol0001d
oookJPCo000000?ooo]Zo`000?l000000_l0002QoookJP00U?oonfX4o`000003oookJ_l0003o0000
00;o0000P?oonfX5o`0007Cooo]Z2Ol0002QoookJP00U?oonfX4o`000003oookJ_l0003o000000;o
0000P?oonfX5o`0007Cooo]Z2Ol0002QoookJP00U?oonfX9o`00083ooo]Z1Ol0001doookJPWo0000
XOoonfX009Cooo]Z2Ol00020oookJPGo0000MOoonfX8o`000:7ooo]Z002DoookJPWo0000LooonfX3
o`00O`[ooo]Z1Ol0001eoookJPOo0000X_oonfX009Gooo]Z1ol0001doookJP?o001o2_oonfX5o`00
07Gooo]Z1ol0002RoookJP00UOoonfX7o`0007Cooo]Z0ol007l:oookJPGo0000MOoonfX7o`000:;o
oo]Z002EoookJPOo0000M?oonfX3o`00O`[ooo]Z1Ol0001eoookJPOo0000X_oonfX009Gooo]Z1ol0
001doookJP?o001o2_oonfX6o`0007Cooo]Z1ol0002RoookJP00UOoonfX7o`0007Cooo]Z0ol007l:
oookJPGo0000MOoonfX7o`000:;ooo]Z002EoookJPOo0000M?oonfX3o`00O`[ooo]Z1Ol0001eoook
JPOo0000X_oonfX009Gooo]Z1ol0001doookJP?o001o2_oonfX5o`0007Gooo]Z1_l0002SoookJP00
UOoonfX7o`0007Cooo]Z0ol007l:oookJPGo0000M_oonfX5o`000:?ooo]Z002FoookJPGo0000L_oo
nfX6o`00O`[ooo]Z1Ol0001foookJPGo0000XooonfX009Kooo]Z1Ol0001boookJPKo001o2_oonfX5
o`0007Oooo]Z1?l0002SoookJP00oooonfX@oookJPCo001o2_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o
001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o
0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2
oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooookJP;ooo]Z0ol007l>oook
JP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003n
oookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00
O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l0
07l=oookJPGo0000oooonfXOoookJP00oooonfX>oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo
0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooo
nfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooook
JPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJPCo001o0_oonfX3o`00Oooo
oo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oo
nfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30976 L
.02605 .31036 L
.02729 .31086 L
.02846 .31109 L
.02954 .31107 L
.03053 .31084 L
.03163 .3104 L
.03279 .30976 L
.03504 .30833 L
.03628 .30764 L
.03746 .30718 L
.03813 .30703 L
.03885 .30696 L
.04012 .30709 L
.04142 .30754 L
.04262 .30818 L
.04521 .30986 L
.04648 .31059 L
.04765 .31107 L
.04872 .31129 L
.04984 .31129 L
.05097 .31103 L
.05221 .3105 L
.05477 .30898 L
.05617 .30817 L
.05687 .30785 L
.05751 .30762 L
.05874 .30739 L
.0594 .30739 L
.06009 .30748 L
.06121 .30785 L
.06244 .30849 L
.0651 .31035 L
.06655 .3113 L
.06726 .31168 L
.0679 .31195 L
.06906 .31225 L
.07029 .31227 L
.07093 .31216 L
.07163 .31195 L
.0729 .31139 L
.07575 .30975 L
.07644 .30939 L
.07719 .30908 L
.07801 .30885 L
.07877 .30874 L
.07946 .30875 L
.08022 .30888 L
.08093 .30912 L
Mistroke
.08159 .30943 L
.08285 .31022 L
.08418 .31126 L
.08683 .31335 L
.08756 .31381 L
.08832 .3142 L
.08898 .31444 L
.08969 .31459 L
.09099 .3146 L
.09172 .31445 L
.09238 .31424 L
.09367 .31365 L
.09488 .31299 L
.09606 .31237 L
.0973 .31185 L
.09836 .31161 L
.09953 .31161 L
.10079 .31197 L
.10149 .31232 L
.10214 .31274 L
.10458 .31487 L
.10576 .31601 L
.10703 .31716 L
.10823 .31805 L
.10934 .31861 L
.11063 .31893 L
.11128 .31894 L
.112 .31885 L
.11324 .31847 L
.11441 .31795 L
.11549 .31741 L
.11667 .31688 L
.11778 .31654 L
.11881 .31643 L
.12001 .31662 L
.12129 .31721 L
.12236 .31801 L
.12354 .31916 L
.12604 .32204 L
.12741 .32353 L
.12868 .32466 L
.12935 .32511 L
.13006 .32548 L
.13085 .32573 L
.13157 .32583 L
.13222 .32581 L
.13293 .32569 L
.13422 .32526 L
.13553 .32469 L
.13676 .32419 L
Mistroke
.13803 .32387 L
.13871 .32383 L
.13944 .32392 L
.14073 .32443 L
.14196 .32536 L
.14306 .32652 L
.14426 .32805 L
.14681 .33168 L
.14816 .33339 L
.14889 .33417 L
.14958 .33479 L
.15082 .33556 L
.15148 .33579 L
.15218 .33591 L
.15344 .3358 L
.15458 .33546 L
.1557 .33502 L
.15689 .33458 L
.15819 .33431 L
.15939 .33441 L
.16051 .33489 L
.16156 .33572 L
.16271 .33703 L
.16394 .33885 L
.16671 .34366 L
.16805 .34589 L
.16928 .34758 L
.17057 .34889 L
.17129 .34936 L
.17196 .34965 L
.17269 .3498 L
.17337 .3498 L
.17411 .34967 L
.17489 .34942 L
.17608 .34895 L
.17736 .34849 L
.17857 .34833 L
.17967 .34854 L
.18096 .34935 L
.18169 .35011 L
.18236 .351 L
.18492 .35574 L
.1874 .36125 L
.18876 .36397 L
.19002 .36599 L
.19068 .36681 L
.19139 .36747 L
.19218 .36795 L
.19289 .36817 L
.19354 .36819 L
Mistroke
.19425 .36807 L
.19553 .36755 L
.19683 .36689 L
.19804 .36642 L
.19931 .36637 L
.19999 .36661 L
.20071 .3671 L
.20199 .36865 L
.20321 .3709 L
.2055 .37678 L
.20773 .38328 L
.20896 .3865 L
.21012 .38898 L
.2112 .39066 L
.21236 .3917 L
.21343 .39194 L
.2144 .39166 L
.21557 .39087 L
.21666 .38989 L
.21795 .38882 L
.21913 .38828 L
.22037 .38851 L
.22154 .3897 L
.22278 .39211 L
.22348 .39399 L
.22412 .39603 L
.22638 .40475 L
.22875 .41443 L
.23 .41854 L
.2307 .42035 L
.23136 .42163 L
.23251 .42285 L
.23374 .42268 L
.23491 .42126 L
.23618 .41873 L
.23729 .41612 L
.23848 .41354 L
.23954 .41191 L
.24071 .41141 L
.24178 .41253 L
.24278 .41516 L
.24405 .4208 L
.24477 .42507 L
.24544 .42963 L
.24797 .44992 L
.24915 .45925 L
.25026 .46653 L
.25155 .4718 L
.25271 .47257 L
.25401 .46784 L
Mistroke
.25466 .46297 L
.25538 .45562 L
.25665 .43747 L
.25784 .41491 L
.26338 .26743 L
.26581 .20659 L
.26704 .18258 L
.2684 .16281 L
.2691 .15548 L
.26986 .14985 L
.27057 .14662 L
.27123 .14533 L
.27251 .14691 L
.27315 .14945 L
.27385 .15328 L
.27632 .17205 L
.27864 .19034 L
.27993 .19815 L
.28066 .20149 L
.28133 .20382 L
.28251 .20621 L
.28376 .20654 L
.2849 .20526 L
.28613 .20281 L
.28719 .20032 L
.28834 .19778 L
.28905 .19654 L
.2897 .19569 L
.29098 .19509 L
.29214 .19594 L
.29338 .19833 L
.29444 .20142 L
.29557 .20557 L
.29763 .21412 L
.29889 .21918 L
.30009 .22331 L
.30116 .22623 L
.30233 .22841 L
.30357 .2296 L
.30471 .22975 L
.30596 .22915 L
.30727 .22804 L
.30833 .2271 L
.30946 .22634 L
.31071 .2261 L
.31188 .22662 L
.31257 .22732 L
.31321 .22822 L
.31468 .23112 L
.31734 .23841 L
Mistroke
.31974 .24513 L
.32109 .24813 L
.32233 .25011 L
.32297 .25082 L
.32367 .25135 L
.32441 .25164 L
.32509 .25171 L
.32634 .25143 L
.32705 .25111 L
.32769 .25079 L
.32888 .25021 L
.33018 .24985 L
.33141 .24999 L
.33254 .25066 L
.33383 .2521 L
.33505 .25406 L
.33782 .25992 L
.33922 .263 L
.34072 .26589 L
.34145 .26703 L
.34214 .26794 L
.34342 .26912 L
.34459 .26963 L
.34568 .26969 L
.34686 .26941 L
.34812 .26893 L
.3493 .26848 L
.35057 .26823 L
.35129 .26825 L
.35196 .26842 L
.35326 .26916 L
.35458 .27051 L
.3558 .27221 L
.35857 .27698 L
.35982 .2791 L
.36117 .28108 L
.36244 .28249 L
.36361 .28332 L
.3647 .28369 L
.3659 .2837 L
.36715 .28338 L
.36831 .28293 L
.36937 .28252 L
.37037 .28223 L
.37152 .28212 L
.37257 .28231 L
.37373 .28288 L
.37495 .28389 L
.376 .28505 L
.37715 .28657 L
Mistroke
.37972 .29021 L
.38098 .29178 L
.38212 .29291 L
.38332 .29373 L
.3846 .29416 L
.38527 .2942 L
.38599 .29413 L
.3873 .29375 L
.3897 .29273 L
.39091 .29234 L
.3916 .29222 L
.39224 .29221 L
.39346 .29244 L
.39457 .29298 L
.39585 .29397 L
.39706 .2952 L
.39918 .29764 L
.4003 .2989 L
.40151 .30007 L
.4028 .30099 L
.40402 .30148 L
.4047 .30159 L
.40542 .30159 L
.4067 .30131 L
.40788 .30083 L
.40899 .30029 L
.41019 .29971 L
.4115 .29925 L
.41224 .29912 L
.41292 .29909 L
.41357 .29916 L
.41425 .29934 L
.41545 .2999 L
.41676 .30085 L
.41945 .30338 L
.42087 .30467 L
.42165 .30528 L
.42238 .30575 L
.42306 .30608 L
.4238 .30633 L
.42508 .30646 L
.42638 .30622 L
.42758 .30574 L
.42994 .30449 L
.43119 .30389 L
.43189 .30364 L
.43253 .30348 L
.43373 .3034 L
.43486 .30361 L
.43591 .30404 L
Mistroke
.43704 .30472 L
.4395 .30667 L
.44071 .30762 L
.44181 .30837 L
.44301 .30897 L
.44431 .30928 L
.44495 .3093 L
.44566 .30922 L
.44639 .30903 L
.44707 .30877 L
.45 .30715 L
.45128 .30646 L
.45195 .30617 L
.45266 .30593 L
.45396 .30573 L
.45516 .30586 L
.45628 .30623 L
.45751 .30689 L
.4602 .30877 L
.46151 .30963 L
.46269 .31023 L
.46391 .31059 L
.46519 .31064 L
.46587 .31053 L
.4666 .31032 L
.46792 .30972 L
.47033 .30825 L
.47164 .30751 L
.47287 .30699 L
.47399 .30674 L
.47518 .30675 L
.47586 .30688 L
.47651 .30708 L
.47771 .30765 L
.47983 .30898 L
.48095 .30971 L
.48216 .31039 L
.48347 .31089 L
.48469 .31107 L
.48541 .31104 L
.48609 .31092 L
.48737 .31046 L
.48856 .30983 L
.48967 .30913 L
.49088 .30837 L
.49218 .30764 L
.49292 .30732 L
.4936 .3071 L
.49426 .30697 L
.49494 .30692 L
Mistroke
.49614 .30707 L
.49745 .30753 L
.49818 .3079 L
.49885 .30829 L
.50035 .30924 L
.50175 .3101 L
.50306 .31072 L
.50416 .31103 L
.50535 .3111 L
.50666 .31086 L
.50787 .31037 L
.50905 .30971 L
.51035 .30888 L
.51173 .30804 L
.51297 .30742 L
.51415 .30706 L
.51527 .30696 L
.51645 .30712 L
.51772 .30759 L
.51884 .3082 L
.52002 .30896 L
.52214 .31031 L
.52343 .31093 L
.5246 .31125 L
.52525 .31132 L
.52596 .3113 L
.52725 .311 L
.52845 .31048 L
.52973 .30975 L
.53203 .30835 L
.53272 .308 L
.53344 .3077 L
.53424 .30748 L
.53497 .30738 L
.53629 .30749 L
.53704 .3077 L
.53773 .308 L
.53904 .30875 L
.54023 .30958 L
.54161 .31057 L
.5429 .31139 L
.54401 .31192 L
.5452 .31224 L
.54651 .31227 L
.54772 .31199 L
.54892 .31148 L
.55022 .31075 L
.55159 .30994 L
.55284 .3093 L
.55402 .30889 L
Mistroke
.55514 .30873 L
.55632 .30886 L
.5576 .30933 L
.55872 .31 L
.5599 .31088 L
.56202 .31262 L
.56329 .31353 L
.56449 .31419 L
.56515 .31443 L
.56587 .31459 L
.56714 .3146 L
.56834 .31432 L
.56962 .31377 L
.57192 .31254 L
.5732 .31196 L
.57392 .31173 L
.57458 .31161 L
.5758 .31162 L
.57709 .31202 L
.57777 .31237 L
.5785 .31286 L
.57981 .31396 L
.5828 .3168 L
.58413 .31786 L
.58538 .31855 L
.58668 .31891 L
.58737 .31895 L
.58811 .31886 L
.58943 .31848 L
.59067 .31791 L
.5919 .3173 L
.59302 .31682 L
.5937 .3166 L
.59435 .31647 L
.59503 .31643 L
.59577 .31651 L
.59642 .31669 L
.5971 .31699 L
.59832 .31783 L
.59975 .31919 L
.60108 .32069 L
.60253 .32239 L
.60411 .32402 L
.60477 .32458 L
.60547 .32507 L
.60673 .32565 L
.6079 .32583 L
.6092 .32567 L
.61035 .32528 L
.61159 .32475 L
Mistroke
.61275 .32426 L
.61384 .32394 L
.6151 .32384 L
.61577 .32395 L
.61648 .32421 L
.61724 .32463 L
.61795 .32518 L
.61927 .32655 L
.62185 .33004 L
.62311 .33182 L
.62426 .33328 L
.62533 .33441 L
.62649 .33529 L
.62772 .33581 L
.62889 .33591 L
.63017 .33567 L
.63089 .33542 L
.63153 .33517 L
.63273 .3347 L
.63398 .33435 L
.63462 .3343 L
.63531 .33435 L
.63654 .3348 L
.63722 .33526 L
.63796 .33594 L
.63929 .33757 L
.64168 .3415 L
.64294 .34374 L
.64428 .34594 L
.64551 .34763 L
.64616 .34835 L
.64686 .34896 L
.64809 .34963 L
.64925 .34982 L
.6505 .34961 L
.6517 .34918 L
.65278 .34875 L
.65394 .3484 L
.65509 .34835 L
.65612 .34865 L
.65716 .34937 L
.65815 .35044 L
.65929 .35217 L
.66035 .35415 L
.66274 .35937 L
.66389 .36189 L
.66515 .36432 L
.66633 .36616 L
.66743 .36735 L
.66871 .36808 L
Mistroke
.66935 .3682 L
.67006 .36815 L
.6713 .36775 L
.67246 .36717 L
.67357 .36664 L
.67474 .36633 L
.67574 .36643 L
.67684 .36705 L
.67802 .3684 L
.67928 .37064 L
.68155 .37638 L
.68422 .3841 L
.68563 .3876 L
.68639 .38915 L
.68711 .3903 L
.68842 .39162 L
.68911 .3919 L
.68985 .39192 L
.69117 .39132 L
.69237 .39033 L
.69354 .38928 L
.69478 .38845 L
.6955 .38825 L
.69615 .38832 L
.69742 .38928 L
.6986 .39128 L
.69988 .39464 L
.70221 .40325 L
.70459 .41308 L
.7059 .41768 L
.70713 .42088 L
.70829 .42257 L
.70954 .42289 L
.71068 .4219 L
.71173 .4201 L
.71299 .41729 L
.71434 .41419 L
.71562 .41203 L
.7168 .41139 L
.71804 .41267 L
.71935 .41659 L
.72005 .41979 L
.7207 .42343 L
.72217 .43368 L
.72492 .45609 L
.72558 .46097 L
.72627 .46549 L
.72752 .47119 L
.72862 .47279 L
.72984 .46976 L
Mistroke
.73115 .46021 L
.73237 .44501 L
.73377 .42014 L
.73511 .39016 L
.73761 .32276 L
.74052 .24205 L
.74194 .20795 L
.74325 .18232 L
.74432 .16615 L
.74545 .15414 L
.74658 .14727 L
.74782 .14527 L
.74908 .14832 L
.74979 .15182 L
.75044 .15586 L
.75288 .17512 L
.7541 .18499 L
.7554 .19405 L
.75608 .19793 L
.75683 .2014 L
.75814 .20535 L
.75938 .20664 L
.76007 .20646 L
.76071 .20582 L
.76195 .20364 L
.76312 .20094 L
.76426 .19835 L
.76533 .1964 L
.76656 .19518 L
.76768 .19529 L
.76874 .19657 L
.76972 .1987 L
.77079 .20197 L
.77192 .2062 L
.77413 .2154 L
.77535 .22015 L
.7765 .22397 L
.77715 .22575 L
.77786 .22731 L
.7791 .22911 L
.78036 .22978 L
.78153 .22953 L
.7827 .22871 L
.78394 .22759 L
.78502 .22672 L
.78616 .22616 L
.7874 .22623 L
.78855 .22707 L
.78925 .22798 L
.78991 .2291 L
Mistroke
.79115 .23181 L
.79555 .24415 L
.79661 .24674 L
.79776 .24899 L
.79902 .25067 L
.80019 .25151 L
.80085 .25169 L
.80157 .25169 L
.80288 .25128 L
.80416 .25064 L
.80534 .2501 L
.80654 .24984 L
.80763 .25 L
.80889 .2508 L
.81008 .25218 L
.81519 .26254 L
.81659 .26533 L
.81736 .26662 L
.81809 .26765 L
.81877 .26842 L
.81951 .26905 L
.8208 .26964 L
.82197 .26968 L
.82327 .26934 L
.82392 .26909 L
.82462 .2688 L
.82588 .26837 L
.82708 .26822 L
.82834 .26849 L
.82941 .26914 L
.83059 .27029 L
.83558 .27841 L
.83702 .28063 L
.83773 .28154 L
.83838 .28225 L
.8396 .2832 L
.84092 .28369 L
.84206 .2837 L
.84314 .28345 L
.84431 .28301 L
.84557 .28251 L
.8469 .28217 L
.84815 .28216 L
.84927 .28251 L
.8505 .28331 L
.85156 .28433 L
.85274 .28576 L
.85512 .28911 L
.85619 .29058 L
.85734 .29196 L
Mistroke
.85842 .293 L
.8594 .29368 L
.86061 .29413 L
.86174 .29419 L
.86297 .29393 L
.86367 .29369 L
.86431 .29342 L
.86561 .29285 L
.86682 .29241 L
.86809 .2922 L
.86876 .29223 L
.86948 .29239 L
.87066 .29293 L
.87196 .2939 L
.87431 .2964 L
.87659 .299 L
.8777 .30007 L
.87873 .30083 L
.88005 .30144 L
.88074 .30158 L
.88147 .3016 L
.88266 .30138 L
.88396 .30088 L
.88535 .3002 L
.88666 .2996 L
.88738 .29934 L
.88817 .29915 L
.88888 .29909 L
.88954 .29913 L
.89074 .29945 L
.89206 .30018 L
.89272 .30067 L
.89344 .30127 L
.89473 .30249 L
.89604 .30376 L
.89727 .30485 L
.89838 .30563 L
.89958 .30621 L
.90083 .30645 L
.90198 .30637 L
.90322 .30599 L
.90454 .30536 L
.90677 .30416 L
.90802 .30366 L
.90916 .30342 L
.90979 .3034 L
.91048 .30347 L
.91174 .30386 L
.91299 .30456 L
.91415 .3054 L
Mistroke
.91551 .30651 L
.91697 .30768 L
.91765 .30815 L
.91836 .30858 L
.91963 .30911 L
.92027 .30925 L
.92096 .3093 L
.92219 .30914 L
.92295 .3089 L
.92366 .30859 L
.925 .30786 L
.92736 .30652 L
.92855 .30602 L
.92986 .30575 L
.93053 .30574 L
.93126 .30584 L
.93257 .30628 L
.93388 .307 L
.93507 .30781 L
.9366 .30892 L
.93735 .30942 L
.93804 .30982 L
.93934 .31039 L
.94002 .31057 L
.94074 .31065 L
.94179 .31058 L
.94277 .31032 L
.94384 .30986 L
.94499 .30921 L
.94611 .30851 L
.94732 .30778 L
.94847 .30721 L
.94953 .30686 L
.95051 .30672 L
.9516 .30678 L
.95273 .3071 L
.95379 .30759 L
.95565 .30873 L
.95769 .31003 L
.95886 .31061 L
.95995 .31096 L
.9611 .31108 L
.96233 .31091 L
.96348 .3105 L
.96456 .30994 L
.96659 .30867 L
.96775 .30796 L
.96899 .30737 L
.97004 .30704 L
.9712 .30693 L
Mistroke
.97244 .3071 L
.97314 .30732 L
.97378 .30759 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00XOoonfX4o`0007Sooo]Z1Ol00021oookJPCo0000VOoonfX00:7o
oo]Z1Ol0001goookJPGo0000POoonfX4o`0009Wooo]Z002QoookJPGo0000J_oonfX3o`00O`[ooo]Z
1Ol00021oookJPGo0000V?oonfX00:3ooo]Z1_l0001ZoookJP?o001o2_oonfX5o`00087ooo]Z1Ol0
002HoookJP00X?oonfX6o`0006[ooo]Z0ol007l:oookJPGo0000P?oonfX6o`0009Sooo]Z002Poook
JPKo0000F_oonfX:o`00O`Kooo]Z0ol007l:oookJPGo0000P?oonfX6o`0009Sooo]Z002PoookJPKo
0000F_oonfX:o`00O`Kooo]Z0ol007l:oookJPKo0000OooonfX7o`0009Oooo]Z002PoookJPKo0000
J_oonfX3o`00O`[ooo]Z1Ol00020oookJPOo0000UooonfX00:3ooo]Z1ol0001YoookJP?o001o2_oo
nfX5o`00083ooo]Z1ol0002GoookJP00WooonfX8o`0006Wooo]Z0ol007l:oookJPGo0000OooonfX8
o`0009Oooo]Z002OoookJPSo0000JOoonfX3o`00O`[ooo]Z1Ol0001ooookJPSo0000UooonfX009oo
oo]Z2?l0001VoookJPKo001o2_oonfX5o`0007oooo]Z2?l0002GoookJP00WooonfX8o`0006Kooo]Z
1_l007l:oookJPGo0000OooonfX9o`0009Kooo]Z002OoookJPWo0000IooonfX4o`00O`[ooo]Z1Ol0
001ooookJPWo0000U_oonfX009oooo]Z2Ol0001XoookJP?o001o2_oonfX5o`0007oooo]Z2Ol0002F
oookJP00WooonfX9o`0007Gooo]Z1Ol0001ooookJPCo000000?ooo]Zo`000?l000000_l0002Foook
JP00WooonfX4o`000003oookJ_l0003o000000;o0000MOoonfX5o`0007oooo]Z1?l000000ooonf[o
0000o`000002o`0009Kooo]Z002OoookJPCo000000?ooo]Zo`000?l000000_l0001eoookJPGo0000
OooonfX4o`000003oookJ_l0003o000000;o0000U_oonfX009oooo]Z1?l000000ooonf[o0000o`00
0002o`0007Gooo]Z1Ol0001ooookJPCo000000?ooo]Zo`000?l000000_l0002FoookJP00WooonfX4
o`000003oookJ_l0003o000000;o0000MOoonfX5o`0007oooo]Z1?l000000ooonf[o0000o`000002
o`0009Kooo]Z002OoookJPCo000000?ooo]Zo`000?l000000_l0001eoookJPGo0000OooonfX4o`00
0003oookJ_l0003o000000?o0000UOoonfX009oooo]Z1?l000000ooonf[o0000o`000003o`0007Co
oo]Z1Ol0001ooookJPCo000000?ooo]Zo`000?l000000ol0002EoookJP00WooonfX4o`000003oook
J_l0003o000000?o0000M?oonfX5o`0007oooo]Z1?l000000ooonf[o0000o`000003o`0009Gooo]Z
002OoookJPCo000000?ooo]Zo`000?l000000ol0001doookJPGo0000OooonfX4o`0000;ooo]Z1?l0
002EoookJP00WooonfX4o`0000;ooo]Z1?l0001doookJPGo0000OooonfX4o`0000;ooo]Z1?l0002E
oookJP00WooonfX4o`0000;ooo]Z1?l0001doookJPGo0000OooonfX4o`0000;ooo]Z1?l0002Eoook
JP00WooonfX4o`0000;ooo]Z1?l0001doookJPGo0000OooonfX4o`0000;ooo]Z1?l0002EoookJP00
WooonfX4o`0000;ooo]Z1?l00003oookJPCo0000KOoonfX5o`0007oooo]Z1?l00002oookJPCo0000
0_oonfX5o`0008kooo]Z002NoookJPGo00000_oonfX5o`000003oookJ_l0003o000000?o0000KOoo
nfX5o`0007kooo]Z1Ol00002oookJPCo00000_oonfX6o`0008gooo]Z002NoookJPGo00000_oonfX<
o`0006cooo]Z1Ol0001noookJPGo00000_oonfX<o`0008gooo]Z002NoookJPGo00000_oonfX<o`00
06cooo]Z1Ol0001noookJPGo00000_oonfX<o`0008gooo]Z002NoookJPCo00001?oonfX<o`0006_o
oo]Z1Ol0001noookJPCo00000ooonfX=o`0008cooo]Z002NoookJPCo00001?oonfX<o`0006_ooo]Z
1Ol0001noookJPCo00001?oonfX<o`0008cooo]Z002NoookJPCo00001?oonfX<o`0006_ooo]Z1Ol0
001noookJPCo00001?oonfX<o`0008cooo]Z002NoookJPCo00001?oonfX7o`000003oookJ_l0003o
000000;o0000JooonfX5o`0007kooo]Z1?l00004oookJPco0000S?oonfX009kooo]Z1?l00004oook
JPOo000000?ooo]Zo`000?l000000_l0001[oookJPGo0000O_oonfX4o`0000Cooo]Z1ol000000ooo
nf[o0000o`000003o`0008_ooo]Z002NoookJPCo00001OoonfX5o`0000;ooo]Z1Ol0001ZoookJPGo
0000O_oonfX4o`0000Gooo]Z1Ol00002oookJPGo0000RooonfX009kooo]Z1?l0000<oookJPGo0000
J_oonfX5o`0007kooo]Z1?l00006oookJPCo00000_oonfX5o`0008_ooo]Z002NoookJPCo00003?oo
nfX5o`0006[ooo]Z1Ol0001noookJPCo00003OoonfX5o`0008[ooo]Z002NoookJPCo00003OoonfX4
o`0006[ooo]Z1Ol0001noookJPCo00003OoonfX5o`0008[ooo]Z002NoookJPCo00003OoonfX5o`00
06Wooo]Z1Ol0001noookJPCo00003OoonfX5o`0008[ooo]Z002NoookJPCo00003OoonfX5o`0006Wo
oo]Z1Ol0001noookJPCo00003_oonfX4o`0008[ooo]Z002NoookJPCo00003OoonfX6o`0006Sooo]Z
1Ol0001noookJPCo00003_oonfX4o`0008[ooo]Z002NoookJPCo00003_oonfX5o`0006Sooo]Z1Ol0
001noookJPCo00003_oonfX5o`0008Wooo]Z002NoookJPCo00003_oonfX5o`000003oookJ_l0003o
000000?o0000A?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0007gooo]Z1Ol0000>
oookJP_o0000PooonfX009kooo]Z1?l0000?oookJP_o0000@_oonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o2OoonfX5o`0007gooo]Z1Ol0000>oookJPco0000P_oonfX009kooo]Z1?l0000?oookJP_o
0000@_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001moookJPGo00003ooonfX;o`0008;ooo]Z002Noook
JPCo00003ooonfX<o`0003Cooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o2?oonfX5o`0007gooo]Z1?l0000@oookJPco0000POoonfX009kooo]Z1?l0000@oookJP_o
0000=?oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001loookJPCo
00004OoonfX;o`00087ooo]Z002NoookJPCo00004OoonfX:o`00043ooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Sooo]Z1Ol0001moookJPCo00004OoonfX;o`00087ooo]Z002NoookJPCo00005ooo
nfX5o`0003oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000OOoo
nfX4o`0001Sooo]Z1Ol00020oookJP00WOoonfX5o`0001Oooo]Z1Ol0000ooookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l9oookJPGo0000OOoonfX4o`0001Sooo]Z1Ol00020oookJP00WOoonfX5o`00
01Oooo]Z1Ol0000ooookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000OOoonfX4o`00
01Sooo]Z1Ol00020oookJP00WOoonfX5o`0001Sooo]Z1Ol0000noookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Wooo]Z1Ol0001ooookJP00WOoonfX4o`0001Wooo]Z
1Ol0000ooookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001moookJPCo
00006OoonfX5o`0007oooo]Z002MoookJPCo00006OoonfX5o`0003oooo]Z1ol007l9oookJPOo001o
2?oonfX5o`0007gooo]Z1?l0000IoookJPKo0000O_oonfX009gooo]Z1?l0000JoookJPGo0000?ooo
nfX5o`00O`[ooo]Z1ol007l8oookJPGo0000OOoonfX4o`0001[ooo]Z1Ol0001noookJP00WOoonfX4
o`0001[ooo]Z2ol0001GoookJPGo0000OOoonfX4o`0001[ooo]Z2ol0001hoookJP00WOoonfX4o`00
01[ooo]Z3?l0001FoookJPGo0000OOoonfX4o`0001_ooo]Z2ol0001goookJP00WOoonfX4o`0001_o
oo]Z3?l0001EoookJPGo0000OOoonfX4o`0001_ooo]Z2ol0001goookJP00WOoonfX4o`0001cooo]Z
2ol0001EoookJPGo0000OOoonfX4o`0001cooo]Z2ol0001foookJP00WOoonfX4o`0001cooo]Z3?l0
001DoookJPGo0000OOoonfX4o`0001gooo]Z2_l0001foookJP00WOoonfX4o`0002?ooo]Z1Ol0001D
oookJPGo0000OOoonfX4o`0002;ooo]Z1_l0001eoookJP00WOoonfX4o`0002?ooo]Z1Ol0001Doook
JPGo0000OOoonfX4o`0002?ooo]Z1Ol0001eoookJP00WOoonfX4o`0002Cooo]Z1Ol0001CoookJPGo
0000OOoonfX4o`0002?ooo]Z1_l0001doookJP00WOoonfX4o`0002Cooo]Z1Ol0001CoookJPGo0000
OOoonfX4o`0002Cooo]Z1_l0001coookJP00WOoonfX4o`0002Cooo]Z1_l0001BoookJPGo0000OOoo
nfX4o`0002Cooo]Z1_l0001coookJP00WOoonfX4o`0002Gooo]Z2ol0001<oookJPGo0000OOoonfX4
o`0002Gooo]Z3?l0001/oookJP00WOoonfX4o`0002Gooo]Z3?l0001;oookJPGo0000OOoonfX4o`00
02Kooo]Z2ol0001/oookJP008_oonfX3o`00OgGooo]Z0ol007l4o`0000;ooo]Z0ol007l3oookJPGo
001o6OoonfX<o`0004[ooo]Z1Ol0001doookJPGo001o1?oonfX4o`0000;ooo]Z1Ol007lOoookJP_o
0000C?oonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX4o`00O`Co00000_oonfX3o`00O`;ooo]Z
1ol007lHoookJPco0000B_oonfX5o`0007?ooo]Z1ol007l3oookJPCo000000?ooo]Zo`00Ool007l0
1Ol007lNoookJPco0000BooonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`03oookJ_l0
003o000000;o00000_oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
6_oonfX;o`0004Wooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`0000Co
001o00Cooo]Zo`00Ool007oo001o8?oonfX;o`0004[ooo]Z0ol007lMoookJP004ooonfX:o`00O`Go
oo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1?l00006oookJP?o001o0ooonfX3o`00Oaoo
oo]Z1Ol00019oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00000ol007l3oookJP?o
001o9?oonfX7o`0004Wooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o
0_oonfX3o`00O`;ooo]Z1?l0000<oookJP?o001o7ooonfX6o`0004Sooo]Z1Ol0001boookJP?o001o
0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o9OoonfX6o`0004Wooo]Z0ol007lMoookJP008_oo
nfX3o`00Og?ooo]Z0ol007l2oookJPCo00003?oonfX3o`00Ob3ooo]Z1_l000000ooonf[o0000o`00
0002o`0004;ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o9_oo
nfX6o`000003oookJ_l0003o000000?o0000@_oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3
o`00O`;ooo]Z1?l00007oookJP;o001o0_oonfX4o`00Ob3ooo]Z3Ol00010oookJPGo0000L_oonfX3
o`00O`?ooo]Z0ol007l00ooonf[o0000o`000003o`000003oookJ_l007oo001o00;ooo]Z1?l007lW
oookJPco0000@OoonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`;ooo]Z1?l00007oook
JPOo001o8_oonfX=o`0003oooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o0000
00?o000000?ooo]Zo`00Ool007l01Ol007lXoookJPgo0000@?oonfX3o`00Oagooo]Z000RoookJP?o
001oLooonfX3o`00O`;ooo]Z1?l00007oookJPKo001o9?oonfX<o`0003oooo]Z1Ol0001boookJP?o
001o0ooonfX3o`00O`03oookJ_l0003o000000?o000000?ooo]Zo`00Ool007l01?l007lZoookJPco
0000@?oonfX3o`00Oagooo]Z000OoookJPKo001oLooonfX3o`00O`;ooo]Z1?l00007oookJP;o001o
:?oonfX=o`0003kooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o0000
0_oonfX2o`00Obkooo]Z3Ol0000loookJPKo001o7OoonfX001oooo]Z1_l007mdoookJP?o001o00?o
oo]Zo`000?l000000_l00007oookJP;o001o<?oonfX6o`0003gooo]Z1Ol0001coookJP?o001o00Co
oo]Zo`00Ool007oo001o0_oonfX4o`0000;ooo]Z0_l007lfoookJPKo0000>ooonfX6o`00Oagooo]Z
000QoookJPCo001oM?oonfX3o`00O`Go00002?oonfX7o`00Ob[ooo]Z3_l0000eoookJPGo0000Looo
nfX7o`00O`;ooo]Z1?l00003oookJPOo001o<?oonfX>o`0003Gooo]Z1?l007lMoookJP008_oonfX3
o`00OgGooo]Z0_l007l5o`0000Sooo]Z1ol007l[oookJPko0000=?oonfX5o`0007Cooo]Z1Ol007l3
oookJPCo00000ooonfX7o`00Oc7ooo]Z3_l0000eoookJP?o001o7OoonfX009cooo]Z1Ol0000koook
JPgo0000=?oonfX5o`0007cooo]Z1?l0000loookJPko0000E?oonfX009cooo]Z1?l0000moookJPgo
0000<ooonfX5o`0007cooo]Z1?l0000moookJPgo0000E?oonfX009cooo]Z1?l0000noookJPKo0000
00?ooo]Zo`000?l000003?l0000ZoookJPGo0000O?oonfX4o`0003kooo]Z1_l000000ooonf[o0000
o`00000<o`0004_ooo]Z002LoookJPCo0000AOoonfX?o`0002Wooo]Z1Ol0001loookJPCo0000A_oo
nfX?o`0004Wooo]Z002LoookJPCo0000A_oonfX?o`0000?ooo]Z1_l0000OoookJPGo0000O?oonfX4
o`0004Kooo]Z4?l000000ooonf[o0000o`000005o`00043ooo]Z002LoookJPCo0000AooonfXHo`00
00Cooo]Z1_l0000DoookJPGo0000O?oonfX4o`0004Oooo]Z6?l00004oookJPKo0000=OoonfX000ko
oo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0
003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`00
02Go00003ooonfX001cooo]Z1ol00004oookJPOo00000ooonfX9o`000003oookJ_l0003o000000oo
000000?ooo]Zo`000?l000001Ol00018oookJPCo0000JOoonfX6o`0000Cooo]Z1ol00003oookJPSo
00001?oonfX7o`0000Cooo]Z6_l000000ooonf[o0000o`000005o`0004Sooo]Z1?l0001YoookJPKo
00001?oonfX8o`0000Cooo]Z00?o0000oookJ_oonfX07?oonfX003?ooo]Z1_l00004oookJQOo0000
B?oonfX4o`0007gooo]Z1Ol0000CoookJPKo00001?oonfXGo`0004Sooo]Z1?l0002NoookJP00?Ooo
nfX8o`0000;ooo]Z3_l00017oookJPCo0000OOoonfX5o`0001kooo]Z1ol000000ooonf[o0000o`00
000>o`0004Kooo]Z1?l0002NoookJP00AooonfX?o`0004Kooo]Z1?l0001moookJPGo0000:?oonfX?
o`0004Gooo]Z1?l0002NoookJP00BOoonfX>o`000003oookJ_l0003o000000Co0000?_oonfX4o`00
07gooo]Z1Ol0000YoookJQKo0000?OoonfX4o`0009kooo]Z001AoookJPko0000?OoonfX4o`0007go
oo]Z1Ol0000aoookJPko0000?OoonfX4o`0009kooo]Z001BoookJPko0000??oonfX4o`0007gooo]Z
1Ol0000coookJPgo0000??oonfX4o`0009kooo]Z001CoookJPko0000>ooonfX4o`0007gooo]Z1Ol0
000coookJPko0000>ooonfX4o`0009kooo]Z001DoookJPko0000>_oonfX4o`0007gooo]Z1Ol0000d
oookJPko0000>_oonfX4o`0009kooo]Z001LoookJPKo0000>_oonfX4o`0007gooo]Z1Ol0000loook
JPKo0000>_oonfX4o`0009kooo]Z001MoookJPco0000<ooonfX4o`0007gooo]Z1Ol0000moookJPco
0000<ooonfX4o`0009kooo]Z001NoookJPco0000<_oonfX4o`0007gooo]Z1Ol0000noookJPco0000
<_oonfX4o`0009kooo]Z001NoookJPgo0000<OoonfX4o`0007gooo]Z1Ol0000noookJPco0000<_oo
nfX4o`0009kooo]Z001OoookJPco0000<OoonfX4o`0007gooo]Z1Ol0000ooookJPco0000<?oonfX5
o`0009kooo]Z001PoookJPGo000000?ooo]Zo`000?l000001?l0000_oookJPGo0000OOoonfX5o`00
043ooo]Z1Ol000000ooonf[o0000o`000004o`0002oooo]Z1Ol0002NoookJP00IooonfX5o`0002oo
oo]Z1Ol0001moookJPGo0000A_oonfX6o`0002oooo]Z1Ol0002NoookJP00IooonfX6o`0002kooo]Z
1Ol0001moookJPGo0000AooonfX6o`0002kooo]Z1?l0002OoookJP00J?oonfX;o`0002Sooo]Z1?l0
001noookJPGo0000B?oonfX;o`0002Sooo]Z1?l0002OoookJP00J?oonfX<o`0002Oooo]Z1?l0001n
oookJPGo0000B?oonfX=o`0002Kooo]Z1?l0002OoookJP00JOoonfX<o`0002Kooo]Z1?l0001noook
JPGo0000BOoonfX<o`0002Kooo]Z1?l0002OoookJP00J_oonfX;o`0002Kooo]Z1?l0001noookJPGo
0000B_oonfX<o`0002Gooo]Z1?l0002OoookJP00J_oonfX<o`0002Gooo]Z1?l0001noookJPGo0000
BooonfX;o`0002Gooo]Z1?l0002OoookJP00LOoonfX5o`0002Gooo]Z1?l0001noookJPGo0000DOoo
nfX6o`0002Cooo]Z1?l0002OoookJP00LOoonfX6o`0002Cooo]Z1?l0001noookJPGo0000D_oonfX5
o`0002Cooo]Z1?l0002OoookJP00L_oonfX6o`0002?ooo]Z1?l0001noookJPGo0000D_oonfX5o`00
02Cooo]Z1?l0002OoookJP00L_oonfX6o`0002?ooo]Z1?l0001noookJPGo0000DooonfX5o`0002?o
oo]Z1?l0002OoookJP00LooonfX5o`0002?ooo]Z1?l0001noookJPGo0000DooonfX6o`0002;ooo]Z
1?l0002OoookJP00M?oonfX:o`0001gooo]Z1?l0001noookJPGo0000DooonfX<o`0001cooo]Z1?l0
002OoookJP00M?oonfX;o`0001cooo]Z1?l0001noookJPGo0000E?oonfX;o`0001cooo]Z1?l0002O
oookJP00M?oonfX;o`0001cooo]Z1?l0001noookJPGo0000EOoonfX;o`0001_ooo]Z1?l0002Ooook
JP00MOoonfX;o`0001_ooo]Z1?l0001noookJPGo0000EOoonfX;o`0001_ooo]Z1?l0002OoookJP00
M_oonfX:o`0001_ooo]Z1?l0001noookJPGo0000E_oonfX:o`0001_ooo]Z1?l0002OoookJP00Nooo
nfX6o`0001[ooo]Z1?l0001noookJPGo0000G?oonfX5o`0001Wooo]Z1Ol0002OoookJP00O?oonfX5
o`0001[ooo]Z1?l0001noookJPGo0000G?oonfX5o`0001Wooo]Z1Ol0002OoookJP00O?oonfX5o`00
01[ooo]Z1?l0001noookJPGo0000G?oonfX5o`0001Wooo]Z1Ol0002OoookJP00OOoonfX5o`0001Wo
oo]Z1?l0001PoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000GOoonfX5o`0001So
oo]Z1?l0002PoookJP00OOoonfX6o`0001Sooo]Z1?l0001OoookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007l9oookJPGo0000GOoonfX5o`0001Sooo]Z1?l0002PoookJP00OOoonfX6o`0001Sooo]Z1?l0
001OoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005gooo]Z1_l0000GoookJPCo0000X?oonfX007kooo]Z
1Ol0000HoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z
1Ol0001NoookJPGo00005ooonfX4o`000:3ooo]Z001ooookJP[o00004_oonfX4o`0005kooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001MoookJPKo000000?ooo]Zo`000?l000000_l0
000AoookJPCo0000X?oonfX007oooo]Z2ol0000AoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o2?oonfX5o`0005oooo]Z2ol0000@oookJPCo0000X?oonfX007oooo]Z3?l0000?oook
JPGo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001Ooook
JPco00003ooonfX4o`000:3ooo]Z0020oookJP_o00003ooonfX5o`0005kooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`Wooo]Z1Ol0001PoookJP_o00003ooonfX4o`000:3ooo]Z0020oookJP_o0000
3ooonfX5o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001PoookJP_o0000
3ooonfX4o`000:3ooo]Z0021oookJPGo000000?ooo]Zo`000?l000000_l0000?oookJPCo0000Gooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`00067ooo]Z2ol0000>oookJPCo0000X?oo
nfX008Oooo]Z1Ol0000>oookJPCo0000H?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l0
07l>oookJPGo0000IooonfX5o`0000kooo]Z1?l0002PoookJP00QooonfX5o`0000kooo]Z1?l0001P
oookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001WoookJPGo00003_oonfX4o`000:3ooo]Z0027oook
JPGo00003_oonfX4o`00067ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0006Sooo]Z1Ol0000=oook
JPCo0000X?oonfX008Sooo]Z1Ol0000=oookJPCo0000OooonfX5o`0006Sooo]Z1Ol0000=oookJPCo
0000X?oonfX008Sooo]Z1Ol0000=oookJPCo0000OooonfX5o`0006Sooo]Z1Ol0000=oookJPCo0000
X?oonfX008Sooo]Z1Ol0000=oookJPCo0000OooonfX5o`0006Wooo]Z1Ol0000<oookJPCo0000X?oo
nfX008Wooo]Z1Ol0000<oookJPCo0000OooonfX5o`0006Wooo]Z1Ol0000<oookJPCo0000X?oonfX0
08Wooo]Z1Ol00002oookJPGo00001OoonfX4o`0007oooo]Z1Ol0001YoookJPGo00000_oonfX5o`00
00Gooo]Z1?l0002PoookJP00ROoonfX5o`000003oookJ_l0003o000000Co00001OoonfX4o`0007oo
oo]Z1Ol0001ZoookJPCo000000?ooo]Zo`000?l000001?l00005oookJPCo0000X?oonfX008[ooo]Z
1?l000000ooonf[o0000o`000005o`0000Cooo]Z1?l0001ooookJPGo0000J_oonfX<o`0000Cooo]Z
1?l0002PoookJP00R_oonfX<o`0000Cooo]Z1?l0001ooookJPGo0000J_oonfX<o`0000Cooo]Z1?l0
002PoookJP00R_oonfX<o`0000Cooo]Z1?l0001ooookJPGo0000J_oonfX<o`0000Cooo]Z1?l0002P
oookJP00R_oonfX<o`0000Cooo]Z1?l0001ooookJPGo0000JooonfX;o`0000Cooo]Z1?l0002Poook
JP00RooonfX;o`0000Cooo]Z1?l0001ooookJPGo0000JooonfX<o`0000?ooo]Z1?l0002PoookJP00
RooonfX<o`0000?ooo]Z1?l0001ooookJPGo0000JooonfX<o`0000?ooo]Z1?l0002PoookJP00Rooo
nfX6o`000003oookJ_l0003o000000?o00000_oonfX5o`0007oooo]Z1Ol0001[oookJPKo000000?o
oo]Zo`000?l000000ol00003oookJPCo0000X?oonfX008cooo]Z1Ol000000ooonf[o0000o`000003
o`0000;ooo]Z1Ol0001ooookJPGo0000K?oonfX5o`0000;ooo]Z1?l00003oookJPCo0000X?oonfX0
09?ooo]Z1?l00002oookJPGo0000OooonfX5o`0007?ooo]Z1?l00003oookJPCo0000X?oonfX009?o
oo]Z1?l00002oookJPCo0000P?oonfX5o`0007?ooo]Z1?l00003oookJPCo0000X?oonfX009?ooo]Z
1?l00002oookJPCo0000P?oonfX5o`0007?ooo]Z1?l00002oookJPGo0000X?oonfX009?ooo]Z1?l0
0002oookJPCo0000P?oonfX5o`0007?ooo]Z1?l00002oookJPGo0000X?oonfX009?ooo]Z1?l00002
oookJPCo0000P?oonfX5o`0007?ooo]Z1?l00002oookJPGo0000X?oonfX009?ooo]Z1Ol000000ooo
nf[o0000o`000002o`00083ooo]Z1Ol0001coookJPCo00000_oonfX4o`000:7ooo]Z002CoookJPGo
000000?ooo]Zo`000?l000000_l00020oookJPGo0000LooonfX5o`000003oookJ_l0003o000000;o
0000XOoonfX009?ooo]Z1Ol000000ooonf[o0000o`000002o`00083ooo]Z1Ol0001coookJPGo0000
00?ooo]Zo`000?l000000_l0002QoookJP00U?oonfX4o`000003oookJ_l0003o000000;o0000P?oo
nfX5o`0007?ooo]Z1Ol000000ooonf[o0000o`000002o`000:7ooo]Z002DoookJPWo0000P?oonfX5
o`0007Cooo]Z1?l000000ooonf[o0000o`000002o`000:7ooo]Z002DoookJPWo0000P?oonfX5o`00
07Cooo]Z1?l000000ooonf[o0000o`000002o`000:7ooo]Z002DoookJPWo0000P?oonfX5o`0007Co
oo]Z1?l000000ooonf[o0000o`000002o`000:7ooo]Z002DoookJPSo0000POoonfX5o`0007Cooo]Z
2Ol0002QoookJP00U?oonfX8o`00087ooo]Z1Ol0001doookJPWo0000XOoonfX009Cooo]Z2?l00021
oookJPGo0000M?oonfX9o`000:7ooo]Z002DoookJPSo0000M?oonfX3o`00O`[ooo]Z1Ol0001eoook
JPSo0000XOoonfX009Gooo]Z1ol0001doookJP?o001o2_oonfX5o`0007Gooo]Z1ol0002RoookJP00
UOoonfX7o`0007Cooo]Z0ol007l:oookJPGo0000MOoonfX7o`000:;ooo]Z002EoookJPOo0000M?oo
nfX3o`00O`[ooo]Z1Ol0001eoookJPOo0000X_oonfX009Gooo]Z1ol0001doookJP?o001o2_oonfX6
o`0007Cooo]Z1ol0002RoookJP00UOoonfX7o`0007Cooo]Z0ol007l:oookJPGo0000MOoonfX7o`00
0:;ooo]Z002FoookJPKo0000M?oonfX3o`00O`[ooo]Z1Ol0001foookJPKo0000X_oonfX009Kooo]Z
1_l0001doookJP?o001o2_oonfX5o`0007Kooo]Z1_l0002RoookJP00U_oonfX6o`0007Cooo]Z0ol0
07l:oookJPGo0000M_oonfX6o`000:;ooo]Z002FoookJPKo0000LOoonfX6o`00O`[ooo]Z1Ol0001f
oookJPKo0000X_oonfX009Kooo]Z1Ol0001boookJPKo001o2_oonfX5o`0007Kooo]Z1_l0002Roook
JP00UooonfX4o`0007Cooo]Z1?l007l:oookJPGo0000MooonfX4o`000:?ooo]Z003ooookJQ7ooo]Z
0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z
1Ol007l:oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol0
07l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo
001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3
o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00
O`kooo]Z0ol007l8oookJPKo0000oooonfXNoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`So
oo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z
1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00o_oonfX6o`00
O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo
0000oooonfXOoookJP00oooonfX1oookJPCo001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z
003ooookJP;ooo]Z0ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z
003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPCo001o3OoonfX5
o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoo
oo]Z1Ol007l:oookJPKo0000oooonfXNoookJP00oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oo
oookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o
001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z
003ooookJPkooo]Z1ol007oooookJRgooo]Z003ooookJPoooo]Z1Ol007oooookJRkooo]Z003ooook
J_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30827 L
.02605 .30769 L
.02729 .30721 L
.02846 .30702 L
.02954 .30709 L
.03053 .30737 L
.03163 .30787 L
.03279 .30855 L
.03504 .30998 L
.03631 .31061 L
.03746 .31097 L
.03812 .31106 L
.03883 .31105 L
.04012 .31077 L
.04142 .3102 L
.04262 .3095 L
.04386 .3087 L
.04521 .30792 L
.04648 .30739 L
.04765 .30716 L
.04871 .3072 L
.04987 .30751 L
.05108 .30809 L
.05221 .3088 L
.05343 .30963 L
.05475 .31048 L
.056 .31111 L
.05715 .31145 L
.05779 .31152 L
.05849 .3115 L
.05923 .31137 L
.05992 .31116 L
.06114 .31059 L
.06244 .30983 L
.06373 .30905 L
.06443 .30866 L
.06509 .30835 L
.06639 .30795 L
.06756 .30788 L
.06824 .30798 L
.06896 .30819 L
.07024 .30882 L
.07163 .30976 L
.07315 .31092 L
.07459 .31191 L
.0753 .3123 L
.07596 .31259 L
.07671 .31281 L
.07754 .31292 L
Mistroke
.07823 .31289 L
.07898 .31275 L
.07968 .31252 L
.08045 .31219 L
.08184 .31143 L
.08318 .31067 L
.08443 .31008 L
.0856 .30974 L
.08686 .3097 L
.08758 .30984 L
.08826 .31008 L
.08954 .31079 L
.09234 .31308 L
.09357 .31411 L
.09423 .31459 L
.09493 .31504 L
.09609 .31556 L
.09717 .31577 L
.09842 .31569 L
.09955 .31535 L
.10073 .31481 L
.102 .31413 L
.10266 .3138 L
.10335 .31349 L
.10458 .3131 L
.10579 .31303 L
.10648 .31314 L
.10713 .31336 L
.10782 .3137 L
.10846 .31411 L
.10988 .31531 L
.11228 .31774 L
.11354 .31893 L
.11423 .31948 L
.11488 .31991 L
.11606 .32045 L
.11737 .32064 L
.11848 .3205 L
.11968 .32009 L
.12082 .31957 L
.12204 .319 L
.12318 .31858 L
.12423 .31839 L
.12554 .31852 L
.12677 .31906 L
.12746 .31955 L
.1281 .3201 L
.12955 .32164 L
.13222 .32489 L
.13364 .32638 L
Mistroke
.13443 .32704 L
.13516 .3275 L
.13645 .32797 L
.13768 .32801 L
.1388 .32776 L
.14003 .32729 L
.14133 .32674 L
.14204 .32648 L
.14271 .32631 L
.14401 .32626 L
.14519 .32661 L
.14636 .32738 L
.1476 .32863 L
.14985 .33172 L
.1523 .3353 L
.15297 .33614 L
.15369 .33691 L
.15497 .33793 L
.15628 .33846 L
.15704 .33852 L
.15774 .33846 L
.159 .3381 L
.16037 .33756 L
.16162 .33715 L
.16293 .33704 L
.16406 .33733 L
.16529 .33814 L
.18376 .35182 L
.20503 .3724 L
.22434 .39423 L
.22903 .41203 L
.23017 .41664 L
.23139 .42073 L
.2321 .42251 L
.23274 .42369 L
.23399 .42473 L
.23468 .42457 L
.23533 .42398 L
.23603 .42292 L
.23678 .4214 L
.23815 .41808 L
.23943 .41507 L
.2407 .41313 L
.24141 .4128 L
.24206 .41312 L
.24322 .41536 L
.24444 .42023 L
.24563 .42731 L
.24671 .43539 L
.24913 .45588 L
Mistroke
.2502 .46402 L
.25137 .47055 L
.25248 .4734 L
.25349 .47236 L
.25468 .46593 L
.25578 .45438 L
.257 .43547 L
.25831 .40832 L
.26341 .26467 L
.26594 .19984 L
.26667 .18511 L
.26736 .17321 L
.26865 .15652 L
.26986 .14745 L
.27098 .14456 L
.27221 .1466 L
.27351 .15337 L
.27626 .17561 L
.27777 .18783 L
.27852 .19297 L
.27921 .197 L
.27984 .20001 L
.28054 .20254 L
.28125 .20423 L
.28199 .20512 L
.2833 .20471 L
.28453 .20264 L
.28678 .1972 L
.28791 .19489 L
.28914 .19346 L
.28979 .1933 L
.29048 .19364 L
.29173 .19557 L
.29298 .19904 L
.29411 .20323 L
.2967 .2143 L
.29807 .2196 L
.29882 .22203 L
.29952 .22392 L
.30078 .22632 L
.30145 .22705 L
.30217 .22743 L
.30345 .22725 L
.30462 .22641 L
.3058 .22527 L
.30708 .22417 L
.30829 .22364 L
.3094 .22384 L
.3107 .22506 L
.31135 .22609 L
Mistroke
.31207 .22751 L
.31449 .234 L
.31677 .24082 L
.31803 .24405 L
.31922 .24643 L
.32033 .24793 L
.32153 .24879 L
.32263 .24895 L
.32364 .24869 L
.32476 .24814 L
.32594 .24751 L
.32723 .24707 L
.32842 .24714 L
.32972 .24791 L
.33046 .24869 L
.33114 .24964 L
.33369 .25468 L
.33635 .26076 L
.33766 .26328 L
.33886 .26506 L
.33953 .26579 L
.34025 .26634 L
.34096 .26669 L
.34175 .26683 L
.3424 .2668 L
.3431 .26664 L
.34437 .26617 L
.34569 .26565 L
.34692 .2654 L
.34821 .26557 L
.3489 .2659 L
.34964 .26645 L
.35088 .26782 L
.35219 .26977 L
.35452 .274 L
.35583 .27634 L
.35707 .27824 L
.35776 .27911 L
.3585 .27987 L
.3598 .28073 L
.36055 .28096 L
.36135 .281 L
.36204 .28091 L
.36279 .28071 L
.36422 .28016 L
.36492 .27989 L
.36558 .27969 L
.36683 .27951 L
.36749 .27957 L
.36819 .27977 L
Mistroke
.36944 .28052 L
.37058 .2816 L
.37191 .28328 L
.37335 .28539 L
.37459 .28726 L
.37596 .2891 L
.37723 .29047 L
.37842 .29132 L
.37968 .29176 L
.38038 .2918 L
.38103 .29173 L
.38217 .29141 L
.38342 .2909 L
.38452 .29044 L
.38569 .29009 L
.3869 .29 L
.38802 .29024 L
.38922 .29088 L
.39054 .292 L
.39292 .29477 L
.39509 .29732 L
.39573 .29796 L
.39643 .29855 L
.39769 .29931 L
.39839 .29955 L
.39913 .29965 L
.39977 .29963 L
.40047 .2995 L
.40171 .29906 L
.40305 .29844 L
.40422 .2979 L
.40547 .29751 L
.4062 .2974 L
.40687 .29741 L
.40816 .29774 L
.40889 .2981 L
.40968 .29863 L
.4111 .29987 L
.4137 .30251 L
.41512 .30375 L
.41582 .30423 L
.41645 .30457 L
.41765 .30496 L
.41894 .30498 L
.41961 .30484 L
.42035 .30459 L
.42167 .30397 L
.42296 .30329 L
.42418 .30272 L
.42528 .30237 L
Mistroke
.42648 .30225 L
.42769 .30247 L
.42882 .30296 L
.43004 .30377 L
.43134 .30484 L
.43353 .30671 L
.43477 .30756 L
.4359 .3081 L
.43655 .30828 L
.43727 .30836 L
.43801 .30832 L
.43871 .30818 L
.43998 .3077 L
.44135 .30696 L
.44268 .3062 L
.44394 .30559 L
.44507 .30523 L
.4463 .30512 L
.44759 .30535 L
.44881 .30589 L
.44951 .30631 L
.45015 .30674 L
.45159 .30783 L
.45301 .30886 L
.45433 .30962 L
.45499 .30989 L
.4557 .31008 L
.45649 .31016 L
.45721 .31011 L
.45851 .30977 L
.4597 .3092 L
.46099 .30844 L
.46241 .30759 L
.46364 .30698 L
.46479 .30661 L
.46601 .30651 L
.46732 .30675 L
.46801 .30701 L
.46865 .30732 L
.46986 .30806 L
.47127 .30902 L
.47257 .30985 L
.47371 .31043 L
.47491 .3108 L
.47611 .31087 L
.4768 .31078 L
.47744 .31061 L
.4804 .30904 L
.48186 .30813 L
.4825 .30777 L
Mistroke
.48321 .30744 L
.48443 .30706 L
.48573 .30698 L
.48641 .30708 L
.48715 .30728 L
.48784 .30757 L
.48847 .30789 L
.49092 .30942 L
.49212 .31013 L
.4932 .31064 L
.49435 .31096 L
.49558 .311 L
.49622 .3109 L
.49692 .3107 L
.49818 .31013 L
.5008 .3085 L
.5015 .30808 L
.50224 .30769 L
.50293 .30739 L
.50359 .30718 L
.50483 .30701 L
.50596 .30714 L
.50721 .30757 L
.50792 .30792 L
.50857 .3083 L
.51105 .30988 L
.5123 .31053 L
.51301 .3108 L
.51367 .31097 L
.5144 .31106 L
.51506 .31105 L
.51582 .31092 L
.51654 .31069 L
.51781 .31009 L
.51918 .30926 L
.52048 .30844 L
.5217 .30778 L
.52297 .30731 L
.52364 .30718 L
.52437 .30715 L
.52565 .30737 L
.52687 .30787 L
.52796 .30851 L
.52915 .30931 L
.53042 .31016 L
.53161 .31084 L
.53267 .31128 L
.53383 .31151 L
.53509 .31144 L
.53573 .31129 L
Mistroke
.53642 .31103 L
.53766 .31041 L
.53881 .30972 L
.53988 .30907 L
.54103 .30846 L
.54213 .30806 L
.54314 .30788 L
.54432 .30796 L
.54557 .30837 L
.54662 .30894 L
.54778 .30973 L
.54901 .31066 L
.55033 .31162 L
.55157 .31234 L
.55269 .31276 L
.55397 .31292 L
.55517 .31275 L
.55646 .31227 L
.5572 .3119 L
.55787 .31152 L
.55899 .31088 L
.56019 .31026 L
.56133 .30984 L
.56236 .30968 L
.56353 .30977 L
.56463 .31016 L
.56582 .31085 L
.56712 .31186 L
.56842 .31299 L
.56982 .31416 L
.57047 .31463 L
.57115 .31505 L
.57236 .31558 L
.57309 .31574 L
.57376 .31578 L
.5745 .31571 L
.57529 .31551 L
.57601 .31524 L
.57668 .31493 L
.57794 .31426 L
.57916 .31365 L
.58044 .31318 L
.58154 .31302 L
.58275 .31316 L
.58405 .31372 L
.58478 .31421 L
.58545 .31475 L
.58798 .31724 L
.58915 .31841 L
.59042 .31948 L
Mistroke
.59163 .3202 L
.59273 .32057 L
.59402 .32061 L
.59468 .3205 L
.59539 .32028 L
.59664 .31975 L
.5978 .31919 L
.59899 .3187 L
.60011 .31842 L
.60111 .3184 L
.60221 .31868 L
.6034 .31935 L
.60466 .32046 L
.60694 .32309 L
.60938 .32594 L
.61005 .32658 L
.61075 .32713 L
.61201 .3278 L
.61319 .32804 L
.61429 .32795 L
.61549 .32759 L
.61678 .32705 L
.61746 .32676 L
.61818 .3265 L
.61897 .3263 L
.6197 .32623 L
.62102 .32646 L
.62177 .32682 L
.62247 .32731 L
.62377 .32861 L
.62497 .33015 L
.62765 .33413 L
.62894 .33587 L
.63015 .33717 L
.63124 .33798 L
.63242 .33845 L
.63371 .33849 L
.63436 .33837 L
.63507 .33815 L
.63634 .33765 L
.6375 .33724 L
.63868 .33703 L
.63979 .33716 L
.64096 .33773 L
.64223 .33891 L
.64334 .34038 L
.64453 .34231 L
.64665 .3462 L
.64784 .3483 L
.64909 .35018 L
Mistroke
.64975 .35098 L
.65047 .35168 L
.65173 .35244 L
.65293 .35264 L
.6542 .35242 L
.65541 .35196 L
.6565 .35152 L
.65718 .35131 L
.6579 .3512 L
.65919 .3514 L
.6599 .35179 L
.66057 .35234 L
.66131 .35318 L
.66209 .35434 L
.66485 .35997 L
.66737 .36569 L
.66867 .36809 L
.66989 .36974 L
.67098 .37064 L
.67216 .371 L
.67345 .37078 L
.6741 .3705 L
.67481 .37013 L
.67609 .36946 L
.67725 .3691 L
.67843 .36923 L
.67954 .36997 L
.68072 .3715 L
.68199 .37403 L
.68429 .38031 L
.68641 .38666 L
.6876 .38977 L
.68888 .39234 L
.69009 .39385 L
.6912 .39439 L
.69249 .39412 L
.69322 .39364 L
.6939 .39304 L
.69514 .39185 L
.69579 .39128 L
.69647 .39082 L
.6972 .39057 L
.69787 .39061 L
.69918 .39166 L
.70035 .3938 L
.70164 .39744 L
.70428 .40794 L
.70567 .41391 L
.70715 .41941 L
.70844 .42283 L
Mistroke
.70918 .42404 L
.70987 .42463 L
.71108 .42442 L
.71238 .42262 L
.71365 .41981 L
.71497 .41651 L
.71611 .41416 L
.71735 .41284 L
.71857 .4135 L
.71967 .41619 L
.72095 .42193 L
.72216 .42974 L
.7243 .44723 L
.72543 .45678 L
.72665 .46567 L
.72796 .47199 L
.72918 .47336 L
.7299 .47162 L
.73058 .46801 L
.73186 .45576 L
.73306 .4378 L
.73417 .41577 L
.73668 .35084 L
.73922 .27562 L
.74191 .20486 L
.74331 .17714 L
.74411 .16508 L
.74485 .15637 L
.74616 .14696 L
.74689 .14482 L
.74756 .14466 L
.74821 .14598 L
.74891 .14879 L
.75016 .15662 L
.753 .18021 L
.75417 .18935 L
.75544 .19722 L
.75617 .20057 L
.75684 .20284 L
.75814 .20509 L
.75935 .20487 L
.76046 .20318 L
.76169 .20037 L
.763 .19713 L
.76366 .1957 L
.76438 .19445 L
.76568 .19332 L
.76694 .19391 L
.76811 .19599 L
.78672 .22484 L
Mistroke
.80551 .24759 L
.82616 .26676 L
.84563 .28052 L
.86654 .29182 L
.86907 .29471 L
.87145 .2975 L
.87265 .29857 L
.87394 .29934 L
.87463 .29956 L
.87537 .29965 L
.87668 .29949 L
.87737 .29928 L
.8781 .29898 L
.87942 .29835 L
.88023 .29798 L
.88099 .29769 L
.88168 .2975 L
.88242 .2974 L
.88306 .29741 L
.88376 .29754 L
.8845 .2978 L
.88519 .29816 L
.88641 .29907 L
.88774 .30031 L
.89031 .3029 L
.89102 .30352 L
.89177 .30408 L
.89248 .3045 L
.89312 .30477 L
.89439 .30502 L
.8951 .30498 L
.89576 .30485 L
.89696 .30441 L
.89824 .30377 L
.89938 .30317 L
.90061 .30262 L
.90176 .30231 L
.90282 .30226 L
.90406 .30253 L
.90475 .30283 L
.9054 .30319 L
.90785 .30511 L
.9101 .30699 L
.91124 .30772 L
.91248 .30821 L
.91313 .30834 L
.91383 .30836 L
.91509 .30813 L
.91634 .30762 L
.91748 .307 L
Mistroke
.91856 .30637 L
.91971 .30577 L
.92096 .3053 L
.92212 .30511 L
.9232 .3052 L
.92421 .30551 L
.92532 .30607 L
.92651 .30687 L
.92916 .30883 L
.92988 .30928 L
.93065 .30968 L
.93138 .30995 L
.93204 .3101 L
.93334 .31012 L
.93407 .30998 L
.93474 .30975 L
.93597 .30916 L
.93728 .30838 L
.93845 .30767 L
.93971 .30703 L
.94089 .30663 L
.94197 .30651 L
.94324 .30667 L
.94395 .30691 L
.94462 .30721 L
.94712 .30878 L
.94879 .30987 L
.94963 .31031 L
.95055 .31067 L
.95156 .31086 L
.95249 .31086 L
.95334 .31069 L
.95425 .31036 L
.95747 .30849 L
.95834 .30797 L
.95916 .30755 L
.96001 .30722 L
.96095 .30701 L
.96198 .30698 L
.96309 .3072 L
.96412 .30761 L
.96506 .30811 L
.96692 .30929 L
.9679 .3099 L
.96894 .31045 L
.96986 .3108 L
.97087 .311 L
.97179 .311 L
.97266 .31084 L
.97355 .31053 L
Mistroke
.97436 .31014 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00XOoonfX4o`0007Sooo]Z1Ol00021oookJPCo0000VOoonfX00:3o
oo]Z1_l0001goookJPGo0000P?oonfX6o`0009Sooo]Z002PoookJPKo0000J_oonfX3o`00O`[ooo]Z
1Ol00020oookJPKo0000V?oonfX00:3ooo]Z1_l0001ZoookJP?o001o2_oonfX5o`00083ooo]Z1_l0
002HoookJP00X?oonfX6o`0006[ooo]Z0ol007l:oookJPGo0000P?oonfX6o`0009Sooo]Z002Poook
JPKo0000F_oonfX:o`00O`Kooo]Z0ol007l:oookJPGo0000P?oonfX7o`0009Oooo]Z002PoookJPKo
0000F_oonfX:o`00O`Kooo]Z0ol007l:oookJPKo0000OooonfX7o`0009Oooo]Z002PoookJPKo0000
J_oonfX3o`00O`[ooo]Z1Ol00020oookJPOo0000UooonfX00:3ooo]Z1_l0001ZoookJP?o001o2_oo
nfX5o`00083ooo]Z1ol0002GoookJP00X?oonfX7o`0006Wooo]Z0ol007l:oookJPGo0000OooonfX8
o`0009Oooo]Z002PoookJPOo0000JOoonfX3o`00O`[ooo]Z1Ol0001ooookJPSo0000UooonfX009oo
oo]Z2?l0001VoookJPKo001o2_oonfX5o`0007oooo]Z2?l0002GoookJP00WooonfX8o`0006Kooo]Z
1_l007l:oookJPGo0000OooonfX8o`0009Oooo]Z002OoookJPSo0000J?oonfX4o`00O`[ooo]Z1Ol0
001ooookJPWo0000U_oonfX009oooo]Z2?l0001YoookJP?o001o2_oonfX5o`0007oooo]Z2Ol0002F
oookJP00WooonfX9o`0007Gooo]Z1Ol0001ooookJPWo0000U_oonfX009oooo]Z2Ol0001eoookJPGo
0000OooonfX4o`000003oookJ_l0003o000000;o0000U_oonfX009oooo]Z2Ol0001eoookJPGo0000
OooonfX4o`000003oookJ_l0003o000000;o0000U_oonfX009oooo]Z1?l000000ooonf[o0000o`00
0002o`0007Gooo]Z1Ol0001ooookJPCo000000?ooo]Zo`000?l000000_l0002FoookJP00WooonfX4
o`000003oookJ_l0003o000000;o0000MOoonfX5o`0007oooo]Z1?l000000ooonf[o0000o`000002
o`0009Kooo]Z002OoookJPCo000000?ooo]Zo`000?l000000_l0001eoookJPGo0000OooonfX4o`00
0003oookJ_l0003o000000;o0000U_oonfX009oooo]Z1?l000000ooonf[o0000o`000003o`0007Co
oo]Z1Ol0001ooookJPCo000000?ooo]Zo`000?l000000_l0002FoookJP00WooonfX4o`000003oook
J_l0003o000000?o0000M?oonfX5o`0007oooo]Z1?l000000ooonf[o0000o`000003o`0009Gooo]Z
002OoookJPCo000000?ooo]Zo`000?l000000ol0001doookJPGo0000OooonfX4o`000003oookJ_l0
003o000000?o0000UOoonfX009oooo]Z1?l00002oookJPCo0000M?oonfX5o`0007oooo]Z1?l00000
0ooonf[o0000o`000003o`0009Gooo]Z002OoookJPCo00000_oonfX4o`0007Cooo]Z1Ol0001ooook
JPCo00000_oonfX4o`0009Gooo]Z002OoookJPCo00000_oonfX4o`0000;ooo]Z1?l0001^oookJPGo
0000O_oonfX5o`0000;ooo]Z1?l00002oookJPCo0000SooonfX009kooo]Z1Ol00002oookJPCo0000
00?ooo]Zo`000?l000000ol0001^oookJPGo0000O_oonfX5o`0000;ooo]Z1?l000000ooonf[o0000
o`000004o`0008kooo]Z002NoookJPGo00000_oonfX;o`0006gooo]Z1Ol0001noookJPGo00000_oo
nfX4o`000003oookJ_l0003o000000Co0000S_oonfX009kooo]Z1Ol00002oookJPco0000K?oonfX5
o`0007kooo]Z1?l00003oookJPCo000000?ooo]Zo`000?l000001?l0002>oookJP00W_oonfX4o`00
00?ooo]Z3?l0001/oookJPGo0000O_oonfX4o`0000?ooo]Z3?l0002=oookJP00W_oonfX4o`0000?o
oo]Z3?l0001/oookJPGo0000O_oonfX4o`0000?ooo]Z3Ol0002<oookJP00W_oonfX4o`0000?ooo]Z
3?l0001/oookJPGo0000O_oonfX4o`0000?ooo]Z3Ol0002<oookJP00W_oonfX4o`0000Cooo]Z1_l0
00000ooonf[o0000o`000002o`0006cooo]Z1Ol0001noookJPCo00001?oonfX=o`0008_ooo]Z002N
oookJPCo00001?oonfX6o`000003oookJ_l0003o000000?o0000JooonfX5o`0007kooo]Z1?l00004
oookJPOo000000?ooo]Zo`000?l000001?l0002:oookJP00W_oonfX4o`0000Cooo]Z1_l000000ooo
nf[o0000o`000003o`0006_ooo]Z1Ol0001noookJPCo00001?oonfX6o`0000;ooo]Z1_l0002:oook
JP00W_oonfX4o`0000Gooo]Z1Ol000000ooonf[o0000o`000003o`0006_ooo]Z1Ol0001noookJPCo
00001OoonfX5o`0000?ooo]Z1_l00029oookJP00W_oonfX4o`0000cooo]Z1Ol0001ZoookJPGo0000
O_oonfX4o`0000kooo]Z1_l00028oookJP00W_oonfX4o`0000cooo]Z1Ol0001ZoookJPGo0000O_oo
nfX4o`0000kooo]Z1_l00028oookJP00W_oonfX4o`0000cooo]Z1Ol0001ZoookJPGo0000O_oonfX4
o`0000oooo]Z1_l00027oookJP00W_oonfX4o`0000gooo]Z1Ol0001YoookJPGo0000O_oonfX4o`00
013ooo]Z1_l00026oookJP00W_oonfX4o`0000gooo]Z1Ol0001YoookJPGo0000O_oonfX4o`00013o
oo]Z1_l00026oookJP00W_oonfX4o`0000gooo]Z1Ol0001YoookJPGo0000O_oonfX4o`00017ooo]Z
1_l00025oookJP00W_oonfX4o`0000kooo]Z2_l0001SoookJPGo0000O_oonfX4o`0001;ooo]Z1_l0
0024oookJP00W_oonfX4o`0000kooo]Z2ol00014oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:
oookJPGo0000O_oonfX4o`0001;ooo]Z1_l00024oookJP00W_oonfX4o`0000kooo]Z2ol00013oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000O_oonfX4o`0001?ooo]Z1_l00023oook
JP00W_oonfX4o`0000kooo]Z2ol00013oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0007kooo]Z1?l0000D
oookJPKo0000P_oonfX009kooo]Z1?l0000?oookJP_o0000=OoonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000O_oonfX4o`0001Cooo]Z1ol00021oook
JP00WOoonfX5o`0000oooo]Z1Ol000000ooonf[o0000o`000003o`0003Gooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000OOoonfX4o`0001Gooo]Z1ol00020oookJP00
WOoonfX5o`0001Gooo]Z1Ol00011oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000
O_oonfX4o`0001Kooo]Z1ol0001ooookJP00WOoonfX5o`0001Kooo]Z1Ol00010oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0007kooo]Z1?l0000GoookJPOo0000O_oo
nfX009gooo]Z1?l0000GoookJPGo0000@?oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5
o`0007kooo]Z1?l0000HoookJPKo0000O_oonfX009gooo]Z1?l0000GoookJPKo0000?ooonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0007kooo]Z1?l0000IoookJPKo0000OOoonfX009go
oo]Z1?l0000HoookJPGo0000?ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0007go
oo]Z1Ol0000JoookJPKo0000O?oonfX009gooo]Z1?l0000HoookJPGo0000@?oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000OOoonfX5o`0001[ooo]Z1ol0001koookJP00
WOoonfX4o`0001Wooo]Z2_l0000joookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001moookJPGo0000
6ooonfX7o`0007[ooo]Z002MoookJPCo00006OoonfX;o`0003[ooo]Z1Ol007l:oookJPOo001o2?oo
nfX5o`0007gooo]Z1?l0000MoookJPSo0000N?oonfX009gooo]Z1?l0000IoookJP_o0000F?oonfX5
o`0007gooo]Z1?l0000NoookJPSo0000MooonfX009gooo]Z1?l0000JoookJP[o0000F?oonfX5o`00
07gooo]Z1?l0000OoookJPSo0000M_oonfX009gooo]Z1?l0000KoookJP[o0000EooonfX5o`0007go
oo]Z1?l0000PoookJPSo0000MOoonfX009gooo]Z1?l0000PoookJPKo0000E_oonfX5o`0007gooo]Z
1?l0000RoookJPOo0000M?oonfX009gooo]Z1?l0000PoookJPKo0000E_oonfX5o`0007gooo]Z1?l0
000SoookJPOo0000LooonfX009gooo]Z1?l0000QoookJPKo0000EOoonfX5o`0007gooo]Z1?l0000T
oookJPOo0000L_oonfX009gooo]Z1?l0000RoookJPGo0000EOoonfX5o`0007gooo]Z1?l0000Uoook
JPOo0000LOoonfX009gooo]Z1?l0000RoookJPKo0000E?oonfX5o`0007gooo]Z1?l0000VoookJPOo
0000L?oonfX009gooo]Z1?l0000SoookJP_o0000C_oonfX5o`0007gooo]Z1?l0000WoookJPOo0000
KooonfX009gooo]Z1?l0000SoookJPco0000COoonfX5o`0007gooo]Z1?l0000XoookJPSo0000KOoo
nfX009gooo]Z1?l0000ToookJP_o0000COoonfX5o`0007gooo]Z1?l0000YoookJPSo0000K?oonfX0
09gooo]Z1?l0000UoookJP_o0000C?oonfX5o`0007gooo]Z1?l0000ZoookJPSo0000JooonfX002;o
oo]Z0ol007meoookJP?o001o1?l00002oookJP?o001o0ooonfX5o`00OaSooo]Z2ol0001<oookJPGo
0000M?oonfX5o`00O`Cooo]Z1?l00002oookJPGo001o9?oonfX8o`0004[ooo]Z0ol007lMoookJP00
8_oonfX3o`00OgCooo]Z1?l007l4o`0000;ooo]Z0ol007l2oookJPOo001o7OoonfX6o`0004_ooo]Z
1Ol0001coookJPOo001o0ooonfX4o`000003oookJ_l007oo001o00Go001o9OoonfX8o`0004Sooo]Z
0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Oakooo]Z1_l0001:oookJPGo0000
LooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1?l00004o`00O`04oookJ_l007oo001oo`00
ObKooo]Z2?l00017oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l2oookJPCo00001_oonfX3o`00O`?ooo]Z0ol007lMoookJPOo0000BOoonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o0_oonfX4o`0000?o001o0ooonfX3o`00ObKooo]Z2?l00016oookJP?o
001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l2oookJPCo0000
3?oonfX3o`00Oakooo]Z3?l00013oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo0000
1_oonfX3o`00ObOooo]Z2?l00015oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oo
nfX4o`0000cooo]Z0ol007lOoookJPco0000@_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oo
nfX4o`0000Kooo]Z0ol007lYoookJPSo0000@ooonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3
o`00O`;ooo]Z1?l00007oookJP;o001o0_oonfX4o`00Ob3ooo]Z3?l00011oookJPGo0000L_oonfX3
o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Zo`00Ool007l00_oonfX4o`00Ob[ooo]Z2Ol00011
oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4o`0000Oooo]Z1ol007lQoook
JPco0000@OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o
00Go001o;?oonfX:o`0003oooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo
00001ooonfX6o`00Ob?ooo]Z3?l00010oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo
000000?ooo]Zo`00Ool007l01?l007l^oookJP_o0000?OoonfX3o`00Oagooo]Z000OoookJPKo001o
LooonfX3o`00O`;ooo]Z1?l00007oookJP;o001o;_oonfX6o`0003oooo]Z1Ol0001boookJP?o001o
0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`0doookJP_o0000>?oonfX6o`00Oagooo]Z
000OoookJPKo001oM?oonfX3o`00O`Go00001ooonfX2o`00Obkooo]Z3Ol0000hoookJPGo0000Looo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1?l000000ooonf[o001oo`00O`0foookJP_o0000
=_oonfX6o`00Oagooo]Z000QoookJPCo001oM?oonfX3o`00O`Go00002?oonfX7o`00ObWooo]Z3Ol0
000goookJPGo0000LooonfX7o`00O`?ooo]Z1?l00002oookJPOo001o<_oonfX:o`0003Oooo]Z1?l0
07lMoookJP008_oonfX3o`00OgGooo]Z0_l007l5o`0000Sooo]Z1ol007lZoookJPgo0000=_oonfX5
o`0007Cooo]Z1Ol007l4oookJPCo00000_oonfX7o`00OcCooo]Z2Ol0000goookJP?o001o7OoonfX0
09cooo]Z1?l0000joookJPgo0000=_oonfX5o`0007cooo]Z1Ol0000ooookJPOo0000EooonfX009co
oo]Z1?l0000loookJPGo000000?ooo]Zo`000?l000003?l0000]oookJPGo0000O?oonfX5o`00047o
oo]Z3_l0001>oookJP00W?oonfX4o`0004?ooo]Z3_l0000/oookJPGo0000O?oonfX5o`0004;ooo]Z
3_l0001=oookJP00W?oonfX4o`0004?ooo]Z3_l00004oookJPGo00008ooonfX5o`0007cooo]Z1?l0
0013oookJPoo00000ooonfX4o`0004Gooo]Z002LoookJPCo0000A?oonfXGo`0002;ooo]Z1Ol0001l
oookJPCo0000A?oonfXGo`0004?ooo]Z002LoookJPCo0000A_oonfX6o`000003oookJ_l0003o0000
00go00000ooonfX6o`0001Sooo]Z1Ol0001loookJPCo0000A_oonfXFo`0000;ooo]Z1ol0000ioook
JP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oo
nf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`00
0?oo00009Ol0000?oookJP007OoonfX01?l0003ooo]ZoookJ_oonfX7o`0000Cooo]Z1ol00003oook
JQSo0000C_oonfX4o`0006Gooo]Z1Ol00005oookJPKo00001?oonfX9o`0000;ooo]Z1ol00002oook
JPSo00000ooonfXIo`0004gooo]Z1?l0001UoookJPGo00001OoonfX6o`0000Cooo]Z1ol0000Noook
JP00=_oonfX8o`0000;ooo]Z5ol00015oookJPCo0000OOoonfX5o`0001Oooo]Z1ol000000ooonf[o
0000o`00000>o`0000;ooo]Z1Ol00016oookJPCo0000W_oonfX0047ooo]Z5_l00015oookJPCo0000
OOoonfX5o`00027ooo]Z5ol00014oookJPCo0000W_oonfX004;ooo]Z1Ol00003oookJPko0000A?oo
nfX4o`0007gooo]Z1Ol0000RoookJPKo00000ooonfX=o`0004Cooo]Z1?l0002NoookJP00BooonfX>
o`0004?ooo]Z1?l0001moookJPGo0000:ooonfX>o`0004?ooo]Z1?l0002NoookJP00C?oonfX>o`00
0003oookJ_l0003o000000?o0000??oonfX4o`0007gooo]Z1Ol0000/oookJPko000000?ooo]Zo`00
0?l000001?l0000koookJPCo0000W_oonfX005Cooo]Z3Ol0000koookJPCo0000OOoonfX5o`0003Co
oo]Z3Ol0000koookJPCo0000W_oonfX005Gooo]Z3Ol0000joookJPCo0000OOoonfX5o`0003Gooo]Z
3_l0000ioookJPCo0000W_oonfX005Kooo]Z3Ol0000ioookJPCo0000OOoonfX5o`0003Kooo]Z3Ol0
000ioookJPCo0000W_oonfX005Oooo]Z3Ol0000hoookJPCo0000OOoonfX5o`0003Oooo]Z3Ol0000h
oookJPCo0000W_oonfX005kooo]Z1ol0000goookJPCo0000OOoonfX5o`0003kooo]Z1_l0000goook
JPGo0000W_oonfX005oooo]Z3?l0000aoookJPCo0000OOoonfX5o`0003oooo]Z3?l0000`oookJPGo
0000W_oonfX0063ooo]Z3Ol0000^oookJPGo0000OOoonfX5o`00043ooo]Z3?l0000_oookJPGo0000
W_oonfX0067ooo]Z3Ol0000]oookJPGo0000OOoonfX5o`00043ooo]Z3Ol0000^oookJPCo0000Wooo
nfX0067ooo]Z3ol0000[oookJPGo0000OOoonfX5o`00047ooo]Z3?l0000^oookJPCo0000WooonfX0
06;ooo]Z3ol0000ZoookJPCo0000O_oonfX5o`0004;ooo]Z2ol0000^oookJPCo0000WooonfX006[o
oo]Z2?l0000YoookJPCo0000O_oonfX5o`0004Wooo]Z1Ol0000]oookJPCo0000WooonfX006_ooo]Z
2Ol0000WoookJPCo0000O_oonfX5o`0004Wooo]Z1_l0000/oookJPCo0000WooonfX006gooo]Z2?l0
000VoookJPCo0000O_oonfX5o`0004Wooo]Z1ol0000[oookJPCo0000WooonfX006kooo]Z2?l0000U
oookJPCo0000O_oonfX5o`0004[ooo]Z3?l0000UoookJPCo0000WooonfX006oooo]Z2?l0000Toook
JPCo0000O_oonfX5o`0004_ooo]Z2ol0000UoookJPCo0000WooonfX0077ooo]Z1ol0000SoookJPCo
0000O_oonfX5o`0004cooo]Z2ol0000ToookJPCo0000WooonfX007;ooo]Z1ol0000RoookJPCo0000
O_oonfX5o`0004cooo]Z2ol0000ToookJPCo0000WooonfX007?ooo]Z1ol0000QoookJPCo0000O_oo
nfX5o`0004gooo]Z2ol0000SoookJPCo0000WooonfX007Cooo]Z1ol0000PoookJPCo0000O_oonfX5
o`0005?ooo]Z1Ol0000SoookJPCo0000WooonfX007Gooo]Z1ol0000OoookJPCo0000O_oonfX5o`00
05?ooo]Z1Ol0000SoookJPCo0000WooonfX007Kooo]Z1ol0000NoookJPCo0000O_oonfX5o`0005Co
oo]Z1Ol0000RoookJPCo0000WooonfX007Oooo]Z1ol0000MoookJPCo0000O_oonfX5o`0005Cooo]Z
1_l0000QoookJPCo0000WooonfX007Sooo]Z1ol0000LoookJPCo0000O_oonfX5o`0005Cooo]Z1_l0
000QoookJPCo0000WooonfX007Wooo]Z1ol0000KoookJPCo0000O_oonfX5o`0005Gooo]Z2ol0000K
oookJPCo0000WooonfX007[ooo]Z1ol0000JoookJPCo0000O_oonfX5o`0005Kooo]Z2ol0000Joook
JPCo0000WooonfX007_ooo]Z1_l0000JoookJPCo0000O_oonfX5o`0005Kooo]Z3?l0000IoookJPCo
0000WooonfX007cooo]Z1_l0000IoookJPCo0000O_oonfX5o`0005Oooo]Z2ol0000IoookJPCo0000
WooonfX007gooo]Z1_l0000HoookJPCo0000O_oonfX5o`0005Sooo]Z2_l0000IoookJPCo0000Wooo
nfX007gooo]Z1ol0000GoookJPCo0000O_oonfX5o`0005kooo]Z1Ol0000HoookJPCo0000WooonfX0
07kooo]Z1ol0000FoookJPCo0000H?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`00
05kooo]Z1Ol0000HoookJPCo0000WooonfX007oooo]Z1ol0000EoookJPCo0000GooonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o2OoonfX5o`0005kooo]Z1Ol0000HoookJPCo0000WooonfX0083ooo]Z
1ol0000DoookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001OoookJPGo00005_oonfX5o`00
09oooo]Z0021oookJPOo00004_oonfX5o`0005kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l8oookJPGo0000GooonfX5o`0001Kooo]Z1Ol0002OoookJP00P_oonfX7o`00017ooo]Z
1Ol0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000G_oonfX5o`0001Kooo]Z
1Ol0002OoookJP00PooonfX7o`00013ooo]Z1Ol0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l8oookJPGo0000H?oonfX:o`00013ooo]Z1?l0002PoookJP00Q?oonfX7o`0000oooo]Z1?l0001O
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`00063ooo]Z2ol0000?
oookJPCo0000X?oonfX008Gooo]Z1ol0000>oookJPCo0000GooonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o2OoonfX5o`00063ooo]Z3?l0000>oookJPCo0000X?oonfX008Kooo]Z1_l0000>oookJPCo
0000GooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`00067ooo]Z2ol0000>oookJPCo
0000X?oonfX008Oooo]Z1Ol0000>oookJPCo0000GooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
3_oonfX5o`00067ooo]Z2ol0000>oookJPCo0000X?oonfX008Sooo]Z1Ol0000=oookJPCo0000H?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000H_oonfX:o`0000kooo]Z
1?l0002PoookJP00R?oonfX5o`0000gooo]Z1?l0001PoookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0
001XoookJPGo00003OoonfX4o`000:3ooo]Z0028oookJPGo00003OoonfX4o`00067ooo]Z1Ol007l:
oookJPOo001o2?oonfX5o`0006Sooo]Z1Ol0000=oookJPCo0000X?oonfX008Wooo]Z1?l0000=oook
JPCo0000OooonfX5o`0006Sooo]Z1Ol0000=oookJPCo0000X?oonfX008Wooo]Z1?l0000=oookJPCo
0000OooonfX5o`0006Wooo]Z1Ol0000<oookJPCo0000X?oonfX008Wooo]Z1Ol0000<oookJPCo0000
OooonfX5o`0006Wooo]Z1Ol0000<oookJPCo0000X?oonfX008Wooo]Z1Ol0000<oookJPCo0000Oooo
nfX5o`0006Wooo]Z1Ol0000<oookJPCo0000X?oonfX008Wooo]Z1Ol00002oookJPGo00001OoonfX4
o`0007oooo]Z1Ol0001ZoookJPCo00000ooonfX4o`0000Gooo]Z1?l0002PoookJP00R_oonfX4o`00
00;ooo]Z1Ol00005oookJPCo0000OooonfX5o`0006[ooo]Z1?l00002oookJPGo00001OoonfX4o`00
0:3ooo]Z002:oookJPGo000000?ooo]Zo`000?l000001?l00004oookJPCo0000OooonfX5o`0006[o
oo]Z1?l00002oookJPKo00001?oonfX4o`000:3ooo]Z002:oookJPco00001?oonfX4o`0007oooo]Z
1Ol0001ZoookJPGo000000?ooo]Zo`000?l000001?l00004oookJPCo0000X?oonfX008[ooo]Z3Ol0
0003oookJPCo0000OooonfX5o`0006[ooo]Z3Ol00003oookJPCo0000X?oonfX008_ooo]Z3?l00003
oookJPCo0000OooonfX5o`0006[ooo]Z3Ol00003oookJPCo0000X?oonfX008_ooo]Z3?l00002oook
JPGo0000OooonfX5o`0006_ooo]Z3?l00003oookJPCo0000X?oonfX008_ooo]Z3?l00002oookJPGo
0000OooonfX5o`0006_ooo]Z3?l00003oookJPCo0000X?oonfX008_ooo]Z1ol000000ooonf[o0000
o`000002o`0000;ooo]Z1Ol0001ooookJPGo0000JooonfX<o`0000?ooo]Z1?l0002PoookJP00S?oo
nfX6o`000003oookJ_l0003o000000;o00000_oonfX4o`00083ooo]Z1Ol0001/oookJPKo000000?o
oo]Zo`000?l000000_l00002oookJPGo0000X?oonfX008gooo]Z1?l00002oookJPCo00000_oonfX4
o`00083ooo]Z1Ol0001]oookJPCo00000_oonfX4o`0000;ooo]Z1Ol0002PoookJP00TooonfX5o`00
0003oookJ_l0003o000000;o0000P?oonfX5o`0007?ooo]Z1?l00002oookJPGo0000X?oonfX009?o
oo]Z1Ol000000ooonf[o0000o`000002o`00083ooo]Z1Ol0001coookJPGo000000?ooo]Zo`000?l0
00000_l0002QoookJP00TooonfX5o`000003oookJ_l0003o000000;o0000P?oonfX5o`0007?ooo]Z
1Ol000000ooonf[o0000o`000002o`000:7ooo]Z002DoookJPCo000000?ooo]Zo`000?l000000_l0
0020oookJPGo0000LooonfX5o`000003oookJ_l0003o000000;o0000XOoonfX009Cooo]Z1?l00000
0ooonf[o0000o`000002o`00083ooo]Z1Ol0001doookJPCo000000?ooo]Zo`000?l000000_l0002Q
oookJP00U?oonfX4o`000003oookJ_l0003o000000;o0000P?oonfX5o`0007Cooo]Z1?l000000ooo
nf[o0000o`000002o`000:7ooo]Z002DoookJPCo000000?ooo]Zo`000?l000000_l00020oookJPGo
0000M?oonfX9o`000:7ooo]Z002DoookJPCo000000?ooo]Zo`000?l000000_l00020oookJPGo0000
M?oonfX9o`000:7ooo]Z002DoookJPWo0000P?oonfX5o`0007Cooo]Z2Ol0002QoookJP00U?oonfX9
o`00083ooo]Z1Ol0001eoookJPSo0000XOoonfX009Cooo]Z2Ol00020oookJPGo0000MOoonfX8o`00
0:7ooo]Z002EoookJPSo0000P?oonfX5o`0007Gooo]Z2?l0002QoookJP00UOoonfX8o`00083ooo]Z
1Ol0001eoookJPSo0000XOoonfX009Gooo]Z2?l00020oookJPGo0000MOoonfX8o`000:7ooo]Z002E
oookJPSo0000LooonfX3o`00O`[ooo]Z1Ol0001eoookJPSo0000XOoonfX009Gooo]Z2?l0001coook
JP?o001o2_oonfX5o`0007Gooo]Z2?l0002QoookJP00UOoonfX8o`0007?ooo]Z0ol007l:oookJPGo
0000MOoonfX8o`000:7ooo]Z002EoookJPSo0000LooonfX3o`00O`[ooo]Z1Ol0001eoookJPSo0000
XOoonfX009Gooo]Z2?l0001coookJP?o001o2_oonfX6o`0007Cooo]Z2?l0002QoookJP00U_oonfX6
o`0007Cooo]Z0ol007l:oookJPGo0000M_oonfX7o`000:7ooo]Z002FoookJPKo0000M?oonfX3o`00
O`[ooo]Z1Ol0001foookJPKo0000X_oonfX009Kooo]Z1_l0001doookJP?o001o2_oonfX5o`0007Ko
oo]Z1_l0002RoookJP00U_oonfX6o`0007Cooo]Z0ol007l:oookJPGo0000M_oonfX6o`000:;ooo]Z
002FoookJPKo0000LOoonfX6o`00O`[ooo]Z1Ol0001goookJPGo0000X_oonfX009Kooo]Z1Ol0001b
oookJPKo001o2_oonfX5o`0007Oooo]Z1Ol0002RoookJP00UooonfX4o`0007Cooo]Z1?l007l:oook
JPGo0000MooonfX4o`000:?ooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXN
oookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;o
oo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l0
07l:oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXO
oookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00oooonfX1oookJPCo
001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o
2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000
oooonfXOoookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4
o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oookJPKo0000oooonfXNoook
JP00oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3
oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oo
oo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z
003ooookJPoooo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30976 L
.02605 .31034 L
.02729 .31079 L
.02846 .31095 L
.02954 .31083 L
.03053 .3105 L
.03163 .30996 L
.03279 .30926 L
.03394 .30852 L
.03504 .30788 L
.03631 .30735 L
.03746 .30713 L
.03874 .30721 L
.03946 .30741 L
.04012 .30769 L
.04133 .30835 L
.04262 .30919 L
.04387 .30999 L
.04519 .31067 L
.04588 .31091 L
.04664 .31107 L
.04733 .31111 L
.04797 .31105 L
.04925 .31069 L
.05041 .31012 L
.05176 .3093 L
.05302 .30853 L
.05414 .30795 L
.05534 .30755 L
.05653 .30745 L
.05722 .30753 L
.05786 .3077 L
.05901 .30821 L
.06007 .30886 L
.06244 .31052 L
.06373 .31127 L
.0649 .31172 L
.06555 .31184 L
.06625 .31187 L
.06752 .31166 L
.06872 .31118 L
.06998 .31048 L
.07117 .30977 L
.07225 .30918 L
.07352 .30869 L
.07422 .30854 L
.07489 .30851 L
.07607 .3087 L
.07735 .30926 L
Mistroke
.07809 .30973 L
.07876 .31021 L
.08027 .31139 L
.08156 .31237 L
.08229 .31285 L
.08297 .31321 L
.08363 .31347 L
.08433 .31364 L
.08508 .3137 L
.08576 .31364 L
.08708 .31327 L
.08832 .31267 L
.08967 .31191 L
.09109 .3112 L
.09184 .31094 L
.09266 .31077 L
.0934 .31075 L
.0941 .31085 L
.09539 .31135 L
.09603 .31174 L
.09674 .31226 L
.09915 .31441 L
.10051 .31558 L
.10126 .31611 L
.10196 .31652 L
.10262 .31681 L
.10334 .31699 L
.10458 .31703 L
.10582 .31673 L
.10695 .31624 L
.10816 .31562 L
.1088 .3153 L
.10949 .315 L
.11071 .31463 L
.11184 .31457 L
.1129 .31482 L
.11407 .31544 L
.11672 .31786 L
.11816 .31943 L
.11951 .32075 L
.12066 .32164 L
.12189 .32223 L
.12259 .32239 L
.12325 .32242 L
.12449 .32221 L
.1258 .32171 L
.127 .32116 L
.12832 .32063 L
.12898 .32046 L
.12972 .32038 L
Mistroke
.13045 .32044 L
.13112 .32063 L
.13189 .32101 L
.13263 .32153 L
.13393 .32278 L
.13535 .32451 L
.13791 .32774 L
.13865 .32852 L
.13934 .32914 L
.14064 .32995 L
.14187 .33026 L
.143 .33019 L
.14424 .32982 L
.14555 .32928 L
.14677 .32883 L
.14746 .32867 L
.1481 .32862 L
.14927 .32882 L
.15051 .32952 L
.15162 .33056 L
.15267 .33185 L
.15504 .33546 L
.15742 .33886 L
.15862 .34008 L
.15993 .34086 L
.16062 .34105 L
.16136 .34109 L
.16205 .341 L
.16268 .34083 L
.16391 .34037 L
.1652 .33989 L
.16633 .33969 L
.16756 .33987 L
.16868 .3405 L
.16973 .34153 L
.17097 .34324 L
.1721 .34519 L
.17464 .35003 L
.1757 .35186 L
.17683 .35346 L
.17806 .35468 L
.17921 .35526 L
.18038 .35536 L
.18148 .35509 L
.18247 .3547 L
.18354 .35426 L
.18479 .35396 L
.18593 .3541 L
.18724 .35493 L
.18848 .35644 L
Mistroke
.18963 .35845 L
.19069 .36071 L
.19308 .36643 L
.19424 .369 L
.1955 .37126 L
.19621 .37224 L
.19687 .37291 L
.19816 .3736 L
.19947 .37354 L
.20022 .37325 L
.20091 .37288 L
.20158 .37249 L
.20228 .37212 L
.20353 .37171 L
.20417 .37172 L
.20486 .37196 L
.2056 .37251 L
.20629 .37332 L
.20754 .37554 L
.20889 .37887 L
.21121 .38595 L
.21243 .38965 L
.21374 .39299 L
.21446 .39444 L
.21526 .39565 L
.21598 .39635 L
.21666 .39668 L
.21735 .3967 L
.21799 .39647 L
.21869 .39599 L
.21943 .39532 L
.22063 .39407 L
.22191 .39301 L
.22264 .39273 L
.22331 .39277 L
.22462 .3939 L
.22943 .40992 L
.23064 .41527 L
.23178 .41984 L
.23281 .42313 L
.23393 .42549 L
.23511 .4264 L
.23619 .4258 L
.23737 .42383 L
.23863 .42076 L
.24002 .41714 L
.24134 .41469 L
.24252 .41417 L
.24379 .41612 L
.2451 .42124 L
Mistroke
.24584 .42554 L
.24654 .43034 L
.24943 .45505 L
.25072 .46519 L
.25193 .47188 L
.2526 .47377 L
.25333 .474 L
.25461 .46908 L
.25581 .45763 L
.25713 .43705 L
.2585 .40721 L
.2598 .37286 L
.26228 .29735 L
.26459 .22928 L
.26576 .20013 L
.26686 .17767 L
.26814 .15875 L
.26929 .14833 L
.27058 .14394 L
.27176 .14573 L
.27306 .15264 L
.27372 .1575 L
.27444 .1635 L
.27702 .18578 L
.27777 .19119 L
.27847 .19553 L
.27911 .19872 L
.27979 .20127 L
.28104 .2037 L
.28219 .20364 L
.28343 .2017 L
.28414 .20003 L
.2848 .1983 L
.28597 .19526 L
.28706 .19301 L
.2882 .19175 L
.28944 .19202 L
.29052 .19373 L
.2915 .19639 L
.29263 .20052 L
.2937 .20508 L
.29594 .21488 L
.29717 .21936 L
.29831 .22251 L
.29955 .22459 L
.30021 .22513 L
.30091 .22533 L
.30217 .22485 L
.30331 .22383 L
.3046 .2225 L
Mistroke
.30582 .22157 L
.3069 .22131 L
.30808 .22188 L
.30937 .22362 L
.31002 .22492 L
.31073 .22663 L
.31316 .23386 L
.31545 .24056 L
.31673 .24342 L
.31789 .24519 L
.31898 .24609 L
.32016 .24634 L
.32127 .24604 L
.32231 .2455 L
.32349 .24483 L
.32477 .2444 L
.32598 .24453 L
.32708 .24525 L
.32831 .24677 L
.32901 .24795 L
.32965 .24922 L
.33236 .25553 L
.33375 .2587 L
.33506 .26117 L
.33624 .26278 L
.33752 .26378 L
.33818 .26402 L
.33891 .26408 L
.33967 .26396 L
.34039 .26373 L
.34167 .2632 L
.34237 .26293 L
.34303 .26274 L
.34368 .26266 L
.34439 .26272 L
.34562 .26327 L
.34687 .26443 L
.34801 .26602 L
.3506 .27074 L
.35197 .27332 L
.35344 .27569 L
.35475 .27721 L
.35593 .27803 L
.35712 .27834 L
.35825 .27823 L
.35952 .27782 L
.36068 .27736 L
.36196 .277 L
.36261 .27694 L
.36332 .27701 L
Mistroke
.36456 .27751 L
.36573 .27845 L
.36678 .27966 L
.36793 .28128 L
.37033 .28501 L
.37165 .28685 L
.37289 .28819 L
.37406 .28901 L
.37533 .28939 L
.37648 .28934 L
.37754 .28903 L
.3786 .28861 L
.37976 .28814 L
.38085 .28783 L
.38186 .28777 L
.38305 .28803 L
.38432 .28877 L
.38538 .28973 L
.38655 .29107 L
.38897 .29418 L
.39025 .29564 L
.39094 .2963 L
.39159 .29681 L
.39275 .29743 L
.39403 .29765 L
.39511 .29751 L
.39627 .29712 L
.39738 .29661 L
.39856 .29609 L
.39956 .29576 L
.40067 .29561 L
.40133 .29566 L
.40205 .29585 L
.40334 .29652 L
.40411 .29711 L
.40485 .29779 L
.40623 .29923 L
.40755 .30066 L
.40896 .30201 L
.40964 .30253 L
.41029 .30293 L
.41149 .30338 L
.41267 .30346 L
.41375 .30324 L
.41494 .30277 L
.41619 .30213 L
.41738 .30156 L
.41864 .30111 L
.41937 .30099 L
.42003 .30099 L
Mistroke
.42133 .30128 L
.44043 .30465 L
.44518 .30793 L
.44649 .30879 L
.44714 .30911 L
.44786 .30936 L
.44913 .30953 L
.45031 .30934 L
.45104 .30909 L
.45173 .30877 L
.45302 .30804 L
.45453 .30715 L
.4552 .30681 L
.45593 .3065 L
.45716 .30619 L
.45846 .30622 L
.45914 .30638 L
.45987 .30667 L
.46057 .30702 L
.4612 .3074 L
.46355 .30905 L
.46485 .30984 L
.46606 .31037 L
.46675 .31053 L
.4675 .31059 L
.46881 .3104 L
.46946 .31018 L
.47014 .30986 L
.47136 .30917 L
.47358 .30781 L
.47482 .30725 L
.47596 .30696 L
.4766 .30692 L
.4773 .30698 L
.47856 .30734 L
.47983 .30798 L
.48099 .30872 L
.48219 .30951 L
.48333 .31017 L
.48464 .31071 L
.48585 .31092 L
.48717 .31078 L
.48791 .31054 L
.48861 .31023 L
.49119 .30867 L
.49187 .30825 L
.49261 .30784 L
.49325 .30754 L
.49394 .3073 L
.49523 .30709 L
Mistroke
.49643 .30722 L
.49709 .30742 L
.4978 .30772 L
.49909 .30843 L
.50048 .30932 L
.50121 .30978 L
.50201 .31022 L
.50333 .31075 L
.50457 .31094 L
.50526 .31091 L
.50599 .31076 L
.50729 .31025 L
.5085 .30956 L
.50963 .30884 L
.51085 .30809 L
.5115 .30775 L
.51218 .30746 L
.51293 .30723 L
.51362 .30713 L
.51427 .30712 L
.51498 .30722 L
.5163 .30768 L
.51753 .30835 L
.51893 .30927 L
.52046 .31022 L
.52116 .31057 L
.52191 .31086 L
.52261 .31104 L
.52324 .31111 L
.5245 .31099 L
.52521 .31078 L
.52586 .31051 L
.52831 .30907 L
.52948 .30837 L
.53057 .30785 L
.5317 .30752 L
.53294 .30746 L
.53359 .30757 L
.5343 .30779 L
.53558 .30843 L
.53798 .31007 L
.53933 .31096 L
.54008 .31135 L
.54078 .31162 L
.54201 .31187 L
.54266 .31186 L
.54336 .31175 L
.54463 .31131 L
.54577 .31071 L
.547 .30998 L
Mistroke
.54834 .30923 L
.54958 .30872 L
.55072 .30852 L
.55181 .30859 L
.55296 .30897 L
.55557 .31069 L
.55701 .31183 L
.55772 .31235 L
.55838 .31279 L
.55964 .31341 L
.56031 .3136 L
.56102 .3137 L
.56217 .3136 L
.56344 .31319 L
.56474 .31254 L
.56594 .31187 L
.56722 .31123 L
.56795 .31096 L
.56863 .3108 L
.56977 .31076 L
.571 .31108 L
.57231 .3118 L
.5735 .31273 L
.57623 .31519 L
.57697 .31578 L
.57776 .31631 L
.57844 .31666 L
.57918 .31692 L
.57988 .31704 L
.58052 .31705 L
.58126 .31694 L
.58196 .31674 L
.5832 .31621 L
.58455 .31552 L
.5852 .3152 L
.58588 .31492 L
.58711 .3146 L
.58842 .31463 L
.58917 .31485 L
.58987 .31519 L
.59113 .31611 L
.59229 .31721 L
.59488 .31998 L
.59599 .32101 L
.59718 .32184 L
.59848 .32234 L
.59968 .32241 L
.6008 .32218 L
.60185 .32178 L
.60309 .3212 L
Mistroke
.60424 .32072 L
.60546 .32041 L
.60611 .32038 L
.6068 .32048 L
.60753 .32072 L
.60822 .32109 L
.6095 .32214 L
.61071 .32347 L
.61182 .32487 L
.61433 .328 L
.61563 .32922 L
.61685 .32996 L
.61755 .33019 L
.61819 .33027 L
.61892 .33024 L
.61962 .33009 L
.621 .32959 L
.62173 .32928 L
.6225 .32898 L
.62318 .32877 L
.62391 .32864 L
.62521 .32875 L
.62647 .32935 L
.62718 .32992 L
.62783 .33057 L
.63026 .33393 L
.63264 .33759 L
.63368 .33895 L
.63483 .34009 L
.63606 .34084 L
.63735 .34109 L
.63804 .34104 L
.63877 .34086 L
.63946 .34062 L
.64009 .34037 L
.64131 .33992 L
.642 .33975 L
.64264 .33969 L
.64382 .33989 L
.64507 .34066 L
.66347 .35497 L
.68487 .37831 L
.68732 .38569 L
.68866 .38976 L
.68994 .39302 L
.69113 .39522 L
.69242 .39651 L
.69359 .39669 L
.69468 .39615 L
.69702 .39387 L
Mistroke
.69767 .3933 L
.69836 .39287 L
.69961 .39281 L
.70028 .39327 L
.70099 .39417 L
.70224 .39691 L
.70293 .399 L
.70358 .40128 L
.70504 .40733 L
.70629 .41293 L
.70765 .41864 L
.70893 .42295 L
.71012 .42549 L
.71119 .42638 L
.71236 .42583 L
.71359 .42378 L
.71474 .42097 L
.71608 .41747 L
.71735 .41493 L
.71849 .41411 L
.71973 .41551 L
.72044 .41755 L
.72108 .42021 L
.72182 .42421 L
.72252 .42883 L
.7251 .45052 L
.72627 .46043 L
.72735 .46807 L
.72849 .47309 L
.72973 .47369 L
.7308 .46907 L
.73178 .46022 L
.73291 .44428 L
.73398 .4237 L
.73893 .28315 L
.74116 .21914 L
.74234 .19165 L
.74357 .16906 L
.74472 .15453 L
.74597 .14582 L
.74711 .14393 L
.74817 .14656 L
.74946 .15406 L
.75062 .16345 L
.75199 .17552 L
.75324 .18601 L
.75448 .19446 L
.75578 .20059 L
.75709 .20356 L
.75783 .20392 L
Mistroke
.75853 .2035 L
.75978 .20134 L
.76093 .19846 L
.76218 .19522 L
.76286 .19372 L
.76351 .19261 L
.76462 .19166 L
.76586 .19226 L
.76691 .19418 L
.76804 .19754 L
.77044 .2075 L
.77175 .21327 L
.77297 .21804 L
.77404 .22139 L
.7752 .22385 L
.77648 .22518 L
.77764 .22524 L
.7787 .22459 L
.77985 .22347 L
.78092 .22238 L
.78194 .2216 L
.78316 .22132 L
.78429 .2219 L
.78549 .2235 L
.78681 .22635 L
.78921 .23339 L
.79138 .23989 L
.79202 .24152 L
.79272 .24304 L
.79399 .24508 L
.79469 .24578 L
.79544 .24621 L
.79607 .24634 L
.79677 .24628 L
.79802 .24577 L
.79936 .245 L
.80062 .24447 L
.80178 .24442 L
.80308 .24508 L
.80374 .24573 L
.80446 .24671 L
.80575 .24902 L
.80695 .25168 L
.80838 .25512 L
.80988 .25858 L
.81117 .26104 L
.81191 .26214 L
.81258 .26293 L
.81381 .26383 L
.81513 .26408 L
Mistroke
.81635 .26382 L
.8175 .26335 L
.81814 .26308 L
.81882 .26284 L
.82005 .26266 L
.82136 .263 L
.82211 .26349 L
.82281 .26415 L
.82779 .27263 L
.82915 .27498 L
.8299 .27605 L
.8306 .27688 L
.83126 .27749 L
.83197 .27796 L
.83321 .27833 L
.83441 .27824 L
.83572 .27782 L
.837 .27732 L
.83771 .27709 L
.83836 .27697 L
.83962 .27703 L
.84081 .27755 L
.84191 .27844 L
.8431 .27982 L
.84551 .28344 L
.84777 .28676 L
.84891 .28802 L
.85013 .28894 L
.85079 .28923 L
.85149 .28939 L
.85273 .28932 L
.8538 .28901 L
.85494 .28855 L
.85592 .28815 L
.85699 .28784 L
.85824 .28778 L
.85942 .28811 L
.86057 .28882 L
.86163 .2898 L
.86404 .29273 L
.86632 .29552 L
.86758 .29667 L
.86829 .29713 L
.86895 .29743 L
.87012 .29765 L
.87135 .2975 L
.87242 .29713 L
.87358 .29661 L
.87458 .29616 L
.87567 .29578 L
Mistroke
.87688 .29561 L
.87816 .29582 L
.87934 .29639 L
.88044 .29723 L
.8829 .29975 L
.8842 .30112 L
.8849 .30179 L
.88557 .30234 L
.88677 .30307 L
.88809 .30345 L
.88921 .30342 L
.89042 .30308 L
.89192 .30238 L
.89334 .30166 L
.89462 .30117 L
.89534 .30102 L
.89601 .30098 L
.8973 .3012 L
.89847 .30175 L
.89912 .30218 L
.89982 .30272 L
.90109 .30385 L
.90347 .30593 L
.90415 .30641 L
.9048 .30678 L
.90601 .30721 L
.90716 .30728 L
.90821 .30708 L
.90938 .30662 L
.91061 .30597 L
.91184 .30528 L
.91249 .30496 L
.91317 .30467 L
.91442 .30436 L
.91557 .30438 L
.91623 .30452 L
.91693 .30478 L
.91819 .30549 L
.92105 .30768 L
.92237 .30861 L
.92304 .30898 L
.92377 .30928 L
.92457 .30948 L
.92531 .30953 L
.92599 .30946 L
.92673 .30927 L
.92742 .30901 L
.92817 .30864 L
.92953 .30785 L
.93087 .30707 L
Mistroke
.93209 .30651 L
.93339 .30619 L
.93461 .30621 L
.9359 .30659 L
.93663 .30695 L
.93729 .30734 L
.93982 .3091 L
.94092 .30978 L
.94212 .31032 L
.9432 .31057 L
.94421 .31056 L
.94517 .31035 L
.94618 .30994 L
.94843 .30861 L
.94953 .30795 L
.95053 .30744 L
.95146 .3071 L
.95233 .30694 L
.95326 .30695 L
.95427 .30716 L
.9553 .30759 L
.9564 .30821 L
.95838 .3095 L
.9595 .31016 L
.96069 .31067 L
.96199 .31091 L
.96319 .31082 L
.9643 .31046 L
.96535 .30994 L
.96772 .30846 L
.96882 .30783 L
.96986 .30738 L
.97079 .30715 L
.97181 .3071 L
.97291 .3073 L
.97408 .30776 L
.97508 .30832 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00XOoonfX4o`0007Sooo]Z1Ol00021oookJPCo0000VOoonfX00:7o
oo]Z1?l0001hoookJPGo0000P?oonfX5o`0009Wooo]Z002PoookJPGo0000JooonfX3o`00O`[ooo]Z
1Ol00020oookJPGo0000VOoonfX00:3ooo]Z1_l0001ZoookJP?o001o2_oonfX5o`00083ooo]Z1Ol0
002IoookJP00X?oonfX6o`0006[ooo]Z0ol007l:oookJPGo0000P?oonfX6o`0009Sooo]Z002Poook
JPKo0000F_oonfX:o`00O`Kooo]Z0ol007l:oookJPGo0000P?oonfX6o`0009Sooo]Z002OoookJPOo
0000F_oonfX:o`00O`Kooo]Z0ol007l:oookJPKo0000OooonfX6o`0009Sooo]Z002OoookJPOo0000
J_oonfX3o`00O`[ooo]Z1Ol00020oookJPKo0000V?oonfX009oooo]Z1ol0001ZoookJP?o001o2_oo
nfX5o`00083ooo]Z1ol0002GoookJP00WooonfX8o`0006Wooo]Z0ol007l:oookJPGo0000P?oonfX7
o`0009Oooo]Z002OoookJPSo0000JOoonfX3o`00O`[ooo]Z1Ol0001ooookJPSo0000UooonfX009oo
oo]Z2?l0001VoookJPKo001o2_oonfX5o`0007oooo]Z2?l0002GoookJP00WooonfX8o`0006Kooo]Z
1_l007l:oookJPGo0000OooonfX8o`0009Oooo]Z002OoookJPSo0000J?oonfX4o`00O`[ooo]Z1Ol0
001ooookJPSo0000UooonfX009oooo]Z2?l0001YoookJP?o001o2_oonfX5o`0007oooo]Z2Ol0002F
oookJP00WooonfX8o`0007Kooo]Z1Ol0001ooookJPWo0000U_oonfX009oooo]Z2?l0001foookJPGo
0000OooonfX9o`0009Kooo]Z002OoookJPWo0000MOoonfX5o`0007oooo]Z1?l000000ooonf[o0000
o`000002o`0009Kooo]Z002OoookJPWo0000MOoonfX5o`0007oooo]Z1?l000000ooonf[o0000o`00
0002o`0009Kooo]Z002OoookJPWo0000MOoonfX5o`0007oooo]Z1?l000000ooonf[o0000o`000002
o`0009Kooo]Z002OoookJPCo000000?ooo]Zo`000?l000000_l0001eoookJPGo0000O_oonfX5o`00
0003oookJ_l0003o000000;o0000U_oonfX009oooo]Z1?l000000ooonf[o0000o`000002o`0007Go
oo]Z1Ol0001noookJPGo000000?ooo]Zo`000?l000000_l0002FoookJP00WooonfX4o`000003oook
J_l0003o000000;o0000MOoonfX5o`0007kooo]Z1Ol000000ooonf[o0000o`000002o`0009Kooo]Z
002OoookJPCo000000?ooo]Zo`000?l000000_l0001eoookJPGo0000O_oonfX4o`0000;ooo]Z1?l0
002FoookJP00WooonfX4o`000003oookJ_l0003o000000?o0000M?oonfX5o`0007kooo]Z1?l00002
oookJPCo0000U_oonfX009kooo]Z1Ol000000ooonf[o0000o`000003o`000003oookJ_l0003o0000
00;o0000KooonfX5o`0007kooo]Z1?l00002oookJPGo000000?ooo]Zo`000?l000000_l0002@oook
JP00W_oonfX5o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000000ol0001^oookJPGo
0000O_oonfX4o`0000;ooo]Z1Ol000000ooonf[o0000o`000003o`0008oooo]Z002NoookJPGo0000
0_oonfX:o`0006kooo]Z1Ol0001noookJPCo00000_oonfX<o`0008kooo]Z002NoookJPCo00000ooo
nfX;o`0006gooo]Z1Ol0001noookJPCo00000ooonfX;o`0008kooo]Z002NoookJPCo00000ooonfX;
o`0006gooo]Z1Ol0001noookJPCo00000ooonfX;o`0008kooo]Z002NoookJPCo00000ooonfX<o`00
06cooo]Z1Ol0001noookJPCo00000ooonfX;o`0008kooo]Z002NoookJPCo00000ooonfX<o`0006co
oo]Z1Ol0001noookJPCo00000ooonfX<o`0008gooo]Z002NoookJPCo00000ooonfX<o`0006cooo]Z
1Ol0001noookJPCo00001?oonfX;o`0008gooo]Z002NoookJPCo00000ooonfX7o`000003oookJ_l0
003o000000;o0000K?oonfX5o`0007kooo]Z1?l00004oookJP_o0000SOoonfX009kooo]Z1?l00004
oookJPKo000000?ooo]Zo`000?l000000_l0001/oookJPGo0000O_oonfX4o`0000Cooo]Z1_l00000
0ooonf[o0000o`000003o`0008cooo]Z002NoookJPCo00001?oonfX5o`0000;ooo]Z1?l0001/oook
JPGo0000O_oonfX4o`0000Cooo]Z1Ol00002oookJPGo0000S?oonfX009kooo]Z1?l0000;oookJPGo
0000JooonfX5o`0007kooo]Z1?l0000;oookJPGo0000S?oonfX009kooo]Z1?l0000;oookJPGo0000
JooonfX5o`0007kooo]Z1?l0000<oookJPCo0000S?oonfX009kooo]Z1?l0000;oookJPGo0000Jooo
nfX5o`0007kooo]Z1?l0000<oookJPCo0000S?oonfX009gooo]Z1Ol0000<oookJPCo0000JooonfX5
o`0007kooo]Z1?l0000<oookJPGo0000RooonfX009gooo]Z1Ol0000<oookJPGo0000J_oonfX5o`00
07kooo]Z1?l0000<oookJPGo0000RooonfX009gooo]Z1Ol0000<oookJPGo000000?ooo]Zo`000?l0
00000_l0001UoookJPGo0000O_oonfX4o`0000cooo]Z1Ol0002;oookJP00WOoonfX4o`0000gooo]Z
2ol0001ToookJPGo0000O_oonfX4o`0000gooo]Z2_l00025oookJP00WOoonfX4o`0000kooo]Z2ol0
001SoookJPGo0000O_oonfX4o`0000gooo]Z2ol00024oookJP00WOoonfX4o`0000kooo]Z2ol00015
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000O_oonfX4o`0000gooo]Z2ol00024
oookJP00WOoonfX4o`0000oooo]Z2_l00014oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oook
JPGo0000O_oonfX4o`0000kooo]Z2_l00024oookJP00WOoonfX4o`0000oooo]Z2ol00013oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2OoonfX5o`0007kooo]Z1?l0000>oookJP_o0000PooonfX009gooo]Z1?l0000@oook
JPCo000000?ooo]Zo`000?l000000ol0000foookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001noookJPCo00003ooonfX4o`000003oookJ_l0003o0000
00?o0000PooonfX009gooo]Z1?l0000EoookJPKo0000=OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Sooo]Z1_l0001moookJPCo00005?oonfX6o`0008;ooo]Z002MoookJPCo0000
5_oonfX5o`00047ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001noookJPCo0000
5OoonfX5o`0008;ooo]Z002MoookJPCo00005_oonfX5o`00047ooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l8oookJPGo0000OOoonfX5o`0001Gooo]Z1Ol00022oookJP00WOoonfX4
o`0001Oooo]Z1Ol00010oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000OOoonfX5
o`0001Kooo]Z1Ol00021oookJP00WOoonfX4o`0001Oooo]Z1Ol00010oookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007l:oookJPGo0000OOoonfX5o`0001Kooo]Z1Ol00021oookJP00WOoonfX4o`0001Oo
oo]Z1_l0000ooookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Oo
oo]Z1_l00020oookJP00WOoonfX4o`0001Sooo]Z2_l0000koookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00O`kooo]Z1Ol0001moookJPCo00006?oonfX:o`0007_ooo]Z002MoookJPCo0000
6?oonfX;o`0003[ooo]Z1ol007l9oookJPOo001o2?oonfX5o`0007gooo]Z1?l0000HoookJP_o0000
N_oonfX009gooo]Z1?l0000IoookJP[o0000>ooonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000OOoo
nfX4o`0001Wooo]Z2_l0001joookJP00WOoonfX4o`0001Wooo]Z2ol0001HoookJPGo0000OOoonfX4
o`0001Wooo]Z2ol0001ioookJP00WOoonfX4o`0001[ooo]Z2_l0001HoookJPGo0000OOoonfX4o`00
01[ooo]Z2_l0001ioookJP00WOoonfX4o`0001oooo]Z1_l0001GoookJPGo0000OOoonfX4o`0001oo
oo]Z1Ol0001ioookJP00WOoonfX4o`00023ooo]Z1Ol0001GoookJPGo0000OOoonfX4o`00023ooo]Z
1Ol0001hoookJP00WOoonfX4o`00023ooo]Z1Ol0001GoookJPGo0000OOoonfX4o`00023ooo]Z1Ol0
001hoookJP00WOoonfX4o`00027ooo]Z1Ol0001FoookJPGo0000OOoonfX4o`00023ooo]Z1_l0001g
oookJP00WOoonfX4o`00027ooo]Z1_l0001EoookJPGo0000OOoonfX4o`00027ooo]Z1_l0001foook
JP00WOoonfX4o`00027ooo]Z2ol0001@oookJPGo0000OOoonfX4o`00027ooo]Z3?l0001`oookJP00
W?oonfX5o`0002;ooo]Z2ol0001?oookJPGo0000OOoonfX4o`0002;ooo]Z2ol0001`oookJP00W?oo
nfX5o`0002?ooo]Z2ol0001>oookJPGo0000OOoonfX4o`0002?ooo]Z2_l0001`oookJP00W?oonfX5
o`0002?ooo]Z2ol0001>oookJPGo0000O?oonfX5o`0002?ooo]Z2ol0001_oookJP00W?oonfX4o`00
02Gooo]Z2ol0001=oookJPGo0000O?oonfX5o`0002Cooo]Z2ol0001^oookJP008_oonfX3o`00OgGo
oo]Z0_l007l4o`0000?ooo]Z0ol007l3oookJPGo001o7OoonfX5o`0004gooo]Z1Ol0001doookJPGo
001o0ooonfX5o`0000;ooo]Z1Ol007lRoookJPOo0000COoonfX3o`00Oagooo]Z000RoookJP?o001o
M?oonfX3o`00O`Co00000ooonfX3o`00O`;ooo]Z1ol007lLoookJPKo0000C?oonfX5o`0007?ooo]Z
1ol007l2oookJPCo00000_oonfX7o`00Ob;ooo]Z1_l0001=oookJP?o001o7OoonfX002;ooo]Z0ol0
07mdoookJP?o001o1?l00003oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007lMoookJPKo0000BooonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo
000000?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lSoookJPKo0000C?oonfX3o`00
Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o00?ooo]Zo`000?l0
00000_l000000ol007oooo]ZoookJP04oookJP?o001o0ooonfX3o`00Oacooo]Z3?l00015oookJPGo
0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`000004oookJ_l007oo001oo`00
O`?ooo]Z0ol007lSoookJP_o0000A_oonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOo
oo]Z2_l007l2oookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o
001o7OoonfX<o`0004Cooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o
00001ooonfX3o`00Ob?ooo]Z3?l00015oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o
00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o001o7_oonfX;o`0004Cooo]Z
1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00001ooonfX3o`00Ob?ooo]Z
3?l00015oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l0
00000ol007oooo]ZoookJP05oookJP;o001o0_oonfX4o`00Oakooo]Z3?l00013oookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l007l2oookJPCo001o9?oo
nfX<o`0004Cooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002
o`000003o`00Oooonf[ooo]Z00Gooo]Z1ol007lVoookJPKo0000@_oonfX5o`0007;ooo]Z0ol007l3
oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJPOo001o;?oonfX5o`0004Cooo]Z0ol007lM
oookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z
00Gooo]Z1_l007lWoookJPKo0000@_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`00
0?l000000_l00002oookJPKo001o;OoonfX6o`0004?ooo]Z0ol007lMoookJP007ooonfX6o`00Og?o
oo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l/oookJPco
0000>ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP;o
001o<_oonfX<o`0003Wooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z
0_l007l]oookJPgo0000>OoonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo
00000_oonfX2o`00Oc;ooo]Z3Ol0000hoookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o
1?l00009oookJPOo001o9ooonfX=o`0003Wooo]Z1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z
1ol007l]oookJPgo0000>OoonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00002Ooo
nfX7o`00ObSooo]Z3Ol0000hoookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPOo001o;_oo
nfX=o`0003Wooo]Z0ol007lMoookJP00W?oonfX4o`0003oooo]Z3_l0000`oookJPGo0000O?oonfX4
o`0003oooo]Z3_l0001AoookJP00W?oonfX4o`00043ooo]Z3Ol0000`oookJPGo0000O?oonfX4o`00
043ooo]Z3_l0001@oookJP00W?oonfX4o`00047ooo]Z3Ol0000_oookJPGo0000O?oonfX4o`00047o
oo]Z3_l0001?oookJP00W?oonfX4o`0004;ooo]Z5ol0000ToookJPGo0000O?oonfX4o`0004;ooo]Z
5Ol00017oookJP00W?oonfX4o`0004?ooo]Z6ol0000OoookJPGo0000O?oonfX4o`0004?ooo]Z5_l0
0015oookJP00W?oonfX4o`0004[ooo]Z6?l00004oookJPCo00004ooonfX5o`0007cooo]Z1?l0001;
oookJQOo00001?oonfX4o`0003Cooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000LoookJPOo00000ooonfX7o`00
00?ooo]Z2?l000000ooonf[o0000o`00000Eo`0004cooo]Z1?l0001[oookJPGo00001?oonfX7o`00
00;ooo]Z2?l00003oookJPOo00000ooonfX8o`000003oookJ_l0003o000001Ko0000BooonfX4o`00
06_ooo]Z1_l00003oookJPOo00001?oonfX00ol0003ooo]ZoookJP0LoookJP00<_oonfX4o`0000Co
oo]Z5ol0001;oookJPCo0000OOoonfX5o`0001;ooo]Z1Ol00003oookJQOo0000BooonfX4o`0009ko
oo]Z000loookJPGo00000ooonfX?o`000003oookJ_l0003o000000?o0000@ooonfX4o`0007gooo]Z
1Ol0000LoookJPGo00000ooonfX>o`000003oookJ_l0003o000000Co0000@_oonfX5o`0009kooo]Z
0015oookJQKo0000@OoonfX4o`0007gooo]Z1Ol0000UoookJQGo0000@OoonfX5o`0009kooo]Z001=
oookJPko0000@OoonfX4o`0007gooo]Z1Ol0000]oookJPko0000@?oonfX5o`0009kooo]Z001>oook
JPko0000@?oonfX4o`0007gooo]Z1Ol0000^oookJPko0000?ooonfX4o`0009oooo]Z001?oookJPko
0000?ooonfX4o`0007gooo]Z1Ol0000_oookJPko0000?_oonfX4o`0009oooo]Z001GoookJPgo0000
>?oonfX4o`0007gooo]Z1Ol0000goookJPgo0000=ooonfX4o`0009oooo]Z001HoookJPgo0000=ooo
nfX4o`0007gooo]Z1Ol0000hoookJPco0000=ooonfX4o`0009oooo]Z001IoookJPco0000=ooonfX4
o`0007gooo]Z1Ol0000ioookJPco0000=_oonfX4o`0009oooo]Z001IoookJPgo0000=_oonfX4o`00
07gooo]Z1Ol0000joookJPco0000=OoonfX4o`0009oooo]Z001KoookJP_o0000=OoonfX5o`0007go
oo]Z1Ol0000koookJPCo000000?ooo]Zo`000?l000001?l0000eoookJPCo0000WooonfX0067ooo]Z
1_l0000doookJPGo0000OOoonfX5o`00047ooo]Z1_l0000doookJPCo0000WooonfX006;ooo]Z2ol0
000^oookJPGo0000OOoonfX5o`0004;ooo]Z3Ol0000/oookJPCo0000WooonfX006;ooo]Z3?l0000]
oookJPCo0000O_oonfX5o`0004;ooo]Z3_l0000[oookJPCo0000WooonfX006?ooo]Z3?l0000/oook
JPCo0000O_oonfX5o`0004?ooo]Z3_l0000ZoookJPCo0000WooonfX006Cooo]Z2ol0000/oookJPCo
0000O_oonfX5o`0004Cooo]Z3_l0000YoookJPCo0000WooonfX006[ooo]Z1_l0000[oookJPCo0000
O_oonfX5o`0004cooo]Z2?l0000WoookJPCo0000WooonfX006_ooo]Z1_l0000ZoookJPCo0000O_oo
nfX5o`0004gooo]Z2?l0000VoookJPCo0000WooonfX006_ooo]Z1_l0000ZoookJPCo0000O_oonfX5
o`0004kooo]Z2?l0000UoookJPCo0000WooonfX006cooo]Z2ol0000ToookJPCo0000O_oonfX5o`00
04oooo]Z2?l0000ToookJPCo0000WooonfX006gooo]Z2ol0000SoookJPCo0000O_oonfX5o`00057o
oo]Z1ol0000SoookJPCo0000WooonfX006gooo]Z2ol0000SoookJPCo0000O_oonfX5o`0005;ooo]Z
1_l0000SoookJPCo0000WooonfX006kooo]Z2ol0000RoookJPCo0000O_oonfX5o`0005?ooo]Z1_l0
000RoookJPCo0000WooonfX006oooo]Z2_l0000RoookJPCo0000O_oonfX5o`0005Cooo]Z1_l0000Q
oookJPCo0000WooonfX007Cooo]Z1Ol0000RoookJPCo0000O_oonfX5o`0005Cooo]Z1ol0000Poook
JPCo0000WooonfX007Gooo]Z1Ol0000QoookJPCo0000O_oonfX5o`0005Gooo]Z1ol0000OoookJPCo
0000WooonfX007Gooo]Z1_l0000PoookJPCo0000O_oonfX5o`0005Kooo]Z1ol0000NoookJPCo0000
WooonfX007Gooo]Z1_l0000PoookJPCo0000O_oonfX5o`0005Oooo]Z1ol0000MoookJPCo0000Wooo
nfX007Kooo]Z1Ol0000PoookJPCo0000O_oonfX5o`0005Sooo]Z1_l0000MoookJPCo0000WooonfX0
07Oooo]Z2_l0000JoookJPCo0000O_oonfX5o`0005Wooo]Z1_l0000LoookJPCo0000WooonfX007Oo
oo]Z2ol0000IoookJPCo0000O_oonfX5o`0005[ooo]Z1_l0000KoookJPCo0000WooonfX007Oooo]Z
3?l0000HoookJPCo0000O_oonfX5o`0005[ooo]Z1ol0000JoookJPCo0000WooonfX007Sooo]Z2ol0
000HoookJPCo0000O_oonfX5o`0005_ooo]Z1ol0000IoookJPCo0000WooonfX007Wooo]Z2_l0000H
oookJPCo0000O_oonfX5o`0005cooo]Z1ol0000HoookJPCo0000WooonfX007oooo]Z1?l0000Hoook
JPCo0000H?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0005gooo]Z1_l0000Hoook
JPCo0000WooonfX007oooo]Z1?l0000HoookJPCo0000GooonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o2OoonfX5o`0005kooo]Z1_l0000GoookJPCo0000WooonfX007oooo]Z1Ol0000GoookJPCo0000
GooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00O`Wooo]Z1Ol0001OoookJPGo00005ooonfX4o`0009oooo]Z001ooookJPGo
00005ooonfX4o`0005kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo
0000GooonfX6o`0001Kooo]Z1?l0002OoookJP00OooonfX5o`0001Oooo]Z1?l0001NoookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000GooonfX5o`0001Kooo]Z1?l0002OoookJP00P?oo
nfX5o`0001Kooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000H?oo
nfX5o`0001Gooo]Z1Ol0002OoookJP00P?oonfX5o`0000;ooo]Z1?l0000?oookJPGo0000G_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001QoookJPCo00000_oonfX4
o`0000oooo]Z1Ol0002OoookJP00P?oonfX<o`0000kooo]Z1Ol0001NoookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l9oookJPGo0000HOoonfX;o`0000kooo]Z1Ol0002OoookJP00POoonfX;o`0000ko
oo]Z1Ol0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000HOoonfX;o`0000ko
oo]Z1?l0002PoookJP00POoonfX;o`0000kooo]Z1?l0001OoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l>oookJPGo0000HOoonfX<o`0000gooo]Z1?l0002PoookJP00P_oonfX;o`0000gooo]Z1?l0
001PoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001RoookJP_o0000
3OoonfX4o`000:3ooo]Z0023oookJP[o00003OoonfX4o`00063ooo]Z1ol007l9oookJPOo001o2?oo
nfX5o`0006?ooo]Z2_l0000=oookJPCo0000X?oonfX008?ooo]Z2_l0000=oookJPCo0000HOoonfX5
o`00O`[ooo]Z1ol007l8oookJPGo0000I?oonfX4o`000003oookJ_l0003o000000;o00003OoonfX4
o`000:3ooo]Z0029oookJPCo00003OoonfX4o`0007oooo]Z1Ol0001YoookJPGo00003?oonfX4o`00
0:3ooo]Z0029oookJPCo00003OoonfX4o`0007oooo]Z1Ol0001YoookJPGo00003?oonfX4o`000:3o
oo]Z0029oookJPGo00003?oonfX4o`0007oooo]Z1Ol0001YoookJPGo00003?oonfX4o`000:3ooo]Z
0029oookJPGo00003?oonfX4o`0007oooo]Z1Ol0001ZoookJPGo00002ooonfX4o`000:3ooo]Z0029
oookJPGo00003?oonfX4o`0007oooo]Z1Ol0001ZoookJPGo00002ooonfX4o`000:3ooo]Z002:oook
JPGo00000_oonfX4o`0000Gooo]Z1?l0001ooookJPGo0000J_oonfX5o`0000;ooo]Z1?l00005oook
JPCo0000X?oonfX008[ooo]Z1Ol00002oookJPGo00001?oonfX4o`0007oooo]Z1Ol0001[oookJPGo
000000?ooo]Zo`000?l000000ol00004oookJPCo0000X?oonfX008[ooo]Z1Ol000000ooonf[o0000
o`000004o`0000Cooo]Z1?l0001ooookJPGo0000JooonfX;o`0000Cooo]Z1?l0002PoookJP00Rooo
nfX<o`0000?ooo]Z1?l0001ooookJPGo0000JooonfX<o`0000?ooo]Z1?l0002PoookJP00RooonfX<
o`0000?ooo]Z1?l0001ooookJPGo0000K?oonfX;o`0000?ooo]Z1?l0002PoookJP00RooonfX<o`00
00;ooo]Z1Ol0001ooookJPGo0000K?oonfX;o`0000?ooo]Z1?l0002PoookJP00S?oonfX;o`0000;o
oo]Z1Ol0001ooookJPGo0000K?oonfX;o`0000?ooo]Z1?l0002PoookJP00S?oonfX;o`0000;ooo]Z
1Ol0001ooookJPGo0000K?oonfX<o`0000;ooo]Z1?l0002PoookJP00S?oonfX<o`000003oookJ_l0
003o000000;o0000P?oonfX5o`0006cooo]Z3?l00002oookJPCo0000X?oonfX008gooo]Z1Ol00000
0ooonf[o0000o`000003o`000003oookJ_l0003o000000;o0000P?oonfX5o`0006gooo]Z1Ol00000
0ooonf[o0000o`000003o`0000;ooo]Z1?l0002PoookJP00SOoonfX4o`0000;ooo]Z1Ol000000ooo
nf[o0000o`000002o`00083ooo]Z1Ol0001]oookJPCo00000ooonfX4o`0000;ooo]Z1?l0002Poook
JP00U?oonfX4o`000003oookJ_l0003o000000;o0000P?oonfX5o`0007Cooo]Z1?l000000ooonf[o
0000o`000003o`000:3ooo]Z002DoookJPCo000000?ooo]Zo`000?l000000_l00020oookJPGo0000
M?oonfX4o`000003oookJ_l0003o000000?o0000X?oonfX009Cooo]Z1?l000000ooonf[o0000o`00
0002o`00083ooo]Z1Ol0001doookJPCo000000?ooo]Zo`000?l000000ol0002PoookJP00U?oonfX4
o`000003oookJ_l0003o000000;o0000P?oonfX5o`0007Cooo]Z1?l000000ooonf[o0000o`000002
o`000:7ooo]Z002DoookJPCo000000?ooo]Zo`000?l000000_l00020oookJPGo0000M?oonfX9o`00
0:7ooo]Z002DoookJPWo0000P?oonfX5o`0007Cooo]Z2Ol0002QoookJP00U?oonfX9o`00083ooo]Z
1Ol0001doookJPWo0000XOoonfX009Cooo]Z2Ol00020oookJPGo0000MOoonfX8o`000:7ooo]Z002E
oookJPSo0000P?oonfX5o`0007Gooo]Z2?l0002QoookJP00UOoonfX8o`00083ooo]Z1Ol0001eoook
JPSo0000XOoonfX009Gooo]Z2?l00020oookJPGo0000MOoonfX8o`000:7ooo]Z002EoookJPSo0000
P?oonfX5o`0007Gooo]Z2?l0002QoookJP00UOoonfX8o`00083ooo]Z1Ol0001eoookJPSo0000XOoo
nfX009Gooo]Z2?l0001coookJP?o001o2_oonfX5o`0007Gooo]Z2?l0002QoookJP00UOoonfX8o`00
07?ooo]Z0ol007l:oookJPGo0000MOoonfX8o`000:7ooo]Z002EoookJPSo0000LooonfX3o`00O`[o
oo]Z1Ol0001foookJPOo0000XOoonfX009Gooo]Z2?l0001coookJP?o001o2_oonfX5o`0007Kooo]Z
1ol0002QoookJP00UOoonfX8o`0007?ooo]Z0ol007l:oookJPKo0000MOoonfX7o`000:7ooo]Z002F
oookJPOo0000LooonfX3o`00O`[ooo]Z1Ol0001foookJPOo0000XOoonfX009Kooo]Z1ol0001coook
JP?o001o2_oonfX5o`0007Kooo]Z1ol0002QoookJP00U_oonfX6o`0007Cooo]Z0ol007l:oookJPGo
0000M_oonfX6o`000:;ooo]Z002FoookJPKo0000M?oonfX3o`00O`[ooo]Z1Ol0001foookJPKo0000
X_oonfX009Oooo]Z1Ol0001aoookJPKo001o2_oonfX5o`0007Kooo]Z1_l0002RoookJP00UooonfX5
o`00077ooo]Z1_l007l:oookJPGo0000MooonfX5o`000:;ooo]Z002GoookJPCo0000M?oonfX4o`00
O`[ooo]Z1Ol0001goookJPGo0000X_oonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003ooookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol0
07l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003o
oookJQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2Ooo
nfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003o
oookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z
1ol007l8oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z
1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00oooonfX>
oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooook
JQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o
2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3
o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oook
JP00oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z
;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.04262 .30855 L
.04376 .30791 L
.04498 .30744 L
.04561 .30731 L
.04631 .30727 L
.04754 .30748 L
.0487 .30796 L
.04995 .3087 L
.0522 .31019 L
.05288 .31058 L
.05363 .31092 L
.05434 .31114 L
.055 .31125 L
.05624 .31119 L
.05693 .31101 L
.05756 .31077 L
.06011 .30932 L
.06122 .30867 L
.06244 .30812 L
.0637 .30786 L
.06438 .30786 L
.06502 .30797 L
.06572 .30819 L
.06636 .30848 L
.06781 .30939 L
.07022 .31114 L
.07089 .31155 L
.07159 .31191 L
.07286 .31231 L
.07408 .31234 L
.07522 .31207 L
.07648 .3115 L
.07784 .31073 L
.07903 .31005 L
.0803 .30951 L
.08137 .30929 L
.08255 .30935 L
.08327 .30956 L
.08404 .30992 L
.08477 .31036 L
.08544 .31085 L
.08807 .31301 L
.08943 .31393 L
.09021 .3143 L
.09093 .31452 L
.0917 .31462 L
.09239 .31458 L
.0932 .31441 L
.09396 .31413 L
Mistroke
.09642 .31285 L
.09713 .3125 L
.0978 .31223 L
.09904 .31194 L
.09976 .31194 L
.10042 .31206 L
.10115 .31232 L
.10192 .31274 L
.10319 .3137 L
.10458 .315 L
.1058 .31618 L
.1071 .31728 L
.10778 .31773 L
.10852 .31811 L
.10984 .31844 L
.11107 .31834 L
.11177 .31814 L
.1124 .31789 L
.11365 .31729 L
.11481 .31674 L
.11586 .31635 L
.11698 .31618 L
.11822 .31637 L
.11935 .31692 L
.12053 .31785 L
.12181 .31916 L
.12413 .32177 L
.12535 .32294 L
.12665 .32382 L
.1274 .32412 L
.12808 .32425 L
.12877 .32426 L
.12942 .32416 L
.1301 .32396 L
.13082 .32369 L
.1321 .32311 L
.13277 .32283 L
.13349 .32259 L
.13428 .32244 L
.13502 .32243 L
.13624 .32278 L
.13693 .32318 L
.13757 .32368 L
.13887 .32503 L
.14026 .32682 L
.14254 .32985 L
.14384 .33122 L
.14506 .33208 L
.1463 .33248 L
.147 .33251 L
Mistroke
.14764 .33242 L
.14831 .33224 L
.14904 .33197 L
.15037 .33143 L
.15161 .33106 L
.15292 .33105 L
.15416 .33153 L
.15528 .33244 L
.15788 .33595 L
.16061 .34033 L
.16205 .34211 L
.16286 .34283 L
.16362 .34329 L
.16431 .34353 L
.16495 .34361 L
.16568 .34355 L
.16638 .34338 L
.16763 .34292 L
.16832 .34265 L
.16896 .34244 L
.1701 .34228 L
.17135 .34257 L
.17201 .34296 L
.17271 .34358 L
.17395 .34516 L
.17529 .34744 L
.17675 .35032 L
.1792 .35489 L
.17991 .35591 L
.18057 .3567 L
.18181 .35768 L
.18299 .358 L
.18407 .35787 L
.18526 .35743 L
.18652 .35689 L
.18773 .35661 L
.18906 .35685 L
.1903 .35782 L
.19146 .35941 L
.19261 .3616 L
.19364 .36397 L
.19597 .36971 L
.19719 .37238 L
.19848 .37453 L
.19916 .37531 L
.1999 .37588 L
.2012 .37619 L
.20242 .37582 L
.20374 .37507 L
.20498 .3744 L
Mistroke
.20611 .37417 L
.20725 .37456 L
.20846 .37586 L
.20949 .37772 L
.21062 .38052 L
.21299 .38784 L
.21429 .39191 L
.21553 .39519 L
.21667 .3974 L
.21793 .3987 L
.21906 .39887 L
.22012 .3983 L
.22122 .39724 L
.22221 .39614 L
.22335 .3951 L
.22443 .39473 L
.22559 .39533 L
.22683 .39738 L
.22801 .40069 L
.22908 .40471 L
.23173 .41664 L
.2329 .42146 L
.23419 .42551 L
.23542 .42761 L
.23672 .42774 L
.23741 .42698 L
.23814 .42563 L
.23948 .42222 L
.24076 .41871 L
.24145 .41709 L
.2421 .41598 L
.24324 .41537 L
.2445 .41732 L
.24565 .42188 L
.2469 .42974 L
.24917 .44928 L
.25025 .45892 L
.25139 .46764 L
.25236 .47275 L
.25343 .47475 L
.25467 .471 L
.2558 .46097 L
.25711 .4411 L
.25835 .41436 L
.26297 .27479 L
.26422 .23679 L
.26556 .20104 L
.26684 .1744 L
.26801 .15706 L
.26907 .14749 L
Mistroke
.27023 .14337 L
.27144 .14525 L
.27257 .15141 L
.27532 .17508 L
.27668 .18657 L
.27793 .19492 L
.27906 .19995 L
.28026 .20246 L
.28147 .20234 L
.28216 .20134 L
.2828 .19995 L
.28489 .19428 L
.28594 .19185 L
.28708 .1903 L
.28833 .19036 L
.28948 .19219 L
.29055 .19527 L
.29169 .19969 L
.29425 .2113 L
.29551 .21635 L
.29667 .21993 L
.29773 .22208 L
.29885 .22318 L
.29997 .22319 L
.3012 .22231 L
.3025 .2209 L
.3037 .21972 L
.30502 .21912 L
.30569 .21924 L
.30643 .21975 L
.30766 .22152 L
.30835 .22299 L
.30898 .22459 L
.31138 .23201 L
.31251 .23558 L
.31373 .23894 L
.31487 .24139 L
.31591 .24289 L
.31708 .24374 L
.31818 .24383 L
.31938 .24337 L
.32068 .2426 L
.32197 .24197 L
.32319 .24188 L
.32388 .24214 L
.32452 .2426 L
.32526 .24341 L
.32595 .24445 L
.32734 .24717 L
.32863 .25024 L
Mistroke
.33013 .25398 L
.33155 .25714 L
.33277 .25928 L
.33346 .26016 L
.33409 .26077 L
.33522 .26135 L
.3364 .26139 L
.33768 .26099 L
.33887 .26047 L
.34018 .26007 L
.34091 .26004 L
.34158 .26018 L
.34276 .26088 L
.34387 .26207 L
.34508 .26393 L
.34639 .26638 L
.34888 .27125 L
.35013 .27327 L
.35085 .27418 L
.3515 .27483 L
.3527 .27556 L
.35398 .27575 L
.35516 .2755 L
.35628 .27508 L
.35731 .27469 L
.35839 .27444 L
.35958 .27452 L
.36067 .275 L
.36196 .27613 L
.36313 .27762 L
.36578 .28183 L
.36695 .28365 L
.36823 .28528 L
.36944 .28636 L
.37056 .28691 L
.37124 .28703 L
.37198 .287 L
.37268 .28686 L
.37332 .28665 L
.37462 .28612 L
.37583 .2857 L
.37713 .28552 L
.37782 .28561 L
.37855 .28586 L
.37933 .28631 L
.38006 .2869 L
.38143 .28838 L
.38365 .29135 L
.38488 .29293 L
.38604 .29418 L
Mistroke
.38669 .29472 L
.38741 .29518 L
.38866 .29559 L
.38993 .29554 L
.39112 .29517 L
.39234 .29464 L
.39299 .29435 L
.39367 .29408 L
.39493 .29379 L
.39609 .29384 L
.39677 .29404 L
.39741 .29435 L
.39811 .29482 L
.39887 .29545 L
.40139 .29819 L
.40254 .29946 L
.40376 .3006 L
.40439 .30107 L
.4051 .30147 L
.40634 .30183 L
.4075 .30178 L
.40876 .3014 L
.40994 .30085 L
.41103 .30031 L
.41209 .29987 L
.41307 .29963 L
.41415 .29962 L
.41531 .29993 L
.41653 .30062 L
.41767 .30155 L
.41982 .3036 L
.42097 .30463 L
.42221 .30549 L
.42338 .30598 L
.42444 .30611 L
.42569 .30591 L
.4264 .30566 L
.42705 .30536 L
.42824 .30472 L
.42953 .30405 L
.43023 .30375 L
.43088 .30355 L
.43214 .30342 L
.4333 .30362 L
.43451 .30418 L
.43582 .30509 L
.43704 .3061 L
.43837 .30719 L
.43907 .30769 L
.43982 .30814 L
Mistroke
.44106 .30864 L
.44221 .30876 L
.44329 .30859 L
.44448 .30813 L
.44669 .30688 L
.44766 .30636 L
.44872 .30592 L
.44988 .30568 L
.45109 .30575 L
.45173 .30593 L
.45242 .30621 L
.45365 .30693 L
.45585 .30854 L
.45701 .30931 L
.45826 .30991 L
.45896 .3101 L
.4596 .31018 L
.46086 .31006 L
.46153 .30985 L
.46227 .30953 L
.4636 .30878 L
.46493 .30796 L
.46618 .3073 L
.46731 .3069 L
.46852 .30677 L
.46923 .30684 L
.46998 .30704 L
.47062 .3073 L
.47131 .30767 L
.47275 .30859 L
.47429 .30961 L
.47503 .31004 L
.47574 .31037 L
.47705 .31073 L
.47829 .31071 L
.47899 .31055 L
.47963 .31032 L
.48079 .30973 L
.48203 .30895 L
.48311 .30828 L
.48429 .30765 L
.485 .30738 L
.48566 .30721 L
.48696 .30715 L
.48815 .30743 L
.48942 .30802 L
.49076 .30884 L
.49222 .30977 L
.49288 .31014 L
.49359 .31047 L
Mistroke
.49486 .31082 L
.49607 .31083 L
.49721 .31055 L
.49845 .30997 L
.49979 .30915 L
.50111 .30832 L
.50235 .30766 L
.50364 .30724 L
.50433 .30717 L
.50507 .3072 L
.50631 .30753 L
.50762 .30817 L
.50996 .30965 L
.51128 .31037 L
.51202 .31066 L
.5127 .31083 L
.51401 .31088 L
.51524 .31057 L
.51595 .31027 L
.51669 .30987 L
.51802 .30905 L
.51959 .3081 L
.52028 .30776 L
.52103 .30748 L
.52225 .30727 L
.52341 .30739 L
.52406 .30759 L
.52474 .30788 L
.52597 .30859 L
.5282 .31008 L
.52945 .31076 L
.53061 .31116 L
.53127 .31126 L
.53199 .31125 L
.53275 .31112 L
.53346 .31089 L
.53475 .31026 L
.53614 .30942 L
.53748 .30863 L
.53876 .30808 L
.5399 .30786 L
.54115 .30795 L
.54237 .30839 L
.54349 .30904 L
.54601 .31086 L
.54716 .3116 L
.54823 .31209 L
.54935 .31235 L
.55057 .3123 L
.55122 .31213 L
Mistroke
.55192 .31187 L
.5532 .31121 L
.55434 .31054 L
.55559 .30987 L
.55629 .30958 L
.55695 .30938 L
.55764 .30928 L
.55838 .3093 L
.55907 .30943 L
.55973 .30967 L
.56096 .31036 L
.56349 .31238 L
.56488 .31346 L
.56618 .31421 L
.56729 .31456 L
.56848 .3146 L
.56912 .31448 L
.5698 .31427 L
.57102 .31371 L
.57232 .31301 L
.57355 .3124 L
.57422 .31215 L
.57496 .31197 L
.57625 .31198 L
.577 .31218 L
.57779 .31255 L
.57847 .31298 L
.57921 .31356 L
.58198 .31617 L
.58318 .3172 L
.58446 .318 L
.5852 .31829 L
.58587 .31842 L
.58718 .31836 L
.5884 .31798 L
.58972 .31735 L
.59086 .3168 L
.59212 .31633 L
.59333 .31618 L
.59447 .31639 L
.59567 .317 L
.59695 .31806 L
.59926 .32059 L
.60028 .32172 L
.6014 .32282 L
.6027 .32375 L
.60341 .32406 L
.60408 .32423 L
.60482 .32427 L
.60549 .32418 L
Mistroke
.60623 .32398 L
.60701 .32369 L
.60823 .32314 L
.60954 .32263 L
.6103 .32246 L
.61098 .32242 L
.61167 .32251 L
.61232 .32273 L
.61353 .32348 L
.61481 .32474 L
.6171 .32771 L
.62228 .33245 L
.66018 .35789 L
.68127 .37436 L
.70054 .39473 L
.70168 .39523 L
.70292 .39714 L
.70408 .4003 L
.70516 .40424 L
.70774 .41581 L
.70894 .42092 L
.71007 .42471 L
.71132 .4273 L
.71199 .42788 L
.7127 .42787 L
.71344 .4272 L
.71415 .42602 L
.71546 .4228 L
.71663 .41955 L
.71786 .41666 L
.7185 .41572 L
.71921 .41533 L
.72046 .41675 L
.72172 .42128 L
.72292 .42847 L
.72517 .44743 L
.72634 .45803 L
.72758 .46769 L
.7283 .47172 L
.72895 .47401 L
.73023 .4738 L
.7314 .467 L
.73249 .4545 L
.73368 .43378 L
.73494 .40455 L
.73937 .26795 L
.74059 .23147 L
.74192 .19722 L
.74317 .17194 L
.74433 .15559 L
Mistroke
.74537 .14682 L
.74652 .1433 L
.74772 .14558 L
.74884 .15197 L
.75142 .17426 L
.75283 .18629 L
.75414 .19505 L
.75526 .19999 L
.75646 .20247 L
.75714 .20268 L
.75779 .2022 L
.759 .19993 L
.76105 .19435 L
.76209 .19192 L
.76323 .19033 L
.76446 .19032 L
.76562 .19206 L
.76668 .19506 L
.76782 .19944 L
.77037 .21096 L
.77162 .21606 L
.77279 .21973 L
.77384 .22196 L
.77496 .22314 L
.7762 .22318 L
.77733 .22237 L
.77855 .22106 L
.77986 .21975 L
.78109 .21913 L
.78221 .21942 L
.78348 .22087 L
.78467 .22332 L
.78597 .22688 L
.78737 .23136 L
.7897 .23838 L
.79087 .24104 L
.79217 .24297 L
.79327 .24374 L
.79446 .24382 L
.79558 .24337 L
.7966 .24276 L
.79782 .2421 L
.79912 .24185 L
.80034 .24231 L
.80145 .24342 L
.80276 .24556 L
.80418 .24868 L
.80675 .255 L
.80815 .25794 L
.80945 .25994 L
Mistroke
.81011 .26062 L
.81082 .26112 L
.8116 .26139 L
.81231 .26143 L
.81357 .26111 L
.81428 .26081 L
.81494 .26052 L
.81615 .26011 L
.81743 .26009 L
.81856 .26058 L
.8198 .26175 L
.8211 .26363 L
.8223 .26583 L
.8246 .2704 L
.82573 .27239 L
.82678 .27387 L
.828 .27508 L
.82865 .27546 L
.82933 .27569 L
.83043 .27572 L
.83165 .2754 L
.83295 .27489 L
.83366 .27464 L
.83434 .27448 L
.83566 .27449 L
.83686 .27501 L
.85513 .28606 L
.86007 .29165 L
.86125 .29314 L
.86249 .29441 L
.86355 .29515 L
.86472 .29557 L
.86536 .29562 L
.86605 .29555 L
.8673 .29518 L
.86873 .29455 L
.86943 .29425 L
.87008 .29401 L
.8713 .29377 L
.87194 .29379 L
.87262 .29392 L
.87372 .29442 L
.87494 .29535 L
.87716 .29771 L
.8795 .30022 L
.88073 .30117 L
.88143 .30153 L
.88207 .30175 L
.88321 .30184 L
.88442 .30159 L
Mistroke
.88558 .30112 L
.88682 .3005 L
.88792 .3 L
.88909 .29966 L
.89014 .2996 L
.8913 .29985 L
.89235 .30038 L
.89333 .30109 L
.89574 .30334 L
.89706 .30455 L
.89831 .30544 L
.89902 .30579 L
.89979 .30603 L
.90048 .30611 L
.90113 .30608 L
.9024 .30574 L
.90304 .30546 L
.90374 .3051 L
.90501 .30441 L
.90621 .30384 L
.90687 .30361 L
.90759 .30345 L
.90885 .30347 L
.91005 .30384 L
.91133 .30459 L
.91362 .30642 L
.91469 .30728 L
.91581 .30803 L
.91704 .30858 L
.91817 .30876 L
.91923 .30865 L
.92021 .30834 L
.92129 .30781 L
.92244 .30715 L
.9237 .30644 L
.92436 .30613 L
.92506 .30587 L
.92635 .30566 L
.92753 .30581 L
.92867 .30625 L
.92973 .30687 L
.93216 .30862 L
.93341 .30943 L
.93405 .30975 L
.93475 .31001 L
.93599 .31019 L
.93715 .31003 L
.93782 .30982 L
.93852 .3095 L
.93977 .30879 L
Mistroke
.94113 .30795 L
.94188 .30753 L
.94259 .3072 L
.94387 .30682 L
.94504 .30679 L
.94613 .30703 L
.94731 .30756 L
.94978 .30915 L
.95108 .30996 L
.95181 .31032 L
.95248 .31056 L
.95373 .31076 L
.9549 .31062 L
.95599 .31024 L
.95717 .30961 L
.95957 .30812 L
.96026 .30775 L
.96092 .30747 L
.96213 .30716 L
.96329 .30717 L
.96435 .30743 L
.96552 .30797 L
.96675 .30871 L
.96882 .31 L
.96998 .31054 L
.97103 .31082 L
.97169 .31087 L
.9724 .31081 L
.9737 .31043 L
.97499 .30977 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00X?oonfX4
o`0007Wooo]Z1Ol00021oookJPCo0000VOoonfX00:3ooo]Z1Ol0001hoookJPGo0000POoonfX4o`00
09Wooo]Z002PoookJPGo0000N?oonfX5o`00083ooo]Z1Ol0002IoookJP00X?oonfX5o`0006_ooo]Z
0ol007l:oookJPGo0000P?oonfX5o`0009Wooo]Z002PoookJPKo0000J_oonfX3o`00O`[ooo]Z1Ol0
0020oookJPKo0000V?oonfX00:3ooo]Z1_l0001ZoookJP?o001o2_oonfX5o`0007oooo]Z1ol0002H
oookJP00WooonfX7o`0005[ooo]Z2_l007l6oookJP?o001o2_oonfX5o`0007oooo]Z1ol0002Hoook
JP00WooonfX7o`0005[ooo]Z2_l007l6oookJP?o001o2_oonfX6o`0007kooo]Z1ol0002HoookJP00
WooonfX7o`0006[ooo]Z0ol007l:oookJPGo0000OooonfX7o`0009Sooo]Z002OoookJPOo0000J_oo
nfX3o`00O`[ooo]Z1Ol0001ooookJPOo0000V?oonfX009oooo]Z1ol0001ZoookJP?o001o2_oonfX5
o`0007oooo]Z1ol0002HoookJP00WooonfX7o`0006[ooo]Z0ol007l:oookJPGo0000OooonfX7o`00
09Sooo]Z002OoookJPSo0000I_oonfX6o`00O`[ooo]Z1Ol0001ooookJPSo0000UooonfX009oooo]Z
2?l0001VoookJPKo001o2_oonfX5o`0007oooo]Z2?l0002GoookJP00WooonfX8o`0006Sooo]Z1?l0
07l:oookJPGo0000OooonfX8o`0009Oooo]Z002OoookJPSo0000JOoonfX3o`00O`[ooo]Z1Ol0001o
oookJPSo0000UooonfX009oooo]Z2?l0001foookJPGo0000OooonfX8o`0009Oooo]Z002OoookJPSo
0000M_oonfX5o`0007oooo]Z2?l0002GoookJP00WooonfX8o`0007Kooo]Z1Ol0001ooookJPSo0000
UooonfX009oooo]Z2?l0001foookJPGo0000OooonfX8o`0009Oooo]Z002OoookJPSo0000M_oonfX5
o`0007oooo]Z2?l0002GoookJP00WooonfX9o`0007Gooo]Z1Ol0001ooookJPWo0000U_oonfX009oo
oo]Z2Ol0001eoookJPGo0000OooonfX9o`0009Kooo]Z002OoookJPWo0000MOoonfX5o`0007kooo]Z
2_l0002FoookJP00WooonfX4o`000003oookJ_l0003o000000;o0000MOoonfX5o`0007kooo]Z1Ol0
00000ooonf[o0000o`000002o`0009Kooo]Z002NoookJPGo000000?ooo]Zo`000?l000000_l0001e
oookJPGo0000O_oonfX5o`000003oookJ_l0003o000000;o0000U_oonfX009kooo]Z1Ol000000ooo
nf[o0000o`000002o`0000;ooo]Z1?l0001_oookJPGo0000O_oonfX4o`0000;ooo]Z1?l00002oook
JPCo0000T?oonfX009kooo]Z1Ol000000ooonf[o0000o`000009o`0006kooo]Z1Ol0001noookJPCo
00000_oonfX;o`0008oooo]Z002NoookJPCo00000_oonfX;o`0006kooo]Z1Ol0001noookJPCo0000
0_oonfX<o`0008kooo]Z002NoookJPCo00000_oonfX;o`0006kooo]Z1Ol0001noookJPCo00000_oo
nfX<o`0008kooo]Z002NoookJPCo00000ooonfX;o`0006gooo]Z1Ol0001noookJPCo00000ooonfX;
o`0008kooo]Z002NoookJPCo00000ooonfX;o`0006gooo]Z1Ol0001noookJPCo00000ooonfX;o`00
08kooo]Z002NoookJPCo00000ooonfX;o`0006gooo]Z1Ol0001noookJPCo00000ooonfX;o`0008ko
oo]Z002NoookJPCo00000ooonfX6o`000003oookJ_l0003o000000;o0000KOoonfX5o`0007kooo]Z
1?l00003oookJPKo000000?ooo]Zo`000?l000000ol0002=oookJP00W_oonfX4o`0000?ooo]Z1_l0
00000ooonf[o0000o`000002o`0006gooo]Z1Ol0001noookJPCo00000ooonfX6o`000003oookJ_l0
003o000000?o0000SOoonfX009kooo]Z1?l00004oookJPGo000000?ooo]Zo`000?l000000ol0001/
oookJPGo0000O_oonfX4o`0000Cooo]Z1Ol000000ooonf[o0000o`000003o`0008gooo]Z002Noook
JPCo00002_oonfX5o`0006cooo]Z1Ol0001noookJPCo00002ooonfX5o`0008cooo]Z002NoookJPCo
00002_oonfX5o`0006cooo]Z1Ol0001noookJPCo00002ooonfX5o`0008cooo]Z002NoookJPCo0000
2ooonfX4o`0006cooo]Z1Ol0001noookJPCo00002ooonfX5o`0008cooo]Z002NoookJPCo00002ooo
nfX5o`0006_ooo]Z1Ol0001moookJPGo00003?oonfX4o`0008cooo]Z002NoookJPCo00002ooonfX5
o`0006_ooo]Z1Ol0001moookJPGo00003?oonfX4o`0008cooo]Z002NoookJPCo00002ooonfX5o`00
0003oookJ_l0003o000000?o0000IOoonfX5o`0007gooo]Z1Ol0000<oookJPCo000000?ooo]Zo`00
0?l000000ol00026oookJP00WOoonfX5o`0000cooo]Z2_l0001UoookJPGo0000OOoonfX4o`0000go
oo]Z2ol00025oookJP00WOoonfX5o`0000cooo]Z2ol0001ToookJPGo0000OOoonfX4o`0000gooo]Z
2ol00025oookJP00WOoonfX5o`0000cooo]Z2ol0001ToookJPGo0000OOoonfX4o`0000gooo]Z2ol0
0025oookJP00WOoonfX4o`0000kooo]Z2_l00016oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:
oookJPGo0000OOoonfX4o`0000kooo]Z2_l00025oookJP00WOoonfX4o`0000kooo]Z2ol00014oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000OOoonfX4o`0000kooo]Z2ol00024oook
JP00WOoonfX4o`0000oooo]Z2_l00014oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000@
oookJPWo0000Q?oonfX009gooo]Z1?l0000DoookJPKo0000=_oonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000OOoonfX4o`0001Cooo]Z1_l00023oook
JP00WOoonfX4o`0001Gooo]Z1Ol0000foookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2?oonfX6o`0007cooo]Z1?l0000EoookJPGo0000PooonfX009gooo]Z1?l0000EoookJPGo0000
@_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0007gooo]Z1?l0000EoookJPGo0000
PooonfX009gooo]Z1?l0000FoookJPCo0000@_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z1Ol0001moookJPCo00005_oonfX5o`0008;ooo]Z002MoookJPCo00005_oonfX5
o`00047ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001moookJPCo00005_oonfX5
o`0008;ooo]Z002MoookJPCo00005_oonfX6o`00043ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
O`[ooo]Z1Ol0001moookJPCo00005_oonfX6o`00087ooo]Z002MoookJPCo00005_oonfX;o`0003_o
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001moookJPCo00005ooonfX:o`0007co
oo]Z002MoookJPCo00005ooonfX;o`0003_ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o3_oonfX5o`0007gooo]Z1?l0000GoookJP[o0000O?oonfX009gooo]Z1?l0000HoookJP[o0000
>ooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000OOoonfX4o`0001Sooo]Z2_l0001koookJP00WOoo
nfX4o`0001Sooo]Z2_l0000loookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001moookJPCo00006?oo
nfX;o`0007[ooo]Z002MoookJPCo00006OoonfX4o`000003oookJ_l0003o000000?o0000FOoonfX5
o`0007gooo]Z1?l0000IoookJP[o0000N_oonfX009gooo]Z1?l0000NoookJPGo0000FOoonfX5o`00
07gooo]Z1?l0000NoookJPGo0000N_oonfX009gooo]Z1?l0000NoookJPKo0000F?oonfX5o`0007go
oo]Z1?l0000OoookJPGo0000NOoonfX009gooo]Z1?l0000OoookJPGo0000F?oonfX5o`0007gooo]Z
1?l0000OoookJPGo0000NOoonfX009gooo]Z1?l0000OoookJPKo0000EooonfX5o`0007gooo]Z1?l0
000OoookJPKo0000N?oonfX009gooo]Z1?l0000PoookJPGo000000?ooo]Zo`000?l000000_l0001B
oookJPGo0000OOoonfX4o`00023ooo]Z1_l0001goookJP00WOoonfX4o`00023ooo]Z2ol0001Aoook
JPGo0000OOoonfX4o`00023ooo]Z2ol0001boookJP00WOoonfX4o`00027ooo]Z2_l0001AoookJPGo
0000OOoonfX4o`00027ooo]Z2ol0001aoookJP00WOoonfX4o`00027ooo]Z2ol0001@oookJPGo0000
OOoonfX4o`0002;ooo]Z2_l0001aoookJP00WOoonfX4o`0002;ooo]Z2ol0001?oookJPGo0000OOoo
nfX4o`0002;ooo]Z2ol0001`oookJP00WOoonfX4o`0002Oooo]Z1_l0001?oookJPGo0000OOoonfX4
o`0002Sooo]Z1Ol0001`oookJP00WOoonfX4o`0002Sooo]Z1_l0001>oookJPGo0000OOoonfX4o`00
02Sooo]Z1_l0001_oookJP008_oonfX3o`00OgGooo]Z0ol007l4o`0000;ooo]Z0ol007l3oookJPGo
001o7?oonfX5o`0004kooo]Z1Ol0001doookJPGo001o1?oonfX4o`0000;ooo]Z1Ol007lRoookJPKo
0000C_oonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX4o`00O`Co00000_oonfX3o`00O`;ooo]Z
1ol007lKoookJP_o0000B?oonfX5o`0007?ooo]Z1ol007l3oookJPCo000000?ooo]Zo`00Ool007l0
1Ol007lQoookJP_o0000BOoonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`03oookJ_l0
003o000000;o00000_oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
7?oonfX;o`0004Oooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`0000Co
001o00Cooo]Zo`00Ool007oo001o8_oonfX<o`0004Oooo]Z0ol007lMoookJP004ooonfX:o`00O`Go
oo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1?l00006oookJP?o001o0ooonfX3o`00Oa_o
oo]Z3?l00016oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00000ol007l3oookJP?o
001o8_oonfX<o`0004Kooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o
0_oonfX3o`00O`;ooo]Z1?l0000<oookJP?o001o7?oonfX;o`0004Kooo]Z1Ol0001boookJP?o001o
0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o8_oonfX>o`0004Cooo]Z0ol007lMoookJP008_oo
nfX3o`00Og?ooo]Z0ol007l2oookJPCo00003?oonfX3o`00Oagooo]Z2ol00015oookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l2oookJPCo00001_oonfX3o`00Ob?ooo]Z3_l00013oookJP?o001o7Ooo
nfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4o`0000Oooo]Z0_l007l2oookJPCo001o8ooonfX6
o`0004Cooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02
oookJPCo001o:_oonfX9o`00047ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oook
JPCo00001ooonfX7o`00ObCooo]Z3?l0000noookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oook
JPCo000000?ooo]Zo`00Ool007l01Ol007l/oookJPWo0000@?oonfX3o`00Oagooo]Z000RoookJP?o
001oLooonfX3o`00O`;ooo]Z1?l00007oookJPKo001o9_oonfX<o`0003gooo]Z1Ol0001boookJP?o
001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`04o`00Oboooo]Z2?l0000ooookJP?o
001o7OoonfX001oooo]Z1_l007mcoookJP?o001o0_oonfX4o`0000Oooo]Z0_l007l[oookJPco0000
??oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o03Cooo]Z
2?l0000koookJPKo001o7OoonfX001oooo]Z1_l007mdoookJP?o001o00?ooo]Zo`000?l000000_l0
0007oookJP;o001o;?oonfX<o`0003_ooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX4o`000003oookJ_l007oo001o03Kooo]Z1ol0000joookJPKo001o7OoonfX0027ooo]Z1?l0
07mdoookJPCo001o1?l00008oookJPOo001o9_oonfX=o`0003[ooo]Z1Ol0001coookJPOo001o0_oo
nfX5o`0000;ooo]Z1ol007laoookJPSo0000>_oonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX3
o`00O`Co00002?oonfX7o`00Obgooo]Z3Ol0000coookJPGo0000M?oonfX5o`00O`?ooo]Z1Ol00002
oookJPOo001o<_oonfX>o`0003Cooo]Z0ol007lMoookJP00WOoonfX4o`0003gooo]Z3Ol0000boook
JPGo0000O?oonfX5o`0003cooo]Z3Ol0001DoookJP00WOoonfX4o`0003kooo]Z3Ol0000aoookJPGo
0000O?oonfX4o`0003kooo]Z3_l0001BoookJP00W?oonfX5o`0003kooo]Z5Ol0000YoookJPGo0000
O?oonfX4o`0003oooo]Z5Ol0001:oookJP00W?oonfX5o`0003oooo]Z5Ol0000XoookJPGo0000O?oo
nfX4o`00043ooo]Z5?l0001:oookJP00W?oonfX5o`0004Oooo]Z3_l000000ooonf[o0000o`000005
o`0001oooo]Z1Ol0001loookJPCo0000AooonfX>o`0000;ooo]Z1_l00011oookJP00W?oonfX4o`00
04Sooo]Z5ol00002oookJPKo00005_oonfX5o`0007cooo]Z1?l00019oookJQGo00000ooonfX6o`00
03Oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z
000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oook
J_oo0000ool0000Uo`0000oooo]Z000MoookJP03o`000?oonf[ooo]Z00[ooo]Z1ol00003oookJQOo
000000?ooo]Zo`000?l000001Ol00019oookJPCo0000I_oonfX6o`0000?ooo]Z1ol00003oookJPWo
000000?ooo]Zo`000?l000001Ol00002oookJPSo00000_oonfXOo`0004Wooo]Z1?l0001WoookJPGo
00000ooonfX7o`0000?ooo]Z1ol0000NoookJP00=OoonfX6o`0000?ooo]Z5Ol00019oookJPCo0000
OOoonfX5o`0001Gooo]Z1_l00002oookJQOo0000B?oonfX4o`0009kooo]Z000noookJPOo000000?o
oo]Zo`000?l000003?l00018oookJPCo0000OOoonfX5o`0001oooo]Z1_l000000ooonf[o0000o`00
000=o`0004Oooo]Z1?l0002NoookJP00AooonfX>o`000003oookJ_l0003o000000Co0000@?oonfX4
o`0007gooo]Z1Ol0000WoookJPko000000?ooo]Zo`000?l000001?l00010oookJPCo0000W_oonfX0
04Sooo]Z5Ol0000ooookJPCo0000OOoonfX5o`0002Wooo]Z5?l0000ooookJPCo0000W_oonfX0053o
oo]Z3Ol0000ooookJPCo0000OOoonfX5o`00037ooo]Z3?l0000ooookJPCo0000W_oonfX0057ooo]Z
3Ol0000noookJPCo0000OOoonfX5o`00037ooo]Z3Ol0000noookJPCo0000W_oonfX005;ooo]Z3Ol0
000moookJPCo0000OOoonfX5o`0003;ooo]Z3Ol0000moookJPCo0000W_oonfX005Wooo]Z3Ol0000f
oookJPCo0000OOoonfX5o`0003Wooo]Z1ol0000loookJPCo0000W_oonfX005[ooo]Z3?l0000foook
JPCo0000OOoonfX5o`0003[ooo]Z2?l0000joookJPCo0000W_oonfX005_ooo]Z3?l0000eoookJPCo
0000OOoonfX5o`0003_ooo]Z2?l0000ioookJPCo0000W_oonfX005cooo]Z3?l0000doookJPCo0000
OOoonfX5o`0003cooo]Z2Ol0000goookJPCo0000W_oonfX005gooo]Z2ol0000doookJPCo0000OOoo
nfX5o`0003gooo]Z2Ol0000eoookJPGo0000W_oonfX006?ooo]Z1_l0000coookJPCo0000OOoonfX5
o`0003oooo]Z2Ol0000coookJPGo0000W_oonfX006Cooo]Z2ol0000]oookJPCo0000OOoonfX5o`00
043ooo]Z2Ol0000boookJPGo0000W_oonfX006Cooo]Z3?l0000/oookJPCo0000OOoonfX5o`0004;o
oo]Z2Ol0000`oookJPCo0000WooonfX006Gooo]Z2ol0000[oookJPGo0000OOoonfX5o`0004?ooo]Z
2Ol0000_oookJPCo0000WooonfX006Kooo]Z2ol0000ZoookJPGo0000OOoonfX5o`0004Gooo]Z2Ol0
000]oookJPCo0000WooonfX006Oooo]Z2ol0000YoookJPGo0000OOoonfX5o`0004Kooo]Z2Ol0000/
oookJPCo0000WooonfX006cooo]Z1_l0000YoookJPCo0000O_oonfX5o`0004Sooo]Z2Ol0000Zoook
JPCo0000WooonfX006gooo]Z1_l0000XoookJPCo0000O_oonfX5o`0004Wooo]Z2Ol0000YoookJPCo
0000WooonfX006kooo]Z1_l0000WoookJPCo0000O_oonfX5o`0004_ooo]Z2Ol0000WoookJPCo0000
WooonfX006kooo]Z2ol0000RoookJPCo0000O_oonfX5o`0004cooo]Z2Ol0000VoookJPCo0000Wooo
nfX006oooo]Z2ol0000QoookJPCo0000O_oonfX5o`0004kooo]Z2Ol0000ToookJPCo0000WooonfX0
06oooo]Z2ol0000QoookJPCo0000O_oonfX5o`0004oooo]Z2Ol0000SoookJPCo0000WooonfX0073o
oo]Z2_l0000QoookJPCo0000O_oonfX5o`00057ooo]Z2?l0000RoookJPCo0000WooonfX0077ooo]Z
2_l0000PoookJPCo0000O_oonfX5o`0005;ooo]Z2Ol0000PoookJPCo0000WooonfX007Kooo]Z1Ol0
000PoookJPCo0000O_oonfX5o`0005Cooo]Z2?l0000OoookJPCo0000WooonfX007Kooo]Z1_l0000O
oookJPCo0000O_oonfX5o`0005Gooo]Z2Ol0000MoookJPCo0000WooonfX007Oooo]Z1Ol0000Ooook
JPCo0000O_oonfX5o`0005Kooo]Z2Ol0000LoookJPCo0000WooonfX007Oooo]Z1_l0000NoookJPCo
0000O_oonfX5o`0005Sooo]Z2?l0000KoookJPCo0000WooonfX007Sooo]Z2_l0000IoookJPCo0000
O_oonfX5o`0005Wooo]Z2?l0000JoookJPCo0000WooonfX007Sooo]Z2ol0000HoookJPCo0000O_oo
nfX5o`0005_ooo]Z1ol0000IoookJPCo0000WooonfX007Wooo]Z2ol0000GoookJPCo0000O_oonfX5
o`0005cooo]Z1ol0000HoookJPCo0000WooonfX007Wooo]Z2ol0000GoookJPCo0000O_oonfX5o`00
05gooo]Z1ol0000GoookJPCo0000WooonfX007[ooo]Z2_l0000GoookJPCo0000H?oonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`0005kooo]Z1ol0000FoookJPCo0000WooonfX0083ooo]Z
1?l0000GoookJPCo0000GooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0005oooo]Z
1ol0000EoookJPCo0000WooonfX0083ooo]Z1?l0000GoookJPCo0000GooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wo
oo]Z1Ol0001PoookJPOo00004ooonfX5o`0009oooo]Z0020oookJPGo00005_oonfX4o`0005kooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000HOoonfX7o`0001;ooo]Z
1Ol0002OoookJP00P?oonfX5o`0001Kooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l8oookJPKo0000HOoonfX7o`00017ooo]Z1Ol0002OoookJP00P?oonfX5o`0001Kooo]Z1?l0001N
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000HooonfX7o`00013ooo]Z1?l0002P
oookJP00POoonfX5o`0001Cooo]Z1Ol0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oook
JPCo001o2?oonfX5o`0006Cooo]Z1ol0000?oookJPCo0000X?oonfX0087ooo]Z1Ol00002oookJPCo
00003_oonfX5o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001UoookJPOo
00003_oonfX4o`000:3ooo]Z0021oookJP_o00003_oonfX5o`0005kooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00O`[ooo]Z1Ol0001VoookJPKo00003_oonfX4o`000:3ooo]Z0022oookJP_o00003Ooo
nfX4o`0005oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001WoookJPKo00003Ooo
nfX4o`000:3ooo]Z0022oookJP_o00003OoonfX4o`00063ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJP;o001o3_oonfX5o`0006Sooo]Z1Ol0000=oookJPCo0000X?oonfX008?ooo]Z2ol0000<
oookJPCo0000H?oonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000J?oonfX6o`0000cooo]Z1?l0002P
oookJP00PooonfX;o`0000cooo]Z1?l0001QoookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001Yoook
JPGo00003?oonfX4o`000:3ooo]Z0024oookJP[o00003?oonfX4o`0007oooo]Z1Ol0001YoookJPGo
00003?oonfX4o`000:3ooo]Z002:oookJPCo00003?oonfX4o`0007oooo]Z1Ol0001ZoookJPCo0000
3?oonfX4o`000:3ooo]Z002:oookJPGo00002ooonfX4o`0007oooo]Z1Ol0001ZoookJPGo00002ooo
nfX4o`000:3ooo]Z002:oookJPGo00002ooonfX4o`0007oooo]Z1Ol0001ZoookJPGo00002ooonfX4
o`000:3ooo]Z002:oookJPGo00002ooonfX4o`0007oooo]Z1Ol0001ZoookJPGo00002ooonfX4o`00
0:3ooo]Z002;oookJPGo00002_oonfX4o`0007oooo]Z1Ol0001[oookJPGo00002_oonfX4o`000:3o
oo]Z002;oookJPGo000000?ooo]Zo`000?l000000ol00004oookJPCo0000OooonfX5o`0006_ooo]Z
1Ol000000ooonf[o0000o`000003o`0000Cooo]Z1?l0002PoookJP00RooonfX5o`000003oookJ_l0
003o000000Co00000ooonfX4o`0007oooo]Z1Ol0001[oookJPGo000000?ooo]Zo`000?l000000ol0
0004oookJPCo0000X?oonfX008cooo]Z1?l000000ooonf[o0000o`000004o`0000?ooo]Z1?l0001o
oookJPGo0000K?oonfX;o`0000?ooo]Z1?l0002PoookJP00S?oonfX;o`0000?ooo]Z1?l0001ooook
JPGo0000K?oonfX;o`0000?ooo]Z1?l0002PoookJP00S?oonfX;o`0000?ooo]Z1?l0001ooookJPGo
0000K?oonfX;o`0000?ooo]Z1?l0002PoookJP00S?oonfX;o`0000?ooo]Z1?l0001ooookJPGo0000
K?oonfX;o`0000?ooo]Z1?l0002PoookJP00S?oonfX<o`0000;ooo]Z1?l0001ooookJPGo0000K?oo
nfX<o`0000;ooo]Z1?l0002PoookJP00S?oonfX<o`000003oookJ_l0003o000000?o0000OooonfX5
o`0006cooo]Z3?l00002oookJPCo0000X?oonfX008gooo]Z2ol000000ooonf[o0000o`000003o`00
07oooo]Z1Ol0001]oookJP_o00000_oonfX4o`000:3ooo]Z002>oookJPGo000000?ooo]Zo`000?l0
00000_l000000ooonf[o0000o`000003o`0007oooo]Z1Ol0001^oookJPGo000000?ooo]Zo`000?l0
00000_l00002oookJPCo0000X?oonfX009Cooo]Z1?l000000ooonf[o0000o`000002o`00083ooo]Z
1Ol0001doookJPCo00000_oonfX4o`000:3ooo]Z002DoookJPCo000000?ooo]Zo`000?l000000_l0
0020oookJPGo0000M?oonfX4o`0000;ooo]Z1?l0002PoookJP00U?oonfX4o`000003oookJ_l0003o
000000;o0000P?oonfX5o`0007Cooo]Z1?l00002oookJPCo0000X?oonfX009Cooo]Z2Ol00020oook
JPGo0000M?oonfX5o`000003oookJ_l0003o000000;o0000X?oonfX009Cooo]Z2Ol00020oookJPGo
0000M?oonfX5o`000003oookJ_l0003o000000;o0000X?oonfX009Cooo]Z2Ol00020oookJPGo0000
M?oonfX5o`000003oookJ_l0003o000000;o0000X?oonfX009Gooo]Z2?l00020oookJPGo0000MOoo
nfX9o`000:3ooo]Z002EoookJPSo0000P?oonfX5o`0007Gooo]Z2Ol0002PoookJP00UOoonfX8o`00
083ooo]Z1Ol0001eoookJPWo0000X?oonfX009Gooo]Z2?l00020oookJPGo0000MOoonfX8o`000:7o
oo]Z002EoookJPSo0000P?oonfX5o`0007Gooo]Z2?l0002QoookJP00UOoonfX8o`00083ooo]Z1Ol0
001eoookJPSo0000XOoonfX009Gooo]Z2?l00020oookJPGo0000MOoonfX8o`000:7ooo]Z002Eoook
JPSo0000LooonfX3o`00O`[ooo]Z1Ol0001eoookJPSo0000XOoonfX009Kooo]Z1ol0001coookJP?o
001o2_oonfX5o`0007Kooo]Z1ol0002QoookJP00U_oonfX7o`0007?ooo]Z0ol007l:oookJPGo0000
M_oonfX7o`000:7ooo]Z002FoookJPOo0000LooonfX3o`00O`[ooo]Z1Ol0001foookJPOo0000XOoo
nfX009Kooo]Z1ol0001coookJP?o001o2_oonfX6o`0007Gooo]Z1ol0002QoookJP00U_oonfX7o`00
07?ooo]Z0ol007l:oookJPGo0000M_oonfX6o`000:;ooo]Z002FoookJPOo0000LooonfX3o`00O`[o
oo]Z1Ol0001foookJPKo0000X_oonfX009Kooo]Z1ol0001coookJP?o001o2_oonfX5o`0007Kooo]Z
1_l0002RoookJP00U_oonfX6o`0007Cooo]Z0ol007l:oookJPGo0000M_oonfX6o`000:;ooo]Z002F
oookJPKo0000LOoonfX6o`00O`[ooo]Z1Ol0001foookJPKo0000X_oonfX009Oooo]Z1Ol0001aoook
JPKo001o2_oonfX5o`0007Oooo]Z1Ol0002RoookJP00UooonfX5o`0007?ooo]Z1?l007l:oookJPGo
0000MooonfX5o`000:;ooo]Z002GoookJPCo0000MOoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z
003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8
oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooook
JQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6
o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooook
JQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z
1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol0
07l8oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0
003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00oooonfX>oook
JPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQko
oo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00
O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00
oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;Ooo
nfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;o
oo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.04262 .31002 L
.04376 .31058 L
.04498 .3109 L
.04561 .31094 L
.04631 .31087 L
.04754 .31048 L
.0487 .30988 L
.04995 .30911 L
.05102 .30845 L
.0522 .30788 L
.05294 .30764 L
.05363 .30753 L
.05429 .30752 L
.055 .30764 L
.05569 .30786 L
.05634 .30816 L
.05756 .30889 L
.05994 .31051 L
.06113 .31114 L
.06244 .31151 L
.06309 .31155 L
.06379 .31147 L
.06505 .31107 L
.0663 .31042 L
.06745 .30972 L
.06878 .30898 L
.06953 .30866 L
.07022 .30846 L
.0715 .30838 L
.07214 .30849 L
.07286 .30874 L
.07532 .31029 L
.07666 .31133 L
.07791 .31218 L
.07899 .31271 L
.08013 .31298 L
.0814 .31291 L
.08255 .31253 L
.08518 .31112 L
.0859 .31075 L
.08666 .31043 L
.08731 .31024 L
.08802 .31015 L
.08878 .31019 L
.08959 .3104 L
.09035 .31075 L
.09105 .31119 L
.09391 .31358 L
.09518 .31458 L
Mistroke
.09588 .31502 L
.09653 .31534 L
.09731 .31558 L
.09801 .31566 L
.09867 .31563 L
.09939 .31547 L
.1007 .31495 L
.10209 .31422 L
.10339 .3136 L
.10458 .31326 L
.1058 .31325 L
.10645 .31341 L
.10714 .31371 L
.10829 .31448 L
.10955 .31562 L
.11192 .31799 L
.11295 .31886 L
.11408 .31954 L
.11532 .3199 L
.11661 .31984 L
.11729 .31965 L
.11802 .31936 L
.11933 .31874 L
.11997 .31844 L
.12066 .31816 L
.12192 .31788 L
.12313 .31799 L
.12426 .31848 L
.12643 .3204 L
.1288 .3232 L
.12988 .32436 L
.13104 .32534 L
.13202 .32588 L
.13311 .32615 L
.13434 .32605 L
.13503 .32585 L
.13567 .3256 L
.13682 .3251 L
.13807 .32464 L
.13922 .32447 L
.14028 .32464 L
.1414 .32522 L
.1426 .3263 L
.14522 .32974 L
.14651 .33153 L
.14769 .33296 L
.14877 .33394 L
.14991 .33456 L
.15106 .33475 L
.15232 .33454 L
Mistroke
.1535 .33411 L
.15458 .33368 L
.15583 .33337 L
.15701 .33343 L
.1581 .33392 L
.15911 .33478 L
.16022 .33613 L
.1614 .33794 L
.16409 .34243 L
.16482 .3435 L
.1656 .34446 L
.16626 .34511 L
.16699 .34563 L
.1683 .34606 L
.16903 .34604 L
.1697 .3459 L
.17101 .34543 L
.17224 .34498 L
.17343 .3448 L
.17468 .34512 L
.17576 .34592 L
.17694 .34739 L
.17821 .34955 L
.17958 .3523 L
.18088 .35498 L
.18206 .35717 L
.18329 .35897 L
.18446 .36005 L
.18569 .36052 L
.18638 .36051 L
.18702 .36037 L
.18817 .35991 L
.18941 .35938 L
.19057 .35914 L
.19164 .35936 L
.19288 .36032 L
.19406 .36201 L
.19534 .36459 L
.19673 .368 L
.19819 .37174 L
.19956 .37486 L
.20079 .37696 L
.20148 .37778 L
.20211 .37828 L
.20335 .3786 L
.20405 .37845 L
.2047 .37816 L
.2061 .37729 L
.20679 .37689 L
.20742 .37662 L
Mistroke
.20811 .37651 L
.20885 .37667 L
.21015 .37781 L
.21082 .37886 L
.21157 .38039 L
.21307 .38449 L
.21559 .39276 L
.21698 .39678 L
.21767 .39835 L
.21831 .3995 L
.21953 .40079 L
.22018 .40097 L
.22087 .40083 L
.2221 .39989 L
.22322 .39861 L
.22434 .39738 L
.22554 .39666 L
.22686 .39714 L
.22809 .39915 L
.22875 .4009 L
.22947 .40328 L
.23078 .40868 L
.23324 .4201 L
.23443 .42479 L
.23556 .42788 L
.23673 .42934 L
.23803 .42877 L
.23914 .42669 L
.24016 .42394 L
.24136 .42041 L
.24246 .41777 L
.24367 .41647 L
.24496 .41794 L
.24616 .42248 L
.2473 .42955 L
.25005 .45402 L
.25126 .46462 L
.25191 .46922 L
.2526 .47293 L
.25388 .47522 L
.25508 .47047 L
.25579 .46411 L
.25646 .45549 L
.25772 .43258 L
.2591 .39827 L
.26038 .35975 L
.26327 .26347 L
.26456 .22399 L
.26592 .18912 L
.26709 .16661 L
Mistroke
.26836 .1505 L
.26908 .14539 L
.26974 .14309 L
.27049 .14298 L
.27121 .14508 L
.27248 .1529 L
.2732 .15891 L
.27386 .16501 L
.27506 .17633 L
.27636 .18732 L
.27758 .19521 L
.2787 .1997 L
.27988 .20153 L
.28114 .20065 L
.28242 .1977 L
.28383 .19359 L
.28509 .19043 L
.28627 .18879 L
.28734 .18886 L
.28849 .19069 L
.28975 .19459 L
.29109 .20024 L
.29347 .21132 L
.29454 .21547 L
.29568 .2188 L
.29676 .22069 L
.29775 .22137 L
.2989 .2211 L
.30016 .21993 L
.30127 .21862 L
.30244 .21749 L
.30365 .21706 L
.30477 .21762 L
.30597 .21934 L
.30728 .22246 L
.30966 .23003 L
.31182 .23661 L
.31246 .23812 L
.31315 .23946 L
.31441 .24103 L
.31511 .24142 L
.31586 .24152 L
.31649 .24138 L
.31719 .24106 L
.31843 .24028 L
.31912 .23987 L
.31977 .23958 L
.32103 .23948 L
.32218 .24012 L
.32351 .2418 L
Mistroke
.3247 .24413 L
.32739 .25083 L
.32859 .25371 L
.32988 .25625 L
.3311 .2579 L
.33222 .2587 L
.33354 .25888 L
.33476 .25852 L
.33551 .25818 L
.33622 .25787 L
.33686 .25764 L
.33755 .25751 L
.33824 .25753 L
.33896 .25776 L
.34027 .25879 L
.34098 .25967 L
.34165 .2607 L
.34318 .26356 L
.34545 .26821 L
.3467 .2704 L
.34788 .27194 L
.34855 .27255 L
.34927 .27298 L
.35054 .27323 L
.35183 .27298 L
.35302 .27252 L
.35425 .27209 L
.35541 .27197 L
.35668 .27233 L
.35739 .2728 L
.35804 .2734 L
.35935 .27505 L
.36078 .27732 L
.36211 .27961 L
.36337 .28159 L
.36454 .28309 L
.36581 .28418 L
.36696 .28464 L
.36802 .28466 L
.36917 .28437 L
.37043 .28388 L
.37175 .28342 L
.37297 .28329 L
.37413 .28357 L
.37522 .28424 L
.37621 .28517 L
.37727 .28646 L
.37968 .28984 L
.38073 .29119 L
.38188 .29239 L
Mistroke
.38308 .29321 L
.38422 .29354 L
.38553 .29345 L
.38674 .29304 L
.38788 .29254 L
.38895 .29213 L
.39018 .29188 L
.3913 .29199 L
.39257 .29256 L
.3932 .29302 L
.3939 .29365 L
.39629 .29637 L
.39764 .29792 L
.39838 .29866 L
.39909 .29924 L
.39974 .29966 L
.40045 .29998 L
.40169 .30017 L
.40291 .29995 L
.40403 .29951 L
.40521 .29894 L
.4065 .29839 L
.40781 .29812 L
.40854 .29814 L
.4092 .29829 L
.41048 .29891 L
.41168 .29985 L
.41441 .30256 L
.41516 .30325 L
.41595 .30388 L
.41663 .3043 L
.41737 .30463 L
.41807 .30479 L
.4187 .30483 L
.41944 .30474 L
.42013 .30454 L
.42137 .304 L
.42272 .30328 L
.42336 .30297 L
.42406 .30268 L
.42532 .30239 L
.42655 .30246 L
.42768 .30288 L
.42891 .30365 L
.43025 .30477 L
.43167 .30601 L
.43297 .30699 L
.43419 .30762 L
.43534 .30788 L
.43656 .30778 L
Mistroke
.43725 .30757 L
.43788 .3073 L
.44009 .30608 L
.44125 .3055 L
.44247 .30512 L
.44378 .30507 L
.44497 .30539 L
.44609 .30597 L
.44732 .30683 L
.44876 .30794 L
.44947 .30846 L
.45012 .30887 L
.45134 .30944 L
.45266 .30967 L
.45398 .30947 L
.45464 .30923 L
.45537 .30888 L
.45677 .30806 L
.45753 .3076 L
.45826 .3072 L
.45894 .30689 L
.45967 .30664 L
.46096 .30649 L
.46226 .30673 L
.46347 .30729 L
.46596 .30895 L
.46661 .30938 L
.46731 .3098 L
.46858 .31034 L
.46929 .31049 L
.46995 .31052 L
.47072 .31043 L
.47145 .31022 L
.47271 .30962 L
.47408 .30879 L
.47538 .308 L
.4766 .30742 L
.47787 .30712 L
.47854 .3071 L
.47927 .30721 L
.48055 .30767 L
.48177 .30836 L
.48297 .30914 L
.48406 .30983 L
.48521 .3104 L
.48629 .31072 L
.48744 .31077 L
.48868 .31048 L
.48976 .30998 L
.49091 .30929 L
Mistroke
.49296 .30802 L
.49412 .3075 L
.49536 .30724 L
.49653 .30732 L
.4976 .30765 L
.49885 .30829 L
.50021 .30915 L
.5015 .30994 L
.50268 .3105 L
.50382 .31077 L
.50502 .31075 L
.50622 .3104 L
.50753 .30973 L
.50876 .30896 L
.50991 .30824 L
.51095 .30771 L
.51208 .30734 L
.51274 .30726 L
.51343 .30728 L
.51468 .30759 L
.516 .30824 L
.51745 .30917 L
.5187 .30996 L
.51939 .31033 L
.52004 .31062 L
.5213 .31092 L
.52245 .31087 L
.52368 .3105 L
.52497 .30983 L
.52639 .30895 L
.5277 .30819 L
.52891 .3077 L
.53005 .30751 L
.53129 .30766 L
.53199 .3079 L
.53263 .3082 L
.53555 .31014 L
.53625 .31059 L
.53699 .31099 L
.53762 .31126 L
.53831 .31146 L
.53959 .31153 L
.54078 .31125 L
.54207 .31066 L
.54346 .30983 L
.54463 .30915 L
.54587 .30861 L
.54659 .30843 L
.54724 .30836 L
.54851 .30854 L
Mistroke
.54982 .30912 L
.55056 .3096 L
.55124 .31009 L
.55257 .31112 L
.55382 .31201 L
.55488 .31258 L
.55601 .31294 L
.55728 .31296 L
.55843 .31266 L
.55963 .3121 L
.56093 .31136 L
.56215 .31072 L
.5633 .31029 L
.56436 .31015 L
.5655 .31031 L
.56677 .31088 L
.56793 .3117 L
.57028 .31373 L
.57153 .31469 L
.57222 .3151 L
.57286 .31539 L
.574 .31565 L
.57509 .31559 L
.57608 .3153 L
.57716 .31481 L
.57838 .31417 L
.57953 .31362 L
.58057 .31329 L
.5817 .31322 L
.58292 .31352 L
.58405 .31416 L
.58528 .31518 L
.58658 .31647 L
.58878 .31858 L
.59001 .31942 L
.59115 .31984 L
.5918 .31992 L
.59252 .31989 L
.59326 .31972 L
.59396 .31947 L
.59534 .31883 L
.5966 .31825 L
.59783 .31791 L
.59899 .31792 L
.60022 .31835 L
.60091 .31879 L
.60155 .31931 L
.61175 .32565 L
.62258 .33138 L
.64207 .34475 L
Mistroke
.66035 .35983 L
.69905 .39904 L
.70029 .39761 L
.70099 .397 L
.70164 .39668 L
.70282 .39694 L
.70408 .39871 L
.70477 .40039 L
.70542 .40241 L
.70689 .4083 L
.7082 .41442 L
.70944 .42016 L
.71061 .42473 L
.71188 .42813 L
.71303 .42938 L
.7141 .42891 L
.71537 .42658 L
.71652 .42342 L
.71787 .41955 L
.7191 .41703 L
.72032 .41661 L
.7216 .41926 L
.72289 .42549 L
.72362 .43052 L
.7243 .43601 L
.7255 .44699 L
.72681 .45919 L
.72804 .46888 L
.72918 .47435 L
.72983 .47532 L
.73054 .47424 L
.73128 .47044 L
.73197 .4642 L
.73319 .44665 L
.73451 .41872 L
.73748 .3296 L
.74021 .2401 L
.74149 .20405 L
.7427 .17683 L
.74379 .15903 L
.74497 .14722 L
.74625 .14273 L
.7469 .14341 L
.74761 .14606 L
.74887 .15448 L
.75004 .16493 L
.75113 .17518 L
.75231 .18546 L
.75342 .19327 L
.75445 .19828 L
Mistroke
.75565 .20121 L
.75692 .2012 L
.758 .1993 L
.75918 .19606 L
.76049 .19229 L
.7612 .19059 L
.76186 .18942 L
.76304 .18863 L
.76432 .18992 L
.76504 .19162 L
.76572 .19379 L
.767 .19898 L
.76839 .20551 L
.76986 .21216 L
.77106 .21655 L
.77237 .21982 L
.77356 .22122 L
.77468 .22131 L
.77599 .22032 L
.77719 .21893 L
.77786 .21819 L
.77858 .21753 L
.7799 .21707 L
.78055 .21729 L
.78123 .21791 L
.78246 .21995 L
.78378 .22334 L
.78522 .22795 L
.78764 .23563 L
.78834 .23742 L
.789 .23884 L
.79023 .24068 L
.79144 .24146 L
.79256 .24142 L
.79378 .24082 L
.79508 .24 L
.79619 .23951 L
.79723 .23948 L
.79837 .24011 L
.7996 .24164 L
.82058 .26607 L
.82182 .26856 L
.82248 .26973 L
.82317 .27081 L
.82444 .2723 L
.82561 .27304 L
.8263 .27321 L
.82695 .27322 L
.82766 .27308 L
.82842 .27283 L
Mistroke
.82907 .27257 L
.82975 .27231 L
.83098 .27199 L
.83222 .27207 L
.83286 .27232 L
.83357 .27279 L
.83484 .27409 L
.83603 .27579 L
.83828 .27957 L
.8395 .28152 L
.84065 .283 L
.84185 .28408 L
.84318 .28464 L
.8443 .28465 L
.8455 .28433 L
.84691 .28376 L
.8476 .28352 L
.84824 .28336 L
.84943 .28332 L
.85073 .28377 L
.85205 .28481 L
.85328 .28622 L
.85608 .29013 L
.85675 .29099 L
.85748 .29183 L
.85813 .29244 L
.85882 .29296 L
.85961 .29335 L
.86035 .29354 L
.86109 .29355 L
.86175 .29344 L
.86296 .29303 L
.86408 .29254 L
.86531 .29207 L
.86663 .29187 L
.86729 .29194 L
.86801 .29216 L
.86932 .29296 L
.8706 .29417 L
.87178 .29552 L
.87289 .29686 L
.87409 .29819 L
.87522 .2992 L
.87625 .29983 L
.87735 .30014 L
.87851 .3001 L
.8797 .29973 L
.881 .29913 L
.88168 .29881 L
.88241 .29849 L
Mistroke
.8831 .29827 L
.88374 .29814 L
.88494 .29817 L
.88622 .29864 L
.88688 .29905 L
.88759 .2996 L
.88887 .30081 L
.89027 .30223 L
.891 .30294 L
.89179 .30361 L
.89252 .30413 L
.89319 .30448 L
.89448 .30482 L
.8958 .3047 L
.89703 .30425 L
.89823 .30364 L
.89951 .30298 L
.90072 .30253 L
.90182 .30237 L
.90297 .30252 L
.90422 .30307 L
.9054 .30389 L
.90649 .30481 L
.90767 .30584 L
.90893 .30684 L
.90965 .30728 L
.91032 .30759 L
.91161 .30788 L
.91278 .30777 L
.91406 .30731 L
.9147 .30698 L
.91539 .3066 L
.91663 .3059 L
.91732 .30556 L
.91806 .30527 L
.91877 .3051 L
.91941 .30504 L
.92064 .30521 L
.92194 .30577 L
.92413 .30731 L
.9252 .30813 L
.92619 .30881 L
.92734 .30937 L
.92858 .30966 L
.92963 .3096 L
.93075 .30926 L
.93198 .30865 L
.93313 .30796 L
.9345 .30718 L
.93576 .30667 L
Mistroke
.93685 .30649 L
.938 .30661 L
.93916 .30702 L
.94043 .30775 L
.94266 .30929 L
.94392 .31001 L
.94508 .31042 L
.9461 .31052 L
.94722 .31035 L
.94839 .30989 L
.94948 .30928 L
.95045 .30867 L
.95152 .30803 L
.95252 .30753 L
.95345 .30722 L
.95453 .3071 L
.95568 .30726 L
.95674 .30767 L
.95771 .3082 L
.95994 .30964 L
.96106 .31025 L
.96229 .31068 L
.96293 .31077 L
.96362 .31077 L
.96486 .31048 L
.9661 .3099 L
.96723 .30921 L
.9683 .30852 L
.96944 .30788 L
.97068 .30739 L
.97183 .30723 L
.9729 .30736 L
.9739 .3077 L
.97501 .30827 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00X?oonfX5
o`0007Sooo]Z1Ol00020oookJPGo0000VOoonfX00:3ooo]Z1Ol0001hoookJPGo0000P?oonfX5o`00
09Wooo]Z002PoookJPGo0000N?oonfX5o`00083ooo]Z1Ol0002IoookJP00WooonfX6o`0006_ooo]Z
0ol007l:oookJPGo0000P?oonfX5o`0009Wooo]Z002OoookJPOo0000J_oonfX3o`00O`[ooo]Z1Ol0
0020oookJPGo0000VOoonfX009oooo]Z1ol0001ZoookJP?o001o2_oonfX5o`00083ooo]Z1_l0002H
oookJP00WooonfX7o`0005[ooo]Z2_l007l6oookJP?o001o2_oonfX5o`0007oooo]Z1ol0002Hoook
JP00WooonfX7o`0005[ooo]Z2_l007l6oookJP?o001o2_oonfX6o`0007kooo]Z1ol0002HoookJP00
WooonfX7o`0006[ooo]Z0ol007l:oookJPGo0000OooonfX7o`0009Sooo]Z002OoookJPOo0000J_oo
nfX3o`00O`[ooo]Z1Ol0001ooookJPOo0000V?oonfX009oooo]Z1ol0001ZoookJP?o001o2_oonfX5
o`0007oooo]Z2?l0002GoookJP00WooonfX7o`0006[ooo]Z0ol007l:oookJPGo0000OooonfX8o`00
09Oooo]Z002OoookJPOo0000IooonfX6o`00O`[ooo]Z1Ol0001ooookJPSo0000UooonfX009oooo]Z
1ol0001WoookJPKo001o2_oonfX5o`0007oooo]Z2?l0002GoookJP00WooonfX7o`0006Wooo]Z1?l0
07l:oookJPGo0000OooonfX8o`0009Oooo]Z002OoookJPOo0000J_oonfX3o`00O`[ooo]Z1Ol0001o
oookJPSo0000UooonfX009oooo]Z2?l0001foookJPGo0000OooonfX8o`0009Oooo]Z002OoookJPSo
0000M_oonfX5o`0007oooo]Z2?l0002GoookJP00WooonfX8o`0007Kooo]Z1Ol0001ooookJPSo0000
UooonfX009oooo]Z2?l0001foookJPGo0000OooonfX8o`0009Oooo]Z002NoookJPWo0000M_oonfX5
o`0007oooo]Z2?l0002GoookJP00W_oonfX9o`0007Kooo]Z1Ol0001ooookJPWo0000U_oonfX009ko
oo]Z2_l0001eoookJPGo0000OooonfX9o`0009Kooo]Z002NoookJPCo000000?ooo]Zo`000?l00000
0ol0001eoookJPGo0000OooonfX9o`0009Kooo]Z002NoookJPCo000000?ooo]Zo`000?l000000ol0
001eoookJPGo0000OooonfX4o`000003oookJ_l0003o000000;o0000U_oonfX009kooo]Z1?l00002
oookJPCo000000?ooo]Zo`000?l000000ol0001_oookJPGo0000OooonfX4o`000003oookJ_l0003o
000000;o000000?ooo]Zo`000?l000000ol0002@oookJP00W_oonfX4o`0000;ooo]Z1?l000000ooo
nf[o0000o`000003o`0006oooo]Z1Ol0001noookJPGo000000?ooo]Zo`000?l000000_l000000ooo
nf[o0000o`000004o`0008oooo]Z002NoookJPCo00000_oonfX:o`0006oooo]Z1Ol0001noookJPGo
000000?ooo]Zo`000?l000002Ol0002?oookJP00W_oonfX4o`0000;ooo]Z2ol0001^oookJPGo0000
O_oonfX5o`000003oookJ_l0003o000000Wo0000SooonfX009kooo]Z1?l00002oookJP_o0000K_oo
nfX5o`0007kooo]Z1?l00002oookJP_o0000SooonfX009kooo]Z1?l00002oookJPco0000KOoonfX5
o`0007kooo]Z1?l00002oookJPco0000S_oonfX009kooo]Z1?l00002oookJPco0000KOoonfX5o`00
07kooo]Z1?l00002oookJPco0000S_oonfX009kooo]Z1?l00002oookJPco0000KOoonfX5o`0007ko
oo]Z1?l00003oookJP_o0000S_oonfX009kooo]Z1?l00003oookJPKo000000?ooo]Zo`000?l00000
0_l0001]oookJPGo0000O_oonfX4o`0000?ooo]Z1_l000000ooonf[o0000o`000002o`0008kooo]Z
002NoookJPCo00000ooonfX5o`0000;ooo]Z1?l0001]oookJPGo0000O_oonfX4o`0000?ooo]Z1_l0
00000ooonf[o0000o`000002o`0008kooo]Z002MoookJPGo00001?oonfX4o`0000;ooo]Z1Ol0001/
oookJPGo0000O_oonfX4o`0000Cooo]Z1?l00002oookJPCo0000S_oonfX009gooo]Z1Ol0000:oook
JPGo0000K?oonfX5o`0007kooo]Z1?l0000:oookJPCo0000S_oonfX009gooo]Z1Ol0000:oookJPGo
0000K?oonfX5o`0007kooo]Z1?l0000:oookJPGo0000SOoonfX009gooo]Z1?l0000<oookJPCo0000
K?oonfX5o`0007kooo]Z1?l0000:oookJPGo0000SOoonfX009gooo]Z1?l0000<oookJPGo0000Jooo
nfX5o`0007kooo]Z1?l0000:oookJPGo0000SOoonfX009gooo]Z1?l0000<oookJP[o0000I_oonfX5
o`0007kooo]Z1?l0000;oookJP[o0000QooonfX009gooo]Z1?l0000<oookJP_o0000IOoonfX5o`00
07kooo]Z1?l0000;oookJP[o0000QooonfX009gooo]Z1?l0000=oookJP[o0000IOoonfX5o`0007ko
oo]Z1?l0000;oookJP_o0000Q_oonfX009gooo]Z1?l0000=oookJP_o0000I?oonfX5o`0007kooo]Z
1?l0000<oookJP[o0000Q_oonfX009gooo]Z1?l0000=oookJP_o0000I?oonfX5o`0007gooo]Z1Ol0
000<oookJP_o0000QOoonfX009gooo]Z1?l0000>oookJP[o0000A_oonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o2_oonfX5o`0007gooo]Z1Ol0000=oookJP[o0000QOoonfX009gooo]Z1?l0000>oook
JPCo00000_oonfX5o`0004Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001moook
JPGo00004_oonfX6o`0008Cooo]Z002MoookJPCo00005?oonfX5o`0004Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9
oookJPGo0000OOoonfX4o`0001Cooo]Z1Ol00024oookJP00WOoonfX4o`0001Cooo]Z1Ol0000goook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001moook
JPCo00005?oonfX5o`0008Cooo]Z002MoookJPCo00005OoonfX4o`0003Oooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000O?oonfX4o`0001Gooo]Z1Ol00023oookJP00
WOoonfX4o`0001Gooo]Z1Ol00012oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000
OOoonfX4o`0001Gooo]Z1Ol00023oookJP00WOoonfX4o`0001Gooo]Z1Ol00012oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0007gooo]Z1?l0000EoookJPGo0000Pooo
nfX009gooo]Z1?l0000EoookJP[o0000?OoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5
o`0007gooo]Z1?l0000FoookJPWo0000O_oonfX009gooo]Z1?l0000FoookJP[o0000??oonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0007gooo]Z1?l0000FoookJP[o0000OOoonfX009go
oo]Z1?l0000FoookJP[o0000??oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0007go
oo]Z1?l0000FoookJP[o0000OOoonfX009gooo]Z1?l0000FoookJP_o0000??oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Oooo]Z2Ol0001moookJP00
WOoonfX4o`0001Oooo]Z2_l0000loookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001moookJPCo0000
5ooonfX:o`0007cooo]Z002MoookJPCo00007?oonfX6o`0003cooo]Z1Ol007l:oookJPOo001o2?oo
nfX5o`0007gooo]Z1?l0000LoookJPKo0000NooonfX009gooo]Z1?l0000MoookJPGo0000F_oonfX5
o`0007gooo]Z1?l0000LoookJPOo0000N_oonfX009gooo]Z1?l0000MoookJPGo0000F_oonfX5o`00
07gooo]Z1?l0000MoookJPOo0000NOoonfX009gooo]Z1?l0000NoookJPGo0000FOoonfX5o`0007go
oo]Z1?l0000NoookJPOo0000N?oonfX009gooo]Z1?l0000NoookJPKo0000F?oonfX5o`0007gooo]Z
1?l0000OoookJPOo0000MooonfX009gooo]Z1?l0000NoookJP_o0000DooonfX5o`0007gooo]Z1?l0
000PoookJPOo0000M_oonfX009gooo]Z1?l0000OoookJP_o0000D_oonfX5o`0007gooo]Z1?l0000Q
oookJPOo0000MOoonfX009gooo]Z1?l0000PoookJP[o0000D_oonfX5o`0007gooo]Z1?l0000Roook
JPOo0000M?oonfX009gooo]Z1?l0000PoookJP_o0000DOoonfX5o`0007gooo]Z1?l0000SoookJPOo
0000LooonfX009gooo]Z1?l0000QoookJP[o0000DOoonfX5o`0007gooo]Z1?l0000ToookJPOo0000
L_oonfX009gooo]Z1?l0000VoookJPKo0000D?oonfX5o`0007gooo]Z1?l0000UoookJPOo0000LOoo
nfX009gooo]Z1?l0000WoookJPGo0000D?oonfX5o`0007gooo]Z1?l0000VoookJPKo0000LOoonfX0
09gooo]Z1?l0000WoookJPKo0000CooonfX5o`0007gooo]Z1?l0000WoookJPKo0000L?oonfX002;o
oo]Z0ol007meoookJP?o001o1?l00002oookJP?o001o0ooonfX5o`00Oa_ooo]Z2ol00019oookJPGo
0000M?oonfX5o`00O`Cooo]Z1?l00002oookJPGo001o8OoonfX;o`0004[ooo]Z0ol007lMoookJP00
8_oonfX3o`00OgCooo]Z1?l007l4o`0000;ooo]Z0ol007l2oookJPOo001o6_oonfX;o`0004Wooo]Z
1Ol0001coookJPOo001o0ooonfX4o`000003oookJ_l007oo001o00Go001o8?oonfX;o`0004[ooo]Z
0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2ol00018oookJPGo0000
LooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1?l00004o`00O`04oookJ_l007oo001oo`00
Ob7ooo]Z2ol00019oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l2oookJPCo00001_oonfX3o`00O`?ooo]Z0ol007lKoookJP_o0000AooonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o0_oonfX4o`0000?o001o0ooonfX3o`00Ob7ooo]Z2_l00019oookJP?o
001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l2oookJPCo0000
3?oonfX3o`00Oa_ooo]Z2ol00017oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo0000
1_oonfX3o`00Ob7ooo]Z2ol00018oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oo
nfX4o`0000cooo]Z0ol007lQoookJPKo0000A_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oo
nfX4o`0000Kooo]Z0ol007lWoookJPKo0000AooonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3
o`00O`;ooo]Z1?l00007oookJP;o001o0_oonfX4o`00Ob;ooo]Z2ol00010oookJPGo0000L_oonfX3
o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Zo`00Ool007l00_oonfX4o`00ObOooo]Z3?l00011
oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4o`0000Oooo]Z1ol007lSoook
JPco0000?ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o
00Go001o:OoonfX<o`00043ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo
00001ooonfX6o`00ObGooo]Z2ol0000ooookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o
0000o`000003o`000003oookJ_l007oo001o00Co001o:ooonfX;o`00043ooo]Z0ol007lMoookJP00
7ooonfX6o`00Og?ooo]Z0ol007l00ooonf[o0000o`000003o`0000Oooo]Z0_l007lZoookJP_o0000
?_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000ol000000ooonf[o001o
o`00O`0`oookJP_o0000??oonfX6o`00Oagooo]Z000OoookJPKo001oM?oonfX3o`00O`Go00001ooo
nfX2o`00Ob[ooo]Z3?l0000moookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z
1Ol000000ooonf[o001oo`00O`0`oookJPco0000>ooonfX6o`00Oagooo]Z000QoookJPCo001oM?oo
nfX3o`00O`Go00002?oonfX7o`00Ob[ooo]Z3Ol0000foookJPGo0000LooonfX7o`00O`;ooo]Z1?l0
0003oookJPOo001o<?oonfX=o`0003Kooo]Z1?l007lMoookJP008_oonfX3o`00OgGooo]Z0_l007l4
o`0000Wooo]Z1ol007l[oookJPgo0000=OoonfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX7
o`00Oc7ooo]Z3Ol0000foookJP?o001o7OoonfX009cooo]Z1?l0000loookJPgo0000=?oonfX5o`00
07cooo]Z1?l0000loookJPgo0000EOoonfX009cooo]Z1?l0000moookJQ?o0000;OoonfX5o`0007co
oo]Z1?l0000moookJQ?o0000C_oonfX009cooo]Z1?l0000noookJPGo000000?ooo]Zo`000?l00000
2ol0000/oookJPGo0000O?oonfX4o`0003kooo]Z1Ol000000ooonf[o0000o`00000;o`0004gooo]Z
002LoookJPCo0000AOoonfX=o`0000?ooo]Z1?l0000ToookJPGo0000O?oonfX4o`0004Cooo]Z3ol0
0002oookJPCo0000AOoonfX009cooo]Z1?l00016oookJQCo00008ooonfX5o`0007cooo]Z1?l00016
oookJQGo0000@ooonfX009cooo]Z1?l00016oookJQko00006OoonfX5o`0007cooo]Z1?l00016oook
JQKo000000?ooo]Zo`000?l000001Ol0000joookJP003_oonf[oo`000?oo00009Ol0000?oookJP00
3_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[o
o`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP007OoonfX01?l0003o
oo]ZoookJ_oonfX;o`0000?ooo]Z1ol000000ooonf[o0000o`00000Eo`0004kooo]Z1?l0001/oook
JPKo00000ooonfX6o`0000;ooo]Z1ol00003oookJPOo00000_oonfX8o`000003oookJ_l0003o0000
01Go0000C_oonfX4o`0006cooo]Z1_l00003oookJPOo00000ooonfX00ol0003ooo]ZoookJP0Loook
JP00>?oonfX7o`000003oookJ_l0003o000001Co0000A_oonfX4o`0007gooo]Z1Ol0000HoookJPOo
000000?ooo]Zo`000?l000005?l00016oookJPCo0000W_oonfX0047ooo]Z5_l00015oookJPCo0000
OOoonfX5o`00027ooo]Z5_l00015oookJPCo0000W_oonfX004?ooo]Z1Ol000000ooonf[o0000o`00
000<o`0004Gooo]Z1?l0001moookJPGo00008ooonfX5o`0000;ooo]Z3ol00013oookJPCo0000W_oo
nfX004_ooo]Z3Ol000000ooonf[o0000o`000003o`0003kooo]Z1?l0001moookJPGo0000:ooonfX@
o`00047ooo]Z1?l0002NoookJP00C?oonfX6o`000003oookJ_l0003o000000[o0000?OoonfX4o`00
07gooo]Z1Ol0000/oookJQ7o0000?ooonfX4o`0009kooo]Z001CoookJPgo0000??oonfX4o`0007go
oo]Z1Ol0000doookJP_o0000?OoonfX4o`0009kooo]Z001DoookJPgo0000>ooonfX4o`0007gooo]Z
1Ol0000foookJP[o0000??oonfX4o`0009kooo]Z001EoookJPco0000>ooonfX4o`0007gooo]Z1Ol0
000hoookJP[o0000>_oonfX4o`0009kooo]Z001LoookJP_o0000=OoonfX4o`0007gooo]Z1Ol0000j
oookJPWo0000>OoonfX4o`0009kooo]Z001MoookJP_o0000=?oonfX4o`0007gooo]Z1Ol0000loook
JPWo0000=ooonfX4o`0009kooo]Z001MoookJPco0000<ooonfX4o`0007gooo]Z1Ol0000moookJP[o
0000=OoonfX4o`0009kooo]Z001NoookJPco0000<OoonfX5o`0007gooo]Z1Ol0000ooookJPWo0000
=?oonfX4o`0009kooo]Z001OoookJP_o0000<OoonfX5o`0007gooo]Z1Ol00010oookJP[o0000<_oo
nfX4o`0009kooo]Z001UoookJPKo0000<?oonfX5o`0007gooo]Z1Ol00012oookJPWo0000<OoonfX4
o`0009kooo]Z001VoookJP[o0000:ooonfX4o`0007kooo]Z1Ol00014oookJPWo0000;ooonfX4o`00
09kooo]Z001VoookJP_o0000:_oonfX4o`0007kooo]Z1Ol00015oookJPWo0000;_oonfX4o`0009ko
oo]Z001WoookJP_o0000:OoonfX4o`0007kooo]Z1Ol00017oookJPSo0000;OoonfX4o`0009kooo]Z
001WoookJPco0000:?oonfX4o`0007kooo]Z1Ol00018oookJPSo0000;?oonfX4o`0009kooo]Z001X
oookJP_o0000:?oonfX4o`0007kooo]Z1Ol0001:oookJPOo0000:ooonfX4o`0009kooo]Z001^oook
JPGo0000:?oonfX4o`0007kooo]Z1Ol0001;oookJPOo0000:OoonfX5o`0009kooo]Z001_oookJPGo
00009ooonfX4o`0007kooo]Z1Ol0001<oookJPOo0000:?oonfX5o`0009kooo]Z001_oookJPKo0000
9_oonfX4o`0007kooo]Z1Ol0001=oookJPOo00009ooonfX5o`0009kooo]Z001_oookJP_o00008Ooo
nfX4o`0007kooo]Z1Ol0001>oookJPOo00009_oonfX4o`0009oooo]Z001`oookJP_o00008?oonfX4
o`0007kooo]Z1Ol0001?oookJPOo00009OoonfX4o`0009oooo]Z001aoookJP[o00008?oonfX4o`00
07kooo]Z1Ol0001@oookJPOo00009?oonfX4o`0009oooo]Z001aoookJP_o00007ooonfX4o`0007ko
oo]Z1Ol0001AoookJPOo00008ooonfX4o`0009oooo]Z001boookJP[o00007ooonfX4o`0007kooo]Z
1Ol0001BoookJPOo00008_oonfX4o`0009oooo]Z001goookJPKo00007_oonfX4o`0007kooo]Z1Ol0
001CoookJPOo00008OoonfX4o`0009oooo]Z001hoookJPGo00007_oonfX4o`0007kooo]Z1Ol0001D
oookJPOo00008?oonfX4o`0009oooo]Z001hoookJPGo00007_oonfX4o`0007kooo]Z1Ol0001Eoook
JPOo00007ooonfX4o`0009oooo]Z001ioookJPCo00007_oonfX4o`0007kooo]Z1Ol0001FoookJPOo
00007_oonfX4o`0009oooo]Z001ioookJPGo00007OoonfX4o`0007kooo]Z1Ol0001GoookJPOo0000
7OoonfX4o`0009oooo]Z001ioookJP_o00005ooonfX4o`0007kooo]Z1Ol0001HoookJPOo00007?oo
nfX4o`0009oooo]Z001ioookJP_o00005ooonfX4o`0007kooo]Z1Ol0001IoookJPOo00006ooonfX4
o`0009oooo]Z001joookJP_o00005OoonfX5o`00063ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
O`[ooo]Z1Ol0001JoookJPOo00006_oonfX4o`0009oooo]Z001koookJP[o00005OoonfX5o`0005oo
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001KoookJPOo00006OoonfX4o`0009oo
oo]Z001loookJP[o00005?oonfX5o`0005oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000G?oonfX7o`00
01Sooo]Z1?l0002OoookJP00POoonfX5o`0001Cooo]Z1?l0001OoookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o2?oonfX5o`0005gooo]Z1ol0000GoookJPCo0000WooonfX0087ooo]Z
1Ol0000DoookJPCo0000GooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0005gooo]Z
1ol0000FoookJPCo0000WooonfX008;ooo]Z1Ol0000CoookJPCo0000GooonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o2?oonfX5o`0005oooo]Z1ol0000EoookJPCo0000WooonfX008;ooo]Z1Ol0000C
oookJPCo0000GooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001P
oookJPOo00005?oonfX4o`0009oooo]Z0022oookJPGo00004ooonfX4o`0005oooo]Z0ol007l3oook
JP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001QoookJPOo00004ooonfX4o`0009oooo]Z0023oookJPGo
00004_oonfX4o`0005oooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001RoookJPOo
00004_oonfX4o`0009oooo]Z0023oookJP[o00003OoonfX4o`0005oooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`kooo]Z1Ol0001SoookJP[o00003OoonfX5o`0009oooo]Z0023oookJP_o00003?oo
nfX4o`00063ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0006Cooo]Z
2_l0000<oookJPGo0000WooonfX008Cooo]Z2_l0000<oookJPCo0000H?oonfX7o`00O`Wooo]Z1ol0
07l8oookJPGo0000IOoonfX9o`0000cooo]Z1Ol0002OoookJP00Q?oonfX:o`0000cooo]Z1?l0001Q
oookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001VoookJPSo00003?oonfX4o`000:3ooo]Z0024oook
JP[o00003?oonfX4o`0007oooo]Z1Ol0001WoookJPOo00003?oonfX4o`000:3ooo]Z0025oookJP[o
00002ooonfX4o`0007oooo]Z1Ol0001ZoookJPGo00002ooonfX4o`000:3ooo]Z002:oookJPGo0000
2ooonfX4o`0007oooo]Z1Ol0001ZoookJPGo00002ooonfX4o`000:3ooo]Z002:oookJPGo00002ooo
nfX4o`0007oooo]Z1Ol0001ZoookJPGo00002ooonfX4o`000:3ooo]Z002;oookJPCo00002ooonfX4
o`0007oooo]Z1Ol0001[oookJPGo00002_oonfX4o`000:3ooo]Z002;oookJPCo00002ooonfX4o`00
07oooo]Z1Ol0001[oookJPGo00002_oonfX4o`000:3ooo]Z002;oookJPGo00000_oonfX4o`0000Co
oo]Z1?l0001ooookJPGo0000JooonfX5o`0000;ooo]Z1?l00004oookJPCo0000X?oonfX008_ooo]Z
1Ol000000ooonf[o0000o`000004o`0000?ooo]Z1?l0001ooookJPGo0000K?oonfX5o`000003oook
J_l0003o000000;o00001?oonfX4o`000:3ooo]Z002;oookJPGo000000?ooo]Zo`000?l000001?l0
0003oookJPCo0000OooonfX5o`0006cooo]Z2ol00003oookJPCo0000X?oonfX008cooo]Z1?l00000
0ooonf[o0000o`000004o`0000?ooo]Z1?l0001ooookJPGo0000K?oonfX;o`0000?ooo]Z1?l0002P
oookJP00S?oonfX;o`0000?ooo]Z1?l0001ooookJPGo0000KOoonfX;o`0000;ooo]Z1?l0002Poook
JP00S?oonfX;o`0000?ooo]Z1?l0001ooookJPGo0000KOoonfX;o`0000;ooo]Z1?l0002PoookJP00
S?oonfX<o`0000;ooo]Z1?l0001ooookJPGo0000KOoonfX;o`0000;ooo]Z1?l0002PoookJP00SOoo
nfX;o`0000;ooo]Z1?l0001ooookJPGo0000KOoonfX;o`0000;ooo]Z1?l0002PoookJP00SOoonfX;
o`0000;ooo]Z1?l0001ooookJPGo0000KOoonfX;o`0000;ooo]Z1?l0002PoookJP00S_oonfX:o`00
00;ooo]Z1?l0001ooookJPGo0000KOoonfX;o`0000;ooo]Z1?l0002PoookJP00S_oonfX5o`000003
oookJ_l0003o000000;o00000_oonfX4o`0007oooo]Z1Ol0001^oookJPGo000000?ooo]Zo`000?l0
00002?l0002PoookJP00U?oonfX5o`000003oookJ_l0003o000000;o0000OooonfX5o`0007Cooo]Z
2_l0002PoookJP00U?oonfX5o`000003oookJ_l0003o000000;o0000OooonfX5o`0007Cooo]Z2_l0
002PoookJP00U?oonfX5o`000003oookJ_l0003o000000;o0000OooonfX5o`0007Gooo]Z2?l0002Q
oookJP00UOoonfX4o`000003oookJ_l0003o000000;o0000OooonfX5o`0007Gooo]Z2?l0002Qoook
JP00UOoonfX4o`000003oookJ_l0003o000000;o0000OooonfX5o`0007Gooo]Z2?l0002QoookJP00
UOoonfX9o`0007oooo]Z1Ol0001eoookJPSo0000XOoonfX009Gooo]Z2Ol0001ooookJPGo0000MOoo
nfX8o`000:7ooo]Z002EoookJPWo0000OooonfX5o`0007Gooo]Z2?l0002QoookJP00UOoonfX8o`00
083ooo]Z1Ol0001eoookJPSo0000XOoonfX009Gooo]Z2?l00020oookJPGo0000MOoonfX8o`000:7o
oo]Z002FoookJPOo0000P?oonfX5o`0007Gooo]Z2?l0002QoookJP00U_oonfX7o`00083ooo]Z1Ol0
001eoookJPSo0000XOoonfX009Kooo]Z1ol0001coookJP?o001o2_oonfX5o`0007Gooo]Z2?l0002Q
oookJP00U_oonfX7o`0007?ooo]Z0ol007l:oookJPGo0000M_oonfX7o`000:7ooo]Z002FoookJPOo
0000LooonfX3o`00O`[ooo]Z1Ol0001foookJPOo0000XOoonfX009Kooo]Z1ol0001coookJP?o001o
2_oonfX5o`0007Kooo]Z1ol0002QoookJP00U_oonfX7o`0007?ooo]Z0ol007l:oookJPKo0000MOoo
nfX7o`000:7ooo]Z002FoookJPOo0000LooonfX3o`00O`[ooo]Z1Ol0001foookJPOo0000XOoonfX0
09Kooo]Z1ol0001coookJP?o001o2_oonfX5o`0007Kooo]Z1ol0002QoookJP00U_oonfX7o`0007?o
oo]Z0ol007l:oookJPGo0000MooonfX6o`000:7ooo]Z002GoookJPKo0000LooonfX3o`00O`[ooo]Z
1Ol0001goookJPKo0000XOoonfX009Oooo]Z1Ol0001aoookJPKo001o2_oonfX5o`0007Oooo]Z1Ol0
002RoookJP00UooonfX5o`00077ooo]Z1_l007l:oookJPGo0000MooonfX5o`000:;ooo]Z002Goook
JPGo0000LooonfX4o`00O`[ooo]Z1Ol0001goookJPGo0000X_oonfX009Sooo]Z1?l0001doookJP?o
001o2_oonfX5o`0007Oooo]Z1Ol0002RoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`?o
oo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3
o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXNoookJP00oooonfX2oookJP?o001o3_oonfX3o`00
O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`So
oo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00o_oonfX6
o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oook
JPGo0000oooonfXOoookJP00oooonfX1oookJPCo001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoo
oo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPCo001o3Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooook
JPoooo]Z1Ol007l:oookJPKo0000oooonfXNoookJP00oooonfXAoookJPCo001o2OoonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol0
07oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oook
JP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRco
oo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z003ooookJPoooo]Z1Ol007oooookJRkooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30828 L
.02605 .30773 L
.02729 .30735 L
.02846 .30732 L
.02954 .30758 L
.03053 .30803 L
.03279 .30943 L
.03388 .31007 L
.03506 .31057 L
.03635 .31077 L
.03756 .3106 L
.03821 .31037 L
.03891 .31004 L
.0402 .30927 L
.04136 .30853 L
.04262 .30786 L
.04332 .30759 L
.04396 .30744 L
.04523 .30742 L
.04638 .30775 L
.04759 .30837 L
.04892 .30923 L
.05034 .31015 L
.05103 .31052 L
.05168 .31079 L
.0529 .31105 L
.05403 .31097 L
.05508 .31064 L
.05623 .31005 L
.05745 .3093 L
.05859 .30862 L
.05982 .30808 L
.06053 .3079 L
.06118 .30784 L
.06244 .30803 L
.10458 .31677 L
.10703 .31584 L
.10832 .31518 L
.10902 .31488 L
.10968 .31468 L
.11088 .31458 L
.11219 .31493 L
.11331 .31561 L
.1145 .31667 L
.11599 .31824 L
.11741 .31969 L
.11868 .32071 L
.11939 .32112 L
.12006 .32136 L
Mistroke
.12134 .32146 L
.1225 .32119 L
.12315 .32094 L
.12384 .32062 L
.12511 .32005 L
.1263 .31967 L
.12742 .31962 L
.12864 .32 L
.12995 .32092 L
.13061 .32157 L
.13132 .32237 L
.13262 .32398 L
.13378 .32541 L
.13506 .32674 L
.13625 .32761 L
.13737 .32802 L
.13854 .32804 L
.13981 .32769 L
.14091 .32723 L
.14194 .32682 L
.14313 .32654 L
.1442 .32662 L
.14536 .32713 L
.14661 .32821 L
.14777 .32963 L
.14884 .33117 L
.15125 .3346 L
.15191 .33536 L
.15262 .33602 L
.1539 .33678 L
.15454 .33693 L
.15523 .33695 L
.15649 .33668 L
.15772 .3362 L
.15886 .3358 L
.16006 .33565 L
.16075 .33577 L
.1614 .33604 L
.1627 .33709 L
.16343 .33797 L
.1641 .33894 L
.16632 .34274 L
.16754 .34483 L
.16869 .34649 L
.16976 .34762 L
.17093 .34831 L
.17199 .34847 L
.17297 .34831 L
.17399 .34794 L
.17509 .34751 L
Mistroke
.1763 .34725 L
.17743 .34743 L
.17867 .34826 L
.1798 .34965 L
.18109 .35188 L
.18231 .35441 L
.18356 .35708 L
.18491 .35969 L
.18618 .36156 L
.18735 .3626 L
.1884 .36296 L
.18957 .36283 L
.19078 .36234 L
.19191 .36183 L
.19254 .36164 L
.19323 .36157 L
.19449 .362 L
.19571 .36326 L
.19684 .36518 L
.19806 .36792 L
.19941 .37143 L
.20074 .37489 L
.20146 .37659 L
.20213 .37797 L
.20327 .37974 L
.20452 .38075 L
.20557 .38087 L
.2067 .38044 L
.20734 .38004 L
.20803 .37957 L
.20928 .37888 L
.2105 .37881 L
.21162 .37958 L
.21269 .38118 L
.21368 .38343 L
.21595 .39051 L
.21817 .39774 L
.2194 .40073 L
.22053 .40238 L
.22117 .40282 L
.22186 .40291 L
.22311 .40218 L
.22436 .40075 L
.22551 .39937 L
.22677 .39847 L
.22749 .39849 L
.22815 .39896 L
.22886 .39999 L
.2295 .40142 L
.23024 .40364 L
Mistroke
.23094 .40624 L
.23324 .4169 L
.2345 .42276 L
.23568 .42721 L
.23695 .43012 L
.23763 .43072 L
.23836 .43061 L
.23965 .42866 L
.24083 .42545 L
.24197 .42192 L
.24318 .4188 L
.24433 .41754 L
.24537 .41852 L
.2466 .42281 L
.24729 .42677 L
.24793 .43131 L
.25033 .45342 L
.25134 .46281 L
.25243 .47092 L
.25362 .47559 L
.25473 .4743 L
.25597 .46486 L
.25715 .44736 L
.25822 .42467 L
.25937 .39334 L
.26389 .24166 L
.26513 .20529 L
.26643 .17493 L
.26754 .15672 L
.26876 .14531 L
.26946 .14259 L
.2701 .14232 L
.27084 .14431 L
.27153 .14806 L
.27277 .15792 L
.27411 .17081 L
.27538 .18261 L
.27607 .18817 L
.27672 .19254 L
.27787 .19797 L
.27913 .20042 L
.28043 .19959 L
.28117 .198 L
.28185 .19609 L
.2832 .19193 L
.28442 .18882 L
.28563 .18732 L
.28677 .18779 L
.28796 .19033 L
.28926 .19506 L
Mistroke
.29202 .20812 L
.29274 .2113 L
.29352 .21425 L
.29425 .21645 L
.29493 .218 L
.29623 .21951 L
.29741 .21941 L
.29872 .21819 L
.30014 .21644 L
.30136 .21534 L
.30248 .21516 L
.30371 .21615 L
.305 .2186 L
.30613 .22173 L
.30718 .22517 L
.30956 .23303 L
.31021 .23481 L
.31091 .23644 L
.31219 .23846 L
.31344 .23925 L
.31458 .23913 L
.31582 .23844 L
.31654 .23795 L
.31719 .23755 L
.31787 .23725 L
.31861 .23714 L
.31929 .23729 L
.31994 .23769 L
.32115 .23914 L
.32183 .24036 L
.32247 .24172 L
.32517 .24864 L
.3263 .25143 L
.32749 .25384 L
.3288 .25561 L
.33 .25637 L
.34096 .26246 L
.34335 .26731 L
.34455 .26912 L
.34523 .26986 L
.34588 .27035 L
.34657 .27067 L
.34721 .27078 L
.34795 .27073 L
.34865 .27055 L
.34989 .27007 L
.35121 .26964 L
.35247 .26961 L
.35361 .27009 L
.35476 .27111 L
Mistroke
.35584 .27254 L
.3583 .27672 L
.35964 .27898 L
.36089 .28069 L
.36194 .28169 L
.36306 .28226 L
.3643 .28236 L
.36543 .28208 L
.36648 .28168 L
.3676 .28127 L
.36855 .28108 L
.3696 .28117 L
.3708 .28172 L
.37192 .2827 L
.37313 .28418 L
.37444 .28608 L
.37559 .28777 L
.37682 .28939 L
.37797 .29055 L
.37902 .29122 L
.38025 .2915 L
.3814 .29136 L
.38265 .29091 L
.38329 .29063 L
.384 .29034 L
.38469 .29012 L
.38533 .28999 L
.386 .28996 L
.38673 .29008 L
.38804 .29072 L
.38924 .29176 L
.39159 .29457 L
.39288 .29612 L
.3941 .29732 L
.39523 .29807 L
.39646 .29842 L
.39758 .29835 L
.3986 .29803 L
.39979 .2975 L
.40105 .29693 L
.40178 .2967 L
.40245 .29658 L
.40374 .29667 L
.40441 .29692 L
.40514 .29733 L
.40583 .29784 L
.40647 .29841 L
.40934 .3014 L
.41048 .30241 L
.4117 .30315 L
Mistroke
.4124 .30338 L
.41304 .30346 L
.41429 .30331 L
.41558 .30281 L
.41698 .30209 L
.41762 .30178 L
.41831 .3015 L
.41954 .30123 L
.42078 .30134 L
.42148 .30159 L
.42214 .30193 L
.42347 .30292 L
.42489 .30421 L
.42621 .30538 L
.42746 .30627 L
.42859 .30676 L
.42981 .3069 L
.4305 .3068 L
.43114 .30661 L
.43185 .30632 L
.43261 .30592 L
.43406 .30512 L
.43485 .30474 L
.43559 .30447 L
.43623 .30433 L
.43692 .30429 L
.43768 .30438 L
.43838 .3046 L
.43969 .30531 L
.44093 .30624 L
.4422 .30726 L
.44338 .30812 L
.44461 .30876 L
.44526 .30896 L
.44596 .30904 L
.44721 .30888 L
.44839 .30842 L
.44945 .30784 L
.45061 .30715 L
.45132 .30677 L
.45199 .30646 L
.45324 .30612 L
.45394 .30609 L
.45459 .30618 L
.4553 .30638 L
.45605 .30672 L
.45864 .30848 L
.45992 .30933 L
.4611 .30991 L
.46225 .31018 L
Mistroke
.46348 .3101 L
.46471 .30967 L
.46541 .30931 L
.46607 .30892 L
.46721 .30821 L
.46827 .30761 L
.46938 .30716 L
.47059 .30697 L
.47183 .30714 L
.47314 .3077 L
.47437 .30845 L
.47548 .3092 L
.47679 .30999 L
.47752 .31032 L
.4782 .31054 L
.47944 .31064 L
.48076 .31035 L
.48292 .30921 L
.48398 .30853 L
.48497 .30796 L
.4861 .30748 L
.48734 .30727 L
.48838 .30737 L
.48949 .30775 L
.49014 .30808 L
.49084 .30849 L
.4921 .3093 L
.49323 .30998 L
.49446 .31052 L
.49564 .31074 L
.49688 .31061 L
.49803 .31018 L
.4991 .30959 L
.50154 .30807 L
.50277 .30753 L
.50347 .30735 L
.50413 .30729 L
.50484 .30735 L
.5055 .3075 L
.50625 .30779 L
.50697 .30816 L
.50824 .30895 L
.50959 .3098 L
.51088 .31044 L
.51205 .31074 L
.51323 .31071 L
.51433 .3104 L
.51563 .30974 L
.51682 .30899 L
.51812 .3082 L
Mistroke
.51883 .30785 L
.51951 .30759 L
.52068 .30738 L
.52174 .30748 L
.52273 .30782 L
.52382 .30839 L
.52606 .30987 L
.52734 .31058 L
.52854 .31098 L
.5297 .31105 L
.53095 .31076 L
.5316 .31049 L
.53228 .31013 L
.5335 .30939 L
.53456 .30875 L
.53569 .3082 L
.53693 .30787 L
.53809 .3079 L
.53932 .3083 L
.54002 .30866 L
.54067 .30908 L
.54211 .31011 L
.54341 .311 L
.54463 .31162 L
.54578 .31192 L
.547 .31187 L
.54769 .31169 L
.54833 .31144 L
.54966 .31073 L
.5511 .30988 L
.55176 .30954 L
.55246 .30925 L
.5537 .309 L
.55445 .30903 L
.55514 .30919 L
.5559 .3095 L
.55671 .30997 L
.55943 .31208 L
.56069 .31297 L
.56132 .31331 L
.56203 .31358 L
.56278 .31373 L
.56349 .31374 L
.56414 .31363 L
.56485 .31341 L
.56735 .31213 L
.56801 .31179 L
.56871 .31147 L
.56998 .31115 L
.57123 .31123 L
Mistroke
.57237 .31167 L
.57302 .31207 L
.57372 .31259 L
.57499 .31372 L
.57622 .31485 L
.57739 .31579 L
.57844 .31641 L
.57958 .31677 L
.58081 .31676 L
.58195 .31643 L
.58318 .31586 L
.58448 .31519 L
.58561 .31475 L
.58666 .31457 L
.58782 .31471 L
.58907 .31531 L
.59949 .32088 L
.60083 .32025 L
.60156 .31994 L
.60226 .31972 L
.60291 .31961 L
.60361 .31962 L
.60484 .32 L
.60552 .32042 L
.60623 .32101 L
.60753 .32238 L
.60894 .32414 L
.61047 .32597 L
.61176 .32717 L
.61295 .32785 L
.61414 .32808 L
.61527 .32793 L
.61658 .32746 L
.61779 .32694 L
.61849 .3267 L
.61912 .32657 L
.61986 .32654 L
.62055 .32666 L
.62171 .32724 L
.62296 .32839 L
.62413 .32987 L
.6252 .33143 L
.62649 .33333 L
.62786 .33509 L
.62903 .33619 L
.63032 .33685 L
.63163 .33693 L
.63286 .33662 L
.63356 .33634 L
.6343 .33605 L
Mistroke
.63562 .33568 L
.63677 .33572 L
.63803 .33633 L
.63868 .33689 L
.63938 .33767 L
.64064 .33949 L
.64303 .34366 L
.64428 .34568 L
.64497 .3466 L
.64562 .34731 L
.64678 .34817 L
.64806 .34847 L
.64915 .34831 L
.65032 .34788 L
.65145 .34745 L
.65268 .34725 L
.65384 .34752 L
.65491 .34832 L
.65598 .34964 L
.65695 .35125 L
.65911 .35573 L
.66024 .35809 L
.66145 .36028 L
.66214 .36128 L
.66277 .36199 L
.66401 .36282 L
.66528 .36294 L
.666 .36275 L
.66666 .36248 L
.66796 .36189 L
.66917 .36157 L
.6702 .36174 L
.6713 .36253 L
.67253 .36423 L
.67365 .36649 L
.67595 .37238 L
.67722 .37559 L
.67841 .37813 L
.67907 .37922 L
.6798 .3801 L
.68105 .38086 L
.68233 .38071 L
.68351 .38005 L
.68419 .37959 L
.68491 .37914 L
.68622 .37874 L
.68694 .37891 L
.68759 .37935 L
.68836 .38029 L
.68909 .3816 L
Mistroke
.69141 .38805 L
.69392 .39644 L
.69461 .39845 L
.69535 .40023 L
.69666 .40233 L
.6979 .40292 L
.6986 .40271 L
.69925 .40223 L
.7004 .40095 L
.70164 .39943 L
.70282 .39851 L
.70391 .3986 L
.70518 .40024 L
.70581 .40175 L
.70652 .40393 L
.70889 .41425 L
.7102 .42056 L
.71144 .42575 L
.71213 .42797 L
.71288 .42969 L
.71419 .43076 L
.71543 .42949 L
.71613 .42797 L
.71676 .42624 L
.71792 .42266 L
.71914 .41929 L
.72028 .41762 L
.72152 .41843 L
.72265 .42214 L
.7237 .42826 L
.72495 .43831 L
.72608 .4491 L
.7274 .46169 L
.72863 .47099 L
.7297 .47539 L
.73083 .47464 L
.73196 .46699 L
.73322 .44967 L
.73429 .42733 L
.73546 .39638 L
.73756 .32781 L
.73996 .24542 L
.74128 .20625 L
.74253 .17682 L
.74369 .15732 L
.74495 .14534 L
.74609 .14219 L
.74715 .14483 L
.7484 .15306 L
.74957 .16369 L
Mistroke
.75097 .17717 L
.75224 .18797 L
.75288 .19231 L
.75357 .19602 L
.75484 .1999 L
.75554 .2005 L
.75628 .20008 L
.75692 .19902 L
.75762 .19729 L
.75894 .19329 L
.76017 .1898 L
.76145 .18758 L
.76213 .18726 L
.76286 .18768 L
.76365 .18902 L
.7644 .19109 L
.76507 .19351 L
.7658 .19661 L
.76709 .20275 L
.76851 .20946 L
.76915 .21216 L
.76984 .21467 L
.77109 .21794 L
.77182 .21904 L
.77252 .21955 L
.77382 .21926 L
.77504 .21803 L
.77617 .21663 L
.77741 .21543 L
.77873 .21518 L
.77998 .21626 L
.78068 .21747 L
.78134 .21897 L
.78409 .22765 L
.7853 .23168 L
.78662 .23537 L
.78787 .2378 L
.78902 .239 L
.78967 .23926 L
.79038 .23925 L
.79113 .23898 L
.79183 .23856 L
.79308 .23772 L
.79439 .23717 L
.79508 .23717 L
.79584 .23747 L
.79652 .23806 L
.79716 .23888 L
.79792 .24016 L
.7986 .24159 L
Mistroke
.80015 .24542 L
.80257 .2516 L
.80378 .25401 L
.80448 .25503 L
.80513 .25573 L
.80583 .25622 L
.80648 .25643 L
.80723 .25644 L
.80793 .25626 L
.80917 .25572 L
.80987 .25541 L
.81052 .25518 L
.81182 .25511 L
.81299 .25566 L
.81425 .25702 L
.81495 .2581 L
.81561 .25927 L
.81803 .26435 L
.81922 .26673 L
.82032 .26855 L
.8215 .26993 L
.82279 .27068 L
.82388 .27077 L
.82503 .27048 L
.82627 .26999 L
.82743 .26963 L
.82871 .26962 L
.82943 .26988 L
.83008 .27029 L
.83118 .27139 L
.8322 .2728 L
.83452 .27678 L
.83568 .27875 L
.83678 .28032 L
.83804 .28162 L
.83918 .28224 L
.85986 .29047 L
.89838 .30196 L
.90093 .30407 L
.90219 .3052 L
.90335 .30608 L
.904 .30645 L
.90468 .30673 L
.90537 .30688 L
.90614 .30689 L
.90745 .30657 L
.90868 .30599 L
.90985 .30534 L
.91093 .30479 L
.91207 .3044 L
Mistroke
.91331 .3043 L
.91457 .3046 L
.91527 .30493 L
.91591 .30533 L
.9183 .30719 L
.9195 .30808 L
.92077 .30875 L
.92144 .30895 L
.92217 .30904 L
.92346 .30887 L
.92467 .30838 L
.92598 .30764 L
.9272 .30693 L
.92833 .3064 L
.92902 .3062 L
.92975 .3061 L
.93055 .30614 L
.93129 .30631 L
.93198 .30659 L
.93273 .307 L
.93409 .30793 L
.93543 .30889 L
.93615 .30936 L
.93683 .30972 L
.93804 .31012 L
.93936 .31015 L
.94055 .30982 L
.94182 .30918 L
.9441 .3078 L
.94536 .30723 L
.94655 .30698 L
.94785 .3071 L
.94859 .30734 L
.94926 .30766 L
.95162 .30917 L
.95278 .30988 L
.95382 .31037 L
.95493 .31063 L
.95612 .31058 L
.95741 .31016 L
.95863 .30951 L
.96076 .30818 L
.96183 .30765 L
.96302 .30731 L
.96402 .30728 L
.9651 .30752 L
.96613 .30797 L
.96706 .30851 L
.9693 .30992 L
.97057 .31049 L
Mistroke
.97174 .31073 L
.97288 .31065 L
.9739 .31033 L
.97508 .30972 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00X?oonfX4
o`0007Wooo]Z1Ol00020oookJPCo0000V_oonfX00:3ooo]Z1Ol0001hoookJPGo0000P?oonfX5o`00
09Wooo]Z002PoookJPGo0000N?oonfX5o`00083ooo]Z1Ol0002IoookJP00X?oonfX5o`0006_ooo]Z
0ol007l:oookJPGo0000P?oonfX5o`0009Wooo]Z002PoookJPGo0000JooonfX3o`00O`[ooo]Z1Ol0
0020oookJPKo0000V?oonfX009oooo]Z1_l0001[oookJP?o001o2_oonfX5o`0007oooo]Z1ol0002H
oookJP00WooonfX7o`0005[ooo]Z2_l007l6oookJP?o001o2_oonfX5o`0007oooo]Z1ol0002Hoook
JP00WooonfX7o`0005[ooo]Z2_l007l6oookJP?o001o2_oonfX6o`0007kooo]Z1ol0002HoookJP00
WooonfX7o`0006[ooo]Z0ol007l:oookJPGo0000OooonfX7o`0009Sooo]Z002OoookJPOo0000J_oo
nfX3o`00O`[ooo]Z1Ol0001ooookJPOo0000V?oonfX009oooo]Z1ol0001ZoookJP?o001o2_oonfX5
o`0007oooo]Z1ol0002HoookJP00WooonfX7o`0006[ooo]Z0ol007l:oookJPGo0000OooonfX7o`00
09Sooo]Z002OoookJPSo0000I_oonfX6o`00O`[ooo]Z1Ol0001ooookJPOo0000V?oonfX009kooo]Z
2Ol0001VoookJPKo001o2_oonfX5o`0007oooo]Z1ol0002HoookJP00W_oonfX9o`0006Sooo]Z1?l0
07l:oookJPGo0000O_oonfX8o`0009Sooo]Z002NoookJPWo0000JOoonfX3o`00O`[ooo]Z1Ol0001n
oookJPSo0000V?oonfX009kooo]Z1?l000000ooonf[o0000o`000002o`0007Kooo]Z1Ol0001noook
JPWo0000UooonfX009kooo]Z1?l000000ooonf[o0000o`000002o`0007Kooo]Z1Ol0001noookJPWo
0000UooonfX009kooo]Z1?l000000ooonf[o0000o`000002o`0007Kooo]Z1Ol0001noookJPWo0000
UooonfX009kooo]Z1?l000000ooonf[o0000o`000002o`0007Kooo]Z1Ol0001noookJPCo000000?o
oo]Zo`000?l000000_l0002GoookJP00W_oonfX4o`000003oookJ_l0003o000000;o0000M_oonfX5
o`0007kooo]Z1?l000000ooonf[o0000o`000002o`0009Oooo]Z002NoookJPCo000000?ooo]Zo`00
0?l000000_l0001foookJPGo0000O_oonfX4o`000003oookJ_l0003o000000;o0000UooonfX009ko
oo]Z1?l000000ooonf[o0000o`000002o`0007Kooo]Z1Ol0001noookJPCo000000?ooo]Zo`000?l0
00000ol0002FoookJP00W_oonfX4o`000003oookJ_l0003o000000;o0000M_oonfX5o`0007kooo]Z
1?l000000ooonf[o0000o`000003o`0009Kooo]Z002NoookJPCo000000?ooo]Zo`000?l000000ol0
00000ooonf[o0000o`000002o`00073ooo]Z1Ol0001noookJPCo000000?ooo]Zo`000?l000000ol0
00000ooonf[o0000o`000002o`00097ooo]Z002NoookJPCo000000?ooo]Zo`000?l000002?l0001`
oookJPGo0000O_oonfX4o`0000;ooo]Z2_l0002@oookJP00W_oonfX4o`000003oookJ_l0003o0000
00Wo0000KooonfX5o`0007kooo]Z1?l00002oookJP[o0000T?oonfX009kooo]Z1?l00002oookJP[o
0000KooonfX5o`0007kooo]Z1?l00002oookJP_o0000SooonfX009kooo]Z1?l00002oookJP_o0000
K_oonfX5o`0007kooo]Z1?l00002oookJP_o0000SooonfX009kooo]Z1?l00002oookJP_o0000K_oo
nfX5o`0007kooo]Z1?l00002oookJP_o0000SooonfX009kooo]Z1?l00002oookJP_o0000K_oonfX5
o`0007kooo]Z1?l00002oookJP_o0000SooonfX009kooo]Z1?l00002oookJP_o0000K_oonfX5o`00
07kooo]Z1?l00002oookJPco0000S_oonfX009kooo]Z1?l00003oookJP_o0000KOoonfX5o`0007ko
oo]Z1?l00002oookJPco0000S_oonfX009kooo]Z1?l00003oookJPGo000000?ooo]Zo`000?l00000
0ol0001]oookJPGo0000O_oonfX4o`0000;ooo]Z1_l000000ooonf[o0000o`000003o`0008kooo]Z
002NoookJPCo00000ooonfX5o`000003oookJ_l0003o000000?o0000KOoonfX5o`0007kooo]Z1?l0
0003oookJPGo00000_oonfX4o`0008kooo]Z002NoookJPCo00002_oonfX4o`0006gooo]Z1Ol0001n
oookJPCo00002_oonfX5o`0008gooo]Z002NoookJPCo00002_oonfX4o`0006gooo]Z1Ol0001noook
JPCo00002_oonfX5o`0008gooo]Z002NoookJPCo00002_oonfX5o`0006cooo]Z1Ol0001noookJPCo
00002_oonfX5o`0008gooo]Z002NoookJPCo00002_oonfX5o`0006cooo]Z1Ol0001noookJPCo0000
2ooonfX4o`0008gooo]Z002NoookJPCo00002_oonfX:o`0006Oooo]Z1Ol0001noookJPCo00002ooo
nfX9o`0008Sooo]Z002NoookJPCo00002ooonfX:o`0006Kooo]Z1Ol0001noookJPCo00002ooonfX:
o`0008Oooo]Z002NoookJPCo00002ooonfX:o`0006Kooo]Z1Ol0001noookJPCo00002ooonfX:o`00
08Oooo]Z002NoookJPCo00002ooonfX:o`0006Kooo]Z1Ol0001noookJPCo00002ooonfX:o`0008Oo
oo]Z002NoookJPCo00002ooonfX;o`0006Gooo]Z1Ol0001noookJPCo00002ooonfX;o`0008Kooo]Z
002NoookJPCo00003?oonfX:o`0006Gooo]Z1Ol0001noookJPCo00003?oonfX:o`0008Kooo]Z002M
oookJPGo00003OoonfX:o`0004Kooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001n
oookJPCo00003OoonfX9o`0008Kooo]Z002MoookJPGo00004_oonfX5o`0004Gooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001moookJPGo00004_oonfX5o`0008Gooo]Z002MoookJPGo
00004_oonfX5o`0004Gooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000OOoonfX5o`0001;ooo]Z1Ol00025
oookJP00WOoonfX4o`0001Cooo]Z1Ol0000goookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001moookJPGo00004_oonfX6o`0008Cooo]Z002MoookJPCo
00005?oonfX5o`0003Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo
0000O?oonfX4o`0001Cooo]Z1Ol00024oookJP00WOoonfX4o`0001Cooo]Z1Ol00013oookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000OOoonfX4o`0001Cooo]Z1Ol00024oookJP00WOoo
nfX4o`0001Gooo]Z2Ol0000noookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oo
nfX5o`0007gooo]Z1?l0000EoookJPWo0000OooonfX009gooo]Z1?l0000EoookJP[o0000?OoonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`0007gooo]Z1?l0000EoookJP[o0000O_oonfX0
09gooo]Z1?l0000EoookJP[o0000?OoonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`00
07gooo]Z1?l0000EoookJP_o0000OOoonfX009gooo]Z1?l0000FoookJP[o0000??oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o3_oonfX5o`0007gooo]Z1?l0000FoookJP[o0000OOoonfX009gooo]Z
1?l0000FoookJP[o0000?OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo
0000OOoonfX4o`0001Oooo]Z2_l0001loookJP00WOoonfX4o`0001_ooo]Z1_l0000loookJPOo001o
2OoonfX7o`00O`Sooo]Z1Ol0001moookJPCo00006ooonfX6o`0007cooo]Z002MoookJPCo00007?oo
nfX5o`0003gooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0007gooo]Z1?l0000LoookJPGo0000O?oo
nfX009gooo]Z1?l0000LoookJPGo0000FooonfX5o`0007gooo]Z1?l0000MoookJPGo0000NooonfX0
09gooo]Z1?l0000MoookJPGo0000F_oonfX5o`0007gooo]Z1?l0000MoookJPGo0000NooonfX009go
oo]Z1?l0000MoookJPKo0000FOoonfX5o`0007gooo]Z1?l0000MoookJPKo0000N_oonfX009gooo]Z
1?l0000MoookJPSo0000EooonfX5o`0007gooo]Z1?l0000NoookJP[o0000MOoonfX009gooo]Z1?l0
000NoookJPSo0000E_oonfX5o`0007gooo]Z1?l0000NoookJP_o0000M?oonfX009gooo]Z1?l0000O
oookJPWo0000E?oonfX5o`0007gooo]Z1?l0000OoookJP[o0000M?oonfX009gooo]Z1?l0000Ooook
JP[o0000DooonfX5o`0007gooo]Z1?l0000OoookJP[o0000M?oonfX009gooo]Z1?l0000RoookJPSo
0000D_oonfX5o`0007gooo]Z1?l0000PoookJP[o0000LooonfX009gooo]Z1?l0000SoookJPOo0000
D_oonfX5o`0007gooo]Z1?l0000UoookJPGo0000LooonfX009gooo]Z1?l0000UoookJPKo0000DOoo
nfX5o`0007gooo]Z1?l0000UoookJPKo0000L_oonfX009gooo]Z1?l0000VoookJPKo0000D?oonfX5
o`0007gooo]Z1?l0000VoookJPKo0000LOoonfX009gooo]Z1?l0000VoookJP_o0000BooonfX5o`00
07gooo]Z1?l0000VoookJP_o0000K?oonfX002;ooo]Z0ol007meoookJP?o001o1?l00002oookJP?o
001o0ooonfX5o`00Oa[ooo]Z2ol0001:oookJPGo0000M?oonfX5o`00O`Cooo]Z1?l00002oookJPGo
001o8?oonfX;o`0004_ooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z1?l007l4o`0000;ooo]Z
0ol007l2oookJPOo001o6_oonfX:o`0004[ooo]Z1Ol0001coookJPOo001o0ooonfX4o`000003oook
J_l007oo001o00Go001o8?oonfX:o`0004_ooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol0
07l00ooonf[o0000o`000002o`0000;ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00Oa[ooo]Z2ol00019oookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z1?l00004o`00O`04oookJ_l007oo001oo`00Ob3ooo]Z2ol0001:oookJP?o001o7OoonfX001?o
oo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l2oookJPCo00001_oonfX3o`00O`?o
oo]Z0ol007lOoookJPGo0000BOoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`0000?o
001o0ooonfX3o`00ObCooo]Z1_l0001:oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001o
IooonfX:o`00O`;ooo]Z0ol007l2oookJPCo00003?oonfX3o`00Oaoooo]Z1_l00018oookJPGo0000
L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00001_oonfX3o`00ObGooo]Z1ol00018oookJP?o001o
7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000ol0000<oookJP?o001o8?oo
nfX;o`0004;ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o9_oo
nfX6o`0004Sooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000003
o`0000Oooo]Z0_l007l2oookJPCo001o8?oonfX<o`00047ooo]Z1Ol0001boookJP?o001o0ooonfX3
o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02oookJPCo001o9_oonfX8o`0004Kooo]Z0ol007lM
oookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000003o`0000Oooo]Z1ol007lRoook
JP_o0000@OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o
00Go001o:?oonfX:o`0004?ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o
0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z1_l007lToookJP_o0000@?oonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o00Co001o:_oonfX<o`00043o
oo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00
Oooonf[ooo]Z00Gooo]Z0_l007lYoookJPCo000000?ooo]Zo`000?l000001?l0000ooookJPGo0000
L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000003o`000003oookJ_l007oo001o02oooo]Z
3_l0000joookJPKo001o7OoonfX001oooo]Z1_l007mdoookJP?o001o1?l00008oookJP;o001o;_oo
nfX<o`0003Wooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX5o`000003oook
J_l007oo001o037ooo]Z3ol0000goookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o1?l0
0009oookJPOo001o:OoonfX<o`0003Sooo]Z1Ol0001coookJPOo001o0_oonfX5o`0000;ooo]Z1ol0
07l^oookJPoo0000=_oonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00002OoonfX7
o`00Ob[ooo]Z3?l0000goookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPOo001o<OoonfX@
o`0003?ooo]Z0ol007lMoookJP00W?oonfX4o`0003_ooo]Z4_l0000`oookJPGo0000O?oonfX4o`00
03kooo]Z4?l0001@oookJP00W?oonfX4o`0003cooo]Z1?l000000ooonf[o0000o`00000;o`0002oo
oo]Z1Ol0001loookJPCo0000@OoonfXAo`0004cooo]Z002LoookJPCo0000@_oonfX=o`0002kooo]Z
1Ol0001loookJPCo0000A?oonfXAo`0004Wooo]Z002LoookJPCo0000@ooonfXDo`0002Kooo]Z1Ol0
001loookJPCo0000B?oonfX?o`0004Oooo]Z002LoookJPCo0000A?oonfXDo`0000;ooo]Z1Ol0000N
oookJPGo0000O?oonfX4o`0004_ooo]Z3Ol00003oookJPCo0000?ooonfX009cooo]Z1?l0001;oook
JQGo00001?oonfX4o`0001Gooo]Z1Ol0001loookJPCo0000CooonfXBo`0000?ooo]Z1?l0000foook
JP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oo
nf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`00
0?oo00009Ol0000?oookJP007OoonfX00ol0003ooo]ZoookJP07o`0000;ooo]Z2?l00007oookJQSo
0000C?oonfX4o`0006Sooo]Z1Ol00003oookJPOo00000_oonfX9o`000003oookJ_l0003o000000Co
00000ooonfX6o`0000;ooo]Z8?l0001:oookJPCo0000J?oonfX5o`0000Cooo]Z1_l00002oookJPOo
00007_oonfX003gooo]Z5?l0001;oookJPCo0000OOoonfX5o`0001Cooo]Z1?l00003oookJQWo0000
B?oonfX4o`0009kooo]Z0011oookJQOo0000A?oonfX4o`0007gooo]Z1Ol0000MoookJPGo00000_oo
nfXDo`0004Cooo]Z1?l0002NoookJP00A_oonfXCo`0004?ooo]Z1?l0001moookJPGo00009OoonfX7
o`000003oookJ_l0003o000000[o0000@ooonfX4o`0009kooo]Z001=oookJPgo0000@_oonfX4o`00
07gooo]Z1Ol0000_oookJP_o0000@_oonfX4o`0009kooo]Z001>oookJPgo0000@OoonfX4o`0007go
oo]Z1Ol0000aoookJP[o0000@OoonfX4o`0009kooo]Z001?oookJPGo000000?ooo]Zo`000?l00000
2_l0000koookJPCo0000OOoonfX5o`0003Gooo]Z3?l0000koookJPCo0000W_oonfX005Kooo]Z3?l0
000joookJPCo0000OOoonfX5o`0003Kooo]Z3?l0000joookJPCo0000W_oonfX005Oooo]Z3?l0000i
oookJPCo0000OOoonfX5o`0003Oooo]Z3?l0000ioookJPCo0000W_oonfX005Oooo]Z3?l0000ioook
JPCo0000OOoonfX5o`0003Sooo]Z3?l0000hoookJPCo0000W_oonfX005kooo]Z1_l000000ooonf[o
0000o`000002o`0003?ooo]Z1?l0001moookJPGo0000?_oonfX:o`0003Cooo]Z1?l0002NoookJP00
GooonfX;o`0003;ooo]Z1?l0001moookJPGo0000?ooonfX;o`0003;ooo]Z1?l0002NoookJP00Gooo
nfX<o`00037ooo]Z1?l0001moookJPGo0000@?oonfX;o`00037ooo]Z1?l0002NoookJP00H?oonfX;
o`00037ooo]Z1?l0001moookJPGo0000@?oonfX;o`00037ooo]Z1?l0002NoookJP00HOoonfX;o`00
033ooo]Z1?l0001moookJPGo0000@OoonfX;o`00033ooo]Z1?l0002NoookJP00IooonfX6o`0002oo
oo]Z1?l0001moookJPGo0000AooonfX6o`0002oooo]Z1?l0002NoookJP00IooonfX6o`0002oooo]Z
1?l0001moookJPGo0000AooonfX7o`0002kooo]Z1?l0002NoookJP00J?oonfX;o`0002Wooo]Z1?l0
001moookJPGo0000B?oonfX;o`0002Wooo]Z1?l0002NoookJP00JOoonfX:o`0002Wooo]Z1?l0001m
oookJPGo0000BOoonfX;o`0002Sooo]Z1?l0002NoookJP00JOoonfX;o`0002Sooo]Z1?l0001moook
JPGo0000BOoonfX;o`0002Sooo]Z1?l0002NoookJP00J_oonfX:o`0002Sooo]Z1?l0001moookJPGo
0000B_oonfX:o`0002Sooo]Z1?l0002NoookJP00KooonfX6o`0002Oooo]Z1?l0001moookJPGo0000
D?oonfX5o`0002Oooo]Z1?l0002NoookJP00L?oonfX6o`0002Gooo]Z1Ol0001moookJPGo0000D?oo
nfX5o`0002Oooo]Z1?l0002NoookJP00L?oonfX6o`0002Gooo]Z1Ol0001moookJPGo0000D?oonfX6
o`0002Kooo]Z1?l0002NoookJP00LOoonfX5o`0002Gooo]Z1Ol0001moookJPGo0000DOoonfX6o`00
02Gooo]Z1?l0002NoookJP00L_oonfX:o`0001oooo]Z1?l0001noookJPGo0000DOoonfX;o`0001oo
oo]Z1Ol0002NoookJP00L_oonfX;o`0001kooo]Z1?l0001noookJPGo0000D_oonfX;o`0001kooo]Z
1Ol0002NoookJP00L_oonfX;o`0001kooo]Z1?l0001noookJPGo0000D_oonfX;o`0001kooo]Z1Ol0
002NoookJP00LooonfX:o`0001kooo]Z1?l0001noookJPGo0000DooonfX:o`0001kooo]Z1?l0002O
oookJP00NOoonfX4o`0001kooo]Z1?l0001noookJPGo0000FOoonfX5o`0001gooo]Z1?l0002Ooook
JP00NOoonfX5o`0001gooo]Z1?l0001noookJPGo0000FOoonfX5o`0001gooo]Z1?l0002OoookJP00
NOoonfX5o`0001gooo]Z1?l0001noookJPGo0000FOoonfX5o`0001gooo]Z1?l0002OoookJP00NOoo
nfX6o`0001cooo]Z1?l0001noookJPGo0000F_oonfX5o`0001cooo]Z1?l0002OoookJP00N_oonfX6
o`0001_ooo]Z1?l0001noookJPGo0000F_oonfX6o`0001_ooo]Z1?l0002OoookJP00N_oonfX;o`00
01Kooo]Z1?l0001noookJPGo0000F_oonfX;o`0001Kooo]Z1?l0002OoookJP00NooonfX:o`0001Ko
oo]Z1?l0001PoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000FooonfX:o`0001Ko
oo]Z1?l0002OoookJP00NooonfX;o`0001Gooo]Z1?l0001OoookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007l9oookJPGo0000G?oonfX9o`0001Kooo]Z1?l0002OoookJP00O?oonfX:o`0001Gooo]Z1?l0
001OoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005cooo]Z2_l0000EoookJPCo0000WooonfX007gooo]Z
2Ol0000EoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z
1Ol0001LoookJP[o00005OoonfX4o`0009oooo]Z0022oookJPGo00005?oonfX4o`0005kooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001PoookJPKo00005?oonfX4o`0009oooo]Z0022
oookJPGo00005?oonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001R
oookJPGo00005?oonfX4o`0009oooo]Z0022oookJPGo00005?oonfX4o`0005kooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000H_oonfX5o`0001Cooo]Z1?l0002Ooook
JP00PooonfX4o`0001Cooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo
0000HooonfX5o`0001?ooo]Z1?l0002OoookJP00PooonfX5o`0001?ooo]Z1?l0001NoookJP?o001o
0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000HooonfX5o`0001?ooo]Z1?l0002OoookJP00Pooo
nfX5o`0001?ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000Hooo
nfX5o`0001?ooo]Z1?l0002OoookJP00PooonfX;o`0000gooo]Z1?l0001OoookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001ToookJP[o00003OoonfX4o`0009oooo]Z0024
oookJP[o00003OoonfX4o`0005oooo]Z1ol007l9oookJPOo001o2?oonfX5o`0006Cooo]Z2ol0000<
oookJPCo0000WooonfX008Cooo]Z2ol0000<oookJPCo0000H?oonfX5o`00O`[ooo]Z1ol007l8oook
JPGo0000I?oonfX;o`0000cooo]Z1?l0002OoookJP00Q?oonfX;o`0000cooo]Z1?l0001noookJPGo
0000IOoonfX:o`0000cooo]Z1?l0002OoookJP00QOoonfX:o`0000cooo]Z1?l0001noookJPGo0000
IOoonfX:o`0000cooo]Z1?l0002OoookJP00Q_oonfX9o`0000cooo]Z1?l0001noookJPGo0000I_oo
nfX9o`0000cooo]Z1?l0002OoookJP00RooonfX4o`0000_ooo]Z1Ol0001noookJPGo0000JooonfX5
o`0000_ooo]Z1?l0002OoookJP00RooonfX5o`0000[ooo]Z1Ol0001noookJPGo0000JooonfX5o`00
00[ooo]Z1Ol0002OoookJP00RooonfX5o`0000[ooo]Z1Ol0001noookJPGo0000JooonfX5o`0000[o
oo]Z1Ol0002OoookJP00RooonfX5o`0000[ooo]Z1?l0001ooookJPGo0000K?oonfX4o`0000[ooo]Z
1Ol0002OoookJP00S?oonfX4o`0000;ooo]Z1Ol00003oookJPCo0000OooonfX5o`0006cooo]Z1Ol0
00000ooonf[o0000o`000003o`0000?ooo]Z1?l0002PoookJP00S?oonfX4o`0000;ooo]Z1Ol00003
oookJPCo0000OooonfX5o`0006cooo]Z1Ol000000ooonf[o0000o`000003o`0000?ooo]Z1?l0002P
oookJP00S?oonfX<o`0000;ooo]Z1?l0001ooookJPGo0000K?oonfX5o`000003oookJ_l0003o0000
00Co00000_oonfX4o`000:3ooo]Z002<oookJPco00000_oonfX4o`0007oooo]Z1Ol0001]oookJP_o
00000_oonfX4o`000:3ooo]Z002<oookJPco00000_oonfX4o`0007oooo]Z1Ol0001]oookJP_o0000
0_oonfX4o`000:3ooo]Z002=oookJP_o00000_oonfX4o`0007oooo]Z1Ol0001]oookJP_o00000_oo
nfX4o`000:3ooo]Z002=oookJP_o00000_oonfX4o`0007oooo]Z1Ol0001^oookJP[o00000_oonfX4
o`000:3ooo]Z002=oookJP_o00000_oonfX4o`0007oooo]Z1Ol0001^oookJP[o00000_oonfX4o`00
0:3ooo]Z002>oookJP[o00000_oonfX4o`0007oooo]Z1Ol0001^oookJP[o00000_oonfX4o`000:3o
oo]Z002>oookJP[o00000_oonfX4o`0007oooo]Z1Ol0001^oookJP_o000000?ooo]Zo`000?l00000
0_l0002PoookJP00S_oonfX5o`000003oookJ_l0003o000000;o00000_oonfX4o`0007oooo]Z1Ol0
001_oookJPCo000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000002o`000:3ooo]Z002D
oookJP[o0000OooonfX5o`0007Cooo]Z1Ol000000ooonf[o0000o`000002o`000:3ooo]Z002Doook
JP[o0000OooonfX5o`0007Gooo]Z2Ol0002PoookJP00U?oonfX:o`0007oooo]Z1Ol0001eoookJPWo
0000X?oonfX009Gooo]Z2?l00020oookJPGo0000MOoonfX9o`000:3ooo]Z002EoookJPSo0000P?oo
nfX5o`0007Gooo]Z2?l0002QoookJP00UOoonfX8o`00083ooo]Z1Ol0001eoookJPSo0000XOoonfX0
09Gooo]Z2?l00020oookJPGo0000MOoonfX8o`000:7ooo]Z002EoookJPSo0000P?oonfX5o`0007Ko
oo]Z1ol0002QoookJP00UOoonfX8o`00083ooo]Z1Ol0001foookJPOo0000XOoonfX009Kooo]Z1ol0
0020oookJPGo0000M_oonfX7o`000:7ooo]Z002FoookJPOo0000P?oonfX5o`0007Kooo]Z1ol0002Q
oookJP00U_oonfX7o`0007?ooo]Z0ol007l:oookJPGo0000M_oonfX7o`000:7ooo]Z002FoookJPOo
0000LooonfX3o`00O`[ooo]Z1Ol0001foookJPOo0000XOoonfX009Kooo]Z1ol0001coookJP?o001o
2_oonfX5o`0007Kooo]Z1ol0002QoookJP00U_oonfX7o`0007?ooo]Z0ol007l:oookJPGo0000M_oo
nfX7o`000:7ooo]Z002FoookJPOo0000LooonfX3o`00O`[ooo]Z1_l0001eoookJPOo0000XOoonfX0
09Kooo]Z1ol0001coookJP?o001o2_oonfX5o`0007Kooo]Z1ol0002QoookJP00U_oonfX7o`0007?o
oo]Z0ol007l:oookJPGo0000M_oonfX7o`000:7ooo]Z002FoookJPOo0000LooonfX3o`00O`[ooo]Z
1Ol0001foookJPOo0000XOoonfX009Oooo]Z1_l0001coookJP?o001o2_oonfX5o`0007Oooo]Z1_l0
002QoookJP00UooonfX6o`00073ooo]Z1_l007l:oookJPGo0000MooonfX6o`000:7ooo]Z002Goook
JPGo0000LOoonfX6o`00O`[ooo]Z1Ol0001goookJPKo0000XOoonfX009Oooo]Z1Ol0001coookJPCo
001o2_oonfX5o`0007Oooo]Z1Ol0002RoookJP00UooonfX5o`0007Cooo]Z0ol007l:oookJPGo0000
MooonfX5o`000:;ooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0
003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l0
1?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3
o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00
O`Sooo]Z1_l0003ooookJQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2
oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00
O`kooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP7ooo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3Ooo
nfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXO
oookJP00oooonfX>oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[o
oo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooo
nfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX0
0?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o
001ooooonfX/oookJP00oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oo
nfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30975 L
.02605 .31029 L
.02729 .31064 L
.02846 .31064 L
.02954 .31034 L
.03053 .30985 L
.03279 .30845 L
.03396 .30782 L
.03506 .30746 L
.03626 .30738 L
.03756 .30771 L
.03821 .308 L
.03891 .3084 L
.0402 .30923 L
.04136 .30996 L
.04262 .31054 L
.04332 .31073 L
.04396 .31079 L
.04523 .31062 L
.04638 .31015 L
.04759 .30945 L
.04881 .30868 L
.05012 .30799 L
.05087 .30773 L
.05156 .3076 L
.05225 .30759 L
.0529 .30769 L
.05405 .30812 L
.05527 .30885 L
.05747 .31033 L
.05869 .31096 L
.05984 .31126 L
.06109 .31121 L
.0618 .31101 L
.06244 .31074 L
.0649 .30932 L
.06561 .30892 L
.06627 .30862 L
.06752 .30829 L
.0687 .30835 L
.06979 .30871 L
.07098 .30941 L
.07225 .31034 L
.07352 .31127 L
.07422 .31172 L
.07489 .31206 L
.07617 .31243 L
.07735 .31239 L
.07803 .31221 L
Mistroke
.07875 .31192 L
.08004 .31123 L
.08078 .31079 L
.08157 .31037 L
.08224 .31006 L
.08297 .30983 L
.08367 .30973 L
.08442 .30976 L
.08513 .30993 L
.08578 .31021 L
.08653 .31065 L
.08734 .31125 L
.08881 .31248 L
.0902 .31358 L
.0909 .31401 L
.09167 .31437 L
.09233 .31455 L
.09303 .31461 L
.09431 .3144 L
.09556 .31386 L
.09692 .31313 L
.09761 .31278 L
.09835 .31247 L
.09904 .31228 L
.09967 .31221 L
.10088 .31238 L
.1022 .31304 L
.10344 .31403 L
.10458 .31511 L
.10584 .31631 L
.10703 .31724 L
.1081 .31781 L
.10927 .31805 L
.11053 .31789 L
.11117 .31767 L
.11188 .31736 L
.11314 .31673 L
.1143 .31624 L
.1154 .316 L
.11655 .31611 L
.11771 .31664 L
.11898 .31765 L
.12124 .3201 L
.12236 .32127 L
.12338 .32216 L
.12468 .32288 L
.12536 .32305 L
.12609 .32308 L
.12726 .32283 L
.12855 .32229 L
Mistroke
.12926 .32197 L
.12993 .32169 L
.1307 .32146 L
.1314 .32137 L
.13268 .32158 L
.13341 .32194 L
.13408 .32243 L
.14404 .32963 L
.15318 .33409 L
.15442 .33596 L
.1556 .33746 L
.15625 .33811 L
.15695 .33864 L
.15818 .33912 L
.15936 .33908 L
.16061 .33869 L
.16168 .33827 L
.16285 .33795 L
.16409 .33802 L
.16525 .33862 L
.16592 .33924 L
.16663 .34009 L
.1679 .34204 L
.16929 .34456 L
.17077 .3472 L
.17149 .34831 L
.17217 .3492 L
.17344 .35035 L
.1746 .35079 L
.17568 .35073 L
.17685 .35034 L
.1781 .34985 L
.17935 .34962 L
.18052 .34991 L
.1818 .35098 L
.18253 .35195 L
.18318 .35303 L
.20461 .38101 L
.22479 .40359 L
.2259 .40216 L
.22707 .40076 L
.22836 .40011 L
.22954 .40091 L
.23064 .40315 L
.23167 .40653 L
.23401 .41735 L
.23529 .42355 L
.2365 .42834 L
.23717 .43025 L
.23789 .43157 L
Mistroke
.23916 .43187 L
.24034 .43002 L
.24159 .42647 L
.24275 .42268 L
.24382 .41984 L
.2451 .41853 L
.2458 .41921 L
.24647 .42095 L
.24765 .42677 L
.24895 .43677 L
.25168 .46325 L
.25246 .46961 L
.25321 .47397 L
.25387 .47606 L
.25459 .47594 L
.2559 .46819 L
.25656 .46023 L
.25728 .44825 L
.25857 .41905 L
.25976 .38379 L
.26209 .30219 L
.26457 .21806 L
.2658 .18505 L
.26646 .17106 L
.26717 .15902 L
.26841 .14569 L
.26957 .1417 L
.27023 .14265 L
.27095 .14588 L
.27171 .15117 L
.27241 .15733 L
.27375 .17059 L
.27501 .18259 L
.27621 .19163 L
.27752 .19766 L
.2787 .1995 L
.2798 .19856 L
.28098 .19558 L
.28228 .19138 L
.28294 .1894 L
.28364 .18764 L
.28491 .18602 L
.28614 .18679 L
.28729 .18962 L
.28854 .19459 L
.28988 .2011 L
.29105 .20685 L
.29231 .21218 L
.29351 .21574 L
.2946 .21751 L
Mistroke
.29568 .21791 L
.29687 .21715 L
.2981 .21562 L
.29925 .21418 L
.30032 .21337 L
.30129 .21337 L
.3024 .21443 L
.30346 .2165 L
.30587 .22399 L
.30713 .22839 L
.30846 .23246 L
.30962 .23511 L
.3109 .23676 L
.31206 .23717 L
.31314 .23684 L
.31445 .23595 L
.3157 .23518 L
.31681 .23495 L
.31802 .23552 L
.31868 .23625 L
.31938 .23732 L
.32062 .23996 L
.3234 .24736 L
.32453 .25007 L
.32559 .25207 L
.32682 .25355 L
.32794 .2541 L
.329 .25404 L
.32997 .25367 L
.33104 .25316 L
.33218 .25276 L
.33333 .25281 L
.33441 .25344 L
.33569 .25498 L
.33686 .25706 L
.33946 .26271 L
.3407 .26513 L
.34183 .26685 L
.343 .26796 L
.34426 .26841 L
.34538 .26829 L
.34656 .26786 L
.34772 .26742 L
.34897 .26723 L
.34968 .26736 L
.35033 .26766 L
.35161 .2688 L
.3539 .27234 L
.35516 .27465 L
.35634 .2767 L
Mistroke
.35744 .27828 L
.35864 .27947 L
.35973 .28002 L
.36072 .28011 L
.3619 .27985 L
.36319 .27935 L
.36384 .27911 L
.36454 .27894 L
.3658 .27895 L
.36651 .2792 L
.36728 .27969 L
.36802 .28036 L
.36869 .28114 L
.37133 .28504 L
.37245 .28667 L
.37366 .2881 L
.37435 .2887 L
.37498 .2891 L
.37622 .28945 L
.37743 .28931 L
.37875 .28882 L
.37942 .28854 L
.38014 .28827 L
.38141 .28802 L
.38262 .2882 L
.38331 .28852 L
.38395 .28897 L
.38464 .28959 L
.38528 .29028 L
.3867 .29206 L
.38786 .29357 L
.38909 .295 L
.3898 .29565 L
.39044 .29611 L
.39169 .29661 L
.39288 .29662 L
.39416 .29623 L
.39537 .29569 L
.39648 .29523 L
.39754 .29497 L
.39869 .29503 L
.3999 .29552 L
.40103 .29636 L
.40375 .29927 L
.40509 .30062 L
.40633 .30153 L
.40745 .30197 L
.40864 .30201 L
.40983 .30168 L
.41115 .30106 L
Mistroke
.41181 .30073 L
.41253 .3004 L
.41384 .30002 L
.41463 .29999 L
.41535 .30011 L
.41603 .30036 L
.41674 .30076 L
.41815 .30189 L
.41949 .30317 L
.42069 .30429 L
.42198 .30523 L
.42324 .30574 L
.42438 .30581 L
.42554 .30553 L
.42663 .30504 L
.42781 .3044 L
.42907 .30379 L
.42973 .30357 L
.43045 .30344 L
.43173 .30354 L
.43238 .30376 L
.43307 .30411 L
.43429 .30497 L
.43572 .30617 L
.43705 .30722 L
.4382 .30791 L
.43943 .30828 L
.44013 .30831 L
.4408 .30821 L
.44204 .30777 L
.44428 .30652 L
.44541 .30596 L
.44665 .30561 L
.44771 .30561 L
.44884 .30594 L
.44992 .30651 L
.4509 .3072 L
.45204 .30806 L
.45326 .3089 L
.45396 .30929 L
.45459 .30955 L
.45583 .30976 L
.45699 .3096 L
.45824 .30909 L
.45942 .30841 L
.46051 .30775 L
.46177 .30712 L
.46297 .30679 L
.46405 .30679 L
.46521 .30712 L
Mistroke
.46649 .30779 L
.46783 .30871 L
.469 .30949 L
.47026 .31013 L
.47142 .31043 L
.47249 .3104 L
.47351 .31012 L
.47458 .3096 L
.47587 .30881 L
.47708 .30807 L
.47817 .30755 L
.47935 .30726 L
.48064 .30734 L
.48183 .30775 L
.48311 .30848 L
.48447 .30937 L
.48556 .31001 L
.48674 .31049 L
.48802 .31067 L
.48923 .31045 L
.50002 .30903 L
.50124 .30979 L
.50256 .31041 L
.5038 .31068 L
.50494 .31058 L
.50558 .31039 L
.50627 .31009 L
.50768 .30927 L
.50898 .30844 L
.51017 .30781 L
.5109 .30754 L
.5116 .3074 L
.51234 .30737 L
.51314 .3075 L
.51384 .30774 L
.51458 .3081 L
.5159 .30891 L
.51712 .3097 L
.51843 .3104 L
.51918 .31065 L
.51987 .31078 L
.52056 .31078 L
.52122 .31067 L
.52361 .30955 L
.52479 .30881 L
.52587 .30819 L
.52712 .30771 L
.52778 .3076 L
.52847 .30759 L
.5296 .30785 L
Mistroke
.53083 .30845 L
.53219 .30934 L
.53365 .31032 L
.53435 .31072 L
.53502 .31101 L
.53627 .31128 L
.53753 .31115 L
.53869 .31071 L
.53997 .31 L
.54133 .30918 L
.54246 .30862 L
.54371 .30829 L
.54501 .30837 L
.54621 .30883 L
.54735 .30953 L
.54838 .31029 L
.5495 .31113 L
.55069 .31188 L
.55199 .31237 L
.55319 .31244 L
.55447 .31212 L
.55521 .31179 L
.55589 .31142 L
.5571 .31072 L
.55825 .31014 L
.55889 .3099 L
.55958 .30975 L
.56079 .30979 L
.56204 .31024 L
.5632 .311 L
.56539 .31281 L
.56653 .31367 L
.56774 .31432 L
.56837 .31452 L
.56906 .31461 L
.57028 .31446 L
.57232 .31356 L
.57344 .31296 L
.57449 .31249 L
.57563 .31222 L
.57687 .31232 L
.57793 .31276 L
.57907 .31355 L
.58182 .31611 L
.58302 .3171 L
.58433 .31782 L
.58559 .31805 L
.58675 .31788 L
.58799 .3174 L
.5893 .31674 L
Mistroke
.59051 .31623 L
.59182 .31599 L
.59305 .31621 L
.59419 .31683 L
.59521 .31769 L
.59634 .31887 L
.59862 .32134 L
.59929 .32194 L
.60002 .32247 L
.60071 .32282 L
.60135 .32302 L
.60255 .32305 L
.60384 .32269 L
.6045 .32241 L
.60521 .32208 L
.6065 .32156 L
.60724 .3214 L
.60803 .32138 L
.6087 .32152 L
.60944 .32185 L
.61012 .32231 L
.61076 .32288 L
.61196 .32424 L
.61337 .32607 L
.61467 .3277 L
.6158 .32886 L
.61701 .32968 L
.61822 .33001 L
.6189 .32999 L
.61954 .32986 L
.62078 .32941 L
.62195 .32893 L
.6226 .32872 L
.62329 .3286 L
.62451 .32872 L
.62522 .32904 L
.62598 .32959 L
.62662 .33022 L
.62732 .33106 L
.62993 .33495 L
.6312 .33675 L
.6324 .33807 L
.63306 .33859 L
.63378 .33896 L
.63504 .33915 L
.63624 .3389 L
.63751 .3384 L
.6386 .33804 L
.6398 .33793 L
.64097 .33831 L
Mistroke
.6422 .33934 L
.64325 .3407 L
.6444 .34259 L
.6468 .34693 L
.64749 .34804 L
.64814 .34894 L
.64936 .35017 L
.65052 .35074 L
.65159 .35078 L
.65277 .35045 L
.65401 .34995 L
.65507 .34965 L
.65607 .34967 L
.65716 .35019 L
.65833 .3514 L
.67809 .37473 L
.67935 .37801 L
.68068 .3808 L
.68137 .38185 L
.68213 .38263 L
.68282 .38301 L
.68347 .38308 L
.68475 .38262 L
.68591 .38182 L
.68655 .38138 L
.68725 .38101 L
.68852 .38095 L
.68922 .38138 L
.68999 .38229 L
.6908 .38376 L
.69155 .38559 L
.69435 .39481 L
.69565 .39912 L
.69689 .40233 L
.69757 .40357 L
.69832 .40443 L
.69962 .40469 L
.70029 .40428 L
.70102 .40354 L
.70234 .40183 L
.70362 .40045 L
.7048 .40015 L
.70608 .40146 L
.70681 .40308 L
.70749 .40516 L
.70886 .41076 L
.71033 .41798 L
.7116 .42411 L
.71228 .42689 L
.713 .42929 L
Mistroke
.71431 .43181 L
.71552 .43172 L
.71669 .42964 L
.71778 .42647 L
.71897 .42262 L
.72027 .41937 L
.72148 .41861 L
.72261 .42077 L
.7238 .42647 L
.72507 .43615 L
.72718 .45675 L
.72829 .46687 L
.72947 .4743 L
.73013 .47617 L
.73086 .47575 L
.73215 .46763 L
.73345 .4487 L
.73467 .42127 L
.73695 .35016 L
.7394 .2623 L
.74071 .21952 L
.74194 .18623 L
.74263 .17152 L
.74336 .15891 L
.74465 .14532 L
.74589 .14172 L
.74719 .14615 L
.7483 .1546 L
.74952 .16639 L
.75094 .18024 L
.75228 .19083 L
.75302 .195 L
.75383 .19798 L
.75456 .19931 L
.75523 .19945 L
.75646 .19754 L
.75716 .19561 L
.75782 .19351 L
.75913 .18939 L
.75987 .18756 L
.76056 .18643 L
.76175 .18612 L
.76302 .18826 L
.76372 .19044 L
.76438 .19303 L
.76561 .19879 L
.76786 .20962 L
.76899 .21383 L
.77024 .21679 L
.77089 .2176 L
Mistroke
.77158 .21792 L
.77284 .21736 L
.7741 .21588 L
.77524 .21441 L
.77593 .21372 L
.77657 .21335 L
.77727 .2133 L
.77802 .21374 L
.77927 .21565 L
.77999 .21735 L
.78066 .21928 L
.78292 .22703 L
.78416 .23109 L
.78534 .23416 L
.78601 .23544 L
.78673 .23643 L
.78799 .23716 L
.78928 .23687 L
.79047 .23608 L
.79162 .23531 L
.79285 .23495 L
.79356 .2351 L
.79421 .23552 L
.79548 .23718 L
.79679 .2399 L
.79821 .24362 L
.79955 .24724 L
.8008 .25025 L
.80197 .25236 L
.80324 .25372 L
.80439 .25413 L
.80545 .25397 L
.80658 .25347 L
.8078 .25292 L
.80851 .25274 L
.80914 .25273 L
.81039 .25327 L
.81146 .25438 L
.81262 .25623 L
.81472 .26066 L
.81589 .26319 L
.81711 .26551 L
.81815 .267 L
.8193 .26802 L
.82051 .26841 L
.82163 .26827 L
.82285 .26782 L
.82415 .26735 L
.82537 .26724 L
.82653 .26766 L
Mistroke
.82757 .26854 L
.8287 .27 L
.83907 .27947 L
.8404 .27901 L
.84114 .27889 L
.84182 .27892 L
.84313 .27945 L
.84438 .28055 L
.84566 .2822 L
.84706 .28433 L
.84861 .28662 L
.84928 .28748 L
.85 .28825 L
.85131 .28917 L
.85254 .28945 L
.85322 .28939 L
.85394 .28921 L
.85523 .2887 L
.85635 .28826 L
.85755 .28802 L
.85886 .28822 L
.86008 .28892 L
.86264 .29173 L
.86503 .29474 L
.86623 .29585 L
.86753 .29653 L
.86823 .29666 L
.86897 .29663 L
.87028 .29626 L
.87097 .29596 L
.87171 .29562 L
.87235 .29535 L
.87304 .29511 L
.87385 .29496 L
.87461 .29498 L
.87536 .29516 L
.87604 .29549 L
.87728 .29641 L
.87863 .2978 L
.88003 .29937 L
.88136 .3007 L
.88262 .30159 L
.88333 .30189 L
.88399 .30202 L
.88515 .30195 L
.88639 .30153 L
.88772 .30087 L
.88842 .30053 L
.88916 .30024 L
.88981 .30006 L
Mistroke
.89052 .29998 L
.89177 .30018 L
.89293 .30076 L
.89417 .30173 L
.89639 .30385 L
.89705 .30443 L
.89777 .30497 L
.89907 .30564 L
.90033 .30583 L
.9015 .30561 L
.90275 .30508 L
.90393 .30444 L
.90501 .3039 L
.90616 .30351 L
.90741 .30344 L
.90856 .30376 L
.90927 .30412 L
.90993 .30455 L
.91118 .30554 L
.9133 .30726 L
.91436 .30789 L
.91553 .30827 L
.9168 .30825 L
.91799 .30788 L
.91907 .30732 L
.92024 .30665 L
.92091 .30628 L
.92162 .30595 L
.9229 .30561 L
.92361 .30558 L
.92427 .30568 L
.925 .30592 L
.92579 .30632 L
.92834 .30815 L
.92902 .30863 L
.92974 .30908 L
.93104 .30963 L
.93232 .30975 L
.93349 .3095 L
.93415 .30923 L
.93487 .30885 L
.93617 .30807 L
.93736 .30739 L
.93862 .3069 L
.93969 .30675 L
.94087 .30693 L
.94201 .3074 L
.94306 .30804 L
.94431 .30891 L
.94544 .30964 L
Mistroke
.94652 .31016 L
.94754 .31042 L
.94861 .31041 L
.94977 .31009 L
.95165 .30907 L
.95268 .30842 L
.95365 .30787 L
.95481 .30741 L
.95585 .30724 L
.95684 .30734 L
.9579 .3077 L
.95907 .30834 L
.96032 .30914 L
.96139 .30981 L
.96254 .31037 L
.96375 .31065 L
.96487 .31059 L
.96556 .31041 L
.96621 .31014 L
.96744 .30945 L
.96946 .30818 L
.97059 .30765 L
.97162 .30739 L
.97284 .30741 L
.97399 .30776 L
.97505 .3083 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00X?oonfX4o`0007Wooo]Z1Ol00020oookJPCo0000V_oo
nfX00:3ooo]Z1?l0001ioookJPGo0000P?oonfX4o`0009[ooo]Z002OoookJPGo0000NOoonfX5o`00
083ooo]Z1Ol0002IoookJP00WooonfX6o`0007Sooo]Z1Ol00020oookJPGo0000VOoonfX009oooo]Z
1_l0001[oookJP?o001o2_oonfX5o`00083ooo]Z1Ol0002IoookJP00WooonfX6o`0006_ooo]Z0ol0
07l:oookJPGo0000P?oonfX5o`0009Wooo]Z002OoookJPKo0000JooonfX3o`00O`[ooo]Z1Ol00020
oookJPKo0000V?oonfX009oooo]Z1_l0001KoookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0001ooook
JPOo0000V?oonfX009oooo]Z1ol0001JoookJP[o001o1_oonfX3o`00O`[ooo]Z1_l0001noookJPOo
0000V?oonfX009oooo]Z1ol0001ZoookJP?o001o2_oonfX5o`0007oooo]Z1ol0002HoookJP00Wooo
nfX7o`0006[ooo]Z0ol007l:oookJPGo0000OooonfX7o`0009Sooo]Z002OoookJPOo0000J_oonfX3
o`00O`[ooo]Z1Ol0001ooookJPOo0000V?oonfX009oooo]Z1ol0001ZoookJP?o001o2_oonfX5o`00
07oooo]Z1ol0002HoookJP00WooonfX7o`0006Oooo]Z1_l007l:oookJPGo0000OooonfX7o`0009So
oo]Z002NoookJPSo0000IooonfX6o`00O`[ooo]Z1Ol0001noookJPSo0000V?oonfX009kooo]Z2?l0
001YoookJPCo001o2_oonfX5o`0007kooo]Z2?l0002HoookJP00W_oonfX8o`0006[ooo]Z0ol007l:
oookJPGo0000O_oonfX8o`0009Sooo]Z002NoookJPSo0000MooonfX5o`0007kooo]Z2?l0002Hoook
JP00W_oonfX8o`0007Oooo]Z1Ol0001noookJPWo0000UooonfX009kooo]Z2?l0001goookJPGo0000
O_oonfX9o`0009Oooo]Z002NoookJPWo0000M_oonfX5o`0007kooo]Z2Ol0002GoookJP00W_oonfX9
o`0007Kooo]Z1Ol0001noookJPCo000000?ooo]Zo`000?l000000_l0002GoookJP00W_oonfX9o`00
07Kooo]Z1Ol0001noookJPCo000000?ooo]Zo`000?l000000_l0002GoookJP00W_oonfX4o`000003
oookJ_l0003o000000;o0000M_oonfX5o`0007kooo]Z1?l000000ooonf[o0000o`000002o`0009Oo
oo]Z002NoookJPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000002o`00077ooo]Z
1Ol0001noookJPCo000000?ooo]Zo`000?l000000_l00002oookJPCo0000TOoonfX009kooo]Z1?l0
00000ooonf[o0000o`000002o`000003oookJ_l0003o000000?o0000L?oonfX5o`0007kooo]Z1?l0
00000ooonf[o0000o`000008o`00097ooo]Z002NoookJPCo000000?ooo]Zo`000?l000002Ol0001_
oookJPGo0000O_oonfX4o`000003oookJ_l0003o000000Wo0000T?oonfX009kooo]Z1?l000000ooo
nf[o0000o`000009o`0006oooo]Z1Ol0001noookJPCo000000?ooo]Zo`000?l000002Ol0002@oook
JP00W_oonfX4o`000003oookJ_l0003o000000Wo0000KooonfX5o`0007kooo]Z1?l00002oookJP[o
0000T?oonfX009kooo]Z1?l00002oookJP[o0000KooonfX5o`0007kooo]Z1?l00002oookJP[o0000
T?oonfX009kooo]Z1?l00002oookJP[o0000KooonfX5o`0007kooo]Z1?l00002oookJP_o0000Sooo
nfX009kooo]Z1?l00002oookJP[o0000KooonfX5o`0007kooo]Z1?l00002oookJP_o0000SooonfX0
09kooo]Z1?l00002oookJP_o0000K_oonfX5o`0007kooo]Z1?l00002oookJP_o0000SooonfX009ko
oo]Z1?l00002oookJP_o0000K_oonfX5o`0007kooo]Z1?l00002oookJPKo000000?ooo]Zo`000?l0
00000_l0002?oookJP00WOoonfX5o`0000;ooo]Z2ol0001^oookJPGo0000OOoonfX5o`0000?ooo]Z
1Ol000000ooonf[o0000o`000002o`0008oooo]Z002MoookJPGo00000ooonfX4o`0000;ooo]Z1Ol0
001]oookJPGo0000OOoonfX5o`0000?ooo]Z1?l00002oookJPGo0000S_oonfX009gooo]Z1Ol00009
oookJPGo0000KOoonfX5o`0007gooo]Z1Ol00009oookJPGo0000S_oonfX009gooo]Z1?l0000:oook
JPGo0000KOoonfX5o`0007gooo]Z1?l0000:oookJPGo0000S_oonfX009gooo]Z1?l0000;oookJPCo
0000KOoonfX5o`0007gooo]Z1?l0000;oookJPCo0000S_oonfX009gooo]Z1?l0000;oookJPCo0000
00?ooo]Zo`000?l000000_l0001XoookJPGo0000OOoonfX4o`0000_ooo]Z2_l00028oookJP00WOoo
nfX4o`0000_ooo]Z2_l0001WoookJPGo0000OOoonfX4o`0000_ooo]Z2_l00028oookJP00WOoonfX4
o`0000_ooo]Z2_l0001WoookJPGo0000OOoonfX4o`0000_ooo]Z2ol00027oookJP00WOoonfX4o`00
00_ooo]Z2_l0001WoookJPGo0000OOoonfX4o`0000cooo]Z2_l00027oookJP00WOoonfX4o`0000co
oo]Z2_l0001VoookJPGo0000OOoonfX4o`0000cooo]Z2_l00027oookJP00WOoonfX4o`0000gooo]Z
2Ol0001VoookJPGo0000OOoonfX4o`0000cooo]Z2_l00027oookJP00WOoonfX4o`0000gooo]Z2_l0
001UoookJPGo0000OOoonfX4o`0000gooo]Z1?l000000ooonf[o0000o`000003o`0008Kooo]Z002M
oookJPCo00004_oonfX5o`0004Oooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001m
oookJPCo00004_oonfX5o`0008Kooo]Z002MoookJPCo00004_oonfX5o`0004Kooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001moookJPCo00004_oonfX5o`0008Kooo]Z002MoookJPCo
00004ooonfX4o`0004Kooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000OOoonfX4o`0001?ooo]Z1?l00026
oookJP00WOoonfX4o`0001?ooo]Z1Ol0000hoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001moookJPCo00004ooonfX5o`0008Gooo]Z002MoookJPCo
00004ooonfX5o`0003Sooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo
0000O?oonfX4o`0001?ooo]Z1_l00024oookJP00WOoonfX4o`0001?ooo]Z2_l0000ooookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000OOoonfX4o`0001?ooo]Z2_l00020oookJP00WOoo
nfX4o`0001Cooo]Z2_l0000noookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oo
nfX5o`0007gooo]Z1?l0000DoookJP[o0000OooonfX009gooo]Z1?l0000DoookJP[o0000?_oonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`0007gooo]Z1?l0000EoookJPWo0000OooonfX0
09gooo]Z1?l0000EoookJP[o0000?OoonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`00
07gooo]Z1?l0000EoookJP[o0000O_oonfX009gooo]Z1?l0000FoookJPWo0000?OoonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o3_oonfX5o`0007gooo]Z1?l0000EoookJP[o0000O_oonfX009gooo]Z
1?l0000JoookJPGo0000?_oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo
0000OOoonfX4o`0001[ooo]Z1_l0001moookJP00WOoonfX4o`0001_ooo]Z1Ol0000moookJPOo001o
2OoonfX7o`00O`Sooo]Z1Ol0001moookJPCo00006ooonfX5o`0007gooo]Z002MoookJPCo00006ooo
nfX5o`0003kooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0007gooo]Z1?l0000KoookJPGo0000OOoo
nfX009gooo]Z1?l0000KoookJPKo0000FooonfX5o`0007gooo]Z1?l0000LoookJPGo0000O?oonfX0
09gooo]Z1?l0000LoookJPGo0000FooonfX5o`0007gooo]Z1?l0000LoookJPKo0000NooonfX009go
oo]Z1?l0000LoookJP[o0000E_oonfX5o`0007gooo]Z1?l0000LoookJP_o0000M_oonfX009gooo]Z
1?l0000MoookJP[o0000EOoonfX5o`0007gooo]Z1?l0000MoookJP[o0000M_oonfX009gooo]Z1?l0
000MoookJP_o0000E?oonfX5o`0007gooo]Z1?l0000NoookJPWo0000M_oonfX009gooo]Z1?l0000N
oookJP[o0000E?oonfX5o`0007gooo]Z1?l0000NoookJP[o0000MOoonfX009cooo]Z1Ol0000Soook
JPKo0000DooonfX5o`0007gooo]Z1?l0000SoookJPKo0000M?oonfX009cooo]Z1Ol0000ToookJPGo
0000DooonfX5o`0007gooo]Z1?l0000SoookJPKo0000M?oonfX009cooo]Z1Ol0000ToookJPKo0000
D_oonfX5o`0007gooo]Z1?l0000ToookJPKo0000LooonfX009cooo]Z1?l0000VoookJP[o0000COoo
nfX5o`0007gooo]Z1?l0000UoookJPWo0000KooonfX009cooo]Z1?l0000VoookJP_o0000C?oonfX5
o`0007gooo]Z1?l0000UoookJP_o0000KOoonfX009cooo]Z1?l0000WoookJP[o0000C?oonfX5o`00
07gooo]Z1?l0000VoookJP_o0000K?oonfX002;ooo]Z0ol007meoookJP;o001o1?l00003oookJP?o
001o0ooonfX5o`00OaWooo]Z2ol0001;oookJPGo0000M?oonfX5o`00O`Cooo]Z1?l00002oookJPGo
001o7ooonfX<o`0004_ooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z
0ol007l2oookJPOo001o6OoonfX;o`0004[ooo]Z1Ol0001coookJPOo001o0ooonfX4o`000003oook
J_l007oo001o00Go001o7ooonfX<o`0004[ooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol0
07l4o`0000?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Oakooo]Z
1_l0001:oookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1?l00004o`00O`04
oookJ_l007oo001oo`00ObCooo]Z2?l00019oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o
001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Co
oo]Z0ol007l3oookJP?o001o7_oonfX6o`0004Wooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;o
oo]Z1?l00003o`00O`?ooo]Z0ol007lUoookJPOo0000B?oonfX3o`00Oagooo]Z000CoookJP[o001o
1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]Z
oookJP0:oookJP?o001o7ooonfX:o`0004Cooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z
1?l00006oookJP?o001o9_oonfX9o`0004Gooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol0
07l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00[ooo]Z0ol007lOoookJP_o0000@ooo
nfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`0000Kooo]Z0ol007lWoookJPWo0000A?oo
nfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001o
oookJ_oonfX01OoonfX2o`00O`;ooo]Z1?l007lOoookJP_o0000@ooonfX5o`0007;ooo]Z0ol007l3
oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o00;ooo]Z1?l007lXoookJPSo0000A?oonfX3
o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooook
J_oonfX01OoonfX7o`00Ob7ooo]Z2ol00012oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oook
JPCo000000?ooo]Zo`00Ool007l01Ol007lZoookJPSo0000@ooonfX3o`00Oagooo]Z000RoookJP?o
001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX6o`00ObOo
oo]Z1ol00011oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000003o`000003
oookJ_l007oo001o00Co001o;_oonfX6o`0004;ooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z
0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l/oookJPco0000
>ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000ol000000ooonf[o001o
o`00O`0boookJPco0000>OoonfX6o`00Oagooo]Z000OoookJPKo001oM?oonfX3o`00O`Co00002?oo
nfX2o`00Obgooo]Z3?l0000joookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z
1Ol000000ooonf[o001oo`00O`0coookJPco0000>?oonfX6o`00Oagooo]Z000QoookJPCo001oM?oo
nfX3o`00O`Co00002OoonfX7o`00ObSooo]Z3?l0000ioookJPGo0000LooonfX7o`00O`;ooo]Z1?l0
0003oookJPOo001o;_oonfX<o`0003Wooo]Z1?l007lMoookJP008_oonfX3o`00OgGooo]Z0_l007l4
o`0000Wooo]Z1ol007lYoookJQ7o0000<ooonfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX7
o`00Oboooo]Z4Ol0000doookJP?o001o7OoonfX009cooo]Z1?l0000noookJPgo0000<_oonfX5o`00
07cooo]Z1?l0000ooookJPco0000DooonfX009cooo]Z1?l00010oookJPco0000<OoonfX5o`0007co
oo]Z1?l00010oookJPco0000D_oonfX009cooo]Z1?l00010oookJQ?o0000:_oonfX5o`0007cooo]Z
1?l00011oookJPco000000?ooo]Zo`000?l000000ol0001;oookJP00W?oonfX4o`00047ooo]Z5?l0
000XoookJPGo0000O?oonfX4o`00047ooo]Z5?l00019oookJP00W?oonfX4o`0004Sooo]Z3_l00000
0ooonf[o0000o`000004o`00023ooo]Z1Ol0001loookJPCo0000B?oonfXEo`00047ooo]Z002Loook
JPCo0000BOoonfXEo`000003oookJ_l0003o000000Co00006?oonfX5o`0007cooo]Z1?l00019oook
JQGo000000?ooo]Zo`000?l000001?l0000ioookJP003_oonf[oo`000?oo00009Ol0000?oookJP00
3_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[o
o`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP007?oonfX6o`0000;o
oo]Z1ol00002oookJPOo000000?ooo]Zo`000?l000006ol0001:oookJPCo0000KOoonfX6o`0000;o
oo]Z3ol00003oookJPKo00000_oonfXUo`0004[ooo]Z1?l0001]oookJPKo00000ooonfX6o`0000?o
oo]Z00?o0000oookJ_oonfX07?oonfX003Oooo]Z1_l000000ooonf[o0000o`00000Co`0004Wooo]Z
1?l0001moookJPGo00005_oonfX7o`000003oookJ_l0003o000001?o0000BOoonfX4o`0009kooo]Z
000ooookJQGo0000B?oonfX4o`0007gooo]Z1Ol0000OoookJPKo000000?ooo]Zo`000?l000002ol0
0019oookJPCo0000W_oonfX004Oooo]Z5Ol00010oookJPCo0000OOoonfX5o`0002Oooo]Z5?l00011
oookJPCo0000W_oonfX004Wooo]Z5?l0000ooookJPCo0000OOoonfX5o`0002Wooo]Z4ol00010oook
JPCo0000W_oonfX0053ooo]Z3_l0000noookJPCo0000OOoonfX5o`0002oooo]Z3Ol00010oookJPCo
0000W_oonfX0053ooo]Z3ol0000moookJPCo0000OOoonfX5o`00033ooo]Z3Ol0000ooookJPCo0000
W_oonfX005;ooo]Z1Ol00002oookJPSo0000>ooonfX4o`0007gooo]Z1Ol0000boookJQ7o0000>?oo
nfX5o`0009kooo]Z001JoookJPWo0000>OoonfX4o`0007gooo]Z1Ol0000hoookJPco0000=ooonfX5
o`0009kooo]Z001KoookJPWo0000>?oonfX4o`0007gooo]Z1Ol0000ioookJP_o0000=ooonfX5o`00
09kooo]Z001LoookJPWo0000=ooonfX4o`0007gooo]Z1Ol0000joookJP_o0000=_oonfX4o`0009oo
oo]Z001NoookJPSo0000=_oonfX4o`0007gooo]Z1Ol00010oookJPKo0000=OoonfX4o`0009oooo]Z
001PoookJPco0000<?oonfX4o`0007gooo]Z1Ol00010oookJPco0000;ooonfX4o`0009oooo]Z001Q
oookJP_o0000<?oonfX4o`0007gooo]Z1Ol00011oookJPco0000;_oonfX4o`0009oooo]Z001Roook
JP_o0000;ooonfX4o`0007gooo]Z1Ol00012oookJP_o0000;_oonfX4o`0009oooo]Z001SoookJP_o
0000;OoonfX5o`0007gooo]Z1Ol00013oookJP[o0000;_oonfX4o`0009oooo]Z001XoookJPKo0000
;OoonfX5o`0007gooo]Z1Ol00019oookJPGo0000;OoonfX4o`0009oooo]Z001YoookJPKo0000;?oo
nfX5o`0007gooo]Z1Ol00019oookJPKo0000;?oonfX4o`0009oooo]Z001ZoookJP[o00009ooonfX4
o`0007kooo]Z1Ol00019oookJP_o00009ooonfX4o`0009oooo]Z001ZoookJP_o00009_oonfX4o`00
07kooo]Z1Ol0001:oookJP_o00009_oonfX4o`0009oooo]Z001[oookJP[o00009_oonfX4o`0007ko
oo]Z1Ol0001;oookJP[o00009_oonfX4o`0009oooo]Z001[oookJP[o00009_oonfX4o`0007kooo]Z
1Ol0001;oookJP_o00009OoonfX4o`0009oooo]Z001]oookJPWo00009OoonfX4o`0007kooo]Z1Ol0
001=oookJP[o00009?oonfX4o`0009oooo]Z001aoookJPKo00009?oonfX4o`0007kooo]Z1Ol0001A
oookJPOo00008ooonfX4o`0009oooo]Z001aoookJPOo00008ooonfX4o`0007kooo]Z1Ol0001Boook
JPOo00008_oonfX4o`0009oooo]Z001boookJPOo00008_oonfX4o`0007kooo]Z1Ol0001CoookJPOo
00008OoonfX4o`0009oooo]Z001coookJPKo00008_oonfX4o`0007kooo]Z1Ol0001DoookJPOo0000
8?oonfX4o`0009oooo]Z001doookJPKo00008OoonfX4o`0007kooo]Z1Ol0001EoookJPKo00008?oo
nfX4o`0009oooo]Z001eoookJPKo00008?oonfX4o`0007kooo]Z1Ol0001FoookJPKo00007ooonfX4
o`0009oooo]Z001eoookJPOo00007ooonfX4o`0007kooo]Z1Ol0001GoookJPKo00007_oonfX4o`00
09oooo]Z001foookJPOo00007_oonfX4o`0007kooo]Z1Ol0001GoookJPOo00007OoonfX4o`0009oo
oo]Z001goookJPKo00007_oonfX4o`0007kooo]Z1Ol0001HoookJPOo00007?oonfX4o`0009oooo]Z
001hoookJPKo00007OoonfX4o`0007kooo]Z1Ol0001IoookJPOo00006ooonfX4o`0009oooo]Z001i
oookJPKo00007?oonfX4o`0007kooo]Z1Ol0001JoookJPKo00006ooonfX4o`0009oooo]Z001ioook
JPOo00006ooonfX4o`0007kooo]Z1Ol0001KoookJPGo00006ooonfX4o`0009oooo]Z001joookJPOo
00006_oonfX4o`00063ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001LoookJP[o
00005OoonfX4o`0009oooo]Z001koookJPKo00006_oonfX4o`0005oooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`Wooo]Z1Ol0001LoookJP[o00005OoonfX4o`0009oooo]Z001loookJPKo00006Ooo
nfX4o`0005oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l0
0_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000G?oonfX:o`0001Gooo]Z1?l0002OoookJP00
OOoonfX6o`0001Sooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
2?oonfX5o`0005gooo]Z2_l0000CoookJPGo0000WooonfX007gooo]Z1ol0000GoookJPCo0000G_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0005cooo]Z2_l0000CoookJPGo0000Wooo
nfX007kooo]Z1ol0000FoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5
o`0006;ooo]Z1Ol0000CoookJPGo0000WooonfX007oooo]Z1ol0000EoookJPCo0000G_oonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001SoookJPGo00004_oonfX4o`00
0:3ooo]Z0020oookJPOo00005?oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wo
oo]Z1Ol0001SoookJPGo00004_oonfX4o`000:3ooo]Z0021oookJPOo00004ooonfX4o`0005kooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001SoookJPGo00004_oonfX4o`000:3ooo]Z
0022oookJPOo00004_oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0
001ToookJPCo00004_oonfX4o`000:3ooo]Z0023oookJP_o00003OoonfX4o`0005oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0006Cooo]Z1Ol000000ooonf[o0000o`00
0002o`0000cooo]Z1?l0002PoookJP00Q?oonfX:o`0000gooo]Z1?l0001OoookJPOo001o2OoonfX7
o`00O`Sooo]Z1Ol0001ToookJP_o00002ooonfX4o`000:3ooo]Z0025oookJP[o00002ooonfX5o`00
063ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0006Cooo]Z2ol0000;oookJPCo0000X?oonfX008Ko
oo]Z2Ol0000;oookJPGo0000O_oonfX5o`0006Gooo]Z2_l0000;oookJPCo0000X?oonfX008Oooo]Z
2Ol0000:oookJPGo0000O_oonfX5o`0006Gooo]Z2_l0000;oookJPCo0000X?oonfX008Sooo]Z2?l0
000:oookJPCo0000OooonfX5o`0006Kooo]Z2_l0000:oookJPCo0000X?oonfX008_ooo]Z1Ol0000:
oookJPCo0000OooonfX5o`0006Kooo]Z2_l0000:oookJPCo0000X?oonfX008cooo]Z1?l0000:oook
JPCo0000OooonfX5o`0006_ooo]Z1Ol0000:oookJPCo0000X?oonfX008cooo]Z1Ol00009oookJPCo
0000OooonfX5o`0006cooo]Z1?l0000:oookJPCo0000X?oonfX008cooo]Z1Ol00009oookJPCo0000
OooonfX5o`0006cooo]Z1Ol00009oookJPCo0000X?oonfX008cooo]Z1Ol00002oookJPCo00000ooo
nfX4o`0007oooo]Z1Ol0001/oookJPGo00000_oonfX4o`0000?ooo]Z1?l0002PoookJP00SOoonfX4
o`000003oookJ_l0003o000000?o00000ooonfX4o`0007oooo]Z1Ol0001/oookJPGo000000?ooo]Z
o`000?l000000ol00003oookJPCo0000X?oonfX008gooo]Z2ol00002oookJPCo0000OooonfX5o`00
06gooo]Z2ol00002oookJPCo0000X?oonfX008gooo]Z2ol00002oookJPCo0000OooonfX5o`0006go
oo]Z2ol00002oookJPCo0000X?oonfX008gooo]Z2ol00002oookJPCo0000OooonfX5o`0006gooo]Z
2ol00002oookJPCo0000X?oonfX008kooo]Z2_l00002oookJPCo0000OooonfX5o`0006kooo]Z2_l0
0002oookJPCo0000X?oonfX008kooo]Z2_l00002oookJPCo0000OooonfX5o`0006kooo]Z2_l00002
oookJPCo0000X?oonfX008kooo]Z2_l00002oookJPCo0000OooonfX5o`0006kooo]Z2_l00002oook
JPCo0000X?oonfX008kooo]Z2ol000000ooonf[o0000o`000002o`0007oooo]Z1Ol0001^oookJP_o
000000?ooo]Zo`000?l000000_l0002PoookJP00S_oonfX@o`0007oooo]Z1Ol0001^oookJP_o0000
00?ooo]Zo`000?l000000_l0002PoookJP00SooonfX?o`0007oooo]Z1Ol0001^oookJP_o000000?o
oo]Zo`000?l000000_l0002PoookJP00T?oonfX4o`000003oookJ_l0003o000000Oo0000OooonfX5
o`0006oooo]Z1Ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000;o0000X?oonfX0
09Gooo]Z2?l00020oookJPGo0000MOoonfX4o`000003oookJ_l0003o000000;o0000X?oonfX009Go
oo]Z2?l00020oookJPGo0000MOoonfX4o`000003oookJ_l0003o000000;o0000X?oonfX009Gooo]Z
2?l00020oookJPGo0000MOoonfX4o`000003oookJ_l0003o000000;o0000X?oonfX009Gooo]Z2?l0
0020oookJPGo0000MOoonfX4o`000003oookJ_l0003o000000;o0000X?oonfX009Gooo]Z2?l00020
oookJPGo0000MOoonfX9o`000:3ooo]Z002EoookJPSo0000P?oonfX5o`0007Gooo]Z2Ol0002Poook
JP00UOoonfX8o`00083ooo]Z1Ol0001eoookJPWo0000X?oonfX009Gooo]Z2?l00020oookJPGo0000
M_oonfX8o`000:3ooo]Z002EoookJPSo0000P?oonfX5o`0007Kooo]Z2?l0002PoookJP00U_oonfX7
o`00083ooo]Z1Ol0001foookJPSo0000X?oonfX009Kooo]Z1ol0001coookJP?o001o2_oonfX5o`00
07Kooo]Z2?l0002PoookJP00U_oonfX7o`0007?ooo]Z0ol007l:oookJPGo0000M_oonfX8o`000:3o
oo]Z002FoookJPOo0000LooonfX3o`00O`[ooo]Z1Ol0001foookJPSo0000X?oonfX009Kooo]Z1ol0
001coookJP?o001o2_oonfX5o`0007Kooo]Z2?l0002PoookJP00U_oonfX7o`0007?ooo]Z0ol007l:
oookJPKo0000MOoonfX7o`000:7ooo]Z002FoookJPOo0000LooonfX3o`00O`[ooo]Z1Ol0001foook
JPOo0000XOoonfX009Kooo]Z1ol0001coookJP?o001o2_oonfX5o`0007Oooo]Z1_l0002QoookJP00
U_oonfX7o`0007?ooo]Z0ol007l:oookJPGo0000MooonfX6o`000:7ooo]Z002GoookJPKo0000Looo
nfX3o`00O`[ooo]Z1Ol0001goookJPKo0000XOoonfX009Oooo]Z1_l0001`oookJPKo001o2_oonfX5
o`0007Oooo]Z1_l0002QoookJP00UooonfX6o`00073ooo]Z1_l007l:oookJPGo0000MooonfX6o`00
0:7ooo]Z002GoookJPGo0000LooonfX4o`00O`[ooo]Z1Ol0001goookJPGo0000X_oonfX009Oooo]Z
1Ol0001doookJP?o001o2_oonfX5o`0007Oooo]Z1Ol0002RoookJP00V?oonfX4o`00087ooo]Z1Ol0
001hoookJPCo0000X_oonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3
o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0
003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003o
oookJQoooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00?oo
oo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o
2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2Ooo
nfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPKo001o2_oonfX5
o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?ko
oo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[ooo]Z
1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z
2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1?l007l<oook
JPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z
4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol007l9oookJPGo0000oooo
nfXOoookJP00oooonfXCoookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00
Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z
1?l007l2oookJP?o001ooooonfX/oookJP00oooonfX>oookJPOo001ooooonfX]oookJP00oooonfX?
oookJPGo001ooooonfX^oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30828 L
.02605 .30775 L
.02729 .30743 L
.02846 .30748 L
.02954 .30782 L
.03053 .30834 L
.03279 .30976 L
.03396 .31034 L
.03506 .31062 L
.03626 .31058 L
.03756 .31015 L
.03821 .30981 L
.03891 .30938 L
.0402 .30857 L
.04145 .30789 L
.04262 .30753 L
.04386 .30752 L
.04456 .30769 L
.04521 .30795 L
.0464 .30862 L
.04765 .30945 L
.0487 .31011 L
.04983 .31064 L
.05106 .31089 L
.05221 .31076 L
.05479 .30951 L
.0562 .30865 L
.05689 .3083 L
.05753 .30806 L
.05865 .30786 L
.05987 .30801 L
.06112 .30856 L
.06175 .30894 L
.06244 .30942 L
.0638 .31039 L
.06455 .31086 L
.06525 .31122 L
.06591 .31146 L
.06662 .31159 L
.06787 .31151 L
.06858 .31129 L
.06936 .31093 L
.07093 .31001 L
.07169 .30957 L
.07241 .30922 L
.07306 .30898 L
.07376 .30882 L
.07443 .3088 L
.07515 .30891 L
Mistroke
.07643 .30945 L
.07721 .30994 L
.07794 .31049 L
.0793 .31156 L
.08051 .31239 L
.08179 .31294 L
.08246 .31306 L
.0832 .31306 L
.08448 .31271 L
.08513 .31241 L
.08584 .31204 L
.08711 .31132 L
.08836 .31077 L
.08951 .31055 L
.09075 .31072 L
.09145 .31102 L
.09212 .31141 L
.09488 .31372 L
.09607 .31466 L
.09732 .31533 L
.09839 .31556 L
.09955 .31546 L
.10081 .31499 L
.10216 .31429 L
.10341 .3137 L
.10458 .31338 L
.10582 .31345 L
.10647 .31368 L
.10718 .31406 L
.10792 .31461 L
.10862 .31523 L
.10993 .31654 L
.11107 .31766 L
.11228 .31863 L
.11292 .31899 L
.11362 .31925 L
.11485 .31935 L
.11555 .31922 L
.11629 .31896 L
.11761 .31835 L
.11829 .31802 L
.11903 .31772 L
.11983 .31752 L
.12058 .31748 L
.12128 .3176 L
.12203 .31792 L
.12274 .31838 L
.1234 .31894 L
.12597 .3218 L
.12713 .32306 L
Mistroke
.12837 .32409 L
.12955 .32463 L
.13063 .32473 L
.13188 .32444 L
.1326 .32415 L
.13326 .32386 L
.13447 .32337 L
.13576 .32315 L
.13646 .32324 L
.1371 .32347 L
.13781 .3239 L
.13856 .32454 L
.13982 .32597 L
.1412 .32783 L
.14243 .32946 L
.14375 .33087 L
.14499 .33169 L
.14613 .33195 L
.14861 .33132 L
.14983 .33085 L
.15094 .33063 L
.15211 .33081 L
.15337 .33159 L
.15468 .33304 L
.15605 .33507 L
.15817 .3384 L
.15936 .33989 L
.16044 .34081 L
.16171 .34129 L
.16292 .3412 L
.16403 .34084 L
.16523 .34038 L
.16652 .34014 L
.16773 .34042 L
.16842 .34087 L
.16906 .34147 L
.16979 .34238 L
.17048 .34344 L
.17336 .34876 L
.17409 .35 L
.17477 .35101 L
.17604 .3524 L
.17715 .35299 L
.17835 .35303 L
.17963 .35263 L
.1808 .35215 L
.18201 .35191 L
.18333 .35229 L
.184 .35281 L
.18471 .35363 L
Mistroke
.18599 .35576 L
.20729 .38428 L
.22743 .40335 L
.22866 .402 L
.22984 .40178 L
.23048 .40231 L
.23119 .4035 L
.23243 .40712 L
.23361 .41211 L
.23486 .41841 L
.23594 .42387 L
.23712 .42889 L
.23844 .43245 L
.23968 .43321 L
.24089 .43152 L
.24201 .42838 L
.24336 .42379 L
.24463 .42041 L
.24594 .41961 L
.24664 .4208 L
.24739 .42351 L
.24976 .44122 L
.25101 .45397 L
.2517 .46088 L
.25234 .46677 L
.2535 .47454 L
.25478 .47648 L
.25587 .47077 L
.25704 .45582 L
.2581 .43402 L
.25927 .40198 L
.26162 .31964 L
.26381 .23963 L
.26477 .20906 L
.26583 .18113 L
.26706 .15768 L
.26836 .14417 L
.26905 .14152 L
.26978 .1417 L
.27048 .14433 L
.27111 .14843 L
.2735 .17132 L
.27476 .18336 L
.27545 .18881 L
.2761 .19291 L
.2774 .19777 L
.27858 .19843 L
.27969 .19649 L
.28089 .19278 L
.28204 .18891 L
Mistroke
.28325 .18583 L
.28429 .18478 L
.28543 .18568 L
.28611 .18724 L
.28684 .18969 L
.28817 .19566 L
.29067 .20803 L
.29139 .21097 L
.29208 .21319 L
.29279 .21489 L
.29358 .21599 L
.29487 .2162 L
.2956 .21564 L
.29627 .21484 L
.29741 .21326 L
.29862 .21191 L
.29932 .21155 L
.29996 .21159 L
.3012 .21283 L
.30248 .21567 L
.3032 .21784 L
.30386 .22009 L
.30515 .22475 L
.30638 .2289 L
.30755 .23209 L
.30883 .23431 L
.30999 .23512 L
.31106 .235 L
.31222 .23429 L
.3135 .23335 L
.31414 .23301 L
.31484 .23286 L
.31609 .23334 L
.31719 .23468 L
.3184 .23709 L
.32083 .24364 L
.32191 .24654 L
.32308 .2491 L
.32417 .25079 L
.32517 .25165 L
.34582 .26496 L
.36659 .28108 L
.37571 .2865 L
.3769 .28614 L
.37819 .28614 L
.37942 .28667 L
.38055 .28763 L
.38187 .2892 L
.38327 .29111 L
.38457 .29276 L
Mistroke
.38576 .29395 L
.38701 .29469 L
.38767 .29485 L
.38836 .29487 L
.38953 .2946 L
.39081 .29406 L
.39195 .29358 L
.39318 .29331 L
.39434 .29343 L
.39539 .29392 L
.39654 .29484 L
.39761 .29597 L
.39876 .29731 L
.40002 .29872 L
.40112 .29969 L
.40215 .30029 L
.40324 .30055 L
.40441 .30042 L
.40565 .29995 L
.40681 .29939 L
.40808 .29887 L
.40879 .29871 L
.40944 .29867 L
.41074 .29898 L
.41148 .29938 L
.41216 .29987 L
.41473 .30235 L
.41578 .30333 L
.41691 .30414 L
.41816 .30462 L
.41932 .30464 L
.42062 .30425 L
.42186 .30363 L
.42307 .30301 L
.42418 .3026 L
.42543 .30247 L
.42609 .30258 L
.42678 .30283 L
.42795 .30353 L
.42923 .30457 L
.43046 .30566 L
.43162 .30657 L
.43266 .30716 L
.4338 .30747 L
.43444 .30748 L
.43513 .30736 L
.43635 .30689 L
.43777 .30612 L
.43846 .30573 L
.43909 .30542 L
Mistroke
.44022 .30504 L
.44144 .30498 L
.44208 .30511 L
.44277 .30537 L
.44403 .30612 L
.44517 .30699 L
.44641 .30795 L
.44757 .30869 L
.44865 .30912 L
.4499 .30923 L
.45053 .30912 L
.45123 .30889 L
.45244 .30828 L
.45357 .3076 L
.45472 .30697 L
.45581 .30656 L
.45678 .30643 L
.45785 .30656 L
.459 .30703 L
.46023 .3078 L
.46243 .30933 L
.46357 .3099 L
.46481 .31017 L
.46611 .31003 L
.46731 .30954 L
.46962 .30815 L
.47075 .30756 L
.47179 .30723 L
.47302 .30717 L
.47366 .3073 L
.47435 .30754 L
.47545 .30813 L
.47667 .30893 L
.47797 .30975 L
.4787 .31013 L
.47936 .31038 L
.48066 .31055 L
.48189 .31032 L
.48407 .30918 L
.48513 .3085 L
.48612 .30795 L
.48725 .30752 L
.48848 .30739 L
.48953 .30758 L
.49063 .30805 L
.49298 .30952 L
.49363 .30989 L
.49432 .31023 L
.49557 .31059 L
.4968 .31056 L
Mistroke
.49797 .31019 L
.49902 .30964 L
.50016 .30891 L
.5013 .30821 L
.5025 .30766 L
.50381 .30741 L
.50502 .30757 L
.50614 .30802 L
.50719 .30863 L
.50833 .30937 L
.50957 .31008 L
.51028 .31038 L
.51093 .31057 L
.5122 .31062 L
.51336 .31031 L
.51459 .3097 L
.51592 .30886 L
.51718 .30812 L
.51787 .3078 L
.51863 .30757 L
.51932 .30748 L
.51995 .30751 L
.52127 .30789 L
.52246 .30854 L
.52374 .30939 L
.52442 .30983 L
.52513 .31024 L
.52643 .31076 L
.52762 .31088 L
.52874 .31067 L
.52996 .31012 L
.53138 .30926 L
.53272 .30848 L
.53346 .30815 L
.53426 .30792 L
.53499 .30785 L
.53566 .30792 L
.53689 .30833 L
.53758 .30872 L
.53824 .30914 L
.53956 .31008 L
.54029 .31058 L
.54097 .31098 L
.54162 .31129 L
.54232 .31151 L
.54354 .31159 L
.54479 .31128 L
.54593 .31072 L
.54729 .30991 L
.54856 .30923 L
Mistroke
.5492 .30899 L
.54989 .30883 L
.55065 .3088 L
.55135 .30891 L
.55261 .30944 L
.55377 .31022 L
.55503 .3112 L
.55569 .31171 L
.55641 .31221 L
.55761 .31282 L
.55874 .31307 L
.56003 .31293 L
.56121 .31247 L
.5633 .31132 L
.56446 .31079 L
.56552 .31056 L
.56678 .31067 L
.56796 .31119 L
.56905 .31196 L
.57024 .31298 L
.57148 .31406 L
.57264 .3149 L
.57385 .31544 L
.57449 .31556 L
.57518 .31555 L
.5764 .31525 L
.57756 .31471 L
.57869 .31411 L
.57974 .31365 L
.58098 .31336 L
.58164 .31338 L
.58233 .31355 L
.5835 .31415 L
.58478 .3152 L
.58601 .31642 L
.58717 .31757 L
.5883 .31851 L
.58935 .31909 L
.59057 .31936 L
.59122 .31933 L
.5919 .31917 L
.5932 .31864 L
.59395 .31827 L
.59464 .31795 L
.59587 .31755 L
.59719 .31754 L
.59835 .31799 L
.59958 .31893 L
.60837 .32433 L
.61798 .32863 L
Mistroke
.63926 .34117 L
.64048 .34073 L
.64179 .34026 L
.64303 .34015 L
.64415 .34055 L
.64542 .34166 L
.64662 .34335 L
.64932 .34834 L
.65044 .35025 L
.65162 .35183 L
.65264 .35268 L
.65376 .35307 L
.65495 .35294 L
.65625 .35245 L
.65747 .35201 L
.65858 .35194 L
.65975 .35244 L
.66083 .35354 L
.66202 .35544 L
.66329 .35808 L
.66567 .36339 L
.66632 .36463 L
.66701 .36574 L
.66825 .36708 L
.66894 .36745 L
.66959 .36757 L
.6703 .36749 L
.67106 .36721 L
.67171 .36688 L
.67243 .36653 L
.67372 .36614 L
.67438 .36621 L
.67507 .36654 L
.67633 .36791 L
.67757 .37028 L
.67871 .37311 L
.68099 .37943 L
.68224 .38232 L
.6834 .38418 L
.68466 .38511 L
.68533 .38516 L
.68604 .38494 L
.68732 .3841 L
.68848 .38327 L
.68965 .38288 L
.69074 .3833 L
.69193 .38488 L
.6932 .38789 L
.69534 .39508 L
.69647 .39909 L
Mistroke
.69768 .40278 L
.69891 .40538 L
.70006 .40645 L
.70138 .40613 L
.70257 .40481 L
.70368 .40327 L
.70488 .40198 L
.70601 .40177 L
.70706 .40287 L
.70826 .40588 L
.70939 .41026 L
.71196 .42304 L
.71325 .42868 L
.71447 .43217 L
.71514 .43309 L
.71588 .4332 L
.71716 .43134 L
.71936 .42441 L
.72047 .42114 L
.72169 .41947 L
.72301 .4213 L
.72424 .42712 L
.72537 .43579 L
.72658 .44753 L
.72773 .45926 L
.72897 .47018 L
.73014 .47615 L
.73122 .47582 L
.7322 .46947 L
.73327 .45507 L
.73439 .43161 L
.73544 .40249 L
.738 .31263 L
.74043 .22549 L
.74177 .18716 L
.74253 .17023 L
.74323 .15797 L
.74447 .14468 L
.74517 .14166 L
.7458 .14139 L
.747 .14632 L
.74811 .15536 L
.74931 .1674 L
.75062 .18045 L
.75176 .18968 L
.75283 .19549 L
.75396 .19833 L
.75517 .19798 L
.75585 .19658 L
.75657 .19447 L
Mistroke
.75787 .19008 L
.75854 .18799 L
.75926 .18619 L
.76006 .18501 L
.7608 .18481 L
.76145 .1854 L
.76216 .18686 L
.7629 .18921 L
.76359 .19201 L
.76614 .20472 L
.76745 .21046 L
.76868 .21425 L
.76978 .216 L
.77098 .21624 L
.77229 .21506 L
.77295 .21417 L
.77367 .21316 L
.77496 .2118 L
.77616 .2116 L
.77741 .21286 L
.7781 .21424 L
.77874 .21586 L
.78113 .22397 L
.78247 .2286 L
.78318 .23068 L
.78392 .23249 L
.78458 .2337 L
.78529 .2346 L
.78655 .23516 L
.78785 .23469 L
.78902 .23382 L
.78967 .23336 L
.79038 .23299 L
.79166 .23297 L
.79287 .23394 L
.79414 .2361 L
.79523 .23868 L
.79643 .24199 L
.79867 .24788 L
.7998 .25003 L
.80103 .25144 L
.80168 .25179 L
.80238 .25189 L
.80362 .25157 L
.80487 .25095 L
.80599 .25052 L
.80715 .25055 L
.80821 .25117 L
.80938 .25258 L
.81061 .25481 L
Mistroke
.81269 .25948 L
.81379 .26186 L
.81496 .26393 L
.81628 .26547 L
.8175 .26608 L
.81864 .26604 L
.81991 .2656 L
.82102 .26516 L
.82223 .26495 L
.82337 .26525 L
.82442 .26605 L
.82564 .2676 L
.82677 .26953 L
.82813 .27209 L
.82936 .27432 L
.83065 .27622 L
.83187 .27738 L
.83316 .27788 L
.83389 .27787 L
.83456 .27772 L
.83561 .27734 L
.8366 .27697 L
.83775 .27673 L
.8388 .27686 L
.83995 .2775 L
.8412 .2788 L
.84237 .28045 L
.84346 .28217 L
.84469 .28411 L
.84585 .28566 L
.84689 .28666 L
.84802 .28727 L
.84925 .28739 L
.85055 .28705 L
.85167 .2866 L
.85289 .28618 L
.85419 .28611 L
.8554 .28654 L
.85603 .28698 L
.85672 .28761 L
.85813 .28929 L
.86052 .29248 L
.86117 .29322 L
.86186 .29388 L
.86309 .29465 L
.86428 .29488 L
.86538 .29471 L
.8666 .29424 L
.86789 .29368 L
.86911 .29334 L
Mistroke
.87025 .29336 L
.87128 .29374 L
.8724 .29453 L
.8737 .29585 L
.87492 .29727 L
.87636 .29887 L
.87768 .29995 L
.87835 .3003 L
.87907 .30051 L
.88038 .30048 L
.88111 .30026 L
.88189 .29993 L
.88328 .29926 L
.88458 .29878 L
.88532 .29867 L
.88599 .2987 L
.88724 .29912 L
.88855 .30003 L
.89083 .30227 L
.89204 .30339 L
.89331 .30425 L
.89395 .30452 L
.89464 .30466 L
.89587 .30457 L
.89712 .30411 L
.89829 .3035 L
.89935 .30297 L
.90047 .30257 L
.9017 .30248 L
.90282 .30276 L
.90404 .30345 L
.90534 .3045 L
.90646 .3055 L
.90768 .30648 L
.90843 .30695 L
.90911 .30727 L
.90977 .30744 L
.91047 .30749 L
.91167 .30726 L
.91235 .30698 L
.91299 .30666 L
.91413 .30602 L
.91537 .30538 L
.91654 .30502 L
.91762 .30498 L
.91859 .30522 L
.91967 .30576 L
.92079 .30654 L
.92184 .30738 L
.923 .30824 L
Mistroke
.92423 .30891 L
.92527 .30921 L
.92641 .30918 L
.92765 .30879 L
.92896 .30808 L
.93019 .30735 L
.93134 .30678 L
.93257 .30645 L
.93322 .30643 L
.93392 .30653 L
.93466 .30678 L
.93535 .30712 L
.93666 .30797 L
.9378 .30878 L
.93901 .30955 L
.9397 .30987 L
.94034 .31007 L
.94157 .31016 L
.94226 .31004 L
.943 .30978 L
.94431 .30908 L
.94585 .30813 L
.9466 .30772 L
.94728 .30743 L
.94852 .30715 L
.9492 .30717 L
.94985 .3073 L
.95055 .30755 L
.9512 .30787 L
.95266 .30879 L
.95382 .30955 L
.95506 .3102 L
.95623 .31052 L
.95731 .31051 L
.9585 .31016 L
.95981 .30946 L
.96118 .30859 L
.96243 .30789 L
.96308 .30763 L
.96377 .30744 L
.96503 .30743 L
.96574 .30759 L
.96648 .30789 L
.96711 .30822 L
.96781 .30864 L
.96906 .30944 L
.96974 .30985 L
.97039 .31018 L
.97166 .31058 L
.97281 .31059 L
Mistroke
.97366 .31039 L
.97456 .31 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00X?oonfX4o`0007Wooo]Z1Ol00020oookJPCo0000V_oo
nfX00:3ooo]Z1?l0001ioookJPGo0000P?oonfX4o`0009[ooo]Z002OoookJPKo0000N?oonfX5o`00
07oooo]Z1_l0002IoookJP00WooonfX6o`0007Sooo]Z1Ol0001ooookJPKo0000VOoonfX009oooo]Z
1_l0001[oookJP?o001o2_oonfX5o`0007oooo]Z1_l0002IoookJP00WooonfX6o`0006_ooo]Z0ol0
07l:oookJPGo0000OooonfX6o`0009Wooo]Z002OoookJPKo0000JooonfX3o`00O`[ooo]Z1Ol0001o
oookJPKo0000VOoonfX009oooo]Z1_l0001KoookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0001ooook
JPKo0000VOoonfX009oooo]Z1_l0001KoookJP[o001o1_oonfX3o`00O`[ooo]Z1_l0001noookJPKo
0000VOoonfX009oooo]Z1_l0001[oookJP?o001o2_oonfX5o`0007oooo]Z1_l0002IoookJP00Wooo
nfX6o`0006_ooo]Z0ol007l:oookJPGo0000OooonfX6o`0009Wooo]Z002OoookJPOo0000J_oonfX3
o`00O`[ooo]Z1Ol0001ooookJPKo0000VOoonfX009oooo]Z1ol0001ZoookJP?o001o2_oonfX5o`00
07oooo]Z1ol0002HoookJP00WooonfX7o`0006Oooo]Z1_l007l:oookJPGo0000O_oonfX8o`0009So
oo]Z002OoookJPOo0000IooonfX6o`00O`[ooo]Z1Ol0001noookJPSo0000V?oonfX009oooo]Z1ol0
001YoookJPCo001o2_oonfX5o`0007kooo]Z2?l0002HoookJP00W_oonfX8o`0006[ooo]Z0ol007l:
oookJPGo0000O_oonfX8o`0009Sooo]Z002NoookJPSo0000MooonfX5o`0007kooo]Z2?l0002Hoook
JP00W_oonfX8o`0007Oooo]Z1Ol0001noookJPWo0000UooonfX009kooo]Z2?l0001goookJPGo0000
O_oonfX9o`0009Oooo]Z002NoookJPWo0000M_oonfX5o`0007kooo]Z2Ol0002GoookJP00W_oonfX9
o`0007Kooo]Z1Ol0001noookJPCo000000?ooo]Zo`000?l000000_l0002GoookJP00W_oonfX9o`00
07Kooo]Z1Ol0001noookJPCo000000?ooo]Zo`000?l000000_l0002GoookJP00W_oonfX4o`000003
oookJ_l0003o000000;o0000M_oonfX5o`0007kooo]Z1?l000000ooonf[o0000o`000002o`0009Oo
oo]Z002NoookJPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000003o`00073ooo]Z
1Ol0001noookJPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000003o`00097ooo]Z
002NoookJPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000003o`00073ooo]Z1Ol0
001noookJPCo000000?ooo]Zo`000?l000002?l0002AoookJP00W_oonfX4o`000003oookJ_l0003o
000000So0000L?oonfX5o`0007kooo]Z1?l000000ooonf[o0000o`000008o`00097ooo]Z002Noook
JPCo000000?ooo]Zo`000?l000002?l0001`oookJPGo0000O_oonfX4o`000003oookJ_l0003o0000
00So0000TOoonfX009kooo]Z1?l000000ooonf[o0000o`000008o`00073ooo]Z1Ol0001noookJPCo
000000?ooo]Zo`000?l000002Ol0002@oookJP00W_oonfX4o`000003oookJ_l0003o000000Wo0000
KooonfX5o`0007kooo]Z1?l000000ooonf[o0000o`000009o`00093ooo]Z002NoookJPCo000000?o
oo]Zo`000?l000002Ol0001_oookJPGo0000O_oonfX4o`000003oookJ_l0003o000000Wo0000T?oo
nfX009kooo]Z1?l00002oookJP[o0000KooonfX5o`0007kooo]Z1?l000000ooonf[o0000o`000009
o`00093ooo]Z002NoookJPCo00000_oonfX;o`0006kooo]Z1Ol0001noookJPCo00000_oonfX;o`00
08oooo]Z002NoookJPCo00000_oonfX;o`0006kooo]Z1Ol0001noookJPCo00000_oonfX;o`0008oo
oo]Z002NoookJPCo00000_oonfX5o`000003oookJ_l0003o000000?o0000K_oonfX5o`0007kooo]Z
1?l00003oookJPCo000000?ooo]Zo`000?l000000ol0002?oookJP00W_oonfX4o`0000Wooo]Z1Ol0
001]oookJPGo0000O_oonfX4o`0000Wooo]Z1?l0002?oookJP00W_oonfX4o`0000Wooo]Z1Ol0001]
oookJPGo0000OOoonfX5o`0000Wooo]Z1?l0002?oookJP00W_oonfX4o`0000Wooo]Z1Ol0001]oook
JPGo0000OOoonfX5o`0000Wooo]Z1Ol0002>oookJP00W_oonfX4o`0000[ooo]Z2Ol0001XoookJPGo
0000OOoonfX5o`0000Wooo]Z2_l00029oookJP00W_oonfX4o`0000[ooo]Z2Ol0001XoookJPGo0000
OOoonfX4o`0000[ooo]Z2_l00029oookJP00W_oonfX4o`0000[ooo]Z2_l0001WoookJPGo0000OOoo
nfX4o`0000_ooo]Z2_l00028oookJP00W_oonfX4o`0000[ooo]Z2_l0001WoookJPGo0000OOoonfX4
o`0000_ooo]Z2_l00028oookJP00W_oonfX4o`0000[ooo]Z2_l0001WoookJPGo0000OOoonfX4o`00
00_ooo]Z2_l00028oookJP00W_oonfX4o`0000_ooo]Z2_l0001VoookJPGo0000OOoonfX4o`0000co
oo]Z2Ol00028oookJP00W_oonfX4o`0000_ooo]Z2_l0001VoookJPGo0000OOoonfX4o`0000cooo]Z
2_l00027oookJP00W_oonfX4o`00013ooo]Z1Ol0001VoookJPGo0000OOoonfX4o`00017ooo]Z1Ol0
0027oookJP00WOoonfX5o`00017ooo]Z1?l00018oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:
oookJPGo0000OOoonfX4o`00017ooo]Z1Ol00027oookJP00WOoonfX5o`00017ooo]Z1Ol00016oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000OOoonfX4o`0001;ooo]Z1Ol00026oook
JP00WOoonfX5o`00017ooo]Z1Ol00016oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000B
oookJPGo0000Q_oonfX009gooo]Z1?l0000BoookJPKo0000>?oonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000OOoonfX4o`0001;ooo]Z1Ol00026oook
JP00WOoonfX4o`0001?ooo]Z2Ol0000doookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2?oonfX6o`0007cooo]Z1?l0000CoookJP[o0000P?oonfX009gooo]Z1?l0000CoookJP[o0000
?ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0007gooo]Z1?l0000CoookJP[o0000
P?oonfX009gooo]Z1?l0000DoookJP[o0000?_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z1Ol0001moookJPCo00004ooonfX:o`00083ooo]Z002MoookJPCo00005?oonfX:
o`0003kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001moookJPCo00005?oonfX:
o`0007oooo]Z002MoookJPCo00005?oonfX:o`0003kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
O`[ooo]Z1Ol0001moookJPCo00005OoonfX9o`0007oooo]Z002MoookJPCo00006_oonfX5o`0003go
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001moookJPCo00006OoonfX6o`0007ko
oo]Z002MoookJPCo00006_oonfX5o`0003kooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o3_oonfX5o`0007gooo]Z1?l0000JoookJPGo0000O_oonfX009gooo]Z1?l0000JoookJPGo0000
?_oonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000OOoonfX4o`0001[ooo]Z1_l0001moookJP00WOoo
nfX4o`0001_ooo]Z1?l0000ooookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001moookJPCo00006ooo
nfX5o`0007gooo]Z002MoookJPCo00006ooonfX6o`0005_ooo]Z1Ol0001moookJPCo00006ooonfX9
o`0007Wooo]Z002MoookJPCo00006ooonfX7o`0005[ooo]Z1Ol0001moookJPCo00007?oonfX:o`00
07Oooo]Z002MoookJPCo00006ooonfX8o`0005Wooo]Z1Ol0001moookJPCo00007?oonfX:o`0007Oo
oo]Z002MoookJPCo00007?oonfX9o`0005Oooo]Z1Ol0001moookJPCo00007?oonfX:o`0007Oooo]Z
002MoookJPCo00007OoonfX:o`0005Gooo]Z1Ol0001moookJPCo00007OoonfX9o`0007Oooo]Z002M
oookJPCo00007ooonfX9o`0005Cooo]Z1Ol0001moookJPCo00008_oonfX5o`0007Kooo]Z002Moook
JPCo00008?oonfX:o`0005;ooo]Z1Ol0001moookJPCo00008_oonfX6o`0007Gooo]Z002MoookJPCo
00008_oonfX9o`00057ooo]Z1Ol0001moookJPCo00008_oonfX6o`0007Gooo]Z002MoookJPCo0000
9?oonfX9o`0004oooo]Z1Ol0001moookJPCo00008ooonfX:o`00073ooo]Z002MoookJPCo00009Ooo
nfX9o`0004kooo]Z1Ol0001moookJPCo00009?oonfX:o`0006oooo]Z002MoookJPCo00009ooonfX8
o`0004gooo]Z1Ol0001moookJPCo00009?oonfX:o`0006oooo]Z002MoookJPCo0000:?oonfX9o`00
04_ooo]Z1Ol0001loookJPGo00009OoonfX:o`0006kooo]Z000RoookJP?o001oMOoonfX3o`00O`Co
00000_oonfX3o`00O`?ooo]Z1Ol007lMoookJPSo0000B_oonfX5o`0007Cooo]Z1Ol007l3oookJPGo
00000_oonfX5o`00Oaoooo]Z2_l0001=oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJPCo001o
1?l00002oookJP?o001o0_oonfX7o`00Oagooo]Z2?l00019oookJPGo0000LooonfX7o`00O`;ooo]Z
1Ol000000ooonf[o001oo`00O`05o`00Ob;ooo]Z1_l0001=oookJP?o001o7OoonfX002;ooo]Z0ol0
07mdoookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007lNoookJPWo0000AooonfX5o`0007?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l2oookJPCo000000?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lSoook
JPKo0000C?oonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o
001o0_oonfX4o`0000Kooo]Z0ol007l3oookJP?o001o7ooonfX8o`0004Kooo]Z1Ol0001boookJP?o
001o0ooonfX3o`00O`03oookJ_l0003o000000;o000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00
Ob?ooo]Z2_l00017oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l2oookJPCo00003?oonfX3o`00Ob3ooo]Z2?l00015oookJPGo0000L_oonfX3o`00O`?o
oo]Z0ol007l00ooonf[o0000o`000002o`0000Oooo]Z0ol007lSoookJP_o0000A_oonfX3o`00Oago
oo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000?o00003?oonfX3o`00Ob7ooo]Z
2Ol00013oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000Oooo]Z
0ol007lToookJP_o0000AOoonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0
003o000000?o00001ooonfX2o`00O`;ooo]Z1?l007lSoookJPWo0000@OoonfX5o`0007;ooo]Z0ol0
07l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP;o001o0_oonfX4o`00ObGooo]Z2_l0
0015oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000ol00007
oookJPOo001o9OoonfX9o`00043ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o
000000;o00000_oonfX7o`00Ob_ooo]Z1_l00014oookJP?o001o7OoonfX002;ooo]Z0ol007mcoook
JP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP05oookJPKo001o9ooonfX;o`00
03gooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oonfX6o`00
Obgooo]Z2ol0000noookJP?o001o7OoonfX001oooo]Z1_l007mcoookJP?o001o00?ooo]Zo`000?l0
00000_l000000ol007oooo]ZoookJP05oookJP;o001o;OoonfX:o`0003cooo]Z1Ol0001boookJP?o
001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oonfX2o`00Oc7ooo]Z3?l0000joookJPKo
001o7OoonfX001oooo]Z1_l007mdoookJP?o001o1?l00008oookJP;o001o;ooonfX9o`0003_ooo]Z
1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`0000;ooo]Z0_l007lboookJP_o
0000>_oonfX6o`00Oagooo]Z000QoookJPCo001oM?oonfX3o`00O`Co00002OoonfX7o`00Ob[ooo]Z
2?l0000koookJPGo0000LooonfX7o`00O`;ooo]Z1?l00003oookJPOo001o;OoonfX<o`0003[ooo]Z
1?l007lMoookJP008_oonfX3o`00OgGooo]Z0_l007l4o`0000Wooo]Z1ol007l]oookJPco0000=?oo
nfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX7o`00Oc?ooo]Z3?l0000eoookJP?o001o7Ooo
nfX009cooo]Z1?l0000noookJPco0000<ooonfX5o`0007cooo]Z1?l0000moookJPgo0000E?oonfX0
09cooo]Z1?l0000noookJPgo000000?ooo]Zo`000?l000000_l0000]oookJPGo0000O?oonfX4o`00
03kooo]Z3?l000000ooonf[o0000o`000003o`0004kooo]Z002LoookJPCo0000?ooonfXCo`0002_o
oo]Z1Ol0001loookJPCo0000?ooonfXCo`0004cooo]Z002LoookJPCo0000A_oonfX=o`0000;ooo]Z
1?l0000ToookJPGo0000O?oonfX4o`0004Kooo]Z3Ol00002oookJPCo0000AOoonfX009cooo]Z1?l0
0016oookJQCo00008ooonfX5o`0007cooo]Z1?l00016oookJQCo0000A?oonfX009cooo]Z1?l00017
oookJQco00006_oonfX5o`0007cooo]Z1?l00017oookJQ_o0000??oonfX000kooo]Zool0003oo`00
02Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go0000
3ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX0
01gooo]Z00?o0000oookJ_oonfX01_l00002oookJPKo00000ooonfXMo`0004kooo]Z1?l0001Yoook
JPKo00000_oonfX6o`0000?ooo]Z3_l00003oookJPKo000000?ooo]Zo`000?l000007?l0001>oook
JPCo0000J_oonfX5o`0000?ooo]Z1Ol00003oookJPKo00007_oonfX003[ooo]Z6ol00017oookJPCo
0000OOoonfX5o`0001[ooo]Z7?l00016oookJPCo0000W_oonfX0047ooo]Z5?l00017oookJPCo0000
OOoonfX5o`0002;ooo]Z5_l00014oookJPCo0000W_oonfX004?ooo]Z1Ol00002oookJPco0000A_oo
nfX4o`0007gooo]Z1Ol0000SoookJPGo00000_oonfX?o`0004?ooo]Z1?l0002NoookJP00B_oonfXC
o`0003oooo]Z1?l0001moookJPGo0000:_oonfXAo`00047ooo]Z1?l0002NoookJP00C?oonfXBo`00
03kooo]Z1?l0001moookJPGo0000;?oonfX5o`0000;ooo]Z2_l0000ooookJPCo0000W_oonfX005;o
oo]Z3Ol0000moookJPCo0000OOoonfX5o`0003Gooo]Z2Ol0000noookJPCo0000W_oonfX005?ooo]Z
3?l0000moookJPCo0000OOoonfX5o`0003Kooo]Z2_l0000loookJPCo0000W_oonfX005Gooo]Z1?l0
00000ooonf[o0000o`000009o`0003Oooo]Z1?l0001moookJPGo0000>?oonfX:o`0003[ooo]Z1?l0
002NoookJP00FooonfX;o`0003Kooo]Z1?l0001moookJPGo0000>_oonfX:o`0003Sooo]Z1?l0002N
oookJP00FooonfX<o`0003Gooo]Z1?l0001moookJPGo0000>ooonfX:o`0003Oooo]Z1?l0002Noook
JP00G?oonfX;o`0003Gooo]Z1?l0001moookJPGo0000?OoonfX:o`0003Gooo]Z1?l0002NoookJP00
H_oonfX6o`0003Cooo]Z1?l0001moookJPGo0000?ooonfX:o`0003?ooo]Z1?l0002NoookJP00Hooo
nfX:o`0002oooo]Z1?l0001moookJPGo0000@OoonfX<o`0002oooo]Z1?l0002NoookJP00HooonfX;
o`0002kooo]Z1?l0001moookJPGo0000@_oonfX<o`0002kooo]Z1?l0002NoookJP00I?oonfX:o`00
02kooo]Z1?l0001moookJPGo0000A?oonfX:o`0002kooo]Z1?l0002NoookJP00I?oonfX:o`0002ko
oo]Z1?l0001moookJPGo0000A_oonfX9o`0002gooo]Z1?l0002NoookJP00I_oonfX9o`0002gooo]Z
1?l0001moookJPGo0000B_oonfX6o`0002cooo]Z1?l0002NoookJP00J_oonfX6o`0002cooo]Z1?l0
001moookJPGo0000B_oonfX7o`0002_ooo]Z1?l0002NoookJP00J_oonfX;o`0002Oooo]Z1?l0001m
oookJPGo0000BooonfX:o`0002Oooo]Z1?l0002NoookJP00JooonfX;o`0002Kooo]Z1?l0001moook
JPGo0000C?oonfX:o`0002Kooo]Z1?l0002NoookJP00K?oonfX;o`0002Gooo]Z1?l0001moookJPGo
0000COoonfX:o`0002Gooo]Z1?l0002NoookJP00KOoonfX:o`0002Gooo]Z1?l0001moookJPGo0000
COoonfX:o`0002Gooo]Z1?l0002NoookJP00KOoonfX;o`0002Cooo]Z1?l0001moookJPGo0000C_oo
nfX9o`0002Cooo]Z1Ol0002NoookJP00LooonfX6o`0002?ooo]Z1?l0001moookJPGo0000DooonfX5
o`0002?ooo]Z1Ol0002NoookJP00LooonfX6o`0002;ooo]Z1Ol0001moookJPGo0000DooonfX6o`00
02;ooo]Z1Ol0002NoookJP00M?oonfX6o`00027ooo]Z1Ol0001moookJPGo0000DooonfX6o`0002;o
oo]Z1?l0002OoookJP00MOoonfX6o`00023ooo]Z1Ol0001moookJPGo0000E?oonfX:o`0001gooo]Z
1?l0002OoookJP00MOoonfX6o`00023ooo]Z1?l0001noookJPGo0000EOoonfX:o`0001cooo]Z1?l0
002OoookJP00M_oonfX6o`0001oooo]Z1?l0001noookJPGo0000EOoonfX:o`0001cooo]Z1?l0002O
oookJP00MooonfX6o`0001kooo]Z1?l0001noookJPGo0000E_oonfX9o`0001cooo]Z1?l0002Ooook
JP00MooonfX7o`0001gooo]Z1?l0001noookJPGo0000EooonfX9o`0001_ooo]Z1?l0002OoookJP00
N?oonfX6o`0001gooo]Z1?l0001noookJPGo0000FooonfX5o`0001_ooo]Z1?l0002OoookJP00NOoo
nfX6o`0001cooo]Z1?l0001noookJPGo0000FooonfX6o`0001[ooo]Z1?l0002OoookJP00N_oonfX6
o`0001_ooo]Z1?l0001noookJPGo0000G?oonfX5o`0001[ooo]Z1?l0002OoookJP00N_oonfX6o`00
01_ooo]Z1?l0001PoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000G?oonfX5o`00
01[ooo]Z1?l0002OoookJP00NooonfX6o`0001[ooo]Z1?l0001OoookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l9oookJPGo0000GOoonfX9o`0001Gooo]Z1?l0002OoookJP00O?oonfX7o`0001Sooo]Z
1?l0001OoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o
001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005gooo]Z2_l0000DoookJPCo0000WooonfX007co
oo]Z2?l0000GoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`So
oo]Z1Ol0001MoookJP[o00005?oonfX4o`0009oooo]Z001moookJPSo00005_oonfX4o`0005kooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001MoookJP[o00004ooonfX4o`0009oooo]Z
001noookJPSo00005OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0
001NoookJP[o00004ooonfX4o`0009oooo]Z0020oookJPOo00005?oonfX4o`0005kooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000HooonfX5o`0001?ooo]Z1?l0002O
oookJP00POoonfX7o`0001?ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oook
JPGo0000I?oonfX5o`0001;ooo]Z1?l0002OoookJP00P_oonfX7o`0001;ooo]Z1?l0001NoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000I?oonfX5o`0001;ooo]Z1?l0002OoookJP00
PooonfX7o`00017ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000
I?oonfX5o`0001;ooo]Z1?l0002OoookJP00Q?oonfX7o`00013ooo]Z1?l0001OoookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001UoookJPCo00004_oonfX4o`0009oooo]Z
0025oookJP[o00003?oonfX4o`0005oooo]Z1ol007l9oookJPOo001o2?oonfX5o`0006Gooo]Z1?l0
00000ooonf[o0000o`000003o`0000cooo]Z1?l0002OoookJP00Q_oonfX9o`0000cooo]Z1?l0001P
oookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001UoookJP[o00003?oonfX4o`0009oooo]Z0027oook
JPSo00003?oonfX4o`0007kooo]Z1Ol0001UoookJP[o00003?oonfX4o`0009oooo]Z0028oookJPSo
00002ooonfX4o`0007kooo]Z1Ol0001UoookJP_o00002ooonfX4o`0009oooo]Z0029oookJPOo0000
2ooonfX4o`0007kooo]Z1Ol0001VoookJP[o00002ooonfX4o`0009oooo]Z002;oookJPKo00002_oo
nfX4o`0007kooo]Z1Ol0001WoookJPWo00002ooonfX4o`0009oooo]Z002<oookJPGo00002_oonfX4
o`0007kooo]Z1Ol0001WoookJPWo00002ooonfX4o`0009oooo]Z002<oookJPGo00002_oonfX4o`00
07kooo]Z1Ol0001/oookJPCo00002ooonfX4o`0009oooo]Z002=oookJPCo00002_oonfX4o`0007ko
oo]Z1Ol0001/oookJPGo00002_oonfX4o`0009oooo]Z002=oookJPCo00002_oonfX4o`0007kooo]Z
1Ol0001/oookJPGo00002OoonfX5o`0009oooo]Z002=oookJPCo00000_oonfX4o`0000?ooo]Z1Ol0
001noookJPGo0000K?oonfX5o`0000;ooo]Z1?l00003oookJPGo0000WooonfX008gooo]Z1Ol00000
0ooonf[o0000o`000003o`0000;ooo]Z1Ol0001noookJPGo0000KOoonfX;o`0000;ooo]Z1Ol0002O
oookJP00SOoonfX;o`0000;ooo]Z1Ol0001noookJPGo0000KOoonfX;o`0000;ooo]Z1?l0002Poook
JP00SOoonfX;o`0000;ooo]Z1?l0001ooookJPGo0000KOoonfX<o`000003oookJ_l0003o000000;o
0000X?oonfX008kooo]Z2_l00002oookJPCo0000OooonfX5o`0006kooo]Z2ol000000ooonf[o0000
o`000002o`000:3ooo]Z002>oookJP[o00000_oonfX4o`0007oooo]Z1Ol0001^oookJP_o000000?o
oo]Zo`000?l000000_l0002PoookJP00S_oonfX:o`0000;ooo]Z1?l0001ooookJPGo0000K_oonfX;
o`000003oookJ_l0003o000000;o0000X?oonfX008oooo]Z2Ol00002oookJPCo0000OooonfX5o`00
06oooo]Z2_l000000ooonf[o0000o`000002o`000:3ooo]Z002?oookJP[o000000?ooo]Zo`000?l0
00000_l0001ooookJPGo0000KooonfX:o`000003oookJ_l0003o000000;o0000X?oonfX008oooo]Z
2_l000000ooonf[o0000o`000002o`0007oooo]Z1Ol0001_oookJP[o000000?ooo]Zo`000?l00000
0_l0002PoookJP00SooonfX:o`000003oookJ_l0003o000000;o0000OooonfX5o`0006oooo]Z1Ol0
00000ooonf[o0000o`000002o`000003oookJ_l0003o000000;o0000X?oonfX009Gooo]Z1?l00000
0ooonf[o0000o`000002o`0007oooo]Z1Ol0001eoookJPCo000000?ooo]Zo`000?l000000_l0002P
oookJP00UOoonfX4o`000003oookJ_l0003o000000;o0000OooonfX5o`0007Gooo]Z1?l000000ooo
nf[o0000o`000002o`000:3ooo]Z002EoookJPCo000000?ooo]Zo`000?l000000_l0001ooookJPGo
0000MOoonfX9o`000:3ooo]Z002EoookJPCo000000?ooo]Zo`000?l000000_l0001ooookJPGo0000
MOoonfX9o`000:3ooo]Z002EoookJPWo0000OooonfX5o`0007Gooo]Z2Ol0002PoookJP00UOoonfX9
o`0007oooo]Z1Ol0001foookJPOo0000XOoonfX009Gooo]Z2Ol0001ooookJPGo0000M_oonfX7o`00
0:7ooo]Z002EoookJPSo0000P?oonfX5o`0007Kooo]Z1ol0002QoookJP00U_oonfX7o`00083ooo]Z
1Ol0001foookJPOo0000XOoonfX009Kooo]Z1ol00020oookJPGo0000M_oonfX7o`000:7ooo]Z002F
oookJPOo0000LooonfX3o`00O`[ooo]Z1Ol0001foookJPOo0000XOoonfX009Kooo]Z1ol0001coook
JP?o001o2_oonfX5o`0007Kooo]Z1ol0002QoookJP00U_oonfX7o`0007?ooo]Z0ol007l:oookJPGo
0000M_oonfX7o`000:7ooo]Z002FoookJPOo0000LooonfX3o`00O`[ooo]Z1Ol0001foookJPOo0000
XOoonfX009Kooo]Z1ol0001coookJP?o001o2_oonfX6o`0007Gooo]Z1ol0002QoookJP00U_oonfX7
o`0007?ooo]Z0ol007l:oookJPGo0000M_oonfX7o`000:7ooo]Z002FoookJPOo0000LooonfX3o`00
O`[ooo]Z1Ol0001foookJPOo0000XOoonfX009Oooo]Z1_l0001coookJP?o001o2_oonfX5o`0007Oo
oo]Z1_l0002QoookJP00UooonfX6o`0007?ooo]Z0ol007l:oookJPGo0000MooonfX6o`000:7ooo]Z
002GoookJPKo0000L?oonfX6o`00O`[ooo]Z1Ol0001goookJPKo0000XOoonfX009Oooo]Z1_l0001`
oookJPKo001o2_oonfX5o`0007Oooo]Z1_l0002QoookJP00UooonfX6o`0007;ooo]Z1?l007l:oook
JPGo0000MooonfX5o`000:;ooo]Z002GoookJPGo0000M?oonfX3o`00O`[ooo]Z1Ol0001hoookJPCo
0000X_oonfX009Sooo]Z1?l00021oookJPGo0000N?oonfX4o`000:;ooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[o
oo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oo
nfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3
o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2
o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooook
JQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooo
nfXOoookJP00oooonfX>oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00
O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00
oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oo
nfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oook
JP?o001ooooonfX/oookJP00oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z
3_oonfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2
oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30975 L
.02605 .31027 L
.02729 .31057 L
.02846 .31048 L
.02954 .3101 L
.03053 .30955 L
.03162 .30886 L
.03279 .30816 L
.03396 .30765 L
.03506 .30747 L
.03636 .30767 L
.03756 .3082 L
.03883 .30899 L
.04018 .30985 L
.04146 .31045 L
.04262 .31066 L
.04382 .31052 L
.04512 .30997 L
.04635 .30923 L
.04748 .30853 L
.04871 .30793 L
.04941 .30772 L
.05006 .30765 L
.05137 .30784 L
.05211 .30814 L
.05278 .3085 L
.05516 .31009 L
.05581 .31046 L
.0565 .31078 L
.05774 .31106 L
.0589 .31095 L
.05998 .31056 L
.06117 .3099 L
.06244 .30912 L
.06373 .30849 L
.06444 .30829 L
.06509 .30821 L
.06636 .30841 L
.06756 .30898 L
.06897 .30995 L
.07047 .31103 L
.07175 .31173 L
.07247 .31195 L
.07315 .31203 L
.07385 .31198 L
.07452 .31181 L
.07576 .31126 L
.07712 .31047 L
.07786 .31006 L
Mistroke
.07856 .30973 L
.07933 .30949 L
.08002 .30941 L
.08067 .30945 L
.08137 .30963 L
.08214 .30999 L
.08296 .31052 L
.08443 .31168 L
.08566 .31266 L
.08683 .31338 L
.08747 .31363 L
.08818 .31378 L
.0894 .3137 L
.09057 .31328 L
.09181 .31262 L
.09298 .312 L
.09404 .31159 L
.09529 .31146 L
.09594 .31158 L
.09663 .31184 L
.09779 .31257 L
.09905 .31366 L
.10044 .31493 L
.1012 .31555 L
.10192 .31603 L
.10259 .31636 L
.10331 .31657 L
.10458 .31655 L
.10582 .31614 L
.10695 .31558 L
.10816 .31499 L
.10885 .31474 L
.10949 .3146 L
.11063 .31465 L
.11184 .31516 L
.1129 .31596 L
.11407 .31711 L
.11533 .31844 L
.11665 .31967 L
.11735 .32016 L
.11811 .32053 L
.1188 .32071 L
.11944 .32073 L
.12072 .32045 L
.12188 .31994 L
.12313 .31937 L
.12383 .31913 L
.12449 .31901 L
.12581 .31917 L
.12648 .31948 L
Mistroke
.1272 .31998 L
.1285 .32126 L
.12969 .32268 L
.13107 .32432 L
.1318 .32507 L
.13258 .3257 L
.13332 .32613 L
.134 .32635 L
.13532 .32634 L
.13664 .32591 L
.13785 .32538 L
.13849 .32515 L
.13918 .32499 L
.13991 .32496 L
.14059 .3251 L
.14184 .32581 L
.14298 .32694 L
.14555 .33044 L
.14665 .33187 L
.14784 .33306 L
.14914 .33377 L
.15036 .33387 L
.15166 .33352 L
.15232 .33326 L
.15303 .33297 L
.1543 .33266 L
.15547 .3328 L
.15667 .33351 L
.1578 .33473 L
.15881 .33618 L
.15991 .33798 L
.16111 .33994 L
.16238 .34171 L
.16346 .34277 L
.16465 .34335 L
.1755 .34967 L
.17679 .35205 L
.178 .35382 L
.17867 .35451 L
.17939 .35501 L
.18065 .35528 L
.18186 .35499 L
.18313 .35446 L
.18422 .35416 L
.18542 .3543 L
.18661 .35518 L
.18789 .35701 L
.1891 .35944 L
.1902 .36199 L
.19148 .36495 L
Mistroke
.19215 .36635 L
.19287 .36761 L
.19419 .36919 L
.1954 .36973 L
.19652 .36957 L
.19773 .36899 L
.19887 .36845 L
.19991 .3683 L
.20113 .36887 L
.20182 .36963 L
.20246 .37064 L
.20363 .37316 L
.20488 .37655 L
.2062 .38034 L
.20759 .38387 L
.20832 .38528 L
.20911 .38639 L
.20984 .38698 L
.21052 .38717 L
.21121 .38705 L
.21186 .38671 L
.21309 .38578 L
.2144 .38493 L
.21515 .3848 L
.21584 .38504 L
.21702 .38641 L
.21813 .38886 L
.21934 .39264 L
.22066 .39742 L
.22196 .40206 L
.22267 .40423 L
.22333 .40588 L
.2245 .40774 L
.22578 .4081 L
.22705 .40702 L
.22769 .40613 L
.2284 .40509 L
.22965 .40358 L
.23082 .40326 L
.23153 .40384 L
.2322 .40502 L
.23346 .40888 L
.23416 .41186 L
.23481 .41501 L
.23629 .42274 L
.23759 .4289 L
.23882 .4329 L
.23991 .43438 L
.2411 .43353 L
.2424 .4302 L
Mistroke
.24377 .42539 L
.24494 .42184 L
.24622 .42035 L
.24747 .42271 L
.24865 .42899 L
.24971 .43769 L
.25087 .44934 L
.25212 .46242 L
.25281 .46867 L
.25345 .47331 L
.25459 .47721 L
.25584 .47294 L
.25694 .46026 L
.25809 .43739 L
.25908 .4106 L
.26016 .37501 L
.26258 .28287 L
.26481 .20506 L
.26604 .17315 L
.26735 .15114 L
.26866 .14148 L
.26941 .14102 L
.27011 .14333 L
.27137 .15255 L
.27252 .16417 L
.27386 .17811 L
.2751 .18868 L
.27622 .19486 L
.2774 .1976 L
.27859 .1968 L
.2799 .19313 L
.28105 .18905 L
.28211 .18577 L
.28323 .18383 L
.28445 .18413 L
.28576 .18738 L
.28649 .19031 L
.28716 .19347 L
.28965 .20617 L
.29032 .20902 L
.29103 .21149 L
.29181 .21343 L
.29253 .21447 L
.29383 .21468 L
.29456 .21406 L
.29525 .21317 L
.29656 .21127 L
.29781 .21003 L
.29893 .21001 L
.30015 .21148 L
Mistroke
.30147 .21475 L
.30288 .21958 L
.30419 .22441 L
.30541 .22841 L
.30665 .23137 L
.30731 .23238 L
.30802 .23302 L
.30876 .23324 L
.30946 .23309 L
.31077 .23222 L
.31191 .23134 L
.31313 .23087 L
.31376 .23096 L
.31446 .23141 L
.3157 .23311 L
.32683 .24866 L
.32809 .24829 L
.32927 .2486 L
.33049 .24977 L
.33114 .25076 L
.33183 .25204 L
.33465 .25846 L
.3353 .25985 L
.33599 .26116 L
.33723 .26289 L
.3385 .26377 L
.33915 .2639 L
.33987 .26383 L
.34115 .26337 L
.34235 .2629 L
.34352 .26276 L
.34459 .26312 L
.34583 .26423 L
.347 .26595 L
.3496 .27091 L
.35087 .27313 L
.35205 .27463 L
.35311 .27545 L
.35424 .27573 L
.35537 .27554 L
.35662 .27508 L
.3573 .27482 L
.35795 .27466 L
.35917 .27468 L
.36049 .27537 L
.36123 .27609 L
.36191 .27694 L
.36446 .281 L
.36571 .28291 L
.36685 .28426 L
Mistroke
.3679 .28505 L
.3689 .28537 L
.36995 .28531 L
.3711 .28494 L
.37227 .28447 L
.37353 .28416 L
.37471 .28428 L
.37578 .28483 L
.377 .28598 L
.37812 .2874 L
.37933 .28911 L
.38066 .29089 L
.38181 .2921 L
.38289 .29281 L
.38403 .29308 L
.38525 .2929 L
.38657 .29239 L
.38781 .29188 L
.3891 .29162 L
.38979 .29168 L
.39053 .29192 L
.39177 .29275 L
.39308 .29409 L
.39541 .29689 L
.39673 .29815 L
.39747 .29863 L
.39815 .29891 L
.39946 .299 L
.40069 .29866 L
.40139 .29835 L
.40214 .29799 L
.40278 .2977 L
.40347 .29746 L
.40421 .29731 L
.4049 .29731 L
.40572 .29751 L
.40647 .29788 L
.41691 .30243 L
.41816 .30182 L
.41887 .30157 L
.41952 .30144 L
.42072 .30151 L
.42199 .30206 L
.42312 .30289 L
.42418 .30384 L
.42542 .30497 L
.42659 .30586 L
.4277 .30641 L
.42891 .30658 L
.43001 .30637 L
Mistroke
.43103 .30594 L
.43212 .30534 L
.43329 .30473 L
.43458 .3043 L
.43579 .30428 L
.437 .30467 L
.43827 .30547 L
.44055 .30729 L
.4418 .30811 L
.44296 .30855 L
.44423 .30859 L
.44495 .30841 L
.44559 .30815 L
.44808 .30676 L
.44934 .30621 L
.45005 .30604 L
.45071 .306 L
.45144 .30611 L
.45211 .30633 L
.45287 .30671 L
.4536 .30718 L
.45489 .30812 L
.4556 .30863 L
.45626 .30906 L
.45757 .30966 L
.45876 .30982 L
.45988 .30961 L
.46108 .30908 L
.46238 .3083 L
.46361 .30758 L
.46429 .30728 L
.46503 .30705 L
.46632 .307 L
.46757 .30736 L
.46889 .3081 L
.47012 .30894 L
.47127 .30967 L
.47232 .31016 L
.47346 .31039 L
.47472 .31023 L
.47587 .30976 L
.47843 .30821 L
.47913 .30784 L
.47988 .30755 L
.48059 .3074 L
.48123 .30737 L
.48249 .30764 L
.4832 .30795 L
.48385 .30831 L
.48514 .30915 L
Mistroke
.48632 .30987 L
.48754 .31039 L
.48885 .31056 L
.49006 .31031 L
.49121 .30978 L
.49256 .30894 L
.4933 .30847 L
.494 .30807 L
.49522 .30759 L
.49587 .30747 L
.49658 .30747 L
.49789 .30782 L
.49856 .30814 L
.49928 .30856 L
.50058 .30939 L
.50176 .31006 L
.50249 .31036 L
.50318 .31053 L
.5039 .31058 L
.50469 .31047 L
.50537 .31025 L
.5061 .30991 L
.50741 .30912 L
.50862 .30836 L
.50994 .30772 L
.51118 .30747 L
.51234 .30761 L
.51348 .30806 L
.51452 .30867 L
.51565 .30941 L
.51684 .31011 L
.51815 .31058 L
.51935 .31064 L
.52065 .31029 L
.52138 .30993 L
.52206 .30953 L
.52328 .30876 L
.52444 .30812 L
.52507 .30787 L
.52577 .30769 L
.52698 .3077 L
.52811 .30805 L
.52917 .30863 L
.53044 .30948 L
.5316 .31024 L
.53275 .3108 L
.53396 .31106 L
.53517 .31093 L
.53586 .3107 L
.5365 .31039 L
Mistroke
.53755 .30978 L
.53869 .30909 L
.53976 .30855 L
.54075 .30826 L
.54191 .30825 L
.54313 .30864 L
.54416 .30924 L
.54529 .31005 L
.5465 .31093 L
.54779 .31166 L
.54847 .3119 L
.54921 .31203 L
.55052 .31187 L
.55175 .31136 L
.55307 .31061 L
.55422 .30997 L
.55548 .3095 L
.5567 .30943 L
.55784 .30974 L
.55904 .31044 L
.56032 .31144 L
.56152 .31241 L
.56265 .31318 L
.56367 .31363 L
.56477 .3138 L
.56607 .31356 L
.56728 .31302 L
.56873 .31222 L
.57005 .31164 L
.57071 .31149 L
.57143 .31146 L
.57275 .3118 L
.57347 .31221 L
.57425 .31278 L
.57564 .31403 L
.57695 .3152 L
.57763 .31573 L
.57835 .31617 L
.57899 .31644 L
.57968 .31659 L
.58091 .31652 L
.5821 .3161 L
.58337 .31546 L
.58456 .3149 L
.58568 .3146 L
.5869 .31467 L
.58754 .3149 L
.58824 .3153 L
.58894 .31583 L
.58966 .3165 L
Mistroke
.59097 .31786 L
.5921 .31902 L
.5933 .32001 L
.594 .32041 L
.59463 .32063 L
.59586 .32071 L
.59655 .32057 L
.59728 .32031 L
.59859 .3197 L
.59927 .31939 L
.6 .31914 L
.6008 .319 L
.60155 .31905 L
.60224 .31926 L
.603 .31969 L
.60371 .32025 L
.60436 .3209 L
.60693 .32395 L
.6082 .32525 L
.60891 .3258 L
.60957 .32615 L
.61077 .32641 L
.61205 .3262 L
.61319 .32575 L
.61426 .3253 L
.61543 .32498 L
.61668 .32507 L
.61737 .32536 L
.61802 .32579 L
.61872 .32644 L
.61947 .3273 L
.62211 .33095 L
.62324 .33232 L
.62446 .33337 L
.62516 .33371 L
.6258 .33387 L
.62705 .33378 L
.62834 .33333 L
.62955 .33286 L
.63064 .33265 L
.63181 .33285 L
.6331 .33372 L
.63375 .33442 L
.63446 .33536 L
.63689 .33929 L
.63806 .34106 L
.63917 .34236 L
.64045 .34323 L
.64161 .34343 L
.64271 .3432 L
Mistroke
.64373 .34282 L
.64484 .34243 L
.64603 .34233 L
.6473 .34284 L
.64847 .34399 L
.64975 .34594 L
.6511 .3485 L
.65229 .35081 L
.65341 .35275 L
.6547 .35437 L
.65587 .35514 L
.65716 .35525 L
.65789 .35505 L
.65856 .35478 L
.65978 .3543 L
.66106 .35415 L
.66174 .35436 L
.66246 .35485 L
.66377 .35648 L
.66457 .35792 L
.66532 .35952 L
.66675 .36284 L
.66799 .36564 L
.66865 .36691 L
.66934 .36803 L
.67061 .36936 L
.67178 .36974 L
.67291 .36949 L
.67396 .36897 L
.67511 .36843 L
.67635 .36834 L
.67767 .36921 L
.67841 .37023 L
.6791 .37151 L
.6817 .37838 L
.68292 .3818 L
.68407 .38447 L
.68526 .38635 L
.68658 .38716 L
.68881 .38615 L
.6899 .3853 L
.69089 .38483 L
.69194 .38499 L
.69306 .38617 L
.69428 .38877 L
.69543 .3923 L
.69782 .40097 L
.69848 .40312 L
.69917 .40506 L
.70041 .40743 L
Mistroke
.70154 .40817 L
.70259 .40772 L
.70374 .40635 L
.70497 .40455 L
.70619 .40334 L
.70688 .40322 L
.70753 .40362 L
.70883 .40614 L
.70957 .40856 L
.71024 .41136 L
.71277 .4242 L
.714 .42977 L
.71512 .43316 L
.71636 .4344 L
.71705 .43391 L
.71769 .43274 L
.71839 .43083 L
.71904 .42868 L
.71979 .42597 L
.7205 .42358 L
.72181 .42063 L
.72251 .42038 L
.72326 .42147 L
.72404 .42428 L
.72478 .42855 L
.72545 .43363 L
.72618 .44027 L
.72742 .45324 L
.72808 .46011 L
.72877 .46676 L
.73005 .47543 L
.73122 .47684 L
.73192 .47374 L
.73257 .46782 L
.73328 .4578 L
.73405 .4429 L
.73538 .40714 L
.7366 .36583 L
.73899 .27461 L
.74024 .22918 L
.74158 .18892 L
.74274 .16319 L
.74402 .14621 L
.74519 .14086 L
.74629 .14327 L
.74849 .16187 L
.74965 .17412 L
.75088 .18555 L
.75196 .19278 L
.75314 .19701 L
Mistroke
.75421 .19756 L
.75522 .1958 L
.75763 .18773 L
.75832 .18572 L
.75898 .18436 L
.76022 .18372 L
.76135 .18554 L
.76239 .18908 L
.76354 .19444 L
.76476 .20085 L
.76612 .20745 L
.76684 .21026 L
.7676 .21253 L
.76826 .21388 L
.76898 .21468 L
.77026 .21452 L
.7715 .21308 L
.77219 .21208 L
.77283 .21116 L
.77409 .20999 L
.77523 .21008 L
.77641 .21162 L
.77766 .21476 L
.7799 .22269 L
.78107 .22677 L
.78232 .23028 L
.78303 .23171 L
.78369 .2326 L
.78498 .23324 L
.78615 .23282 L
.7874 .23187 L
.78858 .23108 L
.78965 .23088 L
.79091 .23166 L
.79162 .23264 L
.79227 .23386 L
.79475 .2404 L
.79589 .24364 L
.79713 .24659 L
.79783 .24789 L
.79848 .24877 L
.79974 .24967 L
.80104 .24962 L
.80177 .24931 L
.80245 .24895 L
.80369 .24839 L
.80432 .24829 L
.80502 .24839 L
.80565 .24872 L
.80635 .24936 L
Mistroke
.80707 .25033 L
.80775 .2515 L
.81025 .2571 L
.81165 .26018 L
.81234 .26143 L
.81298 .26237 L
.81371 .26317 L
.81451 .2637 L
.81518 .26389 L
.8159 .26386 L
.81711 .26347 L
.81841 .26294 L
.81964 .26275 L
.82076 .26311 L
.82208 .26431 L
.82282 .26535 L
.82351 .2665 L
.82612 .27152 L
.82741 .27363 L
.82806 .27444 L
.82877 .27511 L
.83003 .27569 L
.8312 .27564 L
.83268 .27513 L
.83341 .27485 L
.83408 .27467 L
.83533 .27468 L
.83599 .27492 L
.8367 .27539 L
.83788 .27664 L
.83898 .27824 L
.8403 .28041 L
.84151 .28234 L
.84271 .28392 L
.84399 .28499 L
.84526 .28538 L
.84599 .28534 L
.84666 .28517 L
.84782 .28472 L
.84909 .28427 L
.85028 .28415 L
.85138 .28447 L
.85237 .28515 L
.85346 .28629 L
.85566 .28931 L
.85689 .29094 L
.85806 .29214 L
.8587 .29261 L
.8594 .29293 L
.86063 .29307 L
Mistroke
.86179 .29279 L
.86304 .29226 L
.86421 .29181 L
.86527 .29162 L
.86648 .29182 L
.86761 .29246 L
.86885 .29362 L
.87017 .29518 L
.87156 .29684 L
.87287 .29811 L
.87405 .29881 L
.87533 .29903 L
.87644 .29882 L
.87766 .29831 L
.87886 .29775 L
.88014 .29735 L
.88133 .29735 L
.88243 .29774 L
.88353 .29851 L
.88457 .29949 L
.88586 .30085 L
.88707 .30205 L
.88774 .30259 L
.88847 .30305 L
.88974 .30344 L
.89095 .30335 L
.89224 .30287 L
.89344 .30225 L
.89454 .30174 L
.89583 .30143 L
.89654 .30144 L
.89722 .3016 L
.89842 .30221 L
.89972 .30324 L
.90105 .30448 L
.90246 .30565 L
.90319 .30611 L
.904 .30644 L
.90473 .30657 L
.90541 .30655 L
.90664 .30621 L
.90775 .30565 L
.90896 .30499 L
.91026 .30443 L
.91147 .30424 L
.9126 .30442 L
.91367 .30493 L
.91481 .30573 L
.91603 .30673 L
.91719 .30762 L
Mistroke
.91783 .30803 L
.91852 .30836 L
.91975 .30863 L
.92045 .30858 L
.9212 .30839 L
.92191 .30809 L
.92255 .30775 L
.92381 .30702 L
.92452 .30663 L
.92518 .30633 L
.9265 .30601 L
.92717 .30602 L
.92789 .30618 L
.92919 .30679 L
.93038 .3076 L
.93177 .30862 L
.93249 .30909 L
.93327 .30948 L
.93394 .30971 L
.93469 .30982 L
.936 .30963 L
.93732 .30905 L
.93853 .30832 L
.93983 .30757 L
.94057 .30724 L
.94126 .30704 L
.94242 .30698 L
.94366 .30732 L
.94434 .30765 L
.94498 .30804 L
.94619 .30885 L
.94709 .30945 L
.94805 .30997 L
.94897 .31029 L
.9498 .31039 L
.95078 .31027 L
.95184 .30987 L
.95285 .30931 L
.95378 .30872 L
.95467 .30818 L
.95562 .30771 L
.95668 .30741 L
.95767 .30739 L
.95872 .30765 L
.95982 .30819 L
.9618 .30945 L
.96269 .30996 L
.96352 .31032 L
.96448 .31054 L
.96536 .31053 L
Mistroke
.96619 .31034 L
.96695 .31002 L
.96867 .30899 L
.96951 .30846 L
.97041 .30796 L
.9714 .30759 L
.97232 .30746 L
.97336 .30758 L
.97434 .30793 L
.97523 .30841 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00X?oonfX4o`0007Wooo]Z1Ol00020oookJPCo0000V_oo
nfX00:3ooo]Z1?l0001ioookJPGo0000P?oonfX4o`0009[ooo]Z002PoookJPCo0000NOoonfX5o`00
07oooo]Z1Ol0002JoookJP00WooonfX5o`0007Wooo]Z1Ol0001ooookJPGo0000V_oonfX009oooo]Z
1_l0001[oookJP?o001o2_oonfX5o`0007oooo]Z1_l0002IoookJP00WooonfX6o`0006_ooo]Z0ol0
07l:oookJPGo0000OooonfX6o`0009Wooo]Z002OoookJPKo0000JooonfX3o`00O`[ooo]Z1Ol0001o
oookJPKo0000VOoonfX009oooo]Z1_l0001KoookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0001ooook
JPKo0000VOoonfX009oooo]Z1_l0001KoookJP[o001o1_oonfX3o`00O`[ooo]Z1_l0001noookJPKo
0000VOoonfX009oooo]Z1_l0001[oookJP?o001o2_oonfX5o`0007oooo]Z1ol0002HoookJP00Wooo
nfX7o`0006[ooo]Z0ol007l:oookJPGo0000OooonfX7o`0009Sooo]Z002OoookJPOo0000J_oonfX3
o`00O`[ooo]Z1Ol0001ooookJPOo0000V?oonfX009kooo]Z2?l0001ZoookJP?o001o2_oonfX5o`00
07oooo]Z1ol0002HoookJP00W_oonfX8o`0006Oooo]Z1_l007l:oookJPGo0000OooonfX7o`0009So
oo]Z002NoookJPSo0000IooonfX6o`00O`[ooo]Z1Ol0001ooookJPOo0000V?oonfX009kooo]Z2?l0
001YoookJPCo001o2_oonfX5o`0007oooo]Z1ol0002HoookJP00W_oonfX8o`0006[ooo]Z0ol007l:
oookJPGo0000OooonfX7o`0009Sooo]Z002NoookJPSo0000MooonfX5o`0007oooo]Z1ol0002Hoook
JP00W_oonfX8o`0007Oooo]Z1Ol0001ooookJPOo0000V?oonfX009kooo]Z2?l0001goookJPGo0000
OooonfX7o`0009Sooo]Z002NoookJPSo0000MooonfX5o`0007kooo]Z2?l0002HoookJP00W_oonfX8
o`0007Oooo]Z1Ol0001noookJPSo0000V?oonfX009kooo]Z2?l0001goookJPGo0000O_oonfX9o`00
09Oooo]Z002NoookJPSo00000_oonfX4o`00077ooo]Z1Ol0001noookJPko0000T_oonfX009kooo]Z
3_l0001aoookJPGo0000O_oonfX?o`00097ooo]Z002NoookJPoo0000L?oonfX5o`0007kooo]Z1?l0
00000ooonf[o0000o`000008o`00097ooo]Z002NoookJPoo0000L?oonfX5o`0007kooo]Z1?l00000
0ooonf[o0000o`000008o`00097ooo]Z002NoookJPCo000000?ooo]Zo`000?l000002?l0001`oook
JPGo0000O_oonfX4o`000003oookJ_l0003o000000So0000TOoonfX009kooo]Z1?l000000ooonf[o
0000o`000009o`0006oooo]Z1Ol0001noookJPCo000000?ooo]Zo`000?l000002Ol0002@oookJP00
W_oonfX4o`000003oookJ_l0003o000000Wo0000KooonfX5o`0007kooo]Z1?l000000ooonf[o0000
o`000009o`00093ooo]Z002NoookJPCo000000?ooo]Zo`000?l000002Ol0001_oookJPGo0000O_oo
nfX4o`0000;ooo]Z2_l0002@oookJP00W_oonfX4o`0000;ooo]Z2_l0001_oookJPGo0000O_oonfX4
o`0000;ooo]Z2_l0002@oookJP00W_oonfX4o`0000;ooo]Z2ol0001^oookJPGo0000O_oonfX4o`00
00;ooo]Z2_l0002@oookJP00W_oonfX4o`0000;ooo]Z1Ol000000ooonf[o0000o`000003o`0006ko
oo]Z1Ol0001noookJPCo00000_oonfX5o`000003oookJ_l0003o000000;o0000T?oonfX009kooo]Z
1?l00002oookJPCo00000_oonfX5o`0006kooo]Z1Ol0001noookJPCo00000ooonfX4o`000003oook
J_l0003o000000;o0000T?oonfX009kooo]Z1?l00009oookJPCo0000K_oonfX5o`0007kooo]Z1?l0
0008oookJPGo0000SooonfX009kooo]Z1?l00009oookJPCo0000K_oonfX5o`0007kooo]Z1?l00008
oookJPGo0000SooonfX009kooo]Z1?l00009oookJPWo0000JOoonfX5o`0007kooo]Z1?l00008oook
JPGo000000?ooo]Zo`000?l000000_l0002:oookJP00W_oonfX4o`0000Wooo]Z2_l0001XoookJPGo
0000OOoonfX5o`0000Wooo]Z2_l00029oookJP00W_oonfX4o`0000Wooo]Z2_l0001XoookJPGo0000
OOoonfX5o`0000Wooo]Z2_l00029oookJP00W_oonfX4o`0000Wooo]Z2_l0001XoookJPGo0000OOoo
nfX5o`0000Wooo]Z2_l00029oookJP00W_oonfX4o`0000[ooo]Z2Ol0001XoookJPGo0000OOoonfX4
o`0000_ooo]Z2Ol00029oookJP00W_oonfX4o`0000[ooo]Z2_l0001WoookJPGo0000OOoonfX4o`00
00_ooo]Z2_l00028oookJP00W_oonfX4o`0000_ooo]Z2Ol0001WoookJPGo0000OOoonfX4o`0000co
oo]Z2Ol00028oookJP00W_oonfX4o`0000oooo]Z1Ol0001WoookJPGo0000OOoonfX4o`00013ooo]Z
1_l00027oookJP00W_oonfX4o`00013ooo]Z1Ol0001VoookJPGo0000OOoonfX4o`00017ooo]Z1Ol0
0027oookJP00WOoonfX5o`00013ooo]Z1Ol00018oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:
oookJPGo0000OOoonfX4o`00017ooo]Z1Ol00027oookJP00WOoonfX5o`00013ooo]Z1_l00016oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000OOoonfX4o`0001;ooo]Z1?l00027oook
JP00WOoonfX5o`00017ooo]Z1Ol00016oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000B
oookJPGo0000Q_oonfX009gooo]Z1?l0000BoookJPWo0000=OoonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000OOoonfX4o`0001;ooo]Z2_l00021oook
JP00WOoonfX4o`0001?ooo]Z2Ol0000doookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2?oonfX6o`0007cooo]Z1?l0000BoookJP[o0000POoonfX009gooo]Z1?l0000CoookJPWo0000
@?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0007gooo]Z1?l0000CoookJPWo0000
POoonfX009gooo]Z1?l0000CoookJP[o0000?ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z1Ol0001moookJPCo00004ooonfX:o`00083ooo]Z002MoookJPCo00005?oonfX:
o`0003kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001moookJPCo00005?oonfX9
o`00083ooo]Z002MoookJPCo00006?oonfX7o`0003gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
O`[ooo]Z1Ol0001moookJPCo00006?oonfX6o`0007oooo]Z002MoookJPCo00006OoonfX6o`0003go
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001moookJPCo00006OoonfX5o`0007oo
oo]Z002MoookJPCo00006_oonfX6o`0003gooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o3_oonfX5o`0007gooo]Z1?l0000IoookJPGo0000OooonfX009gooo]Z1?l0000KoookJPKo0000
??oonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000OOoonfX4o`0001[ooo]Z1Ol0001noookJP00WOoo
nfX4o`0001_ooo]Z2?l0000koookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001moookJPCo00006_oo
nfX:o`0007Wooo]Z002MoookJPCo00007?oonfX8o`0005Sooo]Z1Ol0001moookJPCo00006_oonfX:
o`0007Wooo]Z002MoookJPCo00007OoonfX8o`0005Oooo]Z1Ol0001moookJPCo00006ooonfX:o`00
07Sooo]Z002MoookJPCo00007_oonfX7o`0005Oooo]Z1Ol0001moookJPCo00006ooonfX:o`0007So
oo]Z002MoookJPCo00008?oonfX5o`0005Oooo]Z1Ol0001moookJPCo00007?oonfX:o`0007Oooo]Z
002MoookJPCo00008OoonfX5o`0005Kooo]Z1Ol0001moookJPCo00008OoonfX5o`0007Oooo]Z002M
oookJPCo00008OoonfX6o`0005Gooo]Z1Ol0001moookJPCo00008OoonfX5o`0007Oooo]Z002Moook
JPCo00008OoonfX6o`0005Gooo]Z1Ol0001moookJPCo00008_oonfX5o`0007Kooo]Z002MoookJPCo
00008_oonfX:o`00053ooo]Z1Ol0001moookJPCo00008_oonfX:o`00077ooo]Z002LoookJPGo0000
8_oonfX:o`00053ooo]Z1Ol0001moookJPCo00008_oonfX;o`00073ooo]Z002LoookJPGo00008ooo
nfX:o`0004oooo]Z1Ol0001moookJPCo00008ooonfX:o`00073ooo]Z002LoookJPGo00009?oonfX9
o`0004oooo]Z1Ol0001moookJPCo00009?oonfX9o`00073ooo]Z002LoookJPCo00009OoonfX:o`00
04kooo]Z1Ol0001moookJPCo00009OoonfX9o`0006oooo]Z000RoookJP?o001oMOoonfX2o`00O`Co
00000ooonfX3o`00O`?ooo]Z1Ol007lLoookJPGo0000C_oonfX5o`0007Cooo]Z1Ol007l4oookJPCo
00000_oonfX5o`00Ob;ooo]Z1_l0001>oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o
1?l00003oookJP?o001o0_oonfX7o`00Oa_ooo]Z2ol00018oookJPGo0000LooonfX7o`00O`?ooo]Z
1?l000000ooonf[o001oo`00O`05o`00Ob7ooo]Z2ol00019oookJP?o001o7OoonfX002;ooo]Z0ol0
07mdoookJP?o001o1?l00003oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007lLoookJP_o0000AooonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJPCo
00001?l007l01?oonf[o001oo`00Ool007lRoookJP_o0000B?oonfX3o`00Oagooo]Z000CoookJP[o
001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oo
oo]ZoookJP04oookJP?o001o0ooonfX3o`00Oa_ooo]Z2ol00017oookJPGo0000L_oonfX3o`00O`?o
oo]Z0ol007l2oookJPCo00000ol007l3oookJP?o001o8_oonfX;o`0004Oooo]Z0ol007lMoookJP00
4ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`03oookJ_l0003o000000;o0000
00?o001ooookJ_oonfX02_oonfX3o`00Oacooo]Z2ol00016oookJPGo0000L_oonfX3o`00O`?ooo]Z
0ol007l2oookJPCo00001_oonfX3o`00Ob;ooo]Z2ol00017oookJP?o001o7OoonfX002;ooo]Z0ol0
07mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o001o7Ooo
nfX;o`0004Gooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o8ooo
nfX:o`0004Oooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002
o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l2oookJPCo001o8_oonfX6o`0004Gooo]Z1Ol0001b
oookJP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02oookJPCo001o:OoonfX6
o`0004Gooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`00
0003o`00Oooonf[ooo]Z00Gooo]Z1ol007lToookJP_o0000?ooonfX5o`0007;ooo]Z0ol007l3oook
JP?o001o0_oonfX4o`000003oookJ_l007oo001o00Go001o:_oonfX;o`00043ooo]Z0ol007lMoook
JP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Go
oo]Z1_l007lVoookJP_o0000?_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003
oookJ_l007oo001o00Co001o:ooonfX<o`0003oooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z
0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007lZoookJPco0000
?OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o033ooo]Z
3?l0000koookJPKo001o7OoonfX001oooo]Z1_l007mdoookJP?o001o1?l00008oookJP;o001o:ooo
nfX;o`0003gooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`000003oook
J_l007oo001o037ooo]Z2ol0000koookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o1?l0
0009oookJPOo001o:_oonfX<o`0003Oooo]Z1Ol0001coookJPOo001o0ooonfX4o`0000;ooo]Z1ol0
07laoookJP_o0000=ooonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00002OoonfX7
o`00Obcooo]Z2ol0000foookJPGo0000M?oonfX5o`00O`Cooo]Z1?l00002oookJPOo001o<_oonfX;
o`0003Oooo]Z0ol007lMoookJP00W?oonfX4o`0003cooo]Z3?l0000eoookJPGo0000OOoonfX4o`00
03_ooo]Z3?l0001FoookJP00W?oonfX4o`0003gooo]Z4ol0000]oookJPGo0000O?oonfX5o`0003co
oo]Z4_l0001?oookJP00W?oonfX4o`0004?ooo]Z4?l0000ZoookJPGo0000O?oonfX5o`0004;ooo]Z
3?l0001?oookJP00W?oonfX4o`0004Cooo]Z4ol0000VoookJPGo0000O?oonfX5o`0004?ooo]Z4ol0
0017oookJP00W?oonfX4o`0004Gooo]Z4ol00002oookJPCo00007ooonfX5o`0007cooo]Z1?l00015
oookJQ?o00000_oonfX4o`00043ooo]Z002LoookJPCo0000A_oonfX5o`0000;ooo]Z4ol00002oook
JPGo00005_oonfX5o`0007cooo]Z1?l00016oookJQ[o00000_oonfX5o`0003Oooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`00
00oooo]Z000LoookJPKo00000ooonfX5o`0000;ooo]Z9?l0001<oookJPCo0000K_oonfX5o`0000?o
oo]Z1_l000000ooonf[o0000o`000005o`0000;ooo]Z1ol000000ooonf[o0000o`000005o`000003
oookJ_l0003o000001[o0000C?oonfX4o`0006kooo]Z1Ol00003oookJPKo00000ooonfX00ol0003o
oo]ZoookJP0LoookJP00=OoonfX5o`0000;ooo]Z6Ol00017oookJPCo0000OOoonfX5o`0001Gooo]Z
1Ol00002oookJQGo000000?ooo]Zo`000?l000000_l00016oookJPCo0000W_oonfX003gooo]Z1Ol0
0002oookJQ?o0000AOoonfX4o`0007gooo]Z1Ol0000NoookJPCo00000_oonfXDo`0004Cooo]Z1?l0
002NoookJP00AOoonfXCo`0004Cooo]Z1?l0001moookJPGo00009OoonfXCo`0004Cooo]Z1?l0002N
oookJP00COoonfX<o`0004?ooo]Z1?l0001moookJPGo0000;?oonfX=o`0004?ooo]Z1?l0002Noook
JP00COoonfXBo`0003gooo]Z1?l0001moookJPGo0000;_oonfXAo`0003gooo]Z1?l0002NoookJP00
E?oonfX<o`0003cooo]Z1?l0001moookJPGo0000=?oonfX<o`0003cooo]Z1?l0002NoookJP00EOoo
nfX;o`0003cooo]Z1?l0001moookJPGo0000=OoonfX;o`0003cooo]Z1?l0002NoookJP00EOoonfX=
o`0003Wooo]Z1Ol0001moookJPGo0000=_oonfX;o`0003_ooo]Z1?l0002NoookJP00G?oonfX;o`00
03Cooo]Z1Ol0001moookJPGo0000??oonfX;o`0003Gooo]Z1?l0002NoookJP00G?oonfX<o`0003?o
oo]Z1Ol0001moookJPGo0000??oonfX<o`0003Cooo]Z1?l0002NoookJP00GOoonfX;o`0003?ooo]Z
1?l0001noookJPGo0000?OoonfX;o`0003Cooo]Z1?l0002NoookJP00G_oonfX;o`0003;ooo]Z1?l0
001noookJPGo0000?_oonfX;o`0003?ooo]Z1?l0002NoookJP00I?oonfX5o`0003;ooo]Z1?l0001n
oookJPGo0000@ooonfX7o`0003;ooo]Z1?l0002NoookJP00I?oonfX7o`00033ooo]Z1?l0001noook
JPGo0000A?oonfX;o`0002gooo]Z1?l0002NoookJP00IOoonfX7o`0002oooo]Z1?l0001noookJPGo
0000AOoonfX:o`0002cooo]Z1Ol0002NoookJP00IOoonfX9o`0002gooo]Z1?l0001noookJPGo0000
A_oonfX:o`0002_ooo]Z1Ol0002NoookJP00I_oonfX:o`0002_ooo]Z1?l0001noookJPGo0000A_oo
nfX;o`0002[ooo]Z1Ol0002NoookJP00IooonfX:o`0002[ooo]Z1?l0001noookJPGo0000AooonfX:
o`0002[ooo]Z1?l0002OoookJP00JOoonfX9o`0002Wooo]Z1?l0001noookJPGo0000C?oonfX6o`00
02Wooo]Z1?l0002OoookJP00JooonfX;o`0002Gooo]Z1?l0001noookJPGo0000COoonfX9o`0002Go
oo]Z1?l0002OoookJP00KOoonfX:o`0002Cooo]Z1?l0001noookJPGo0000COoonfX:o`0002Cooo]Z
1?l0002OoookJP00K_oonfX:o`0002?ooo]Z1?l0001noookJPGo0000C_oonfX:o`0002?ooo]Z1?l0
002OoookJP00K_oonfX;o`0002;ooo]Z1?l0001noookJPGo0000C_oonfX;o`0002;ooo]Z1?l0002O
oookJP00KooonfX:o`0002;ooo]Z1?l0001noookJPGo0000CooonfX:o`0002;ooo]Z1?l0002Ooook
JP00M?oonfX5o`0002;ooo]Z1?l0001noookJPGo0000E?oonfX5o`0002;ooo]Z1?l0002OoookJP00
MOoonfX5o`00027ooo]Z1?l0001noookJPGo0000E?oonfX5o`0002;ooo]Z1?l0002OoookJP00MOoo
nfX5o`00027ooo]Z1?l0001noookJPGo0000EOoonfX5o`00027ooo]Z1?l0002OoookJP00MOoonfX:
o`0001cooo]Z1?l0001noookJPGo0000EOoonfX:o`0001cooo]Z1?l0002OoookJP00M_oonfX:o`00
01_ooo]Z1?l0001noookJPGo0000EOoonfX;o`0001_ooo]Z1?l0002OoookJP00M_oonfX:o`0001_o
oo]Z1?l0001noookJPGo0000E_oonfX:o`0001_ooo]Z1?l0002OoookJP00MooonfX9o`0001_ooo]Z
1?l0001noookJPGo0000EooonfX9o`0001_ooo]Z1?l0002OoookJP00MooonfX9o`0001_ooo]Z1?l0
001noookJPGo0000EooonfX9o`0001_ooo]Z1?l0002OoookJP00O?oonfX5o`0001[ooo]Z1?l0001n
oookJPGo0000G?oonfX5o`0001[ooo]Z1?l0002OoookJP00O?oonfX5o`0001[ooo]Z1?l0001noook
JPGo0000G?oonfX5o`0001[ooo]Z1?l0002OoookJP00O?oonfX6o`0001Wooo]Z1?l0001PoookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000G?oonfX6o`0001Wooo]Z1?l0002OoookJP00
OOoonfX5o`0001Wooo]Z1?l0001OoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000
GOoonfX5o`0001Wooo]Z1?l0002OoookJP00OOoonfX:o`0001Cooo]Z1?l0001OoookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2OoonfX5o`0005gooo]Z2_l0000DoookJPCo0000WooonfX007kooo]Z2_l0000CoookJPCo0000
G_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001NoookJP[o0000
4ooonfX4o`0009oooo]Z001noookJP[o00004ooonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Sooo]Z1_l0001MoookJP[o00004ooonfX4o`0009oooo]Z001ooookJPWo00004ooonfX4
o`0005kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001OoookJPWo00004ooonfX4
o`0009oooo]Z001ooookJP[o00004_oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l8oookJPGo0000GooonfX:o`0001;ooo]Z1?l0002OoookJP00Q?oonfX5o`00017o
oo]Z1Ol0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000I?oonfX5o`0001;o
oo]Z1?l0002OoookJP00Q?oonfX6o`00013ooo]Z1Ol0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l:oookJPGo0000I?oonfX5o`0001;ooo]Z1?l0002OoookJP00QOoonfX5o`00013ooo]Z1Ol0
001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000IOoonfX5o`00017ooo]Z1?l0
002OoookJP00QOoonfX5o`00013ooo]Z1?l0001PoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX2o`00O`kooo]Z1Ol0001UoookJPGo00004OoonfX4o`0009oooo]Z0026oookJPCo00004?oonfX4
o`00063ooo]Z1ol007l9oookJPOo001o2?oonfX5o`0006Gooo]Z1Ol0000AoookJPCo0000WooonfX0
08Kooo]Z2_l0000:oookJPCo0000HOoonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000I_oonfX9o`00
00cooo]Z1?l0002OoookJP00Q_oonfX:o`0000[ooo]Z1?l0001ooookJPGo0000I_oonfX9o`0000co
oo]Z1?l0002OoookJP00Q_oonfX:o`0000[ooo]Z1?l0001ooookJPGo0000I_oonfX:o`0000_ooo]Z
1?l0002OoookJP00Q_oonfX;o`0000Wooo]Z1?l0001ooookJPGo0000IooonfX:o`0000[ooo]Z1?l0
002OoookJP00QooonfX:o`0000Wooo]Z1?l0001ooookJPGo0000IooonfX:o`0000[ooo]Z1?l0002O
oookJP00QooonfX:o`0000Wooo]Z1?l0001ooookJPGo0000J?oonfX9o`0000[ooo]Z1?l0002Ooook
JP00R?oonfX4o`000003oookJ_l0003o000000;o00002OoonfX4o`0007oooo]Z1Ol0001XoookJPWo
00002_oonfX4o`0009oooo]Z002=oookJPCo00002OoonfX4o`0007oooo]Z1Ol0001]oookJPCo0000
2_oonfX4o`0009oooo]Z002=oookJPCo00002OoonfX4o`0007oooo]Z1Ol0001]oookJPGo00002Ooo
nfX4o`0009oooo]Z002=oookJPGo000000?ooo]Zo`000?l000000_l00003oookJPCo0000OooonfX5
o`0006gooo]Z1Ol00002oookJPCo00000ooonfX4o`0009oooo]Z002=oookJPGo000000?ooo]Zo`00
0?l000000_l00003oookJPCo0000OooonfX5o`0006gooo]Z1Ol000000ooonf[o0000o`000003o`00
00?ooo]Z1?l0002OoookJP00SOoonfX5o`000003oookJ_l0003o000000?o00000_oonfX4o`0007oo
oo]Z1Ol0001^oookJP[o00000ooonfX4o`0009oooo]Z002>oookJP[o00000_oonfX4o`0007oooo]Z
1Ol0001^oookJP[o00000ooonfX4o`0009oooo]Z002>oookJP_o000000?ooo]Zo`000?l000000_l0
001ooookJPGo0000K_oonfX;o`000003oookJ_l0003o000000?o0000WooonfX008kooo]Z2ol00000
0ooonf[o0000o`000002o`0007oooo]Z1Ol0001^oookJP_o000000?ooo]Zo`000?l000000ol0002O
oookJP00S_oonfX;o`000003oookJ_l0003o000000;o0000OooonfX5o`0006kooo]Z2ol000000ooo
nf[o0000o`000003o`0009oooo]Z002?oookJP[o000000?ooo]Zo`000?l000000_l0001ooookJPGo
0000KooonfX:o`000003oookJ_l0003o000000;o0000X?oonfX008oooo]Z2_l000000ooonf[o0000
o`000002o`0007oooo]Z1Ol0001_oookJP[o000000?ooo]Zo`000?l000000_l0002PoookJP00Sooo
nfX:o`000003oookJ_l0003o000000;o0000OooonfX5o`0006oooo]Z2_l000000ooonf[o0000o`00
0002o`000:3ooo]Z002?oookJP[o000000?ooo]Zo`000?l000000_l0001ooookJPGo0000L?oonfX>
o`000:3ooo]Z002@oookJPWo000000?ooo]Zo`000?l000000_l0001ooookJPGo0000L?oonfX>o`00
0:3ooo]Z002EoookJPCo000000?ooo]Zo`000?l000000_l0001ooookJPGo0000MOoonfX9o`000:3o
oo]Z002EoookJPCo000000?ooo]Zo`000?l000000_l0001ooookJPGo0000M_oonfX8o`000:3ooo]Z
002EoookJPWo0000OooonfX5o`0007Kooo]Z2?l0002PoookJP00UOoonfX9o`0007oooo]Z1Ol0001f
oookJPSo0000X?oonfX009Gooo]Z2Ol0001ooookJPGo0000M_oonfX8o`000:3ooo]Z002FoookJPSo
0000OooonfX5o`0007Kooo]Z2?l0002PoookJP00U_oonfX8o`0007oooo]Z1Ol0001foookJPSo0000
X?oonfX009Kooo]Z2?l0001ooookJPGo0000M_oonfX8o`000:3ooo]Z002FoookJPOo0000P?oonfX5
o`0007Kooo]Z2?l0002PoookJP00U_oonfX7o`0007?ooo]Z0ol007l:oookJPGo0000M_oonfX7o`00
0:7ooo]Z002FoookJPOo0000LooonfX3o`00O`[ooo]Z1Ol0001foookJPOo0000XOoonfX009Oooo]Z
1_l0001coookJP?o001o2_oonfX5o`0007Kooo]Z1ol0002QoookJP00UooonfX6o`0007?ooo]Z0ol0
07l:oookJPGo0000MooonfX6o`000:7ooo]Z002GoookJPKo0000LooonfX3o`00O`[ooo]Z1_l0001f
oookJPKo0000XOoonfX009Oooo]Z1_l0001coookJP?o001o2_oonfX5o`0007Oooo]Z1_l0002Qoook
JP00UooonfX6o`0007?ooo]Z0ol007l:oookJPGo0000MooonfX6o`000:7ooo]Z002GoookJPKo0000
LooonfX3o`00O`[ooo]Z1Ol0001goookJPKo0000XOoonfX009Oooo]Z1_l0001coookJP?o001o2_oo
nfX5o`0007Oooo]Z1_l0002QoookJP00UooonfX6o`00073ooo]Z1_l007l:oookJPGo0000MooonfX6
o`000:7ooo]Z002GoookJPKo0000L?oonfX6o`00O`[ooo]Z1Ol0001goookJPKo0000XOoonfX009Oo
oo]Z1_l0001boookJPCo001o2_oonfX5o`0007Sooo]Z1Ol0002QoookJP00UooonfX6o`0007?ooo]Z
0ol007l:oookJPGo0000N?oonfX5o`000:7ooo]Z002HoookJPCo0000POoonfX5o`0007Sooo]Z1?l0
002RoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o
1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oo
nfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXNoookJP00oooonfX2oookJP?o
001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJP;o001o
0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPOo001o2Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l007l:oookJPGo0000oooonfXO
oookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wo
oo]Z0_l007l>oookJPGo0000oooonfXOoookJP00oooonfX1oookJPCo001o2_oonfX7o`00O`Sooo]Z
1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z
1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=
oookJPCo001o3OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4o`00O`cooo]Z1Ol0003ooook
JQoooo]Z003ooookJPoooo]Z1Ol007l:oookJPKo0000oooonfXNoookJP00oooonfXAoookJPCo001o
2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJQ?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oook
JP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z
0ol007oooookJRcooo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z003ooookJPoooo]Z1Ol007oo
oookJRkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30829 L
.02605 .30778 L
.02729 .30751 L
.02846 .30764 L
.02954 .30806 L
.03053 .30863 L
.03162 .30933 L
.03279 .31001 L
.03396 .31045 L
.03506 .31054 L
.03636 .31023 L
.03756 .30962 L
.03883 .30882 L
.03952 .30839 L
.04018 .30804 L
.04146 .30762 L
.04262 .3076 L
.04383 .30798 L
.04495 .30859 L
.04626 .30946 L
.04748 .31019 L
.04871 .31065 L
.04936 .31074 L
.05006 .31071 L
.05079 .31053 L
.05148 .31025 L
.05278 .30951 L
.05395 .30879 L
.05519 .30817 L
.05624 .3079 L
.05741 .30796 L
.05866 .30843 L
.05936 .30884 L
.06001 .30928 L
.06126 .31016 L
.06244 .31087 L
.06373 .31129 L
.0649 .31129 L
.06616 .31088 L
.06687 .31052 L
.06752 .31013 L
.06871 .30942 L
.06982 .30891 L
.07097 .30866 L
.07225 .30883 L
.07291 .30909 L
.07363 .3095 L
.07495 .31046 L
.07624 .31144 L
Mistroke
.07742 .31214 L
.07814 .31241 L
.07881 .31254 L
.07953 .31253 L
.0803 .31235 L
.08098 .31209 L
.08169 .31173 L
.08297 .31099 L
.08366 .31063 L
.08432 .31035 L
.08555 .3101 L
.08687 .31033 L
.08762 .31069 L
.0883 .31114 L
.08954 .31214 L
.09087 .31326 L
.09213 .31411 L
.09328 .31454 L
.09455 .31456 L
.09519 .3144 L
.09589 .31412 L
.09739 .31333 L
.09805 .31299 L
.09876 .31269 L
.09951 .31248 L
.10022 .31244 L
.10103 .31257 L
.10178 .31288 L
.10243 .31329 L
.10314 .31385 L
.10458 .3152 L
.10579 .31633 L
.10708 .31725 L
.10776 .31755 L
.1085 .31772 L
.10981 .3176 L
.11104 .31712 L
.11237 .31645 L
.11362 .31597 L
.11477 .31586 L
.11589 .31616 L
.11693 .31681 L
.11807 .31787 L
.1193 .3192 L
.12058 .32056 L
.12179 .32154 L
.12288 .32205 L
.12407 .32214 L
.12536 .32179 L
.12658 .32125 L
Mistroke
.12726 .32094 L
.12791 .32071 L
.12866 .32057 L
.12934 .32058 L
.13002 .32075 L
.13073 .32112 L
.13202 .32222 L
.13355 .32405 L
.13494 .32578 L
.13623 .32711 L
.13742 .32787 L
.13873 .32811 L
.13938 .32802 L
.14011 .3278 L
.14132 .32729 L
.14262 .32684 L
.14385 .32679 L
.14497 .32723 L
.14615 .32823 L
.14726 .32959 L
.14858 .3315 L
.14978 .33323 L
.15098 .33462 L
.15224 .33554 L
.15351 .33582 L
.15423 .33573 L
.1549 .33553 L
.15609 .33506 L
.15722 .33471 L
.15823 .33468 L
.15933 .3351 L
.16053 .33617 L
.1618 .33792 L
.16407 .34176 L
.16534 .34363 L
.16654 .34487 L
.1672 .34527 L
.16792 .34548 L
.16918 .34538 L
.17048 .34491 L
.17169 .3445 L
.17278 .34447 L
.17396 .34501 L
.17466 .34566 L
.17539 .34661 L
.1767 .34886 L
.1782 .35189 L
.17961 .35453 L
.18081 .35623 L
.1821 .35723 L
Mistroke
.18284 .35742 L
.18353 .35737 L
.18484 .35692 L
.18598 .35645 L
.18722 .3563 L
.18838 .35681 L
.18945 .35798 L
.19069 .36017 L
.19205 .36326 L
.19333 .36634 L
.19453 .36889 L
.19518 .37 L
.19588 .37091 L
.1971 .37175 L
.1978 .37182 L
.19854 .37165 L
.19985 .37098 L
.20107 .37043 L
.20221 .37044 L
.20346 .3714 L
.20416 .37245 L
.2048 .37371 L
.22324 .4039 L
.22436 .40714 L
.22553 .40922 L
.22682 .40969 L
.22801 .40869 L
.22913 .40705 L
.23033 .40535 L
.23146 .40463 L
.23249 .40527 L
.23363 .40776 L
.23472 .41181 L
.23716 .42437 L
.23836 .43015 L
.23963 .43427 L
.2403 .43529 L
.24103 .43542 L
.24231 .43329 L
.24369 .4287 L
.245 .42402 L
.24572 .42214 L
.24651 .42118 L
.24722 .42163 L
.24788 .42336 L
.24857 .42652 L
.24921 .43077 L
.25041 .44148 L
.25171 .45549 L
.25243 .46303 L
Mistroke
.25309 .46924 L
.25429 .47658 L
.25559 .476 L
.2567 .46622 L
.25789 .44517 L
.25856 .4286 L
.25928 .40709 L
.2606 .36053 L
.26307 .26271 L
.26421 .22125 L
.26541 .18517 L
.26673 .15735 L
.26793 .14366 L
.26906 .14045 L
.27011 .14432 L
.27126 .15382 L
.27249 .16686 L
.27384 .18078 L
.27454 .18682 L
.27529 .19178 L
.27595 .19475 L
.27667 .19652 L
.27793 .19619 L
.27917 .19284 L
.28049 .18797 L
.28174 .18415 L
.28288 .18258 L
.28417 .18376 L
.28483 .18556 L
.28556 .18833 L
.28804 .2011 L
.28943 .20766 L
.29022 .2104 L
.29094 .21215 L
.29157 .21305 L
.29226 .2134 L
.29299 .21314 L
.29366 .21246 L
.29499 .2105 L
.29625 .20883 L
.29738 .2083 L
.29861 .20924 L
.29924 .21041 L
.29994 .21218 L
.30136 .21692 L
.30267 .2219 L
.30389 .22612 L
.3051 .22924 L
.30638 .23106 L
.30711 .2314 L
Mistroke
.3078 .23132 L
.30909 .2305 L
.31025 .22955 L
.31147 .22898 L
.3121 .22903 L
.3128 .22945 L
.31403 .23115 L
.31653 .23755 L
.31775 .24115 L
.31889 .24405 L
.31991 .24603 L
.321 .24728 L
.3221 .24769 L
.32331 .24739 L
.3246 .24669 L
.32533 .24636 L
.326 .24621 L
.32723 .24652 L
.32852 .24787 L
.32919 .24897 L
.3299 .25039 L
.33119 .25339 L
.33259 .25673 L
.33333 .25829 L
.33411 .25967 L
.33478 .26059 L
.33552 .26129 L
.33683 .26175 L
.33746 .26168 L
.33815 .26146 L
.33939 .26094 L
.34068 .26061 L
.3419 .2609 L
.34299 .2618 L
.34419 .26349 L
.34675 .26847 L
.3481 .27093 L
.34878 .27192 L
.34952 .27275 L
.35018 .27324 L
.35087 .27353 L
.35214 .27353 L
.35339 .2731 L
.35454 .27268 L
.35574 .27254 L
.35685 .27289 L
.35806 .27391 L
.35935 .27565 L
.36173 .27966 L
.36277 .28123 L
Mistroke
.36391 .28251 L
.36518 .28327 L
.36639 .28336 L
.36706 .28321 L
.36777 .28296 L
.36906 .28245 L
.37036 .28222 L
.37159 .28251 L
.3727 .28329 L
.37389 .28463 L
.37668 .28861 L
.37735 .28946 L
.37808 .29022 L
.37888 .29083 L
.37962 .29116 L
.3803 .29128 L
.38104 .29122 L
.38173 .29104 L
.38238 .29079 L
.3836 .29027 L
.38489 .28994 L
.38605 .29004 L
.38731 .29071 L
.38845 .29178 L
.38952 .29305 L
.39086 .29475 L
.39213 .29616 L
.39327 .29703 L
.39451 .29746 L
.39561 .29739 L
.39678 .29699 L
.39779 .29653 L
.39887 .29608 L
.40002 .29587 L
.4011 .29604 L
.40237 .29674 L
.40354 .29778 L
.40599 .30042 L
.40669 .30107 L
.40735 .30156 L
.40859 .30211 L
.40931 .30218 L
.40997 .30211 L
.41069 .3019 L
.41145 .30158 L
.41273 .30094 L
.41344 .30062 L
.4141 .30041 L
.4154 .30033 L
.41658 .3007 L
Mistroke
.41768 .30143 L
.41889 .3025 L
.42021 .30377 L
.42093 .30441 L
.42161 .3049 L
.42281 .30547 L
.42414 .30557 L
.42635 .30474 L
.42751 .30412 L
.42874 .3036 L
.42982 .30343 L
.431 .30362 L
.43208 .30416 L
.43308 .30489 L
.43432 .30594 L
.4355 .30689 L
.43614 .30732 L
.43685 .30767 L
.43809 .30793 L
.43923 .30777 L
.44045 .30725 L
.44159 .30661 L
.44263 .30604 L
.4433 .30575 L
.444 .30555 L
.4447 .30548 L
.44547 .30557 L
.44613 .30578 L
.44685 .30613 L
.44813 .30701 L
.44947 .30804 L
.45074 .30886 L
.45188 .30929 L
.45311 .30935 L
.45428 .30902 L
.45557 .30834 L
.45682 .30759 L
.45752 .30722 L
.45817 .30694 L
.45944 .3067 L
.46059 .30686 L
.46167 .30733 L
.46285 .30808 L
.46421 .30904 L
.46549 .30977 L
.46664 .31012 L
.46789 .31008 L
.46853 .3099 L
.46924 .30959 L
.47068 .30874 L
Mistroke
.47137 .30831 L
.47203 .30794 L
.47325 .30743 L
.47441 .30729 L
.47566 .30755 L
.47631 .30784 L
.47701 .30823 L
.47825 .30904 L
.47931 .30972 L
.48046 .31025 L
.48173 .31047 L
.48291 .31028 L
.48542 .30894 L
.48665 .30819 L
.48778 .30768 L
.48909 .30749 L
.48978 .30757 L
.49051 .30779 L
.49169 .30839 L
.49299 .30922 L
.49372 .30967 L
.49441 .31004 L
.49521 .31036 L
.49594 .31051 L
.49726 .31041 L
.49801 .31016 L
.4987 .30982 L
.50002 .309 L
.50071 .30856 L
.50144 .30814 L
.50208 .30784 L
.50278 .30761 L
.50402 .30752 L
.50529 .30786 L
.506 .30821 L
.50665 .30859 L
.50783 .30935 L
.50911 .31008 L
.51034 .31049 L
.51148 .31052 L
.51257 .31022 L
.51372 .30963 L
.51488 .30891 L
.51609 .30818 L
.51672 .30789 L
.51742 .30767 L
.51864 .30758 L
.51934 .30772 L
.52009 .30801 L
.52079 .30838 L
Mistroke
.52143 .30878 L
.52268 .30961 L
.52339 .31004 L
.52406 .31037 L
.52537 .31073 L
.52605 .31073 L
.52677 .31059 L
.52808 .31004 L
.52927 .30932 L
.53066 .3085 L
.53144 .30814 L
.53217 .30794 L
.5328 .30788 L
.5335 .30794 L
.53423 .30815 L
.53491 .30847 L
.53731 .31007 L
.53862 .31086 L
.53984 .31128 L
.54048 .31134 L
.54116 .31127 L
.54192 .31106 L
.54261 .31076 L
.54392 .31 L
.54515 .30929 L
.54626 .30882 L
.54746 .30865 L
.54813 .30874 L
.54878 .30895 L
.54999 .30961 L
.55128 .31057 L
.55265 .31158 L
.55394 .31228 L
.55512 .31255 L
.5562 .31244 L
.55738 .31199 L
.55849 .31138 L
.55951 .3108 L
.56063 .31031 L
.56185 .3101 L
.56312 .31036 L
.56431 .31101 L
.5656 .31203 L
.56701 .31322 L
.56765 .3137 L
.56833 .31412 L
.56956 .31456 L
.57073 .31456 L
.57184 .31422 L
.57304 .31362 L
Mistroke
.57435 .31294 L
.57565 .31249 L
.57639 .31243 L
.57708 .31253 L
.57781 .3128 L
.57847 .31319 L
.57924 .31377 L
.57996 .31442 L
.58124 .31565 L
.58194 .3163 L
.58261 .31683 L
.58391 .31754 L
.5851 .31773 L
.58625 .31752 L
.58732 .31708 L
.58856 .31645 L
.58973 .31599 L
.59103 .31586 L
.5922 .31622 L
.59346 .3171 L
.59417 .31778 L
.59483 .31847 L
.59598 .31975 L
.59722 .32097 L
.59793 .32151 L
.59857 .32187 L
.59984 .32216 L
.60114 .32194 L
.60188 .32166 L
.60255 .32135 L
.6038 .32081 L
.60512 .32055 L
.60626 .32078 L
.60731 .32139 L
.60851 .32255 L
.60966 .32394 L
.61171 .32643 L
.61286 .32745 L
.6139 .32797 L
.61514 .32809 L
.6163 .3278 L
.61737 .32735 L
.61853 .32691 L
.61981 .32676 L
.62045 .32689 L
.62116 .32723 L
.62241 .3283 L
.62358 .32977 L
.626 .33326 L
.62723 .33467 L
Mistroke
.62793 .33524 L
.62858 .3356 L
.62929 .33579 L
.62994 .3358 L
.63065 .33567 L
.63141 .33541 L
.63267 .33491 L
.63338 .33471 L
.63402 .33465 L
.63528 .33496 L
.63647 .33589 L
.63756 .33727 L
.63875 .33917 L
.63993 .34121 L
.64121 .34321 L
.64194 .34413 L
.64261 .34477 L
.64392 .34545 L
.64507 .34545 L
.64632 .34504 L
.64752 .3446 L
.64861 .34443 L
.64985 .34481 L
.65054 .34534 L
.65118 .34607 L
.65233 .34783 L
.65357 .35021 L
.65583 .35457 L
.65696 .35618 L
.65821 .35719 L
.65927 .35742 L
.66041 .35717 L
.66149 .35672 L
.66247 .35637 L
.66365 .35635 L
.66476 .35697 L
.66598 .3585 L
.66729 .36104 L
.66978 .36694 L
.67103 .36946 L
.67174 .37053 L
.6724 .37124 L
.67362 .37182 L
.67472 .37165 L
.67599 .37101 L
.67719 .37045 L
.67829 .3704 L
.6793 .37102 L
.68041 .37255 L
.68158 .3751 L
Mistroke
.6916 .38701 L
.69227 .38669 L
.69298 .38666 L
.69376 .3871 L
.69448 .38802 L
.69578 .39096 L
.69652 .39327 L
.69722 .39574 L
.69972 .40484 L
.70098 .40808 L
.70169 .40918 L
.70235 .40968 L
.7036 .40934 L
.70473 .40796 L
.70594 .4061 L
.70727 .40473 L
.70847 .40503 L
.70959 .40709 L
.71065 .41071 L
.71178 .41598 L
.71411 .4282 L
.71542 .43326 L
.71662 .43539 L
.7173 .43537 L
.71803 .43439 L
.71873 .43266 L
.71937 .43056 L
.72061 .42598 L
.72126 .42379 L
.72195 .42205 L
.7232 .42136 L
.72435 .42446 L
.72542 .43096 L
.7266 .44154 L
.72774 .45366 L
.72881 .46491 L
.72977 .47296 L
.73082 .47744 L
.73205 .47451 L
.73318 .46213 L
.73441 .43746 L
.73571 .39937 L
.74027 .22562 L
.74151 .18765 L
.74266 .16181 L
.74385 .14575 L
.74516 .1404 L
.7463 .14431 L
.74733 .15264 L
.74965 .17709 L
Mistroke
.75094 .18837 L
.75214 .19476 L
.75345 .19686 L
.75411 .19621 L
.75484 .19449 L
.75616 .18991 L
.75741 .18554 L
.75853 .18304 L
.75975 .18279 L
.76089 .18514 L
.76211 .18998 L
.7643 .20148 L
.76562 .20766 L
.76687 .2116 L
.76799 .21323 L
.76919 .21313 L
.77026 .21191 L
.77143 .21012 L
.77266 .20864 L
.7738 .20834 L
.77487 .20935 L
.77584 .21138 L
.77696 .21482 L
.77803 .21873 L
.77911 .22281 L
.78025 .22661 L
.78149 .22964 L
.78263 .23111 L
.78389 .23136 L
.78459 .23102 L
.78525 .23053 L
.78643 .22956 L
.78771 .22897 L
.78841 .22907 L
.78905 .2295 L
.79031 .23132 L
.79146 .23398 L
.79268 .23744 L
.7939 .24102 L
.7952 .24434 L
.79595 .24579 L
.79664 .24675 L
.79733 .24737 L
.79798 .24765 L
.79904 .24757 L
.80019 .24703 L
.80119 .2465 L
.80226 .24621 L
.80338 .2465 L
.80442 .24747 L
Mistroke
.80556 .2493 L
.80681 .252 L
.80805 .25503 L
.80939 .25803 L
.81065 .26018 L
.81179 .26135 L
.81293 .26175 L
.81417 .26153 L
.81534 .26104 L
.81641 .26067 L
.81766 .26072 L
.81885 .26146 L
.81991 .26275 L
.82108 .26473 L
.82351 .26956 L
.8242 .27079 L
.82486 .27178 L
.82609 .27306 L
.82727 .27358 L
.82835 .27352 L
.82954 .27312 L
.83079 .27266 L
.83187 .27253 L
.83287 .2728 L
.83397 .27362 L
.83515 .27507 L
.83781 .27948 L
.83921 .28156 L
.83992 .28234 L
.8407 .28296 L
.84138 .28327 L
.84211 .28339 L
.84343 .28315 L
.84474 .28264 L
.84595 .28227 L
.84714 .28228 L
.84824 .28277 L
.84945 .28387 L
.85074 .28554 L
.85315 .28898 L
.8538 .28976 L
.85451 .29043 L
.85579 .29115 L
.85648 .29128 L
.85714 .29124 L
.85838 .29087 L
.85907 .29057 L
.8598 .29027 L
.86112 .28994 L
.86236 .29008 L
Mistroke
.86348 .29069 L
.8648 .29195 L
.86604 .29347 L
.8674 .29516 L
.86814 .29597 L
.86883 .2966 L
.87005 .2973 L
.87069 .29746 L
.87138 .29746 L
.87213 .29731 L
.87293 .29701 L
.87365 .29668 L
.8744 .29634 L
.87508 .29608 L
.87583 .29591 L
.87715 .296 L
.87779 .29625 L
.87849 .29669 L
.87977 .29782 L
.88216 .3004 L
.88286 .30105 L
.88352 .30154 L
.88427 .30194 L
.88496 .30214 L
.88621 .3021 L
.88691 .30189 L
.88756 .30162 L
.88865 .30107 L
.88982 .30055 L
.8911 .3003 L
.8923 .3005 L
.89294 .30079 L
.89364 .30125 L
.89492 .30235 L
.89616 .30355 L
.89731 .30455 L
.89844 .30526 L
.89964 .30559 L
.90084 .30547 L
.90215 .30495 L
.90338 .30429 L
.90454 .30374 L
.90557 .30346 L
.9067 .30349 L
.90736 .30369 L
.90805 .30403 L
.9093 .30491 L
.91073 .30613 L
.91143 .3067 L
.91207 .30716 L
Mistroke
.91322 .30773 L
.91446 .30793 L
.9151 .30785 L
.9158 .30764 L
.91707 .30702 L
.9185 .3062 L
.9192 .30587 L
.91984 .30564 L
.92105 .30549 L
.92235 .30579 L
.92366 .30653 L
.92509 .3076 L
.92586 .30819 L
.9266 .30867 L
.92726 .30902 L
.92797 .30927 L
.92929 .30935 L
.9305 .309 L
.93181 .30831 L
.9332 .30748 L
.9344 .30693 L
.93552 .3067 L
.93675 .30685 L
.93745 .30712 L
.93808 .30745 L
.93921 .3082 L
.94043 .30905 L
.94158 .30972 L
.94265 .31009 L
.94389 .31012 L
.9452 .3097 L
.9463 .3091 L
.94752 .30834 L
.94864 .30773 L
.94971 .30737 L
.95093 .30732 L
.95205 .30763 L
.95311 .30817 L
.95408 .3088 L
.95523 .30956 L
.95629 .31011 L
.95743 .31044 L
.95865 .31039 L
.95973 .31003 L
.96087 .30941 L
.96204 .30866 L
.96329 .30796 L
.96401 .30768 L
.96466 .30752 L
.96593 .30756 L
Mistroke
.96725 .30804 L
.96846 .30875 L
.96977 .30959 L
.97046 .30997 L
.97121 .31029 L
.97246 .31053 L
.97363 .31036 L
.97431 .31011 L
.97497 .30978 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00X?oonfX4o`0007Wooo]Z1Ol00020oookJPCo0000V_oo
nfX009oooo]Z1Ol0001ioookJPGo0000P?oonfX4o`0009[ooo]Z002OoookJPGo0000NOoonfX5o`00
07oooo]Z1Ol0002JoookJP00WooonfX5o`0007Wooo]Z1Ol0001ooookJPGo0000V_oonfX009oooo]Z
1Ol0001/oookJP?o001o2_oonfX5o`0007oooo]Z1Ol0002JoookJP00WooonfX6o`0006_ooo]Z0ol0
07l:oookJPGo0000OooonfX6o`0009Wooo]Z002OoookJPKo0000JooonfX3o`00O`[ooo]Z1Ol0001o
oookJPKo0000VOoonfX009oooo]Z1_l0001KoookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0001ooook
JPKo0000VOoonfX009oooo]Z1_l0001KoookJP[o001o1_oonfX3o`00O`[ooo]Z1_l0001noookJPKo
0000VOoonfX009oooo]Z1_l0001[oookJP?o001o2_oonfX5o`0007oooo]Z1_l0002IoookJP00Wooo
nfX6o`0006_ooo]Z0ol007l:oookJPGo0000OooonfX6o`0009Wooo]Z002OoookJPOo0000J_oonfX3
o`00O`[ooo]Z1Ol0001ooookJPKo0000VOoonfX009oooo]Z1ol0001ZoookJP?o001o2_oonfX5o`00
07oooo]Z1_l0002IoookJP00WooonfX7o`0006Oooo]Z1_l007l:oookJPGo0000OooonfX6o`0009Wo
oo]Z002OoookJPOo0000IooonfX6o`00O`[ooo]Z1Ol0001ooookJPOo0000V?oonfX009oooo]Z1ol0
001YoookJPCo001o2_oonfX5o`0007oooo]Z1ol0002HoookJP00WooonfX7o`0006[ooo]Z0ol007l:
oookJPGo0000OooonfX7o`0009Sooo]Z002NoookJPSo0000MooonfX5o`0007oooo]Z1ol0002Hoook
JP00W_oonfX8o`0007Oooo]Z1Ol0001ooookJPOo0000V?oonfX009kooo]Z2?l0001goookJPGo0000
O_oonfX8o`0009Sooo]Z002NoookJPSo0000MooonfX5o`0007kooo]Z2?l0002HoookJP00W_oonfX8
o`0007Oooo]Z1Ol0001noookJPSo0000V?oonfX009kooo]Z2?l0001goookJPGo0000O_oonfX8o`00
09Sooo]Z002NoookJPSo000000?ooo]Zo`000?l000000ol0001aoookJPGo0000O_oonfX8o`000003
oookJ_l0003o000000?o0000T_oonfX009kooo]Z3_l0001aoookJPGo0000O_oonfX>o`0009;ooo]Z
002NoookJPko0000LOoonfX5o`0007kooo]Z3_l0002BoookJP00W_oonfX?o`00073ooo]Z1Ol0001n
oookJPoo0000TOoonfX009kooo]Z1?l000000ooonf[o0000o`000008o`00073ooo]Z1Ol0001noook
JPCo000000?ooo]Zo`000?l000002?l0002AoookJP00W_oonfX4o`000003oookJ_l0003o000000So
0000L?oonfX5o`0007kooo]Z1?l000000ooonf[o0000o`000008o`00097ooo]Z002NoookJPCo0000
00?ooo]Zo`000?l000002?l0001`oookJPGo0000O_oonfX4o`000003oookJ_l0003o000000So0000
TOoonfX009kooo]Z1?l000000ooonf[o0000o`000009o`0006oooo]Z1Ol0001noookJPCo000000?o
oo]Zo`000?l000002?l0002AoookJP00W_oonfX4o`000003oookJ_l0003o000000Wo0000KooonfX5
o`0007kooo]Z1?l00002oookJP[o0000T?oonfX009kooo]Z1?l00002oookJP[o0000KooonfX5o`00
07kooo]Z1?l00002oookJP[o0000T?oonfX009kooo]Z1?l00002oookJPGo000000?ooo]Zo`000?l0
00000_l0001_oookJPGo0000O_oonfX4o`0000;ooo]Z2_l0002@oookJP00WOoonfX5o`0000Sooo]Z
1?l0001_oookJPGo0000O_oonfX4o`0000Sooo]Z1?l0002@oookJP00WOoonfX5o`0000Sooo]Z1Ol0
001^oookJPGo0000O_oonfX4o`0000Sooo]Z1Ol0002?oookJP00WOoonfX5o`0000Sooo]Z2Ol0001Z
oookJPGo0000OOoonfX5o`0000Sooo]Z2Ol0002;oookJP00WOoonfX4o`0000Wooo]Z2_l0001Yoook
JPGo0000OOoonfX5o`0000Sooo]Z2_l0002:oookJP00WOoonfX4o`0000[ooo]Z2Ol0001YoookJPGo
0000OOoonfX5o`0000Wooo]Z2Ol0002:oookJP00WOoonfX4o`0000[ooo]Z2_l0001XoookJPGo0000
OOoonfX4o`0000[ooo]Z2Ol0002:oookJP00WOoonfX4o`0000[ooo]Z2_l0001XoookJPGo0000OOoo
nfX4o`0000[ooo]Z2_l00029oookJP00WOoonfX4o`0000[ooo]Z2_l0001XoookJPGo0000OOoonfX4
o`0000_ooo]Z2Ol00029oookJP00WOoonfX4o`0000_ooo]Z2Ol0001XoookJPGo0000OOoonfX4o`00
00_ooo]Z2_l00028oookJP00WOoonfX4o`00013ooo]Z1Ol0001WoookJPGo0000OOoonfX4o`00013o
oo]Z1Ol00028oookJP00WOoonfX4o`00013ooo]Z1Ol0001WoookJPGo0000OOoonfX4o`00013ooo]Z
1Ol00028oookJP00WOoonfX4o`00013ooo]Z1Ol0001WoookJPGo0000OOoonfX4o`00017ooo]Z1?l0
0028oookJP00WOoonfX4o`00017ooo]Z1Ol00018oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:
oookJPGo0000OOoonfX4o`00017ooo]Z1Ol00027oookJP00WOoonfX4o`00017ooo]Z1Ol00017oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000OOoonfX4o`00017ooo]Z1Ol00027oook
JP00WOoonfX4o`00017ooo]Z2_l00012oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000A
oookJP[o0000P_oonfX009gooo]Z1?l0000BoookJPWo0000=OoonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000OOoonfX4o`0001;ooo]Z2Ol00022oook
JP00WOoonfX4o`0001;ooo]Z2Ol0000eoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2?oonfX6o`0007cooo]Z1?l0000BoookJP[o0000POoonfX009gooo]Z1?l0000BoookJP[o0000
@?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0007gooo]Z1?l0000CoookJPWo0000
POoonfX009gooo]Z1?l0000CoookJP[o0000?ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z1Ol0001moookJPCo00004ooonfX:o`00083ooo]Z002MoookJPCo00005ooonfX6
o`0003oooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001moookJPCo00006?oonfX5
o`00083ooo]Z002MoookJPCo00006?oonfX5o`0003oooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
O`[ooo]Z1Ol0001moookJPCo00006?oonfX5o`00083ooo]Z002MoookJPCo00006OoonfX4o`0003oo
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001moookJPCo00006OoonfX4o`00083o
oo]Z002MoookJPCo00006OoonfX5o`0003oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o3_oonfX5o`0007gooo]Z1?l0000IoookJPGo0000OooonfX009gooo]Z1?l0000IoookJPWo0000
>ooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000OOoonfX4o`0001Wooo]Z2Ol0001koookJP00WOoo
nfX4o`0001Wooo]Z2_l0000koookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001moookJPCo00006Ooo
nfX:o`0007[ooo]Z002MoookJPCo00006_oonfX:o`0005Sooo]Z1Ol0001moookJPCo00006_oonfX:
o`0007Wooo]Z002MoookJPCo00006_oonfX:o`0005Sooo]Z1Ol0001moookJPCo00006_oonfX:o`00
07Wooo]Z002MoookJPCo00006ooonfX:o`0005Oooo]Z1Ol0001moookJPCo00006ooonfX9o`0007Wo
oo]Z002MoookJPCo00008?oonfX5o`0005Oooo]Z1Ol0001moookJPCo00008?oonfX5o`0007Sooo]Z
002MoookJPCo00008?oonfX5o`0005Oooo]Z1Ol0001moookJPCo00008?oonfX6o`0007Oooo]Z002M
oookJPCo00008OoonfX5o`0005Kooo]Z1Ol0001moookJPCo00008?oonfX6o`0007Oooo]Z002Moook
JPCo00008OoonfX:o`00057ooo]Z1Ol0001moookJPCo00008OoonfX:o`0007;ooo]Z002MoookJPCo
00008OoonfX;o`00053ooo]Z1Ol0001moookJPCo00008_oonfX9o`0007;ooo]Z002MoookJPCo0000
8_oonfX:o`00053ooo]Z1Ol0001moookJPCo00008_oonfX:o`00077ooo]Z002MoookJPCo00008_oo
nfX;o`0004oooo]Z1Ol0001moookJPCo00008_oonfX:o`00077ooo]Z002MoookJPCo0000:?oonfX5
o`0004oooo]Z1Ol0001moookJPCo00009ooonfX6o`00073ooo]Z002MoookJPCo0000:?oonfX6o`00
04kooo]Z1Ol0001loookJPGo0000:?oonfX6o`0006oooo]Z000RoookJP?o001oMOoonfX3o`00O`Co
00000_oonfX3o`00O`?ooo]Z1Ol007lLoookJPWo0000B_oonfX5o`0007Cooo]Z1Ol007l3oookJPGo
00000_oonfX5o`00Ob7ooo]Z2_l0001;oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJPCo001o
1?l00002oookJP?o001o0_oonfX7o`00Oa_ooo]Z2_l00019oookJPGo0000LooonfX7o`00O`;ooo]Z
1Ol000000ooonf[o001oo`00O`05o`00Ob7ooo]Z2_l0001:oookJP?o001o7OoonfX002;ooo]Z0ol0
07mdoookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007lLoookJP[o0000B?oonfX5o`0007?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l2oookJPCo000000?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lQoook
JP_o0000BOoonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o
001o0_oonfX4o`0000Kooo]Z0ol007l3oookJP?o001o6ooonfX:o`0004Sooo]Z1Ol0001boookJP?o
001o0ooonfX3o`00O`03oookJ_l0003o000000;o000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00
Ob7ooo]Z2_l00019oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l2oookJPCo00003?oonfX3o`00Oacooo]Z2_l00017oookJPGo0000L_oonfX3o`00O`?o
oo]Z0ol007l00ooonf[o0000o`000002o`0000Oooo]Z0ol007lRoookJP[o0000B?oonfX3o`00Oago
oo]Z000RoookJP?o001oLooonfX3o`00O`;ooo]Z1?l0000<oookJP?o001o8OoonfX6o`0004Kooo]Z
1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00001ooonfX3o`00ObOooo]Z
1_l00017oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4o`0000Oooo]Z0_l0
07l2oookJPCo001o8OoonfX;o`00047ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0
003o000000;o00000_oonfX2o`00O`;ooo]Z1?l007lWoookJP_o0000@_oonfX3o`00Oagooo]Z000R
oookJP?o001oLooonfX3o`00O`;ooo]Z1?l00007oookJPOo001o8ooonfX;o`00043ooo]Z1Ol0001b
oookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oonfX7o`00ObWooo]Z2ol00011
oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4o`0000Oooo]Z1_l007lUoook
JP[o0000@?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oook
JPKo001o:ooonfX:o`00047ooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l00ooonf[o
0000o`000003o`0000Oooo]Z0_l007lYoookJPco0000?_oonfX5o`0007;ooo]Z0ol007l3oookJP?o
001o00?ooo]Zo`000?l000000_l00002oookJP;o001o;ooonfX;o`0003gooo]Z1_l007lMoookJP00
7ooonfX6o`00OgCooo]Z0ol007l5o`0000Oooo]Z0_l007l_oookJP_o0000>OoonfX5o`0007?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l2oookJPCo00000_oonfX2o`00OcGooo]Z2ol0000goookJPKo
001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o1Ol00008oookJPOo001o:OoonfX<o`0003Sooo]Z
1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z1ol007l_oookJPco0000>?oonfX4o`00Oagooo]Z
000RoookJP?o001oMOoonfX2o`00O`Co00002OoonfX7o`00Ob[ooo]Z3?l0000goookJPGo0000M?oo
nfX5o`00O`?ooo]Z1?l00003oookJPOo001o<?oonfX;o`0003Wooo]Z0ol007lMoookJP00W?oonfX4
o`0003_ooo]Z4Ol0000aoookJPGo0000O?oonfX4o`0003_ooo]Z4Ol0001BoookJP00W?oonfX4o`00
047ooo]Z3?l0000`oookJPGo0000O?oonfX4o`00047ooo]Z3?l0001AoookJP00W?oonfX4o`0004;o
oo]Z4Ol0000ZoookJPGo0000O?oonfX4o`00047ooo]Z4ol0001:oookJP00W?oonfX4o`0004?ooo]Z
4_l0000XoookJPGo0000O?oonfX4o`0004;ooo]Z4ol00019oookJP00W?oonfX4o`0004?ooo]Z6Ol0
000QoookJPGo0000O?oonfX4o`0004Cooo]Z6?l00012oookJP00W?oonfX4o`0004[ooo]Z4ol00000
0ooonf[o0000o`000004o`0001Wooo]Z1Ol0001loookJPCo0000B_oonfXJo`0003[ooo]Z000>oook
J_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000
ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000U
o`0000oooo]Z000MoookJP03o`000?oonf[ooo]Z00Ko00000_oonfX6o`000003oookJ_l0003o0000
023o0000BooonfX4o`0006_ooo]Z1Ol00002oookJPKo00000_oonfX>o`0000;ooo]Z1_l000000ooo
nf[o0000o`00000Qo`0004[ooo]Z1?l0001[oookJPGo00000_oonfX6o`0000;ooo]Z1_l0000Noook
JP00>?oonfX6o`000003oookJ_l0003o0000017o0000B_oonfX4o`0007gooo]Z1Ol0000HoookJPKo
000000?ooo]Zo`000?l000004Ol0001:oookJPCo0000W_oonfX0043ooo]Z6?l00014oookJPCo0000
OOoonfX5o`00023ooo]Z6Ol00013oookJPCo0000W_oonfX004Oooo]Z4ol00012oookJPCo0000OOoo
nfX5o`0002Oooo]Z4ol00012oookJPCo0000W_oonfX004Sooo]Z4_l00012oookJPCo0000OOoonfX5
o`0002Sooo]Z4ol00011oookJPCo0000W_oonfX004oooo]Z3?l00011oookJPCo0000OOoonfX5o`00
02oooo]Z3Ol00010oookJPCo0000W_oonfX0053ooo]Z4Ol0000koookJPCo0000OOoonfX5o`00033o
oo]Z4Ol0000koookJPCo0000W_oonfX005Kooo]Z3?l0000joookJPCo0000OOoonfX5o`0003Kooo]Z
3?l0000joookJPCo0000W_oonfX005Oooo]Z3?l0000ioookJPCo0000OOoonfX5o`0003Sooo]Z2_l0
000joookJPCo0000W_oonfX005Sooo]Z2ol0000ioookJPCo0000OOoonfX5o`0003Sooo]Z2ol0000i
oookJPCo0000W_oonfX005kooo]Z2_l0000doookJPCo0000OOoonfX5o`0003kooo]Z2_l0000doook
JPCo0000W_oonfX005oooo]Z2_l0000coookJPCo0000OOoonfX5o`0003kooo]Z3?l0000boookJPCo
0000W_oonfX005oooo]Z2ol0000aoookJPGo0000OOoonfX5o`0003oooo]Z2ol0000boookJPCo0000
W_oonfX0063ooo]Z2_l0000aoookJPGo0000OOoonfX5o`00043ooo]Z2ol0000aoookJPCo0000W_oo
nfX0067ooo]Z2_l0000`oookJPGo0000OOoonfX5o`00047ooo]Z2_l0000aoookJPCo0000W_oonfX0
06Kooo]Z2_l0000[oookJPCo0000O_oonfX5o`0004Kooo]Z2_l0000/oookJPCo0000W_oonfX006Ko
oo]Z2ol0000ZoookJPCo0000O_oonfX5o`0004Oooo]Z2_l0000[oookJPCo0000W_oonfX006Oooo]Z
2_l0000ZoookJPCo0000O_oonfX5o`0004Oooo]Z2ol0000ZoookJPCo0000W_oonfX006Sooo]Z2_l0
000YoookJPCo0000O_oonfX5o`0004Sooo]Z2_l0000ZoookJPCo0000W_oonfX006Wooo]Z2_l0000X
oookJPCo0000O_oonfX5o`0004Wooo]Z2Ol0000ZoookJPCo0000W_oonfX006gooo]Z1_l0000Xoook
JPCo0000O_oonfX5o`0004kooo]Z1Ol0000YoookJPCo0000W_oonfX006kooo]Z1Ol0000XoookJPCo
0000O_oonfX5o`0004kooo]Z1Ol0000YoookJPCo0000W_oonfX006oooo]Z2Ol0000SoookJPCo0000
O_oonfX5o`0004kooo]Z2_l0000SoookJPGo0000W_oonfX006oooo]Z2_l0000RoookJPCo0000O_oo
nfX5o`0004oooo]Z2_l0000RoookJPGo0000W_oonfX006oooo]Z2_l0000RoookJPCo0000O_oonfX5
o`0004oooo]Z2ol0000QoookJPGo0000W_oonfX0073ooo]Z2_l0000QoookJPCo0000O_oonfX5o`00
053ooo]Z2_l0000QoookJPCo0000WooonfX007Gooo]Z1Ol0000QoookJPCo0000O_oonfX5o`0005Go
oo]Z1_l0000PoookJPCo0000WooonfX007Gooo]Z1_l0000PoookJPCo0000O_oonfX5o`0005Kooo]Z
1Ol0000PoookJPCo0000WooonfX007Kooo]Z1Ol0000PoookJPCo0000O_oonfX5o`0005Kooo]Z1Ol0
000PoookJPCo0000WooonfX007Kooo]Z2_l0000KoookJPCo0000O_oonfX5o`0005Oooo]Z2Ol0000K
oookJPCo0000WooonfX007Oooo]Z2_l0000JoookJPCo0000O_oonfX5o`0005Oooo]Z2_l0000Joook
JPCo0000WooonfX007Oooo]Z2_l0000JoookJPCo0000O_oonfX5o`0005Oooo]Z2_l0000JoookJPCo
0000WooonfX007Sooo]Z2Ol0000JoookJPCo0000O_oonfX5o`0005Sooo]Z2Ol0000JoookJPCo0000
WooonfX007Sooo]Z2_l0000IoookJPCo0000O_oonfX5o`0005Sooo]Z2_l0000IoookJPCo0000Wooo
nfX007gooo]Z1_l0000HoookJPCo0000O_oonfX5o`0005gooo]Z1_l0000HoookJPCo0000WooonfX0
07gooo]Z1_l0000HoookJPCo0000H?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`00
05gooo]Z1ol0000GoookJPCo0000WooonfX007kooo]Z1_l0000GoookJPCo0000GooonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o2OoonfX5o`0005kooo]Z1ol0000FoookJPCo0000WooonfX007oooo]Z
1Ol0000GoookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001OoookJPOo00005OoonfX4o`00
09oooo]Z001ooookJPKo00005_oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l8oookJPGo0000H?oonfX8o`0001?ooo]Z1?l0002OoookJP00P?oonfX6o`0001Gooo]Z
1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000H?oonfX7o`0001?ooo]Z
1?l0002OoookJP00P?oonfX6o`0001Gooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l8oookJPGo0000H_oonfX7o`0001;ooo]Z1?l0002OoookJP00POoonfX6o`0001Cooo]Z1?l0001N
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0006?ooo]Z1_l0000B
oookJPCo0000WooonfX008;ooo]Z1_l0000CoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o2OoonfX5o`0006Cooo]Z1_l0000AoookJPCo0000WooonfX008;ooo]Z1_l0000CoookJPCo
0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0006Gooo]Z1Ol0000AoookJPCo
0000WooonfX008?ooo]Z1_l0000BoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
3_oonfX5o`0006Gooo]Z1Ol0000AoookJPCo0000WooonfX008Cooo]Z1Ol0000BoookJPCo0000Gooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000I_oonfX4o`00017ooo]Z
1?l0002OoookJP00Q?oonfX6o`00017ooo]Z1?l0001OoookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0
001VoookJPGo00004?oonfX4o`0009oooo]Z0025oookJPKo00004?oonfX4o`00063ooo]Z1Ol007l:
oookJPOo001o2?oonfX5o`0006Kooo]Z1Ol0000@oookJPCo0000WooonfX008Gooo]Z2ol0000;oook
JPCo0000O_oonfX5o`0006Kooo]Z2_l0000;oookJPCo0000WooonfX008Kooo]Z2_l0000;oookJPCo
0000O_oonfX5o`0006Oooo]Z2_l0000:oookJPCo0000WooonfX008Oooo]Z2_l0000:oookJPCo0000
O_oonfX5o`0006Oooo]Z2_l0000:oookJPCo0000WooonfX008Oooo]Z2_l0000:oookJPCo0000O_oo
nfX5o`0006Oooo]Z2_l0000:oookJPCo0000WooonfX008Sooo]Z2Ol0000:oookJPCo0000O_oonfX5
o`0006Oooo]Z2_l0000:oookJPCo0000WooonfX008Sooo]Z2Ol0000:oookJPCo0000O_oonfX5o`00
06Sooo]Z2_l00009oookJPCo0000WooonfX008Wooo]Z2?l0000:oookJPCo0000O_oonfX5o`0006Wo
oo]Z2Ol00009oookJPCo0000WooonfX008gooo]Z1Ol00009oookJPCo0000O_oonfX5o`0006gooo]Z
1Ol00009oookJPCo0000WooonfX008gooo]Z1Ol00008oookJPGo0000O_oonfX5o`0006kooo]Z1?l0
0008oookJPGo0000WooonfX008gooo]Z1Ol000000ooonf[o0000o`000003o`0000;ooo]Z1Ol0001n
oookJPGo0000K_oonfX4o`000003oookJ_l0003o000000?o00000_oonfX5o`0009oooo]Z002>oook
JP[o00000_oonfX5o`0007kooo]Z1Ol0001^oookJP[o00000_oonfX5o`0009oooo]Z002>oookJP[o
00000_oonfX4o`0007oooo]Z1Ol0001^oookJP_o000000?ooo]Zo`000?l000000_l0002PoookJP00
S_oonfX;o`000003oookJ_l0003o000000;o0000OooonfX5o`0006kooo]Z2ol000000ooonf[o0000
o`000002o`000:3ooo]Z002?oookJP[o000000?ooo]Zo`000?l000000_l0001ooookJPGo0000Kooo
nfX:o`000003oookJ_l0003o000000;o0000X?oonfX008oooo]Z2_l000000ooonf[o0000o`000002
o`0007oooo]Z1Ol0001_oookJP[o000000?ooo]Zo`000?l000000_l0002PoookJP00SooonfX:o`00
0003oookJ_l0003o000000;o0000OooonfX5o`0006oooo]Z2_l000000ooonf[o0000o`000002o`00
0:3ooo]Z002?oookJP[o000000?ooo]Zo`000?l000000_l0001ooookJPGo0000KooonfX:o`000003
oookJ_l0003o000000;o0000X?oonfX008oooo]Z2_l000000ooonf[o0000o`000002o`0007oooo]Z
1Ol0001_oookJP[o000000?ooo]Zo`000?l000000_l0002PoookJP00SooonfX?o`0007oooo]Z1Ol0
001`oookJPko0000X?oonfX0093ooo]Z3_l0001ooookJPGo0000L?oonfX>o`000:3ooo]Z002Aoook
JPgo0000OooonfX5o`00073ooo]Z3_l0002PoookJP00U_oonfX8o`0007oooo]Z1Ol0001foookJPSo
0000X?oonfX009Kooo]Z2?l0001ooookJPGo0000M_oonfX8o`000:3ooo]Z002FoookJPSo0000Oooo
nfX5o`0007Kooo]Z2?l0002PoookJP00U_oonfX8o`0007oooo]Z1Ol0001foookJPSo0000X?oonfX0
09Kooo]Z2?l0001ooookJPGo0000M_oonfX8o`000:3ooo]Z002FoookJPSo0000OooonfX5o`0007Ko
oo]Z2?l0002PoookJP00U_oonfX8o`0007oooo]Z1Ol0001foookJPSo0000X?oonfX009Kooo]Z2?l0
001ooookJPGo0000M_oonfX7o`000:7ooo]Z002FoookJPSo0000L_oonfX3o`00O`[ooo]Z1Ol0001f
oookJPOo0000XOoonfX009Kooo]Z2?l0001boookJP?o001o2_oonfX5o`0007Kooo]Z1ol0002Qoook
JP00U_oonfX7o`0007?ooo]Z0ol007l:oookJPGo0000M_oonfX7o`000:7ooo]Z002FoookJPOo0000
LooonfX3o`00O`[ooo]Z1Ol0001foookJPOo0000XOoonfX009Oooo]Z1_l0001coookJP?o001o2_oo
nfX6o`0007Kooo]Z1_l0002QoookJP00UooonfX6o`0007?ooo]Z0ol007l:oookJPGo0000MooonfX6
o`000:7ooo]Z002GoookJPKo0000LooonfX3o`00O`[ooo]Z1Ol0001goookJPKo0000XOoonfX009Oo
oo]Z1_l0001coookJP?o001o2_oonfX5o`0007Oooo]Z1_l0002QoookJP00UooonfX6o`0007?ooo]Z
0ol007l:oookJPGo0000MooonfX6o`000:7ooo]Z002GoookJPKo0000L?oonfX6o`00O`[ooo]Z1Ol0
001goookJPKo0000XOoonfX009Oooo]Z1_l0001`oookJPKo001o2_oonfX5o`0007Sooo]Z1Ol0002Q
oookJP00UooonfX6o`0007;ooo]Z1?l007l:oookJPGo0000N?oonfX5o`000:7ooo]Z002HoookJPGo
0000LooonfX3o`00O`[ooo]Z1Ol0001hoookJPGo0000XOoonfX009Sooo]Z1Ol00020oookJPGo0000
N?oonfX4o`000:;ooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJP;o
oo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooo
nfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z
003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00oooonfX>oookJPCo001o3?oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7o
oo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oo
oookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJPCo
001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooo
nfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30975 L
.02605 .31025 L
.02729 .31048 L
.02846 .31032 L
.02954 .30986 L
.03053 .30927 L
.03162 .30857 L
.03279 .30794 L
.03396 .3076 L
.03506 .30761 L
.03636 .30805 L
.03756 .30875 L
.0388 .30955 L
.03945 .30993 L
.04015 .31026 L
.04143 .31055 L
.04262 .31042 L
.05214 .30922 L
.05339 .31005 L
.05408 .31043 L
.05473 .31069 L
.056 .31089 L
.05715 .31068 L
.05836 .31012 L
.05968 .30932 L
.06037 .30891 L
.06111 .30854 L
.06175 .30832 L
.06244 .30819 L
.06321 .30821 L
.06392 .30839 L
.06469 .30873 L
.0655 .30923 L
.06699 .3103 L
.06771 .3108 L
.06837 .31118 L
.06963 .31163 L
.07032 .31169 L
.07098 .31162 L
.07169 .31141 L
.07234 .31111 L
.07382 .31026 L
.07502 .30961 L
.0763 .30921 L
.07704 .30918 L
.07771 .3093 L
.07903 .30991 L
.08042 .31093 L
.08189 .31208 L
Mistroke
.08261 .31255 L
.08328 .31288 L
.08454 .31316 L
.08578 .31297 L
.08691 .31248 L
.08823 .31175 L
.08946 .31115 L
.09071 .31088 L
.09136 .31092 L
.09207 .31112 L
.09281 .31149 L
.09351 .31197 L
.09482 .31308 L
.096 .31412 L
.09725 .31499 L
.09832 .31541 L
.0995 .31546 L
.10076 .31509 L
.10147 .31475 L
.10212 .3144 L
.10332 .31382 L
.10458 .31349 L
.10582 .31363 L
.10652 .31394 L
.10716 .31436 L
.10835 .31538 L
.1096 .31664 L
.11064 .31763 L
.11177 .31843 L
.113 .31888 L
.11415 .31884 L
.11546 .31839 L
.11689 .31769 L
.11754 .31742 L
.11824 .31723 L
.11949 .31724 L
.12068 .31775 L
.1218 .31867 L
.12436 .32151 L
.12552 .32263 L
.12661 .32333 L
.12774 .32361 L
.12897 .32345 L
.13004 .32304 L
.13102 .3226 L
.13214 .32221 L
.1332 .32215 L
.13436 .32255 L
.13558 .32352 L
.13663 .32471 L
Mistroke
.13778 .32621 L
.13901 .32778 L
.13969 .32851 L
.14034 .32907 L
.14159 .32972 L
.14274 .32979 L
.14399 .32945 L
.14469 .32915 L
.14533 .32889 L
.14652 .32857 L
.14777 .32871 L
.1489 .32938 L
.14995 .33047 L
.15234 .33393 L
.15366 .33579 L
.15492 .33705 L
.15605 .33763 L
.15727 .33768 L
.15791 .33752 L
.15861 .33726 L
.15929 .33699 L
.16002 .33674 L
.16133 .33665 L
.16256 .3372 L
.16372 .33836 L
.1648 .33993 L
.16607 .34216 L
.16724 .34418 L
.16846 .34596 L
.16962 .34706 L
.17084 .34753 L
.17216 .34736 L
.17322 .34696 L
.17438 .34657 L
.1756 .34658 L
.17674 .34721 L
.1778 .34844 L
.17877 .35004 L
.18095 .35448 L
.18225 .35691 L
.18347 .35855 L
.18456 .35934 L
.18574 .35947 L
.18703 .35905 L
.18774 .35873 L
.1884 .35849 L
.18956 .3584 L
.19083 .35912 L
.19202 .36071 L
.19315 .36296 L
Mistroke
.19526 .3681 L
.19636 .37057 L
.19753 .37254 L
.19881 .37368 L
.19999 .37379 L
.20127 .37323 L
.20245 .37258 L
.20309 .37236 L
.2038 .37236 L
.20509 .37322 L
.20628 .37517 L
.20756 .37834 L
.20986 .38519 L
.21055 .38701 L
.21127 .38862 L
.21206 .38992 L
.2128 .39063 L
.21411 .3908 L
.21486 .39039 L
.21556 .38981 L
.21687 .38873 L
.21806 .38838 L
.21872 .38867 L
.21943 .38947 L
.22073 .39228 L
.22312 .40076 L
.22443 .4056 L
.22564 .40908 L
.22696 .41104 L
.22765 .41123 L
.2284 .41084 L
.22908 .41007 L
.22972 .4091 L
.23093 .40719 L
.23209 .40606 L
.23332 .40653 L
.23437 .40871 L
.23552 .41301 L
.23812 .42673 L
.23926 .43208 L
.2405 .43574 L
.24177 .43634 L
.24298 .434 L
.24366 .4318 L
.24437 .42907 L
.24566 .42439 L
.24696 .42197 L
.24819 .42369 L
.24929 .42928 L
.25048 .43936 L
Mistroke
.25193 .45501 L
.25328 .469 L
.25396 .47422 L
.25468 .4775 L
.25549 .47747 L
.25623 .47342 L
.25752 .45563 L
.25826 .4394 L
.25894 .42064 L
.2615 .32565 L
.26377 .23459 L
.265 .19356 L
.26615 .16509 L
.2674 .14634 L
.26806 .14155 L
.26876 .14002 L
.27001 .14486 L
.27115 .15504 L
.27339 .17924 L
.27465 .18959 L
.27581 .1949 L
.27682 .19607 L
.27794 .19426 L
.27911 .19026 L
.2802 .18608 L
.28147 .18246 L
.2822 .18159 L
.28286 .18171 L
.28409 .18428 L
.28539 .1898 L
.28768 .20208 L
.28896 .20775 L
.29014 .21096 L
.29141 .21205 L
.29205 .21178 L
.29275 .21102 L
.29404 .20901 L
.29521 .20738 L
.29593 .20686 L
.29661 .20686 L
.29733 .20746 L
.29811 .20882 L
.29879 .21056 L
.29951 .21288 L
.30081 .21776 L
.30202 .22234 L
.30333 .22643 L
.30457 .22884 L
.30573 .22965 L
.30687 .22935 L
Mistroke
.3079 .22853 L
.30903 .22759 L
.31022 .22714 L
.31153 .22786 L
.31273 .2298 L
.31402 .23305 L
.31544 .23731 L
.31667 .24083 L
.31798 .24374 L
.31922 .2453 L
.32035 .24571 L
.32148 .2454 L
.32269 .24472 L
.32372 .24427 L
.32485 .2443 L
.32607 .24522 L
.32738 .24732 L
.32862 .25009 L
.32975 .25291 L
.33075 .25528 L
.33182 .25739 L
.333 .25894 L
.33409 .2596 L
.33532 .25958 L
.33648 .25912 L
.33752 .25869 L
.33865 .25855 L
.33989 .25907 L
.34101 .26029 L
.34231 .26247 L
.34354 .26499 L
.34461 .26717 L
.34573 .26918 L
.34697 .27073 L
.34812 .27143 L
.35853 .27729 L
.37958 .28869 L
.38083 .28828 L
.38154 .28822 L
.38218 .2883 L
.38342 .28893 L
.3846 .29003 L
.38713 .29326 L
.38845 .29473 L
.3892 .29533 L
.38989 .2957 L
.39059 .29588 L
.39124 .29589 L
.39195 .29575 L
.39271 .29547 L
Mistroke
.39345 .29515 L
.39425 .29479 L
.395 .29454 L
.3957 .29442 L
.39641 .29446 L
.39705 .29464 L
.39779 .29504 L
.39849 .29558 L
.40104 .29834 L
.40231 .29964 L
.40349 .30049 L
.40473 .30086 L
.40538 .30083 L
.40608 .30067 L
.40831 .29966 L
.40957 .29921 L
.41073 .29914 L
.41138 .2993 L
.41209 .29963 L
.41284 .30014 L
.41355 .30075 L
.41494 .30213 L
.41622 .30333 L
.41739 .30415 L
.41862 .30454 L
.41986 .30443 L
.42057 .30418 L
.42122 .30388 L
.42249 .30321 L
.42319 .30289 L
.42384 .30266 L
.425 .30255 L
.42626 .30289 L
.42697 .30329 L
.42764 .30378 L
.4289 .30487 L
.43027 .30604 L
.43104 .30657 L
.43173 .30691 L
.433 .30716 L
.43419 .30694 L
.43529 .30644 L
.43648 .30578 L
.43779 .30515 L
.43845 .30495 L
.43918 .30488 L
.44046 .30513 L
.44166 .30577 L
.44281 .30664 L
.44407 .30763 L
Mistroke
.44526 .3084 L
.44635 .30879 L
.44734 .30884 L
.44843 .30857 L
.44956 .30802 L
.45063 .30739 L
.45181 .30676 L
.45305 .30638 L
.4541 .30639 L
.45526 .30676 L
.45651 .30751 L
.45784 .30848 L
.45908 .30928 L
.46024 .30975 L
.46148 .30983 L
.46213 .3097 L
.46284 .30943 L
.46357 .30905 L
.46427 .30863 L
.46558 .30784 L
.4668 .30731 L
.46793 .30714 L
.46918 .30737 L
.4705 .30804 L
.47194 .30901 L
.4727 .3095 L
.4735 .30993 L
.47421 .31019 L
.47498 .31032 L
.47568 .31029 L
.47633 .31015 L
.47702 .30987 L
.47767 .30953 L
.47888 .30878 L
.48018 .30802 L
.48092 .3077 L
.48161 .30752 L
.48278 .30753 L
.48405 .30794 L
.48474 .30832 L
.4854 .30873 L
.48663 .30953 L
.48778 .31013 L
.48885 .31044 L
.49002 .31041 L
.49127 .30997 L
.49264 .30918 L
.49335 .30872 L
.49411 .30826 L
.49477 .30793 L
Mistroke
.4955 .30768 L
.49678 .30756 L
.49802 .30789 L
.49872 .30823 L
.49936 .30861 L
.5006 .3094 L
.50177 .31005 L
.50287 .31042 L
.50405 .31045 L
.50537 .31004 L
.50657 .30936 L
.50786 .30854 L
.50906 .30791 L
.51031 .30758 L
.51097 .30758 L
.51168 .30771 L
.52085 .30943 L
.52215 .30861 L
.52287 .30822 L
.52353 .30793 L
.52425 .30775 L
.52505 .30771 L
.52572 .30783 L
.52644 .30808 L
.52712 .30843 L
.52786 .3089 L
.5292 .30981 L
.53051 .31054 L
.53172 .31087 L
.53302 .31077 L
.53424 .31029 L
.53533 .30965 L
.53651 .30894 L
.5378 .30836 L
.53845 .30821 L
.53917 .30819 L
.54043 .30852 L
.54161 .30917 L
.54286 .31007 L
.54404 .31089 L
.54527 .31149 L
.54593 .31165 L
.54663 .31169 L
.54735 .31157 L
.54811 .31131 L
.54876 .311 L
.54946 .31059 L
.55017 .31017 L
.55084 .3098 L
.55208 .30929 L
Mistroke
.55328 .30919 L
.55457 .30955 L
.55524 .30992 L
.55595 .31042 L
.55722 .31142 L
.55832 .31225 L
.5595 .31289 L
.56079 .31316 L
.562 .31296 L
.56323 .31241 L
.56438 .31177 L
.56564 .31116 L
.56628 .31096 L
.56698 .31088 L
.56815 .31108 L
.56942 .31176 L
.57061 .31272 L
.5717 .3137 L
.5727 .31451 L
.57376 .31516 L
.57493 .31548 L
.57602 .3154 L
.57724 .31496 L
.5784 .31436 L
.57953 .31381 L
.58056 .31352 L
.58171 .31355 L
.58295 .31408 L
.58409 .31497 L
.58518 .31603 L
.58636 .3172 L
.58761 .31822 L
.58834 .31862 L
.58899 .31884 L
.59027 .31886 L
.59091 .31869 L
.59159 .31842 L
.59281 .31782 L
.59412 .3173 L
.59487 .31717 L
.59556 .31721 L
.59682 .31772 L
.59797 .31865 L
.60055 .3215 L
.60169 .32261 L
.60291 .32337 L
.60394 .32361 L
.60509 .32347 L
.60631 .323 L
.60763 .32242 L
Mistroke
.60888 .32214 L
.61002 .3223 L
.6111 .32292 L
.61211 .32387 L
.61439 .32677 L
.61554 .32815 L
.61662 .32914 L
.61786 .32974 L
.61899 .32978 L
.62015 .32946 L
.62139 .32894 L
.62256 .32859 L
.62363 .32861 L
.62488 .32921 L
.62559 .32984 L
.62624 .33059 L
.62872 .33423 L
.62937 .33516 L
.63007 .33605 L
.63134 .33721 L
.63258 .3377 L
.63371 .33763 L
.63494 .3372 L
.63565 .33692 L
.63629 .33672 L
.63697 .33662 L
.6377 .33669 L
.63902 .33741 L
.64017 .3387 L
.64138 .3406 L
.64357 .3444 L
.64478 .34611 L
.64591 .34713 L
.64716 .34754 L
.64786 .34748 L
.6485 .34731 L
.64957 .34689 L
.6507 .34654 L
.65195 .34662 L
.6531 .34737 L
.65428 .34888 L
.65539 .35086 L
.65747 .35515 L
.65863 .35723 L
.65988 .35877 L
.66105 .35943 L
.66212 .35944 L
.66338 .35898 L
.66404 .35868 L
.66475 .35844 L
Mistroke
.66604 .35847 L
.66723 .35932 L
.66844 .36112 L
.66976 .36392 L
.67213 .36968 L
.67284 .37114 L
.6735 .37224 L
.67419 .3731 L
.67495 .37365 L
.6762 .37378 L
.6769 .37353 L
.67754 .37318 L
.67869 .37256 L
.67991 .37234 L
.68095 .37288 L
.6821 .37443 L
.68333 .37718 L
.68465 .38099 L
.68589 .38472 L
.68704 .38773 L
.68819 .38983 L
.68944 .39084 L
.69055 .3907 L
.69172 .38984 L
.69288 .38885 L
.69397 .38837 L
.69495 .3887 L
.69601 .39012 L
.69725 .39325 L
.69839 .39718 L
.69961 .4019 L
.70093 .40664 L
.70216 .40977 L
.7033 .41113 L
.70438 .41101 L
.70553 .4097 L
.70676 .40772 L
.70741 .4068 L
.70809 .40615 L
.70935 .40634 L
.7105 .40854 L
.71115 .4107 L
.71185 .41366 L
.71311 .42017 L
.7146 .42822 L
.71526 .43128 L
.71597 .43396 L
.71666 .43568 L
.7173 .43644 L
.71798 .43633 L
Mistroke
.7187 .43521 L
.71949 .43301 L
.72025 .43029 L
.72093 .42763 L
.72166 .42499 L
.72229 .42319 L
.72299 .42207 L
.72422 .42321 L
.72492 .42593 L
.72566 .43058 L
.72637 .43647 L
.72702 .4429 L
.72814 .45531 L
.72935 .46793 L
.73067 .47687 L
.7319 .47668 L
.73256 .47208 L
.73329 .46306 L
.7346 .43566 L
.73587 .39645 L
.73705 .35206 L
.73943 .25447 L
.74061 .21166 L
.74171 .17954 L
.74296 .15419 L
.74362 .14603 L
.74432 .14121 L
.74558 .14138 L
.74672 .14897 L
.74896 .17285 L
.75014 .18436 L
.75138 .19262 L
.75247 .19583 L
.75367 .19534 L
.75476 .19227 L
.75577 .1884 L
.75706 .18391 L
.75778 .18226 L
.75845 .18156 L
.75968 .18264 L
.76098 .18696 L
.76215 .19273 L
.76324 .19875 L
.76443 .20479 L
.76573 .20959 L
.76703 .21186 L
.76775 .21203 L
.76841 .21164 L
.7696 .21005 L
.77086 .20804 L
Mistroke
.77158 .20721 L
.77236 .2068 L
.77309 .20703 L
.77377 .20781 L
.77505 .21075 L
.77569 .21284 L
.7764 .21543 L
.77761 .22012 L
.7789 .22465 L
.77964 .22672 L
.78031 .22814 L
.78161 .22956 L
.78284 .22947 L
.78353 .22901 L
.78416 .22847 L
.78533 .22751 L
.78656 .22715 L
.78767 .2278 L
.78886 .22967 L
.78998 .23239 L
.79099 .23537 L
.79221 .23904 L
.79335 .24206 L
.79454 .24433 L
.79585 .24556 L
.79714 .24561 L
.79786 .2453 L
.79852 .24492 L
.79973 .24432 L
.801 .24428 L
.80167 .24465 L
.80238 .24537 L
.80367 .24751 L
.8052 .25105 L
.80659 .25447 L
.80781 .25703 L
.8091 .25885 L
.80977 .25938 L
.81051 .25965 L
.81181 .25948 L
.81304 .25895 L
.81436 .25855 L
.81561 .25877 L
.81674 .25971 L
.82676 .27109 L
.82805 .27061 L
.8287 .2705 L
.82941 .27055 L
.83018 .27085 L
.83089 .27138 L
Mistroke
.83155 .27209 L
.83226 .27306 L
.83491 .27761 L
.83621 .27958 L
.83742 .28082 L
.83853 .28136 L
.8397 .28136 L
.84088 .28098 L
.84218 .28049 L
.84326 .28031 L
.84442 .28058 L
.84551 .28135 L
.84651 .28247 L
.84898 .2861 L
.85028 .28784 L
.85101 .28857 L
.85166 .28906 L
.85297 .28948 L
.8542 .28931 L
.85534 .28887 L
.85656 .2884 L
.85771 .28822 L
.85895 .28852 L
.86012 .28935 L
.86119 .29049 L
.86247 .29215 L
.86383 .29387 L
.86499 .29503 L
.86626 .29576 L
.86757 .29587 L
.86879 .29552 L
.87022 .29488 L
.87153 .29447 L
.8727 .29448 L
.87393 .295 L
.87516 .29603 L
.87651 .29751 L
.87775 .29891 L
.87892 .3 L
.87997 .30063 L
.88111 .30086 L
.88235 .30065 L
.88366 .30007 L
.8848 .29953 L
.88602 .29916 L
.88716 .29918 L
.8882 .29958 L
.88924 .30031 L
.89023 .30122 L
.89131 .30231 L
Mistroke
.89246 .30338 L
.89371 .30421 L
.89486 .30454 L
.8961 .30441 L
.89681 .30416 L
.89746 .30385 L
.89874 .30318 L
.89991 .3027 L
.90105 .30254 L
.90212 .30275 L
.90325 .30335 L
.90448 .30433 L
.90582 .30551 L
.90707 .30647 L
.90837 .30706 L
.90906 .30716 L
.90981 .30709 L
.91112 .30663 L
.91237 .30595 L
.9136 .3053 L
.91472 .30494 L
.91586 .30491 L
.91693 .30524 L
.91806 .30592 L
.91928 .30686 L
.92036 .3077 L
.92149 .30842 L
.92246 .30878 L
.92352 .30885 L
.92477 .30851 L
.92592 .30792 L
.92715 .3072 L
.9278 .30685 L
.92849 .30657 L
.92973 .30634 L
.93087 .30653 L
.93194 .30702 L
.93313 .30781 L
.93426 .30864 L
.93547 .30939 L
.93617 .30967 L
.9368 .30982 L
.93804 .30977 L
.93932 .30929 L
.94004 .30889 L
.9407 .30848 L
.942 .30772 L
.94322 .30725 L
.94425 .30714 L
.94535 .30737 L
Mistroke
.94658 .30797 L
.94771 .30871 L
.94888 .30949 L
.95015 .31011 L
.95135 .31033 L
.95247 .31016 L
.95518 .30871 L
.95591 .30826 L
.9566 .30791 L
.95732 .30764 L
.9581 .30749 L
.9588 .3075 L
.95944 .30763 L
.96017 .30791 L
.96087 .30828 L
.9621 .30906 L
.96341 .30986 L
.96458 .31034 L
.96588 .31046 L
.96706 .31016 L
.96816 .3096 L
.96937 .30883 L
.97064 .30808 L
.97131 .30779 L
.97204 .3076 L
.97332 .30762 L
.97404 .30782 L
.97481 .30818 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
X?oonfX4o`0007Wooo]Z1Ol0003ooookJQoooo]Z002OoookJPGo0000NOoonfX5o`0007oooo]Z1Ol0
002JoookJP00WooonfX5o`0007Wooo]Z1Ol0001ooookJPGo0000V_oonfX009oooo]Z1Ol0001ioook
JPGo0000OooonfX5o`0009[ooo]Z002OoookJPGo0000NOoonfX5o`0007oooo]Z1_l0002IoookJP00
WooonfX5o`0006cooo]Z0ol007l:oookJPGo0000OooonfX6o`0009Wooo]Z002OoookJPGo0000K?oo
nfX3o`00O`[ooo]Z1Ol0001ooookJPKo0000VOoonfX009oooo]Z1_l0001[oookJP?o001o2_oonfX5
o`0007oooo]Z1_l0002IoookJP00WooonfX6o`0005_ooo]Z2_l007l6oookJP?o001o2_oonfX5o`00
07oooo]Z1_l0002IoookJP00WooonfX6o`0005_ooo]Z2_l007l6oookJP?o001o2_oonfX6o`0007ko
oo]Z1_l0002IoookJP00W_oonfX7o`0006_ooo]Z0ol007l:oookJPGo0000OooonfX6o`0009Wooo]Z
002NoookJPOo0000JooonfX3o`00O`[ooo]Z1Ol0001ooookJPKo0000VOoonfX009kooo]Z1ol0001[
oookJP?o001o2_oonfX5o`0007oooo]Z1ol0002HoookJP00W_oonfX7o`0006_ooo]Z0ol007l:oook
JPGo0000OooonfX7o`0009Sooo]Z002NoookJPOo0000J?oonfX6o`00O`[ooo]Z1Ol0001ooookJPOo
0000V?oonfX009kooo]Z1ol0001XoookJPKo001o2_oonfX5o`0007oooo]Z1ol0002HoookJP00W_oo
nfX8o`0006Wooo]Z1?l007l:oookJPGo0000O_oonfX8o`0009Sooo]Z002NoookJPSo0000J_oonfX3
o`00O`[ooo]Z1Ol0001noookJPSo0000V?oonfX009kooo]Z2?l0001goookJPGo0000O_oonfX8o`00
09Sooo]Z002NoookJPSo0000MooonfX5o`0007kooo]Z2?l0002HoookJP00W_oonfX8o`0007Oooo]Z
1Ol0001noookJPSo0000V?oonfX009kooo]Z2?l0001goookJPGo0000O_oonfX8o`0009Sooo]Z002N
oookJPSo0000MooonfX5o`0007kooo]Z2Ol0002GoookJP00W_oonfX8o`000003oookJ_l0003o0000
00;o0000L_oonfX5o`0007kooo]Z3Ol0002CoookJP00W_oonfX8o`000003oookJ_l0003o000000?o
0000LOoonfX5o`0007kooo]Z3_l0002BoookJP00W_oonfX>o`00077ooo]Z1Ol0001noookJPCo0000
00?ooo]Zo`000?l000001ol0002BoookJP00W_oonfX?o`00073ooo]Z1Ol0001noookJPCo000000?o
oo]Zo`000?l000001ol0002BoookJP00W_oonfX?o`00073ooo]Z1Ol0001noookJPCo000000?ooo]Z
o`000?l000001ol0002BoookJP00W_oonfX4o`000003oookJ_l0003o000000So0000L?oonfX5o`00
07kooo]Z1?l000000ooonf[o0000o`000008o`00097ooo]Z002NoookJPCo000000?ooo]Zo`000?l0
00002?l0001`oookJPGo0000O_oonfX4o`000003oookJ_l0003o000000So0000TOoonfX009kooo]Z
1?l000000ooonf[o0000o`000008o`00073ooo]Z1Ol0001noookJPCo000000?ooo]Zo`000?l00000
2?l0002AoookJP00W_oonfX4o`000003oookJ_l0003o000000Wo0000KooonfX5o`0007gooo]Z1Ol0
00000ooonf[o0000o`000009o`00093ooo]Z002NoookJPCo00000_oonfX:o`0006oooo]Z1Ol0001m
oookJPGo000000?ooo]Zo`000?l000002Ol0002@oookJP00W_oonfX4o`0000;ooo]Z2_l0001_oook
JPGo0000OOoonfX5o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000000ol0002@oook
JP00W_oonfX4o`0000;ooo]Z1?l00002oookJPCo0000KooonfX5o`0007gooo]Z1?l00003oookJPCo
00000_oonfX4o`00093ooo]Z002NoookJPCo00002?oonfX4o`0006oooo]Z1Ol0001moookJPCo0000
2OoonfX4o`00093ooo]Z002NoookJPCo00002?oonfX5o`0006kooo]Z1Ol0001moookJPCo00002Ooo
nfX4o`00093ooo]Z002NoookJPCo00002?oonfX9o`0006[ooo]Z1Ol0001moookJPCo00002OoonfX9
o`0008_ooo]Z002NoookJPCo00002?oonfX:o`0006Wooo]Z1Ol0001moookJPCo00002OoonfX9o`00
08_ooo]Z002NoookJPCo00002OoonfX9o`0006Wooo]Z1Ol0001moookJPCo00002OoonfX:o`0008[o
oo]Z002NoookJPCo00002OoonfX9o`0006Wooo]Z1Ol0001moookJPCo00002OoonfX:o`0008[ooo]Z
002MoookJPGo00002OoonfX9o`0006Wooo]Z1Ol0001moookJPCo00002_oonfX:o`0008Wooo]Z002M
oookJPGo00002OoonfX:o`0006Sooo]Z1Ol0001moookJPCo00002ooonfX9o`0008Wooo]Z002Moook
JPGo00003_oonfX5o`0006Sooo]Z1Ol0001moookJPCo00003ooonfX5o`0008Wooo]Z002MoookJPCo
00003ooonfX5o`0006Sooo]Z1Ol0001moookJPCo00004?oonfX4o`0008Wooo]Z002MoookJPCo0000
4?oonfX5o`0006Oooo]Z1Ol0001moookJPCo00004?oonfX4o`0008Wooo]Z002MoookJPCo00004?oo
nfX5o`0006Oooo]Z1Ol0001moookJPCo00004?oonfX5o`0008Sooo]Z002MoookJPCo00004?oonfX5
o`0004Wooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001moookJPCo00004?oonfX6
o`0008Oooo]Z002MoookJPCo00004OoonfX9o`0004?ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`Wooo]Z1Ol0001moookJPCo00004?oonfX:o`0008?ooo]Z002MoookJPCo00004OoonfX:o`0004;o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oo
nf[o001oo`00Ool007l9oookJPGo0000OOoonfX4o`00017ooo]Z2_l00022oookJP00WOoonfX4o`00
017ooo]Z2_l0000eoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Sooo]Z1Ol0001moookJPCo00004_oonfX9o`0008;ooo]Z002MoookJPCo00004OoonfX:o`0003Go
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000O?oonfX4o`0001;o
oo]Z2Ol00022oookJP00WOoonfX4o`0001;ooo]Z2Ol00011oookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l8oookJPGo0000OOoonfX4o`0001?ooo]Z2Ol00021oookJP00WOoonfX4o`0001Oooo]Z1Ol0
0010oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0007gooo]Z1?l0
000GoookJPGo0000POoonfX009gooo]Z1?l0000GoookJPGo0000@?oonfX3o`00O`?ooo]Z0ol007l7
oookJPOo001o2OoonfX5o`0007gooo]Z1?l0000GoookJPGo0000POoonfX009gooo]Z1?l0000Goook
JPKo0000?ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0007gooo]Z1?l0000Hoook
JPCo0000POoonfX009gooo]Z1?l0000HoookJPGo0000?ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o3_oonfX5o`0007gooo]Z1?l0000HoookJPGo0000P?oonfX009gooo]Z1?l0000HoookJP[o0000
>ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000OOoonfX4o`0001So
oo]Z2Ol0001loookJP00WOoonfX4o`0001Wooo]Z2Ol0000koookJPOo001o2OoonfX7o`00O`Sooo]Z
1Ol0001moookJPCo00006?oonfX:o`0007_ooo]Z002MoookJPCo00006OoonfX9o`0003cooo]Z1Ol0
07l:oookJPOo001o2?oonfX5o`0007gooo]Z1?l0000IoookJP[o0000N_oonfX009gooo]Z1?l0000I
oookJP[o0000FOoonfX5o`0007gooo]Z1?l0000JoookJPWo0000N_oonfX009gooo]Z1?l0000Koook
JPSo0000FOoonfX5o`0007gooo]Z1?l0000JoookJPWo0000N_oonfX009gooo]Z1?l0000NoookJPKo
0000F?oonfX5o`0007gooo]Z1?l0000OoookJPGo0000NOoonfX009gooo]Z1?l0000OoookJPGo0000
F?oonfX5o`0007gooo]Z1?l0000OoookJPGo0000NOoonfX009gooo]Z1?l0000OoookJPKo0000Eooo
nfX5o`0007gooo]Z1?l0000OoookJPKo0000N?oonfX009gooo]Z1?l0000PoookJPWo0000DooonfX5
o`0007gooo]Z1?l0000PoookJP[o0000LooonfX009gooo]Z1?l0000PoookJP[o0000D_oonfX5o`00
07gooo]Z1?l0000PoookJP[o0000LooonfX009gooo]Z1?l0000QoookJP[o0000DOoonfX5o`0007go
oo]Z1?l0000QoookJP[o0000L_oonfX009gooo]Z1?l0000QoookJP[o0000DOoonfX5o`0007gooo]Z
1?l0000RoookJP[o0000LOoonfX009gooo]Z1?l0000VoookJPKo0000D?oonfX5o`0007gooo]Z1?l0
000VoookJPOo0000L?oonfX009gooo]Z1?l0000WoookJPGo0000D?oonfX5o`0007gooo]Z1?l0000W
oookJPOo0000KooonfX009gooo]Z1?l0000WoookJPKo0000CooonfX5o`0007gooo]Z1?l0000Xoook
JPWo0000K?oonfX002;ooo]Z0ol007meoookJP?o001o1?l00002oookJP?o001o0ooonfX5o`00Oa_o
oo]Z1ol0001=oookJPGo0000M?oonfX5o`00O`Cooo]Z1?l00002oookJPGo001o8_oonfX9o`0004_o
oo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z1?l007l4o`0000;ooo]Z0ol007l2oookJPOo001o
6_oonfX9o`0004_ooo]Z1Ol0001coookJPOo001o0ooonfX4o`000003oookJ_l007oo001o00Go001o
8_oonfX8o`0004_ooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l00ooonf[o0000o`00
0002o`0000;ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z
2Ol0001:oookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1?l00004o`00O`04
oookJ_l007oo001oo`00Ob?ooo]Z2?l0001:oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o
001oIooonfX:o`00O`;ooo]Z0ol007l2oookJPCo00001_oonfX3o`00O`?ooo]Z0ol007lKoookJP[o
0000B?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`0000?o001o0ooonfX3o`00ObCo
oo]Z1ol00019oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z
0ol007l2oookJPCo00003?oonfX3o`00Oagooo]Z2_l00016oookJPGo0000L_oonfX3o`00O`?ooo]Z
0ol007l00ooonf[o0000o`000003o`0000Kooo]Z0ol007lUoookJP[o0000AOoonfX3o`00Oagooo]Z
000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000?o00003?oonfX3o`00Oaoooo]Z2_l0
0014oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000003o`0000Kooo]Z0ol0
07lVoookJP[o0000A?oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o
000000?o00001ooonfX2o`00O`;ooo]Z1?l007lPoookJP_o0000@_oonfX5o`0007;ooo]Z0ol007l3
oookJP?o001o00?ooo]Zo`000?l000000ol000000ooonf[o001oo`00O`02oookJPCo001o9ooonfX:
o`0004?ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000003o`00
00Oooo]Z1ol007lSoookJP_o0000@?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`00
0?l000000_l00002oookJPOo001o:?oonfX:o`0004?ooo]Z0ol007lMoookJP008_oonfX3o`00Og?o
oo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z1_l007lVoookJP_o
0000?_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJPKo
001o:_oonfX:o`0004;ooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l00ooonf[o0000
o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l/oookJPco0000>ooonfX5o`0007;ooo]Z
0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP;o001o<ooonfX;o`0003Wooo]Z
1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z0_l007l^oookJP_o0000>_oo
nfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo00000_oonfX2o`00Oc?ooo]Z
3?l0000hoookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o1?l00009oookJPOo001o:_oo
nfX:o`0003Wooo]Z1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z1ol007l^oookJP_o0000>_oo
nfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00002OoonfX7o`00Obcooo]Z3_l0000c
oookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPOo001o;ooonfXAo`0003Cooo]Z0ol007lM
oookJP00W?oonfX4o`0003kooo]Z3?l0000coookJPGo0000O?oonfX4o`0003oooo]Z2ol0001Doook
JP00W?oonfX4o`00043ooo]Z2ol0000boookJPGo0000O?oonfX4o`0003oooo]Z3?l0001CoookJP00
W?oonfX4o`00047ooo]Z4Ol0000[oookJPGo0000O?oonfX4o`00043ooo]Z4_l0001<oookJP00W?oo
nfX4o`00047ooo]Z4_l0000ZoookJPGo0000O?oonfX4o`00047ooo]Z4_l0001;oookJP00W?oonfX4
o`0004Oooo]Z4ol0000SoookJPGo0000O?oonfX4o`0004Oooo]Z4ol00014oookJP00W?oonfX4o`00
04Sooo]Z6Ol0000LoookJPGo0000O?oonfX4o`0004Sooo]Z6_l0000loookJP003_oonf[oo`000?oo
00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0
000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oook
JP007?oonfX5o`0000;ooo]Z:_l000000ooonf[o0000o`000003o`0004Wooo]Z1?l0001_oookJPGo
00000_oonfX6o`000003oookJ_l0003o000000Go00002_oonfXWo`0004Wooo]Z1?l0001_oookJPGo
00000ooonfX5o`0000?ooo]Z00?o0000oookJ_oonfX07?oonfX003[ooo]Z6_l00018oookJPCo0000
OOoonfX5o`0001_ooo]Z6Ol00018oookJPCo0000W_oonfX004;ooo]Z4_l00018oookJPCo0000OOoo
nfX5o`0002;ooo]Z4_l00018oookJPCo0000W_oonfX004Cooo]Z1?l000000ooonf[o0000o`00000@
o`00047ooo]Z1?l0001moookJPGo00009?oonfX4o`000003oookJ_l0003o0000013o0000@OoonfX4
o`0009kooo]Z001:oookJQ;o0000@?oonfX4o`0007gooo]Z1Ol0000ZoookJQ;o0000@?oonfX4o`00
09kooo]Z001@oookJPgo0000?ooonfX4o`0007gooo]Z1Ol0000`oookJPco0000@?oonfX4o`0009ko
oo]Z001AoookJPco0000?ooonfX4o`0007gooo]Z1Ol0000aoookJPgo0000?_oonfX4o`0009kooo]Z
001CoookJQ3o0000>OoonfX4o`0007gooo]Z1Ol0000coookJQ3o0000>?oonfX5o`0009kooo]Z001H
oookJP_o0000>OoonfX4o`0007gooo]Z1Ol0000hoookJP_o0000>?oonfX5o`0009kooo]Z001Ioook
JP_o0000>?oonfX4o`0007gooo]Z1Ol0000ioookJP_o0000=ooonfX5o`0009kooo]Z001JoookJP_o
0000=ooonfX4o`0007gooo]Z1Ol0000joookJP_o0000=_oonfX4o`0009oooo]Z001OoookJP_o0000
<_oonfX4o`0007gooo]Z1Ol0000ooookJP_o0000<OoonfX4o`0009oooo]Z001PoookJP_o0000<Ooo
nfX4o`0007gooo]Z1Ol00010oookJP_o0000<?oonfX4o`0009oooo]Z001QoookJP[o0000<OoonfX4
o`0007gooo]Z1Ol00011oookJP_o0000;ooonfX4o`0009oooo]Z001QoookJP_o0000<?oonfX4o`00
07gooo]Z1Ol00011oookJP_o0000;ooonfX4o`0009oooo]Z001SoookJP[o0000;ooonfX4o`0007go
oo]Z1Ol00013oookJP[o0000;_oonfX4o`0009oooo]Z001WoookJP[o0000:ooonfX4o`0007gooo]Z
1Ol00018oookJPWo0000:_oonfX4o`0009oooo]Z001XoookJP[o0000:_oonfX4o`0007gooo]Z1Ol0
0018oookJP[o0000:OoonfX4o`0009oooo]Z001YoookJP[o0000:OoonfX4o`0007gooo]Z1Ol00019
oookJP[o0000:?oonfX4o`0009oooo]Z001YoookJP[o0000:?oonfX5o`0007gooo]Z1Ol00019oook
JP[o0000:?oonfX4o`0009oooo]Z001ZoookJP[o00009ooonfX5o`0007gooo]Z1Ol0001:oookJPWo
0000:?oonfX4o`0009oooo]Z001_oookJPGo00009ooonfX5o`0007gooo]Z1Ol0001?oookJPGo0000
9ooonfX4o`0009oooo]Z001_oookJPKo00009_oonfX4o`0007kooo]Z1Ol0001?oookJPKo00009_oo
nfX4o`0009oooo]Z001`oookJPWo00008_oonfX4o`0007kooo]Z1Ol0001?oookJP_o00008OoonfX4
o`0009oooo]Z001`oookJP[o00008OoonfX4o`0007kooo]Z1Ol0001@oookJP[o00008OoonfX4o`00
09oooo]Z001aoookJP[o00008?oonfX4o`0007kooo]Z1Ol0001AoookJPWo00008OoonfX4o`0009oo
oo]Z001aoookJP[o00008?oonfX4o`0007kooo]Z1Ol0001BoookJPWo00008?oonfX4o`0009oooo]Z
001foookJPKo00007ooonfX4o`0007kooo]Z1Ol0001FoookJPGo00008?oonfX4o`0009oooo]Z001g
oookJPGo00007ooonfX4o`0007kooo]Z1Ol0001FoookJPKo00007ooonfX4o`0009oooo]Z001goook
JPGo00007ooonfX4o`0007kooo]Z1Ol0001GoookJPGo00007ooonfX4o`0009oooo]Z001hoookJPSo
00006ooonfX4o`0007kooo]Z1Ol0001GoookJP[o00006_oonfX4o`0009oooo]Z001hoookJPWo0000
6_oonfX4o`0007kooo]Z1Ol0001HoookJP[o00006OoonfX4o`0009oooo]Z001hoookJP[o00006Ooo
nfX4o`0007kooo]Z1Ol0001HoookJP[o00006OoonfX4o`0009oooo]Z001ioookJPWo00006OoonfX4
o`0007kooo]Z1Ol0001IoookJPWo00006OoonfX4o`0009oooo]Z001joookJPWo00006?oonfX4o`00
07kooo]Z1Ol0001IoookJPWo00006OoonfX4o`0009oooo]Z001noookJPGo00006?oonfX4o`00063o
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001NoookJPGo00006?oonfX4o`0009oo
oo]Z001noookJPKo00005ooonfX4o`0005oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z
1Ol0001NoookJPGo00006?oonfX4o`0009oooo]Z001ooookJPGo00005ooonfX4o`0005oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007l9oookJPGo0000G_oonfX6o`0001Oooo]Z1?l0002OoookJP00OooonfX5o`0001Oooo]Z
1?l0001NoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0005oooo]Z
1Ol0000GoookJPCo0000WooonfX0083ooo]Z2Ol0000BoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o2?oonfX6o`0005kooo]Z2_l0000BoookJPCo0000WooonfX0083ooo]Z2Ol0000B
oookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`00063ooo]Z2Ol0000B
oookJPCo0000WooonfX0083ooo]Z2_l0000AoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001PoookJPWo00004_oonfX4o`0009oooo]Z0021oookJPWo
00004OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001PoookJP[o
00004OoonfX4o`0009oooo]Z0021oookJPWo00004OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00O`[ooo]Z1Ol0001QoookJPWo00004OoonfX4o`0009oooo]Z0026oookJPGo00004?oo
nfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001UoookJPKo00004?oo
nfX4o`0009oooo]Z0026oookJPGo00003ooonfX5o`0005oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJP;o001o3_oonfX5o`0006Kooo]Z1Ol0000@oookJPCo0000WooonfX008Kooo]Z1Ol0000?
oookJPGo0000GooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000I_oonfX5o`00013ooo]Z1?l0002O
oookJP00QooonfX4o`0000oooo]Z1Ol0001PoookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001Woook
JPCo00004?oonfX4o`0009oooo]Z0027oookJPGo00003_oonfX4o`0007oooo]Z1Ol0001WoookJPGo
00003ooonfX4o`0009oooo]Z0027oookJPWo00002_oonfX4o`0007oooo]Z1Ol0001WoookJPWo0000
2ooonfX4o`0009oooo]Z0027oookJP[o00002OoonfX4o`0007oooo]Z1Ol0001WoookJP[o00002_oo
nfX4o`0009oooo]Z0028oookJPWo00002OoonfX4o`0007oooo]Z1Ol0001XoookJPWo00002_oonfX4
o`0009oooo]Z0028oookJP[o00002?oonfX4o`0007oooo]Z1Ol0001XoookJPWo00002_oonfX4o`00
09oooo]Z0028oookJP[o00002?oonfX4o`0007oooo]Z1Ol0001XoookJP[o00002OoonfX4o`0009oo
oo]Z0029oookJPWo00002?oonfX4o`0007oooo]Z1Ol0001YoookJPWo00002OoonfX4o`0009oooo]Z
002>oookJPCo00002?oonfX4o`0007oooo]Z1Ol0001]oookJPGo00002?oonfX5o`0009oooo]Z002>
oookJPCo00002?oonfX4o`0007oooo]Z1Ol0001^oookJPCo00002?oonfX5o`0009oooo]Z002>oook
JPGo000000?ooo]Zo`000?l000000_l00002oookJPCo0000OooonfX5o`0006kooo]Z1?l00002oook
JPCo00000_oonfX5o`0009oooo]Z002>oookJPGo000000?ooo]Zo`000?l000000ol000000ooonf[o
0000o`000002o`0007oooo]Z1Ol0001^oookJPCo000000?ooo]Zo`000?l000001?l000000ooonf[o
0000o`000002o`000:3ooo]Z002>oookJP_o000000?ooo]Zo`000?l000000_l0001ooookJPGo0000
K_oonfX;o`000003oookJ_l0003o000000;o0000X?oonfX008oooo]Z2_l000000ooonf[o0000o`00
0002o`0007oooo]Z1Ol0001^oookJP_o000000?ooo]Zo`000?l000000_l0002PoookJP00SooonfX:
o`000003oookJ_l0003o000000;o0000OooonfX5o`0006kooo]Z2ol000000ooonf[o0000o`000002
o`000:3ooo]Z002?oookJP[o000000?ooo]Zo`000?l000000_l0001ooookJPGo0000KooonfX:o`00
0003oookJ_l0003o000000;o0000X?oonfX008oooo]Z2_l000000ooonf[o0000o`000002o`0007oo
oo]Z1Ol0001_oookJP[o000000?ooo]Zo`000?l000000_l0002PoookJP00SooonfX:o`000003oook
J_l0003o000000;o0000OooonfX5o`0006oooo]Z3ol0002PoookJP00T?oonfX>o`0007oooo]Z1Ol0
001`oookJPko0000X?oonfX0093ooo]Z3_l0001ooookJPGo0000L?oonfX>o`000:3ooo]Z002@oook
JPko0000OooonfX5o`00073ooo]Z3_l0002PoookJP00T?oonfX5o`000003oookJ_l0003o000000Ko
0000OooonfX5o`00073ooo]Z1Ol000000ooonf[o0000o`000006o`000:3ooo]Z002FoookJPSo0000
OooonfX5o`0007Kooo]Z2?l0002PoookJP00U_oonfX8o`0007oooo]Z1Ol0001foookJPSo0000X?oo
nfX009Kooo]Z2?l0001ooookJPGo0000M_oonfX8o`000:3ooo]Z002FoookJPSo0000OooonfX5o`00
07Kooo]Z2?l0002PoookJP00U_oonfX8o`0007oooo]Z1Ol0001foookJPSo0000X?oonfX009Kooo]Z
2?l0001ooookJPGo0000M_oonfX8o`000:3ooo]Z002GoookJPOo0000OooonfX5o`0007Kooo]Z2?l0
002PoookJP00UooonfX7o`0007oooo]Z1Ol0001goookJPKo0000XOoonfX009Oooo]Z1ol0001boook
JP?o001o2_oonfX5o`0007Oooo]Z1_l0002QoookJP00UooonfX7o`0007;ooo]Z0ol007l:oookJPGo
0000MooonfX6o`000:7ooo]Z002GoookJPOo0000L_oonfX3o`00O`[ooo]Z1Ol0001goookJPKo0000
XOoonfX009Oooo]Z1ol0001boookJP?o001o2_oonfX5o`0007Oooo]Z1_l0002QoookJP00UooonfX7
o`0007;ooo]Z0ol007l:oookJPKo0000M_oonfX6o`000:7ooo]Z002GoookJPOo0000L_oonfX3o`00
O`[ooo]Z1Ol0001goookJPKo0000XOoonfX009Oooo]Z1ol0001boookJP?o001o2_oonfX5o`0007Oo
oo]Z1_l0002QoookJP00UooonfX6o`0007?ooo]Z0ol007l:oookJPGo0000MooonfX6o`000:7ooo]Z
002GoookJPKo0000LooonfX3o`00O`[ooo]Z1Ol0001goookJPKo0000XOoonfX009Oooo]Z1_l0001`
oookJPKo001o2_oonfX5o`0007Oooo]Z1_l0002QoookJP00UooonfX6o`00073ooo]Z1_l007l:oook
JPGo0000MooonfX6o`000:7ooo]Z002HoookJPGo0000L_oonfX4o`00O`[ooo]Z1Ol0001hoookJPGo
0000XOoonfX009Sooo]Z1Ol0001coookJP?o001o2_oonfX5o`0007Sooo]Z1Ol0002QoookJP00V?oo
nfX4o`00087ooo]Z1Ol0001hoookJPGo0000XOoonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3
o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`00
0?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9
oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`00
0?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2_oo
nfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooook
JPkooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX6o`000?oo
oo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol0
07l9oookJPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/oookJP00oooonfX=oook
JP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRco
oo]Z003ooookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooonfX>oookJPOo001ooooo
nfX]oookJP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30829 L
.02605 .3078 L
.02729 .30759 L
.02846 .3078 L
.02954 .30829 L
.03053 .30891 L
.03162 .3096 L
.03279 .31018 L
.03396 .31045 L
.03506 .31034 L
.03636 .30981 L
.03756 .30908 L
.0388 .30832 L
.0395 .30797 L
.04015 .30775 L
.04135 .30766 L
.04262 .308 L
.04327 .30833 L
.04396 .30875 L
.04519 .30957 L
.04583 .30995 L
.04652 .31029 L
.04727 .31054 L
.04797 .31062 L
.04862 .31057 L
.04933 .31038 L
.05061 .30975 L
.05175 .30904 L
.05302 .30833 L
.05424 .30794 L
.05539 .30796 L
.0566 .3084 L
.05791 .30921 L
.05907 .31001 L
.06028 .31072 L
.06131 .31106 L
.06244 .31108 L
.06315 .3109 L
.06381 .31063 L
.06529 .30978 L
.06657 .30905 L
.06729 .30875 L
.06797 .30859 L
.06915 .30863 L
.07041 .30913 L
.07111 .30957 L
.07176 .31005 L
.073 .31097 L
.0737 .31143 L
Mistroke
.07435 .31178 L
.07511 .31204 L
.0758 .31213 L
.07704 .31193 L
.07775 .31164 L
.07839 .3113 L
.07987 .31045 L
.0806 .3101 L
.08125 .30988 L
.08195 .30977 L
.08269 .30982 L
.0835 .31008 L
.08427 .3105 L
.08673 .31244 L
.08797 .3133 L
.08867 .31363 L
.08933 .31381 L
.09051 .31378 L
.09158 .31342 L
.09276 .3128 L
.09401 .31215 L
.09527 .31175 L
.09598 .31173 L
.09663 .31185 L
.09788 .31248 L
.09906 .31342 L
.10035 .31462 L
.10105 .31523 L
.10171 .31572 L
.10242 .31613 L
.1032 .31639 L
.10387 .31645 L
.10458 .31637 L
.10579 .31593 L
.10714 .31524 L
.10781 .31493 L
.10854 .31469 L
.10985 .31463 L
.11109 .31512 L
.1124 .31615 L
.11474 .31854 L
.11606 .3196 L
.1168 .31996 L
.11747 .32012 L
.11878 .32001 L
.12002 .31952 L
.12136 .31889 L
.12204 .31866 L
.12279 .31853 L
.1236 .3186 L
Mistroke
.12435 .31889 L
.12505 .31934 L
.12579 .32 L
.12837 .32297 L
.12908 .32371 L
.12983 .32436 L
.13054 .32479 L
.13118 .32503 L
.13245 .32505 L
.13316 .32485 L
.13382 .32459 L
.1351 .32403 L
.1363 .32373 L
.13738 .32385 L
.13853 .3245 L
.13981 .32579 L
.14097 .32731 L
.14219 .32896 L
.14351 .33045 L
.14476 .3313 L
.14591 .33153 L
.14709 .3313 L
.14833 .33081 L
.14939 .33044 L
.15055 .33037 L
.1518 .3309 L
.1525 .3315 L
.15314 .33222 L
.15555 .33583 L
.15663 .33742 L
.15778 .33871 L
.15904 .33948 L
.1602 .33958 L
.16128 .33929 L
.16229 .3389 L
.1634 .33858 L
.16459 .33868 L
.16525 .33902 L
.16596 .33962 L
.16723 .34129 L
.16872 .34388 L
.17011 .34637 L
.17076 .34738 L
.17144 .34825 L
.17218 .34896 L
.17287 .34936 L
.17406 .34951 L
.17536 .34914 L
.17662 .34866 L
.17782 .34854 L
Mistroke
.17848 .34874 L
.1792 .34923 L
.18045 .35079 L
.18165 .35298 L
.18292 .35568 L
.1841 .3581 L
.18519 .3599 L
.1864 .36113 L
.18771 .36151 L
.18887 .3612 L
.19011 .36065 L
.19132 .36037 L
.19246 .36076 L
.19349 .36183 L
.1946 .36376 L
.19716 .37 L
.19784 .37162 L
.19856 .37314 L
.19987 .37505 L
.20108 .37575 L
.20218 .37559 L
.20349 .37487 L
.20472 .37428 L
.20577 .37434 L
.20693 .37534 L
.20814 .37756 L
.20927 .38058 L
.21132 .38686 L
.21244 .38977 L
.21348 .39165 L
.21463 .39258 L
.21588 .39235 L
.21694 .39149 L
.21807 .39049 L
.21871 .39012 L
.2194 .39005 L
.22066 .3911 L
.22189 .39377 L
.22302 .3975 L
.22416 .40197 L
.22541 .40676 L
.22659 .41032 L
.22769 .41224 L
.22896 .41254 L
.22967 .41193 L
.23031 .41103 L
.23156 .40894 L
.23271 .4075 L
.2338 .40744 L
.23495 .40934 L
Mistroke
.23611 .4134 L
.23738 .41979 L
.23846 .42589 L
.23963 .43192 L
.24075 .43592 L
.24177 .43745 L
.24308 .43612 L
.24374 .43425 L
.24447 .43157 L
.24575 .42647 L
.24693 .42321 L
.2476 .42268 L
.2483 .42356 L
.24901 .42609 L
.24978 .43079 L
.25045 .43639 L
.25116 .44361 L
.25245 .45819 L
.25374 .47132 L
.25447 .47626 L
.25514 .47832 L
.25637 .47391 L
.25767 .4555 L
.25884 .42647 L
.25993 .38986 L
.26241 .2875 L
.26366 .23637 L
.265 .19076 L
.26614 .16252 L
.2674 .14449 L
.2681 .14031 L
.26875 .13981 L
.26946 .14238 L
.2702 .14786 L
.27146 .16098 L
.27284 .17644 L
.27413 .18797 L
.27531 .19394 L
.27596 .19522 L
.27667 .19512 L
.27796 .19192 L
.27905 .18762 L
.28023 .18328 L
.28152 .18069 L
.28273 .18136 L
.28398 .18526 L
.28517 .19115 L
.28741 .2033 L
.28864 .20808 L
.28978 .21039 L
Mistroke
.29103 .21058 L
.29174 .20986 L
.29237 .20891 L
.29344 .2071 L
.29457 .20567 L
.29581 .20554 L
.29695 .20712 L
.29802 .21 L
.29901 .21357 L
.30127 .22224 L
.30253 .2258 L
.30317 .22697 L
.30387 .22774 L
.30512 .22791 L
.30628 .2271 L
.30756 .22595 L
.3082 .22555 L
.3089 .2254 L
.30967 .2257 L
.31038 .22645 L
.31103 .22755 L
.31173 .22911 L
.3144 .23704 L
.31571 .24055 L
.31692 .24274 L
.31802 .24368 L
.31918 .24373 L
.32035 .24315 L
.32163 .24244 L
.32287 .24231 L
.32405 .24309 L
.3251 .24463 L
.32625 .24707 L
.32866 .25307 L
.32935 .25456 L
.33 .25573 L
.33122 .25718 L
.33239 .25766 L
.33346 .25748 L
.33463 .25697 L
.33587 .25655 L
.33694 .25666 L
.33793 .25733 L
.33902 .25873 L
.34019 .26087 L
.34276 .26622 L
.34406 .26822 L
.3448 .26896 L
.34549 .26937 L
.34672 .26949 L
Mistroke
.34785 .26914 L
.34908 .26867 L
.35039 .26853 L
.35113 .26876 L
.3518 .26921 L
.35311 .27074 L
.35384 .2719 L
.35463 .27331 L
.35607 .27592 L
.35744 .27796 L
.35813 .27868 L
.35889 .27921 L
.35953 .27943 L
.36022 .27947 L
.36147 .27916 L
.36273 .27867 L
.36336 .27849 L
.36406 .27843 L
.36482 .27857 L
.36553 .27893 L
.36618 .27946 L
.36688 .28023 L
.36937 .28396 L
.37003 .28495 L
.37074 .28589 L
.372 .28713 L
.37326 .28766 L
.3744 .2876 L
.37504 .2874 L
.37574 .28712 L
.37701 .28664 L
.37817 .28651 L
.3794 .28691 L
.38045 .28773 L
.38161 .28906 L
.3841 .29236 L
.38478 .2931 L
.38551 .29371 L
.38681 .29427 L
.38746 .2943 L
.38815 .29418 L
.38941 .29371 L
.39062 .29319 L
.39176 .29294 L
.39288 .29308 L
.39411 .29378 L
.39531 .29492 L
.39659 .29643 L
.39779 .2978 L
.39892 .29881 L
Mistroke
.39993 .29935 L
.40104 .2995 L
.42192 .3022 L
.43127 .30511 L
.4325 .3045 L
.43381 .30419 L
.43505 .30437 L
.43617 .30493 L
.43744 .30589 L
.43864 .30688 L
.43993 .30777 L
.44066 .30809 L
.44133 .30824 L
.44202 .30825 L
.44266 .30813 L
.44337 .30787 L
.44413 .30748 L
.44565 .30661 L
.4464 .30624 L
.44709 .30601 L
.44841 .30594 L
.44911 .30611 L
.44985 .30645 L
.45053 .30687 L
.45118 .30733 L
.45237 .30823 L
.45364 .30903 L
.45427 .3093 L
.45497 .30946 L
.45621 .30937 L
.45736 .30893 L
.45861 .3082 L
.45993 .30744 L
.46063 .30714 L
.46139 .30695 L
.46208 .30692 L
.46273 .30703 L
.46402 .30757 L
.4652 .30833 L
.46646 .3092 L
.46713 .3096 L
.46784 .30991 L
.46913 .31013 L
.47032 .3099 L
.47155 .3093 L
.47267 .3086 L
.47376 .30797 L
.47491 .30752 L
.47617 .30744 L
.47733 .30776 L
Mistroke
.47841 .30834 L
.47942 .309 L
.48061 .30974 L
.48172 .31023 L
.48298 .31039 L
.48364 .31028 L
.48435 .31004 L
.48554 .30941 L
.48684 .30858 L
.488 .30795 L
.48926 .3076 L
.49044 .30767 L
.49152 .30807 L
.4928 .30882 L
.49417 .30968 L
.49546 .31027 L
.49664 .31044 L
.49727 .31036 L
.49796 .31016 L
.49921 .30952 L
.50068 .30858 L
.50133 .30821 L
.50203 .30788 L
.50324 .3076 L
.50438 .30772 L
.5057 .30828 L
.50692 .30903 L
.50806 .30974 L
.50913 .31024 L
.51037 .31046 L
.51149 .31027 L
.51276 .30969 L
.5141 .30886 L
.51526 .30818 L
.51649 .30772 L
.51719 .30764 L
.51783 .3077 L
.51907 .30813 L
.51977 .30851 L
.52053 .309 L
.52119 .30944 L
.5219 .30989 L
.5232 .31047 L
.52442 .31062 L
.52513 .3105 L
.52588 .31024 L
.52651 .30992 L
.52721 .30951 L
.52862 .30864 L
.52941 .30824 L
Mistroke
.53012 .308 L
.53079 .30791 L
.53152 .30795 L
.53284 .30842 L
.53405 .30918 L
.53539 .3101 L
.53607 .31051 L
.53679 .31086 L
.5381 .31112 L
.5394 .31088 L
.54063 .31029 L
.54184 .30956 L
.54294 .30896 L
.54408 .3086 L
.5453 .30862 L
.54638 .30901 L
.54752 .30973 L
.54879 .31068 L
.54948 .31118 L
.55014 .31158 L
.55142 .31207 L
.55258 .31209 L
.5538 .3117 L
.55492 .3111 L
.55624 .31036 L
.55747 .30987 L
.55871 .3098 L
.55936 .30995 L
.56007 .31027 L
.56081 .31073 L
.56151 .31127 L
.56282 .31236 L
.56396 .31318 L
.56503 .31369 L
.56627 .31384 L
.56739 .31357 L
.56845 .31308 L
.56943 .31254 L
.5705 .31202 L
.57163 .31173 L
.57277 .31184 L
.574 .31243 L
.57515 .31334 L
.57621 .31431 L
.57745 .31539 L
.57814 .31588 L
.57879 .3162 L
.57998 .31645 L
.58123 .31623 L
.58237 .31573 L
Mistroke
.58362 .3151 L
.58492 .31464 L
.58613 .31464 L
.58726 .31511 L
.5883 .31588 L
.59061 .31823 L
.59191 .31937 L
.59311 .32 L
.59442 .32012 L
.59508 .31997 L
.59581 .3197 L
.59703 .31912 L
.59835 .31863 L
.59959 .31856 L
.60072 .31899 L
.60185 .31987 L
.60305 .32117 L
.60409 .32242 L
.60521 .32365 L
.6059 .32426 L
.60653 .32469 L
.60777 .32509 L
.60891 .32499 L
.6101 .32455 L
.61116 .32408 L
.6123 .32376 L
.61337 .3238 L
.61435 .32423 L
.61549 .32521 L
.61674 .32673 L
.619 .32972 L
.62022 .33088 L
.62135 .33144 L
.62264 .33147 L
.62387 .33108 L
.62492 .33065 L
.62605 .33036 L
.62729 .33052 L
.62843 .33126 L
.63882 .33877 L
.65985 .35724 L
.66109 .35948 L
.66227 .36089 L
.66292 .36132 L
.66363 .3615 L
.66487 .36128 L
.66605 .36075 L
.6673 .36038 L
.66837 .36059 L
.66956 .36166 L
Mistroke
.67077 .36371 L
.67208 .36675 L
.67321 .36964 L
.67444 .37252 L
.6751 .37376 L
.67581 .37478 L
.67655 .37546 L
.67724 .37575 L
.67794 .37573 L
.67859 .37549 L
.67981 .37479 L
.68046 .37444 L
.68118 .37424 L
.68192 .37432 L
.68262 .37478 L
.68387 .37658 L
.68457 .37814 L
.68521 .37985 L
.68656 .38397 L
.68801 .38824 L
.68884 .39022 L
.68959 .39154 L
.69035 .39235 L
.69106 .39263 L
.69171 .39252 L
.69239 .39212 L
.69361 .39103 L
.69493 .39011 L
.69568 .39007 L
.69637 .3905 L
.69765 .39265 L
.69881 .39606 L
.70005 .40074 L
.70142 .40608 L
.7027 .41011 L
.7039 .41226 L
.70517 .41253 L
.70588 .4119 L
.70654 .41097 L
.70774 .40896 L
.70885 .40754 L
.71001 .40745 L
.71127 .4097 L
.71417 .42316 L
.71558 .4308 L
.71689 .4358 L
.71808 .43748 L
.71934 .43596 L
.7206 .4318 L
.72131 .42892 L
Mistroke
.72199 .4263 L
.72322 .42305 L
.72434 .42324 L
.72555 .42797 L
.72686 .4385 L
.72902 .46243 L
.73025 .47381 L
.73141 .47837 L
.73263 .47331 L
.73394 .4539 L
.73462 .43784 L
.73534 .41675 L
.73663 .37022 L
.73895 .27278 L
.74017 .22459 L
.74146 .18298 L
.7421 .16736 L
.7428 .15421 L
.74403 .14142 L
.74528 .14067 L
.74645 .14837 L
.74759 .1603 L
.74863 .17221 L
.74977 .18363 L
.75099 .19191 L
.75228 .19531 L
.75348 .19397 L
.75422 .19167 L
.75491 .18897 L
.75621 .18396 L
.75745 .18096 L
.75859 .18087 L
.75984 .18397 L
.76048 .18662 L
.76117 .1901 L
.7623 .19641 L
.76352 .20293 L
.76468 .20762 L
.76575 .21011 L
.767 .2107 L
.76763 .21023 L
.76832 .20929 L
.76954 .20724 L
.77066 .20576 L
.77173 .20541 L
.77286 .20657 L
.77399 .20932 L
.77523 .21368 L
.77632 .21798 L
.77747 .22225 L
Mistroke
.77845 .22514 L
.77952 .22719 L
.78083 .228 L
.78206 .22745 L
.78275 .22684 L
.78339 .22625 L
.78412 .22569 L
.78481 .22542 L
.78605 .22586 L
.7872 .2275 L
.78846 .23055 L
.7898 .23461 L
.79101 .23828 L
.79232 .24145 L
.79356 .24325 L
.7947 .24381 L
.79573 .24359 L
.79686 .24295 L
.79804 .24237 L
.79914 .24233 L
.80044 .24333 L
.80118 .24443 L
.80186 .24575 L
.80443 .25208 L
.80564 .25476 L
.80677 .25655 L
.80795 .25751 L
.80926 .2576 L
.80989 .25739 L
.81058 .25708 L
.81126 .25678 L
.81198 .25657 L
.81327 .25672 L
.81447 .2577 L
.8152 .25871 L
.81599 .26009 L
.81742 .26307 L
.81881 .26596 L
.82009 .26802 L
.8213 .26918 L
.82245 .26952 L
.82367 .26928 L
.82436 .26901 L
.82499 .26876 L
.82605 .26851 L
.82722 .26871 L
.82843 .26964 L
.82958 .27116 L
.83202 .2755 L
.83267 .27658 L
Mistroke
.83335 .2776 L
.83459 .27891 L
.8353 .27931 L
.83594 .27947 L
.8367 .27944 L
.83742 .27925 L
.83865 .27877 L
.83935 .27854 L
.84 .27843 L
.84123 .27866 L
.84256 .27964 L
.84328 .2805 L
.84397 .28146 L
.84526 .28348 L
.84638 .28517 L
.84758 .28661 L
.84889 .28751 L
.8501 .28768 L
.85085 .28753 L
.85153 .28729 L
.85226 .28698 L
.85307 .28669 L
.85377 .28653 L
.85442 .28652 L
.85511 .28668 L
.85585 .28707 L
.85652 .28762 L
.85725 .28839 L
.85858 .2901 L
.85987 .29185 L
.86106 .29318 L
.8622 .29401 L
.8634 .29431 L
.8646 .29411 L
.86592 .29356 L
.86706 .29311 L
.86828 .29293 L
.86943 .29322 L
.87047 .29391 L
.87112 .29452 L
.87181 .29527 L
.87304 .29673 L
.87373 .29753 L
.87447 .29828 L
.87517 .29885 L
.87581 .29922 L
.87705 .29951 L
.87821 .2993 L
.87948 .29876 L
.88019 .29841 L
Mistroke
.88085 .29814 L
.88154 .29795 L
.88228 .29789 L
.88294 .29799 L
.88363 .29826 L
.88482 .29909 L
.88614 .30038 L
.88754 .30183 L
.88832 .30251 L
.88905 .303 L
.88973 .3033 L
.89047 .30345 L
.89176 .30326 L
.89297 .30274 L
.89431 .30206 L
.89498 .30179 L
.89571 .30161 L
.89701 .3017 L
.89831 .30233 L
.89955 .30332 L
.90076 .30444 L
.90187 .30538 L
.90311 .30609 L
.90376 .30627 L
.90445 .30631 L
.90562 .30604 L
.90689 .30542 L
.90803 .3048 L
.90925 .30431 L
.9104 .3042 L
.91145 .30445 L
.92166 .3067 L
.9228 .30616 L
.92386 .30592 L
.92496 .30601 L
.92619 .30653 L
.92742 .30737 L
.92874 .30836 L
.92997 .3091 L
.93111 .30945 L
.93218 .30942 L
.93319 .3091 L
.93429 .30851 L
.93546 .3078 L
.9367 .30719 L
.93787 .30692 L
.93891 .30702 L
.94005 .30748 L
.94114 .30816 L
.94213 .30886 L
Mistroke
.9432 .30953 L
.94437 .31002 L
.94544 .31012 L
.94644 .30992 L
.94739 .3095 L
.94841 .30889 L
.9496 .30816 L
.95089 .30758 L
.95211 .30742 L
.95323 .30764 L
.95425 .30812 L
.95536 .30883 L
.95643 .30953 L
.9576 .31012 L
.95885 .31039 L
.96003 .31023 L
.96118 .30973 L
.96225 .30908 L
.96349 .30831 L
.96466 .30777 L
.96588 .30758 L
.96652 .30765 L
.96722 .30785 L
.96831 .3084 L
.9695 .30915 L
.97066 .30985 L
.9719 .31034 L
.97307 .31043 L
.97412 .31017 L
.97519 .30964 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
X?oonfX4o`0007Wooo]Z1Ol0003ooookJQoooo]Z002OoookJPGo0000NOoonfX5o`0007oooo]Z1Ol0
002JoookJP00WooonfX5o`0007Wooo]Z1Ol0001ooookJPGo0000V_oonfX009oooo]Z1Ol0001ioook
JPGo0000OooonfX5o`0009[ooo]Z002OoookJPGo0000NOoonfX5o`0007oooo]Z1_l0002IoookJP00
WooonfX5o`0006cooo]Z0ol007l:oookJPGo0000OooonfX6o`0009Wooo]Z002OoookJPGo0000K?oo
nfX3o`00O`[ooo]Z1Ol0001ooookJPKo0000VOoonfX009oooo]Z1Ol0001/oookJP?o001o2_oonfX5
o`0007oooo]Z1_l0002IoookJP00WooonfX5o`0005cooo]Z2_l007l6oookJP?o001o2_oonfX5o`00
07oooo]Z1_l0002IoookJP00W_oonfX7o`0005_ooo]Z2_l007l6oookJP?o001o2_oonfX6o`0007ko
oo]Z1_l0002IoookJP00W_oonfX7o`0006_ooo]Z0ol007l:oookJPGo0000OooonfX6o`0009Wooo]Z
002NoookJPOo0000JooonfX3o`00O`[ooo]Z1Ol0001ooookJPKo0000VOoonfX009kooo]Z1ol0001[
oookJP?o001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX7o`0006_ooo]Z0ol007l:oook
JPGo0000O_oonfX7o`0009Wooo]Z002NoookJPOo0000J?oonfX6o`00O`[ooo]Z1Ol0001noookJPOo
0000VOoonfX009kooo]Z1ol0001XoookJPKo001o2_oonfX5o`0007kooo]Z2?l0002HoookJP00W_oo
nfX7o`0006[ooo]Z1?l007l:oookJPGo0000O_oonfX8o`0009Sooo]Z002NoookJPSo0000J_oonfX3
o`00O`[ooo]Z1Ol0001noookJPSo0000V?oonfX009kooo]Z2?l0001goookJPGo0000O_oonfX8o`00
09Sooo]Z002NoookJPSo0000MooonfX5o`0007kooo]Z2?l0002HoookJP00W_oonfX8o`0007Oooo]Z
1Ol0001noookJPSo0000V?oonfX009kooo]Z2?l0001goookJPGo0000O_oonfX8o`0009Sooo]Z002N
oookJPSo000000?ooo]Zo`000?l000000_l0001boookJPGo0000O_oonfX8o`0009Sooo]Z002Noook
JPSo000000?ooo]Zo`000?l000000_l0001boookJPGo0000O_oonfX8o`000003oookJ_l0003o0000
00;o0000TooonfX009kooo]Z3Ol0001boookJPGo0000O_oonfX>o`0009;ooo]Z002NoookJPko0000
LOoonfX5o`0007kooo]Z3_l0002BoookJP00W_oonfX>o`00077ooo]Z1Ol0001noookJPko0000T_oo
nfX009kooo]Z1?l000000ooonf[o0000o`000008o`00073ooo]Z1Ol0001noookJPko0000T_oonfX0
09kooo]Z1?l000000ooonf[o0000o`000008o`00073ooo]Z1Ol0001noookJPoo0000TOoonfX009ko
oo]Z1?l000000ooonf[o0000o`000008o`00073ooo]Z1Ol0001noookJPoo0000TOoonfX009kooo]Z
1?l000000ooonf[o0000o`000008o`00073ooo]Z1Ol0001noookJPCo000000?ooo]Zo`000?l00000
2?l0002AoookJP00W_oonfX4o`000003oookJ_l0003o000000So0000L?oonfX5o`0007kooo]Z1?l0
00000ooonf[o0000o`000008o`00097ooo]Z002NoookJPCo000000?ooo]Zo`000?l000002Ol0001_
oookJPGo0000O_oonfX4o`000003oookJ_l0003o000000So0000TOoonfX009kooo]Z1?l000000ooo
nf[o0000o`000003o`000003oookJ_l0003o000000?o0000KooonfX5o`0007kooo]Z1?l00002oook
JPCo000000?ooo]Zo`000?l000000_l0002AoookJP00W_oonfX4o`0000Oooo]Z1Ol0001_oookJPGo
0000O_oonfX4o`0000Oooo]Z1Ol0002@oookJP00W_oonfX4o`0000Sooo]Z1?l0001_oookJPGo0000
O_oonfX4o`0000Oooo]Z1Ol0002@oookJP00W_oonfX4o`0000Sooo]Z2?l0001[oookJPGo0000OOoo
nfX5o`0000Oooo]Z2Ol0002<oookJP00W_oonfX4o`0000Sooo]Z2Ol0001ZoookJPGo0000OOoonfX5
o`0000Sooo]Z2Ol0002;oookJP00W_oonfX4o`0000Sooo]Z2_l0001YoookJPGo0000OOoonfX5o`00
00Sooo]Z2Ol0002;oookJP00W_oonfX4o`0000Sooo]Z2_l0001YoookJPGo0000OOoonfX4o`0000Wo
oo]Z2Ol0002;oookJP00W_oonfX4o`0000Sooo]Z2_l0001YoookJPGo0000OOoonfX4o`0000Wooo]Z
2_l0002:oookJP00WOoonfX5o`0000Sooo]Z2_l0001YoookJPGo0000OOoonfX4o`0000[ooo]Z2Ol0
002:oookJP00WOoonfX5o`0000Wooo]Z2Ol0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2Ol00029
oookJP00WOoonfX5o`0000kooo]Z1Ol0001XoookJPGo0000OOoonfX4o`0000oooo]Z1Ol00029oook
JP00WOoonfX4o`0000oooo]Z1Ol0001XoookJPGo0000OOoonfX4o`0000oooo]Z1Ol00029oookJP00
WOoonfX4o`0000oooo]Z1Ol0001XoookJPGo0000OOoonfX4o`00013ooo]Z1?l00029oookJP00WOoo
nfX4o`00013ooo]Z1?l0001XoookJPGo0000OOoonfX4o`00013ooo]Z1?l00029oookJP00WOoonfX4
o`00013ooo]Z2Ol00015oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000OOoonfX4
o`00013ooo]Z2Ol00024oookJP00WOoonfX4o`00013ooo]Z2_l00013oookJPOo001o0ooonfX3o`00
O`;ooo]Z1ol007l9oookJPGo0000OOoonfX4o`00013ooo]Z2_l00023oookJP00WOoonfX4o`00013o
oo]Z2_l00013oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000@oookJP[o0000PooonfX0
09gooo]Z1?l0000AoookJPWo0000=_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l8oookJPGo0000OOoonfX4o`00017ooo]Z2Ol00023oookJP00WOoonfX4o`00017o
oo]Z2Ol0000foookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007co
oo]Z1?l0000AoookJPWo0000PooonfX009gooo]Z1?l0000FoookJPGo0000@OoonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o2?oonfX5o`0007gooo]Z1?l0000FoookJPGo0000P_oonfX009gooo]Z1?l0
000FoookJPGo0000@OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0
001moookJPCo00005_oonfX5o`0008;ooo]Z002MoookJPCo00005_oonfX5o`00047ooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001moookJPCo00005_oonfX6o`00087ooo]Z002Moook
JPCo00005ooonfX5o`00043ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001moook
JPCo00005ooonfX5o`00087ooo]Z002MoookJPCo00005ooonfX:o`0003_ooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`kooo]Z1Ol0001moookJPCo00005ooonfX:o`0007cooo]Z002MoookJPCo0000
5ooonfX:o`0003cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007go
oo]Z1?l0000HoookJPWo0000O?oonfX009gooo]Z1?l0000HoookJP[o0000>ooonfX7o`00O`Wooo]Z
1ol007l8oookJPGo0000OOoonfX4o`0001Sooo]Z2_l0001koookJP00WOoonfX4o`0001Wooo]Z2Ol0
000loookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001moookJPCo00006OoonfX9o`0007_ooo]Z002M
oookJPCo00006OoonfX9o`0005[ooo]Z1Ol0001loookJPGo00006_oonfX9o`0007[ooo]Z002Moook
JPCo00007_oonfX5o`0005Wooo]Z1Ol0001loookJPGo00007_oonfX5o`0007[ooo]Z002MoookJPCo
00007_oonfX5o`0005Wooo]Z1Ol0001loookJPGo00007_oonfX5o`0007[ooo]Z002MoookJPCo0000
7_oonfX6o`0005Sooo]Z1Ol0001loookJPCo00008?oonfX5o`0007Wooo]Z002MoookJPCo00007ooo
nfX9o`0005Cooo]Z1Ol0001loookJPCo00008?oonfX9o`0007Gooo]Z002MoookJPCo00007ooonfX:
o`0005?ooo]Z1Ol0001loookJPCo00008?oonfX:o`0007Cooo]Z002MoookJPCo00008?oonfX9o`00
05?ooo]Z1Ol0001loookJPCo00008OoonfX9o`0007Cooo]Z002LoookJPGo00008OoonfX8o`0005?o
oo]Z1Ol0001loookJPCo00008OoonfX:o`0007?ooo]Z002LoookJPGo00009OoonfX5o`0005;ooo]Z
1Ol0001loookJPCo00009_oonfX5o`0007?ooo]Z002LoookJPGo00009OoonfX6o`00057ooo]Z1Ol0
001loookJPCo00009_oonfX6o`0007;ooo]Z002LoookJPCo00009_oonfX;o`0004cooo]Z1Ol0001l
oookJPCo00009ooonfX9o`0006kooo]Z002LoookJPCo00009ooonfX:o`0004cooo]Z1Ol0001loook
JPCo00009ooonfX:o`0006gooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00000ooonfX3o`00O`?o
oo]Z1Ol007lJoookJP[o0000BooonfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX5o`00Ob3o
oo]Z2_l0001<oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o1?l00003oookJP?o001o
0_oonfX7o`00OaWooo]Z2_l0001;oookJPGo0000LooonfX7o`00O`;ooo]Z1?l00002oookJPOo001o
7ooonfX:o`0004cooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Oa[ooo]Z2_l0001:oookJPGo0000
LooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00Ob7ooo]Z2Ol0001;oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o
001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Co
oo]Z0ol007l3oookJP?o001o7_oonfX9o`0004Kooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03
oookJ_l0003o000000;o000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00ObCooo]Z2Ol00017oook
JP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o
0000o`000002o`000003o`00Oooonf[ooo]Z00[ooo]Z0ol007lNoookJP_o0000A?oonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00007oookJP?o001o9?oonfX;o`0004Go
oo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00
Oooonf[ooo]Z00[ooo]Z0ol007lOoookJP[o0000A?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o
00?ooo]Zo`000?l000000_l00007oookJP?o001o9OoonfX:o`0004Gooo]Z0ol007lMoookJP008_oo
nfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l0
07l2oookJPCo001o8?oonfX:o`0004?ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0
003o000000;o00000_oonfX2o`00O`;ooo]Z1?l007lVoookJP[o0000A?oonfX3o`00Oagooo]Z000R
oookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX7
o`00Ob7ooo]Z2ol00012oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002
o`0000;ooo]Z1ol007lWoookJP_o0000@ooonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00
O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX6o`00ObOooo]Z2ol0000moook
JPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1_l007l]oook
JP_o0000?_oonfX3o`00Oagooo]Z000OoookJPKo001oLooonfX3o`00O`03oookJ_l0003o000000;o
000000?o001ooookJ_oonfX01OoonfX2o`00Obcooo]Z2ol0000loookJPGo0000L_oonfX3o`00O`?o
oo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l007lboookJP_o0000>_oonfX6o`00Oago
oo]Z000OoookJPKo001oM?oonfX3o`00O`Co00002?oonfX2o`00Obgooo]Z2_l0000loookJPGo0000
LooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l00002oookJP;o001o<ooonfX:o`0003[o
oo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol007lXoookJPoo0000
=_oonfX5o`0007?ooo]Z1ol007l2oookJPCo00000ooonfX7o`00Obgooo]Z4?l0000foookJPCo001o
7OoonfX002;ooo]Z0ol007meoookJP;o001o1?l00009oookJPOo001o;OoonfX;o`0003Gooo]Z1Ol0
001doookJPGo001o0ooonfX4o`0000?ooo]Z1ol007lcoookJP_o0000=_oonfX3o`00Oagooo]Z002L
oookJPCo0000?OoonfX<o`0003Cooo]Z1Ol0001loookJPCo0000?OoonfX<o`0005Gooo]Z002Loook
JPCo0000?_oonfX<o`0003?ooo]Z1Ol0001loookJPCo0000?_oonfXAo`0004oooo]Z002LoookJPCo
0000?ooonfXBo`0002cooo]Z1Ol0001loookJPCo0000?ooonfXAo`0004kooo]Z002LoookJPCo0000
AOoonfXCo`0002Gooo]Z1Ol0001loookJPCo0000AOoonfXBo`0004Oooo]Z002LoookJPCo0000A_oo
nfXGo`00023ooo]Z1Ol0001loookJPCo0000A_oonfXBo`000003oookJ_l0003o000000;o0000@Ooo
nfX009cooo]Z1?l00017oookJQSo000000?ooo]Zo`000?l000000ol0000HoookJPGo0000O?oonfX4
o`0004Kooo]Z7ol0000ioookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo
00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0
000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP007OoonfX00ol0003ooo]ZoookJP05o`00
00;ooo]Z1_l000000ooonf[o0000o`00000Oo`0004gooo]Z1?l0001/oookJPGo00000_oonfX6o`00
00;ooo]Z3?l00002oookJPKo000000?ooo]Zo`000?l000007ol0001=oookJPCo0000K?oonfX5o`00
00;ooo]Z1Ol00003oookJPGo00007_oonfX003Kooo]Z1_l000000ooonf[o0000o`00000Fo`0004Oo
oo]Z1?l0001moookJPGo00005ooonfX4o`0000;ooo]Z6Ol00016oookJPCo0000W_oonfX003kooo]Z
1Ol000000ooonf[o0000o`00000@o`0004Kooo]Z1?l0001moookJPGo00007_oonfX5o`000003oook
J_l0003o0000013o0000A_oonfX4o`0009kooo]Z0015oookJQ;o0000AOoonfX4o`0007gooo]Z1Ol0
000UoookJQ;o0000A?oonfX5o`0009kooo]Z001<oookJQ7o0000?ooonfX4o`0007gooo]Z1Ol0000/
oookJQ7o0000?_oonfX5o`0009kooo]Z001=oookJQ7o0000?_oonfX4o`0007gooo]Z1Ol0000]oook
JQ7o0000?OoonfX5o`0009kooo]Z001CoookJP_o0000?_oonfX4o`0007gooo]Z1Ol0000coookJP_o
0000?OoonfX4o`0009oooo]Z001DoookJP_o0000?OoonfX4o`0007gooo]Z1Ol0000doookJP_o0000
??oonfX4o`0009oooo]Z001EoookJQ3o0000=ooonfX4o`0007gooo]Z1Ol0000eoookJQ7o0000=Ooo
nfX4o`0009oooo]Z001JoookJP_o0000=ooonfX4o`0007gooo]Z1Ol0000joookJPgo0000=?oonfX4
o`0009oooo]Z001KoookJP[o0000=ooonfX4o`0007gooo]Z1Ol0000koookJPgo0000<ooonfX4o`00
09oooo]Z001LoookJP_o0000=OoonfX4o`0007gooo]Z1Ol0000loookJPgo0000<_oonfX4o`0009oo
oo]Z001QoookJP_o0000<?oonfX4o`0007gooo]Z1Ol00013oookJPSo0000<?oonfX4o`0009oooo]Z
001QoookJP_o0000;ooonfX5o`0007gooo]Z1Ol00014oookJPSo0000;ooonfX4o`0009oooo]Z001R
oookJP_o0000;_oonfX5o`0007gooo]Z1Ol00015oookJPSo0000;_oonfX4o`0009oooo]Z001Toook
JPWo0000;_oonfX5o`0007gooo]Z1Ol00016oookJPSo0000;OoonfX4o`0009oooo]Z001ToookJP[o
0000;OoonfX4o`0007kooo]Z1Ol00018oookJPOo0000;?oonfX4o`0009oooo]Z001YoookJPWo0000
:OoonfX4o`0007kooo]Z1Ol00019oookJPSo0000:_oonfX4o`0009oooo]Z001YoookJP[o0000:?oo
nfX4o`0007kooo]Z1Ol0001:oookJPSo0000:OoonfX4o`0009oooo]Z001ZoookJP[o00009ooonfX4
o`0007kooo]Z1Ol0001;oookJPSo0000:?oonfX4o`0009oooo]Z001[oookJPWo00009ooonfX4o`00
07kooo]Z1Ol0001<oookJPSo00009ooonfX4o`0009oooo]Z001[oookJP[o00009_oonfX4o`0007ko
oo]Z1Ol0001>oookJPOo00009_oonfX4o`0009oooo]Z001`oookJPGo00009_oonfX4o`0007kooo]Z
1Ol0001?oookJPOo00009OoonfX4o`0009oooo]Z001`oookJPKo00009OoonfX4o`0007kooo]Z1Ol0
001@oookJPKo00009OoonfX4o`0009oooo]Z001aoookJPWo00008OoonfX4o`0007kooo]Z1Ol0001A
oookJPWo00008OoonfX4o`0009oooo]Z001aoookJP[o00008?oonfX4o`0007kooo]Z1Ol0001Boook
JPWo00008?oonfX4o`0009oooo]Z001boookJPWo00008?oonfX4o`0007kooo]Z1Ol0001BoookJP[o
00007ooonfX4o`0009oooo]Z001boookJPWo00008?oonfX4o`0007kooo]Z1Ol0001CoookJPWo0000
7ooonfX4o`0009oooo]Z001goookJPGo00007ooonfX4o`0007kooo]Z1Ol0001GoookJPGo00007ooo
nfX4o`0009oooo]Z001goookJPKo00007_oonfX4o`0007kooo]Z1Ol0001HoookJPGo00007_oonfX4
o`0009oooo]Z001goookJPKo00007_oonfX4o`0007kooo]Z1Ol0001HoookJPKo00007OoonfX4o`00
09oooo]Z001hoookJP[o00006OoonfX4o`0007kooo]Z1Ol0001HoookJP[o00006OoonfX4o`0009oo
oo]Z001ioookJPWo00006OoonfX4o`0007kooo]Z1Ol0001IoookJPWo00006OoonfX4o`0009oooo]Z
001ioookJP[o00006?oonfX4o`0007kooo]Z1Ol0001JoookJPWo00006?oonfX4o`0009oooo]Z001j
oookJPWo00006?oonfX4o`0007kooo]Z1Ol0001JoookJPWo00006?oonfX4o`0009oooo]Z001joook
JPWo00006?oonfX4o`00063ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001Joook
JPWo00006?oonfX4o`0009oooo]Z001ooookJPCo00006?oonfX4o`0005oooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00O`Wooo]Z1Ol0001OoookJPGo00005ooonfX4o`0009oooo]Z001ooookJPGo0000
5ooonfX4o`0005oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool0
07l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000GooonfX5o`0001Oooo]Z1?l0002Ooook
JP00OooonfX6o`0001Kooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o2?oonfX5o`0005oooo]Z1Ol0000GoookJPCo0000WooonfX007oooo]Z1_l0000FoookJPCo0000
G_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0005oooo]Z1Ol0000FoookJPCo0000
WooonfX0083ooo]Z2Ol0000BoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oo
nfX5o`00063ooo]Z2Ol0000BoookJPCo0000WooonfX0087ooo]Z2Ol0000AoookJPCo0000G_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001PoookJP[o00004OoonfX4
o`0009oooo]Z0021oookJPWo00004OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`Wooo]Z1Ol0001QoookJPWo00004OoonfX4o`0009oooo]Z0021oookJPWo00004OoonfX4o`0005ko
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001QoookJP[o00004?oonfX4o`0009oo
oo]Z0022oookJPWo00004?oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z
1Ol0001RoookJPWo00004?oonfX4o`0009oooo]Z0026oookJPGo00004?oonfX4o`0005oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0006Kooo]Z1Ol0000@oookJPCo0000
WooonfX008Kooo]Z1_l0000?oookJPCo0000GooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000Iooo
nfX4o`00013ooo]Z1?l0002OoookJP00QooonfX5o`0000oooo]Z1?l0001PoookJPGo001o2_oonfX7
o`00O`Sooo]Z1Ol0001WoookJPCo00004?oonfX4o`0009oooo]Z0027oookJPGo00003ooonfX4o`00
07kooo]Z1Ol0001WoookJPGo00003ooonfX4o`0009oooo]Z0028oookJPWo00002_oonfX4o`0007ko
oo]Z1Ol0001WoookJP[o00002_oonfX4o`0009oooo]Z0028oookJPWo00002_oonfX4o`0007kooo]Z
1Ol0001WoookJP[o00002_oonfX4o`0009oooo]Z0028oookJPWo00002OoonfX5o`0007kooo]Z1Ol0
001XoookJPWo00002_oonfX4o`0009oooo]Z0028oookJP[o00002?oonfX5o`0007kooo]Z1Ol0001X
oookJPWo00002_oonfX4o`0009oooo]Z0028oookJP[o00002?oonfX5o`0007kooo]Z1Ol0001Xoook
JPWo00002_oonfX4o`0009oooo]Z0029oookJPWo00002?oonfX4o`0007oooo]Z1Ol0001YoookJPWo
00002OoonfX4o`0009oooo]Z0029oookJP[o00001ooonfX4o`0007oooo]Z1Ol0001ZoookJPSo0000
2OoonfX4o`0009oooo]Z002>oookJPGo00001ooonfX4o`0007oooo]Z1Ol0001]oookJPGo00002Ooo
nfX4o`0009oooo]Z002>oookJPGo00001ooonfX4o`0007oooo]Z1Ol0001^oookJPGo00002?oonfX4
o`0009oooo]Z002?oookJPCo000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000002o`00
07oooo]Z1Ol0001^oookJPGo000000?ooo]Zo`000?l000000ol00002oookJPCo0000WooonfX008oo
oo]Z1?l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000;o0000OooonfX5o`0006ko
oo]Z1Ol000000ooonf[o0000o`000003o`0000;ooo]Z1?l0002OoookJP00SooonfX:o`000003oook
J_l0003o000000;o0000OooonfX5o`0006oooo]Z2_l00002oookJPCo0000WooonfX008oooo]Z2_l0
00000ooonf[o0000o`000002o`0007oooo]Z1Ol0001_oookJP[o000000?ooo]Zo`000?l000000ol0
002OoookJP00SooonfX:o`000003oookJ_l0003o000000;o0000OooonfX5o`0006oooo]Z2_l00000
0ooonf[o0000o`000003o`0009oooo]Z002?oookJP[o000000?ooo]Zo`000?l000000_l0001ooook
JPGo0000KooonfX:o`000003oookJ_l0003o000000?o0000WooonfX008oooo]Z3ol0001ooookJPGo
0000L?oonfX>o`000:3ooo]Z002@oookJPko0000OooonfX5o`00073ooo]Z3_l0002PoookJP00T?oo
nfX>o`0007oooo]Z1Ol0001`oookJPko0000X?oonfX0093ooo]Z3_l0001ooookJPGo0000LOoonfX=
o`000:3ooo]Z002AoookJPgo0000OooonfX5o`00077ooo]Z3Ol0002PoookJP00TOoonfX4o`000003
oookJ_l0003o000000Ko0000OooonfX5o`00077ooo]Z1?l000000ooonf[o0000o`000006o`000:3o
oo]Z002FoookJPSo0000OooonfX5o`0007Kooo]Z2?l0002PoookJP00U_oonfX8o`0007oooo]Z1Ol0
001foookJPSo0000X?oonfX009Kooo]Z2?l0001ooookJPGo0000M_oonfX8o`000:3ooo]Z002Foook
JPSo0000OooonfX5o`0007Kooo]Z2?l0002PoookJP00U_oonfX8o`0007oooo]Z1Ol0001foookJPSo
0000X?oonfX009Kooo]Z2?l0001ooookJPGo0000M_oonfX8o`000:3ooo]Z002FoookJPSo0000Oooo
nfX5o`0007Oooo]Z1ol0002PoookJP00UooonfX7o`0007;ooo]Z0ol007l:oookJPGo0000MooonfX7
o`000:3ooo]Z002GoookJPOo0000L_oonfX3o`00O`[ooo]Z1Ol0001goookJPOo0000X?oonfX009Oo
oo]Z1ol0001boookJP?o001o2_oonfX5o`0007Oooo]Z1ol0002PoookJP00UooonfX7o`0007;ooo]Z
0ol007l:oookJPGo0000MooonfX7o`000:3ooo]Z002GoookJPOo0000L_oonfX3o`00O`[ooo]Z1_l0
001foookJPOo0000X?oonfX009Oooo]Z1ol0001boookJP?o001o2_oonfX5o`0007Oooo]Z1ol0002P
oookJP00UooonfX7o`0007;ooo]Z0ol007l:oookJPGo0000MooonfX7o`000:3ooo]Z002HoookJPGo
0000LooonfX3o`00O`[ooo]Z1Ol0001goookJPKo0000XOoonfX009Sooo]Z1Ol0001coookJP?o001o
2_oonfX5o`0007Oooo]Z1_l0002QoookJP00V?oonfX5o`00073ooo]Z1_l007l:oookJPGo0000N?oo
nfX5o`000:7ooo]Z002HoookJPGo0000L?oonfX6o`00O`[ooo]Z1Ol0001hoookJPGo0000XOoonfX0
09Sooo]Z1Ol0001boookJPCo001o2_oonfX5o`0007Sooo]Z1Ol0002QoookJP00V?oonfX5o`0007?o
oo]Z0ol007l:oookJPGo0000N?oonfX5o`000:7ooo]Z002HoookJPCo0000POoonfX5o`0007Sooo]Z
1?l0002RoookJP00V?oonfX4o`00087ooo]Z1Ol0001hoookJPCo0000X_oonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0
003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX0
0?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o
001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o
2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPKo001o2_oo
nfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX0
0?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[o
oo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJPgo
oo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1?l007l<
oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX6o`000?oooo]Z7_oonfX00?oo
oo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol007l9oookJPGo0000
oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3
o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgo
oo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooonfX>oookJPOo001ooooonfX]oookJP00oooo
nfX?oookJPGo001ooooonfX^oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001
\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30974 L
.02605 .31022 L
.02729 .3104 L
.02846 .31016 L
.02954 .30963 L
.03053 .30901 L
.03162 .30834 L
.03279 .30781 L
.03396 .30764 L
.03506 .30785 L
.03636 .3085 L
.03756 .30927 L
.0388 .30999 L
.0395 .31028 L
.04015 .31043 L
.04135 .31038 L
.04262 .3099 L
.04387 .30915 L
.04519 .30835 L
.04588 .30803 L
.04664 .30782 L
.04733 .30777 L
.04797 .30785 L
.04925 .30836 L
.05041 .30908 L
.05176 .30998 L
.05302 .31057 L
.05414 .31075 L
.05534 .31052 L
.05653 .30994 L
.05786 .30913 L
.059 .30852 L
.06022 .30818 L
.06138 .30827 L
.06244 .3087 L
.0649 .31037 L
.06561 .31082 L
.06627 .31114 L
.06752 .31141 L
.0687 .31124 L
.06979 .31076 L
.07097 .31006 L
.07225 .30938 L
.07353 .30901 L
.07473 .30912 L
.07546 .30941 L
.07615 .30982 L
.07746 .31079 L
.07873 .31175 L
Mistroke
.07945 .31218 L
.08009 .31246 L
.08086 .31263 L
.08159 .31262 L
.08225 .31247 L
.08297 .31218 L
.08423 .31149 L
.08493 .3111 L
.08558 .31078 L
.08636 .31052 L
.08707 .31043 L
.08773 .3105 L
.08845 .31073 L
.08914 .31111 L
.08991 .31166 L
.09146 .31298 L
.09215 .31354 L
.09289 .31404 L
.09359 .31439 L
.09423 .31456 L
.09548 .31452 L
.09664 .3141 L
.09802 .31337 L
.09928 .31281 L
.1006 .31264 L
.10184 .31301 L
.10316 .31394 L
.10458 .31528 L
.10579 .31638 L
.10695 .31714 L
.10758 .31737 L
.10827 .31747 L
.10949 .31727 L
.11064 .31677 L
.11187 .31617 L
.11291 .31581 L
.11407 .31578 L
.11473 .31597 L
.11542 .31635 L
.11665 .31739 L
.1181 .31894 L
.1188 .31969 L
.11944 .32029 L
.12061 .32109 L
.12186 .32141 L
.12251 .32137 L
.12321 .32118 L
.12449 .32061 L
.1258 .32007 L
.12703 .31992 L
Mistroke
.12773 .32007 L
.12837 .32038 L
.12911 .32094 L
.12981 .32163 L
.13123 .32332 L
.132 .32427 L
.13273 .32509 L
.13342 .32573 L
.13416 .32623 L
.13545 .32661 L
.13667 .32642 L
.13796 .3259 L
.13907 .32547 L
.14028 .32534 L
.14159 .32582 L
.14233 .32642 L
.14301 .32714 L
.14555 .33061 L
.14665 .33193 L
.14784 .33288 L
.14914 .33324 L
.15036 .33301 L
.15166 .3325 L
.15232 .33227 L
.15303 .33213 L
.1543 .33234 L
.15547 .3332 L
.16465 .34096 L
.18542 .35825 L
.22448 .40042 L
.22572 .40545 L
.22641 .40807 L
.22706 .41026 L
.22831 .41318 L
.22946 .41402 L
.23066 .41314 L
.23197 .41098 L
.23267 .40979 L
.23341 .40885 L
.2341 .40849 L
.23473 .40876 L
.23548 .40995 L
.23617 .4119 L
.23692 .41492 L
.23771 .41891 L
.23916 .42719 L
.23987 .43103 L
.24051 .43404 L
.24174 .43776 L
.24306 .43803 L
Mistroke
.24374 .43666 L
.24449 .43426 L
.24584 .4287 L
.24709 .42446 L
.24826 .42352 L
.24955 .42764 L
.25027 .43255 L
.25093 .43849 L
.25218 .45232 L
.25351 .46738 L
.25427 .47413 L
.25497 .47788 L
.25566 .47857 L
.25632 .47579 L
.25756 .46014 L
.2587 .43314 L
.25996 .39096 L
.26128 .33638 L
.26354 .2392 L
.26473 .1962 L
.266 .16275 L
.26732 .14354 L
.26854 .13943 L
.26969 .14504 L
.27095 .15773 L
.2721 .17114 L
.27331 .18354 L
.27434 .19081 L
.27547 .19443 L
.27678 .19344 L
.27799 .18924 L
.27872 .18616 L
.27941 .18343 L
.28071 .18006 L
.28185 .17996 L
.28309 .18316 L
.28441 .18951 L
.28563 .19651 L
.28668 .20214 L
.28782 .20671 L
.28889 .20906 L
.28987 .20952 L
.29101 .20844 L
.29226 .2063 L
.29344 .20454 L
.29453 .20403 L
.29576 .20531 L
.29693 .20832 L
.29797 .21211 L
.2991 .21668 L
Mistroke
.30033 .22128 L
.30163 .22475 L
.30274 .2262 L
.30396 .22628 L
.30527 .22525 L
.30648 .22415 L
.30711 .22381 L
.3078 .22377 L
.30853 .22419 L
.30921 .22506 L
.31046 .22775 L
.31161 .23112 L
.31294 .23534 L
.31418 .23874 L
.31523 .24075 L
.31635 .24183 L
.3176 .24188 L
.31872 .2413 L
.3199 .24061 L
.32118 .24046 L
.32239 .24132 L
.3235 .24308 L
.33431 .25459 L
.3396 .26244 L
.34072 .26468 L
.34191 .26645 L
.34321 .26743 L
.34442 .26751 L
.34556 .26713 L
.34663 .26672 L
.34781 .26657 L
.34907 .26712 L
.35019 .26832 L
.35138 .27019 L
.35349 .27411 L
.35465 .2759 L
.35589 .27714 L
.35706 .27757 L
.35813 .27745 L
.35938 .27699 L
.36004 .27675 L
.36074 .27659 L
.36203 .27676 L
.36321 .2776 L
.37316 .28512 L
.37443 .2848 L
.37514 .28484 L
.37579 .28506 L
.37655 .28554 L
.37727 .28622 L
Mistroke
.37865 .28796 L
.37997 .28983 L
.38069 .29076 L
.38137 .29151 L
.38256 .29241 L
.38387 .29271 L
.3851 .29244 L
.38623 .29196 L
.38753 .2915 L
.38877 .29147 L
.39009 .29207 L
.39131 .29319 L
.39273 .2949 L
.39407 .29648 L
.39511 .29742 L
.39622 .29801 L
.39746 .29809 L
.3986 .29774 L
.39981 .29719 L
.40094 .29675 L
.40212 .29663 L
.40341 .29705 L
.40561 .29898 L
.40669 .30016 L
.40767 .30113 L
.40871 .30188 L
.40982 .30227 L
.41104 .3022 L
.41219 .30176 L
.41334 .30118 L
.41456 .30069 L
.41526 .30057 L
.4159 .30059 L
.41714 .30105 L
.41827 .30187 L
.41949 .30301 L
.42064 .30409 L
.42171 .30488 L
.42298 .30537 L
.42366 .3054 L
.42438 .30527 L
.42514 .30499 L
.42585 .30463 L
.4265 .30428 L
.42719 .30392 L
.42845 .30349 L
.42961 .30348 L
.43086 .30396 L
.43157 .30442 L
.43223 .30495 L
Mistroke
.43352 .30606 L
.43473 .30697 L
.43583 .30747 L
.43702 .30758 L
.43831 .30721 L
.43903 .30685 L
.43969 .30648 L
.4409 .30583 L
.44217 .30542 L
.44331 .30546 L
.44456 .30596 L
.4457 .30674 L
.44677 .30757 L
.448 .30843 L
.44917 .30893 L
.44981 .30903 L
.45051 .30899 L
.45174 .30858 L
.45401 .30728 L
.45516 .30678 L
.45642 .30663 L
.4575 .30688 L
.45866 .3075 L
.46076 .30897 L
.46201 .30963 L
.46315 .30987 L
.46447 .30965 L
.46571 .30905 L
.46687 .30834 L
.46795 .30774 L
.46908 .30735 L
.47032 .30734 L
.47158 .30779 L
.47228 .3082 L
.47293 .30863 L
.47418 .30946 L
.47534 .31004 L
.47599 .31022 L
.47667 .31027 L
.47744 .31016 L
.47813 .30992 L
.47879 .30959 L
.4795 .30917 L
.48078 .30836 L
.4821 .30775 L
.48333 .30757 L
.48404 .30768 L
.48468 .30789 L
.48543 .30826 L
.48613 .30869 L
Mistroke
.48744 .30953 L
.48816 .30993 L
.48883 .31021 L
.48956 .31037 L
.49036 .31037 L
.49104 .31022 L
.49177 .30992 L
.49434 .30836 L
.49563 .30778 L
.49636 .30764 L
.49705 .30766 L
.49827 .30801 L
.49938 .30862 L
.50067 .30945 L
.50188 .31008 L
.50299 .31038 L
.50419 .3103 L
.50487 .31007 L
.50552 .30975 L
.50673 .309 L
.50792 .30827 L
.50919 .30775 L
.50992 .30764 L
.51058 .30768 L
.51187 .30812 L
.51306 .30882 L
.51415 .30952 L
.51535 .31016 L
.51662 .31046 L
.51772 .31034 L
.51875 .30993 L
.51988 .30926 L
.52108 .30851 L
.52176 .30816 L
.52248 .3079 L
.52377 .30778 L
.52448 .30794 L
.52515 .30821 L
.52589 .30862 L
.52668 .30914 L
.52736 .3096 L
.5281 .31006 L
.5288 .31042 L
.52944 .31064 L
.53067 .31072 L
.53197 .31033 L
.53326 .30962 L
.53394 .30919 L
.53465 .30878 L
.53596 .30825 L
Mistroke
.53717 .30819 L
.53833 .30855 L
.53942 .30918 L
.54059 .31002 L
.54189 .31086 L
.54315 .31135 L
.54384 .31142 L
.54449 .31134 L
.54564 .31093 L
.54689 .31023 L
.54827 .30945 L
.54897 .30917 L
.54973 .30901 L
.55038 .30902 L
.55108 .30917 L
.55233 .30981 L
.55361 .31076 L
.55429 .31129 L
.555 .3118 L
.55631 .31247 L
.55752 .31264 L
.55868 .31238 L
.55977 .31187 L
.56095 .31119 L
.56223 .31061 L
.56348 .31044 L
.56463 .31073 L
.56573 .31138 L
.56691 .31234 L
.56806 .31333 L
.56915 .31408 L
.57012 .3145 L
.57118 .3146 L
.58079 .3153 L
.58192 .31633 L
.58315 .31714 L
.58432 .31746 L
.58539 .31736 L
.58664 .31687 L
.58797 .3162 L
.58909 .31581 L
.59032 .31579 L
.59102 .31602 L
.59166 .31638 L
.59237 .31694 L
.59311 .31766 L
.59446 .31913 L
.59572 .32036 L
.59689 .32113 L
.59813 .32142 L
Mistroke
.59884 .32134 L
.59951 .32114 L
.60076 .32058 L
.60198 .32008 L
.60268 .31993 L
.60332 .31993 L
.60463 .32043 L
.60536 .32099 L
.60603 .32166 L
.60725 .32311 L
.60855 .32468 L
.60966 .32577 L
.61088 .32647 L
.61155 .32661 L
.61227 .32657 L
.61358 .32615 L
.61431 .32583 L
.615 .32556 L
.61572 .32537 L
.61651 .32534 L
.61721 .32552 L
.61785 .32587 L
.61859 .32648 L
.61929 .32725 L
.62052 .32889 L
.62184 .33074 L
.62309 .33217 L
.62423 .33298 L
.62537 .33324 L
.62646 .33304 L
.62772 .33255 L
.62889 .33218 L
.63017 .33223 L
.63089 .33256 L
.63154 .33308 L
.64183 .3406 L
.66027 .35531 L
.68115 .37682 L
.68224 .37621 L
.68342 .37611 L
.68454 .37697 L
.68557 .37874 L
.68677 .38183 L
.68805 .38581 L
.68913 .38916 L
.6903 .39209 L
.69158 .39394 L
.69278 .39426 L
.69347 .39393 L
.6942 .39331 L
Mistroke
.6955 .39209 L
.6967 .39163 L
.69782 .39238 L
.69904 .39485 L
.70035 .39918 L
.70278 .40872 L
.70344 .41084 L
.70415 .41255 L
.70541 .41399 L
.70658 .41347 L
.70768 .41184 L
.70896 .40963 L
.71018 .4085 L
.71126 .40917 L
.71243 .41215 L
.7135 .41678 L
.71449 .42218 L
.71564 .42879 L
.71673 .43412 L
.71798 .43783 L
.71911 .43819 L
.72026 .43571 L
.72152 .43083 L
.72276 .42597 L
.72407 .42339 L
.72531 .42561 L
.72643 .43234 L
.72756 .44313 L
.72863 .45546 L
.72988 .46915 L
.7312 .47801 L
.73232 .47696 L
.73356 .46346 L
.73426 .44966 L
.73489 .43315 L
.73633 .38405 L
.73892 .27304 L
.7402 .22109 L
.74141 .18159 L
.7425 .15676 L
.74368 .14225 L
.74496 .13993 L
.74561 .14308 L
.74632 .14894 L
.74759 .16299 L
.74875 .17627 L
.74992 .18697 L
.75103 .19299 L
.7522 .19461 L
.75348 .19192 L
Mistroke
.75457 .1876 L
.75575 .18291 L
.75687 .18011 L
.75789 .1798 L
.7591 .1825 L
.76037 .18826 L
.76179 .19633 L
.76311 .20323 L
.76439 .20777 L
.7651 .20909 L
.76575 .20954 L
.76647 .2093 L
.76724 .20838 L
.76797 .20715 L
.76865 .20595 L
.76984 .20434 L
.77095 .20411 L
.77217 .20575 L
.77349 .20957 L
.77487 .21499 L
.77617 .22009 L
.77734 .22369 L
.77861 .22593 L
.77925 .22636 L
.77993 .22636 L
.78115 .22554 L
.78183 .22488 L
.78255 .22423 L
.78386 .22374 L
.78508 .22459 L
.78618 .22659 L
.78749 .23017 L
.78873 .2341 L
.79006 .23798 L
.79074 .23954 L
.79148 .24083 L
.79279 .24193 L
.79402 .24179 L
.79473 .24141 L
.79547 .24095 L
.7961 .24061 L
.79679 .24041 L
.79754 .24051 L
.79833 .24106 L
.79909 .24202 L
.79977 .24324 L
.80218 .24919 L
.8035 .25235 L
.80474 .25448 L
.80538 .25518 L
Mistroke
.80607 .2556 L
.80684 .25572 L
.80753 .25557 L
.80817 .25531 L
.80886 .25498 L
.81011 .25459 L
.81128 .25484 L
.81257 .25607 L
.81321 .25707 L
.81391 .25837 L
.81518 .2611 L
.81637 .26365 L
.81762 .26584 L
.81869 .26702 L
.81987 .26754 L
.84108 .27978 L
.84229 .28175 L
.8436 .28373 L
.84483 .28512 L
.84595 .28579 L
.84721 .28587 L
.84841 .2855 L
.84972 .28499 L
.85045 .28482 L
.85112 .28481 L
.8523 .28523 L
.85341 .28617 L
.85444 .28741 L
.85555 .28896 L
.85677 .29062 L
.85806 .29196 L
.85917 .29258 L
.86038 .29268 L
.86164 .29231 L
.86278 .29181 L
.8641 .29144 L
.86535 .29158 L
.86651 .29225 L
.86757 .29328 L
.86882 .29478 L
.86999 .29619 L
.87115 .29731 L
.8724 .298 L
.87307 .29812 L
.87378 .29806 L
.87505 .29763 L
.87629 .29705 L
.87699 .29679 L
.87762 .29665 L
.87837 .29664 L
Mistroke
.87907 .29681 L
.87972 .29713 L
.88043 .29764 L
.8829 .30018 L
.88411 .30134 L
.88522 .30204 L
.88638 .3023 L
.88763 .30207 L
.88828 .3018 L
.88899 .30145 L
.89029 .30084 L
.89149 .30057 L
.89257 .30071 L
.89382 .30136 L
.895 .30236 L
.89609 .3034 L
.89712 .30432 L
.8983 .30509 L
.89938 .3054 L
.90053 .30528 L
.90179 .30476 L
.90287 .30419 L
.90405 .30365 L
.90534 .30343 L
.90605 .30353 L
.90671 .30378 L
.90789 .30452 L
.90917 .30559 L
.90983 .30616 L
.91053 .3067 L
.9118 .3074 L
.91312 .30759 L
.91387 .30745 L
.91456 .30719 L
.91581 .30652 L
.91713 .30581 L
.91826 .30544 L
.9195 .30546 L
.92064 .3059 L
.92186 .30671 L
.92291 .30754 L
.92407 .30836 L
.92475 .30872 L
.92539 .30894 L
.92665 .309 L
.9278 .30864 L
.92901 .30798 L
.93007 .30735 L
.93121 .30683 L
.93229 .30662 L
Mistroke
.93327 .30674 L
.93437 .3072 L
.93557 .30799 L
.93682 .30888 L
.93798 .30954 L
.93914 .30986 L
.94037 .30974 L
.9416 .30922 L
.9423 .30881 L
.94296 .3084 L
.94412 .30775 L
.94522 .30736 L
.94649 .30734 L
.94765 .30774 L
.94871 .30835 L
.94984 .30911 L
.95081 .30971 L
.95186 .31014 L
.9531 .31025 L
.95427 .30994 L
.9554 .30935 L
.95645 .30869 L
.95759 .30803 L
.95882 .30762 L
.95997 .30762 L
.96103 .30796 L
.96226 .30865 L
.96361 .30952 L
.96488 .31016 L
.96605 .31039 L
.96726 .31021 L
.96839 .30969 L
.96974 .30885 L
.97097 .30813 L
.97219 .30769 L
.97348 .30769 L
.97478 .30817 L
.97551 .30858 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
X?oonfX4o`0007Wooo]Z1Ol00020oookJPCo0000V_oonfX00:3ooo]Z1?l0001ioookJPGo0000P?oo
nfX4o`0009[ooo]Z002OoookJPGo0000NOoonfX5o`0007oooo]Z1Ol0002JoookJP00WooonfX5o`00
07Wooo]Z1Ol0001ooookJPGo0000V_oonfX009oooo]Z1Ol0001ioookJPGo0000OooonfX5o`0009[o
oo]Z002OoookJPGo0000K?oonfX3o`00O`[ooo]Z1Ol0001ooookJPGo0000V_oonfX009oooo]Z1Ol0
001/oookJP?o001o2_oonfX5o`0007oooo]Z1Ol0002JoookJP00WooonfX6o`0006_ooo]Z0ol007l:
oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPOo0000FooonfX:o`00O`Kooo]Z0ol007l:oook
JPGo0000O_oonfX6o`0009[ooo]Z002NoookJPOo0000FooonfX:o`00O`Kooo]Z0ol007l:oookJPKo
0000OOoonfX6o`0009[ooo]Z002NoookJPOo0000JooonfX3o`00O`[ooo]Z1Ol0001noookJPOo0000
VOoonfX009kooo]Z1ol0001[oookJP?o001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX7
o`0006_ooo]Z0ol007l:oookJPGo0000O_oonfX7o`0009Wooo]Z002NoookJPOo0000JooonfX3o`00
O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1ol0001XoookJPKo001o2_oonfX5o`0007ko
oo]Z1ol0002IoookJP00W_oonfX7o`0006Sooo]Z1_l007l:oookJPGo0000O_oonfX7o`0009Wooo]Z
002NoookJPOo0000J_oonfX4o`00O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1ol0001[
oookJP?o001o2_oonfX5o`0007kooo]Z2?l0002HoookJP00W_oonfX7o`0007Sooo]Z1Ol0001noook
JPSo0000V?oonfX009kooo]Z1ol0001hoookJPGo0000O_oonfX8o`0009Sooo]Z002NoookJPOo0000
N?oonfX5o`0007kooo]Z2?l0002HoookJP00W_oonfX8o`0007Oooo]Z1Ol0001noookJPSo0000V?oo
nfX009kooo]Z3Ol0001boookJPGo0000O_oonfX=o`0009?ooo]Z002NoookJPgo0000L_oonfX5o`00
07kooo]Z3Ol0002CoookJP00W_oonfX=o`0007;ooo]Z1Ol0001noookJPgo0000TooonfX009kooo]Z
3Ol0001boookJPGo0000O_oonfX=o`0009?ooo]Z002NoookJPko0000LOoonfX5o`0007kooo]Z3_l0
002BoookJP00W_oonfX>o`00077ooo]Z1Ol0001noookJPko0000T_oonfX009kooo]Z3_l0001aoook
JPGo0000O_oonfX>o`0009;ooo]Z002NoookJPko0000LOoonfX5o`0007kooo]Z3_l0002BoookJP00
W_oonfX4o`000003oookJ_l0003o000000So0000L?oonfX5o`0007kooo]Z3ol0002AoookJP00W_oo
nfX4o`000003oookJ_l0003o000000So0000L?oonfX5o`0007kooo]Z1?l000000ooonf[o0000o`00
0008o`00097ooo]Z002NoookJPCo000000?ooo]Zo`000?l000002?l0001`oookJPGo0000O_oonfX4
o`000003oookJ_l0003o000000So0000TOoonfX009kooo]Z1?l000000ooonf[o0000o`000002o`00
00;ooo]Z1?l0001`oookJPGo0000O_oonfX4o`0000;ooo]Z1?l000000ooonf[o0000o`000002o`00
097ooo]Z002NoookJPCo00001ooonfX4o`00073ooo]Z1Ol0001moookJPGo00001ooonfX5o`00093o
oo]Z002NoookJPCo00001ooonfX9o`0006_ooo]Z1Ol0001moookJPGo00001ooonfX9o`0008cooo]Z
002NoookJPCo00001ooonfX9o`0006_ooo]Z1Ol0001moookJPGo00001ooonfX:o`0008_ooo]Z002N
oookJPCo00001ooonfX:o`0006[ooo]Z1Ol0001moookJPCo00002OoonfX9o`0008_ooo]Z002Noook
JPCo00001ooonfX:o`0006[ooo]Z1Ol0001moookJPCo00002OoonfX9o`0008_ooo]Z002NoookJPCo
00002?oonfX:o`0006Wooo]Z1Ol0001moookJPCo00002OoonfX9o`0008_ooo]Z002NoookJPCo0000
2?oonfX:o`0006Wooo]Z1Ol0001moookJPCo00002OoonfX:o`0008[ooo]Z002NoookJPCo00002Ooo
nfX9o`0006Wooo]Z1Ol0001moookJPCo00002_oonfX9o`0008[ooo]Z002NoookJPCo00003_oonfX4
o`0006Wooo]Z1Ol0001moookJPCo00003_oonfX5o`0008[ooo]Z002MoookJPGo00003_oonfX4o`00
06Wooo]Z1Ol0001moookJPCo00003ooonfX5o`0008Wooo]Z002MoookJPGo00003_oonfX5o`0006So
oo]Z1Ol0001moookJPCo00003ooonfX5o`0008Wooo]Z002MoookJPGo00003_oonfX5o`0006Sooo]Z
1Ol0001moookJPCo00003ooonfX5o`0008Wooo]Z002MoookJPCo00003ooonfX9o`0006Cooo]Z1Ol0
001moookJPCo00004?oonfX8o`0008Gooo]Z002MoookJPCo00004?oonfX9o`0004Gooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001moookJPCo00004?oonfX9o`0008Cooo]Z002Moook
JPCo00004?oonfX9o`0004Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001moook
JPCo00004?oonfX9o`0008Cooo]Z002MoookJPCo00004?oonfX9o`0004Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9
oookJPGo0000OOoonfX4o`00013ooo]Z2_l00023oookJP00WOoonfX4o`00017ooo]Z2Ol0000foook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001moook
JPCo00004OoonfX9o`0008?ooo]Z002MoookJPCo00005OoonfX5o`0003Kooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000O?oonfX4o`0001Gooo]Z1Ol00023oookJP00
WOoonfX4o`0001Gooo]Z1_l00011oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000
OOoonfX4o`0001Kooo]Z1?l00023oookJP00WOoonfX4o`0001Kooo]Z1Ol00011oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0007gooo]Z1?l0000FoookJPGo0000P_oo
nfX009gooo]Z1?l0000FoookJPGo0000@OoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5
o`0007gooo]Z1?l0000FoookJPKo0000POoonfX009gooo]Z1?l0000GoookJPWo0000??oonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0007gooo]Z1?l0000FoookJP[o0000OOoonfX009go
oo]Z1?l0000GoookJPWo0000??oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0007go
oo]Z1?l0000GoookJPWo0000OOoonfX009gooo]Z1?l0000GoookJPWo0000?OoonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Oooo]Z2Ol0001moookJP00
WOoonfX4o`0001Sooo]Z2Ol0000loookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001moookJPCo0000
6?oonfX9o`0007cooo]Z002MoookJPCo00006?oonfX:o`0003cooo]Z1Ol007l:oookJPOo001o2?oo
nfX5o`0007cooo]Z1Ol0000IoookJPSo0000O?oonfX009gooo]Z1?l0000LoookJPOo0000FOoonfX5
o`0007cooo]Z1Ol0000LoookJPKo0000NooonfX009gooo]Z1?l0000MoookJPOo0000F?oonfX5o`00
07cooo]Z1Ol0000MoookJPGo0000NooonfX009gooo]Z1?l0000NoookJPOo0000EooonfX5o`0007co
oo]Z1?l0000NoookJPKo0000N_oonfX009gooo]Z1?l0000OoookJPOo0000E_oonfX5o`0007cooo]Z
1?l0000OoookJPWo0000M_oonfX009gooo]Z1?l0000PoookJPKo0000E_oonfX5o`0007cooo]Z1?l0
000OoookJP[o0000MOoonfX009gooo]Z1?l0000QoookJPKo0000EOoonfX5o`0007cooo]Z1?l0000P
oookJPWo0000MOoonfX009gooo]Z1?l0000RoookJPKo0000E?oonfX5o`0007cooo]Z1?l0000Poook
JP[o0000M?oonfX009gooo]Z1?l0000RoookJPOo0000DooonfX5o`0007cooo]Z1?l0000UoookJPGo
0000M?oonfX009gooo]Z1?l0000SoookJPOo0000D_oonfX5o`0007cooo]Z1?l0000UoookJPGo0000
M?oonfX009gooo]Z1?l0000ToookJP[o0000C_oonfX5o`0007cooo]Z1?l0000VoookJPKo0000L_oo
nfX009gooo]Z1?l0000UoookJP[o0000COoonfX5o`0007cooo]Z1?l0000VoookJPOo0000LOoonfX0
09gooo]Z1?l0000VoookJPWo0000COoonfX5o`0007cooo]Z1?l0000VoookJPWo0000KooonfX002;o
oo]Z0ol007meoookJP?o001o1?l00002oookJP?o001o0ooonfX5o`00OaWooo]Z2_l0001<oookJPGo
0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPGo001o7ooonfX:o`0004gooo]Z0ol007lMoookJP00
8_oonfX3o`00OgCooo]Z1?l007l4o`0000;ooo]Z0ol007l2oookJPOo001o6_oonfX9o`0004_ooo]Z
1Ol0001coookJPOo001o0_oonfX4o`0000;ooo]Z1ol007lOoookJP_o0000BooonfX3o`00Oagooo]Z
000RoookJP?o001oM?oonfX3o`00O`03oookJ_l0003o000000;o00000_oonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o7OoonfX:o`0004Oooo]Z1Ol0001coookJP?o001o
00Cooo]Zo`00Ool007oo001o0_oonfX4o`000003oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool0
07oo001o8OoonfX;o`0004Wooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o
001o0_oonfX3o`00O`;ooo]Z1?l00006oookJP?o001o0ooonfX3o`00Oagooo]Z2ol00015oookJPGo
0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`000004oookJ_l007oo001oo`00
O`?ooo]Z0ol007lRoookJP_o0000AooonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOo
oo]Z2_l007l2oookJP?o001o0_oonfX4o`0000cooo]Z0ol007lNoookJP_o0000A?oonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00007oookJP?o001o9?oonfX:o`0004Ko
oo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo00003?oonfX3o`00Oakooo]Z
3?l00013oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000Oooo]Z
0ol007lVoookJPWo0000AOoonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`;ooo]Z1?l0
0007oookJP;o001o0_oonfX4o`00Oaoooo]Z3?l00012oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol0
07l00ooonf[o0000o`000002o`0000;ooo]Z0_l007l2oookJPCo001o:?oonfX7o`0004Gooo]Z0ol0
07lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo00001ooonfX7o`00ObKooo]Z2Ol0000o
oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1ol007l[
oookJP[o0000@?oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`;ooo]Z1?l00007oook
JPKo001o:?oonfX8o`0003oooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o0000
00;o00000_oonfX6o`00Obgooo]Z2_l0000ooookJP?o001o7OoonfX001oooo]Z1_l007mcoookJP?o
001o00?ooo]Zo`000?l000000ol00007oookJP;o001o;OoonfX8o`0003kooo]Z1Ol0001boookJP?o
001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oonfX2o`00Oc7ooo]Z2ol0000koookJPKo
001o7OoonfX001oooo]Z1_l007mdoookJP?o001o1Ol00007oookJP;o001o;_oonfX8o`0003gooo]Z
1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`0000;ooo]Z0_l007lboookJP[o
0000>ooonfX6o`00Oagooo]Z000QoookJPCo001oM?oonfX3o`00O`Go00002?oonfX7o`00Ob[ooo]Z
3?l0000goookJPGo0000LooonfX7o`00O`;ooo]Z1?l00003oookJPOo001o<OoonfX;o`0003Oooo]Z
1?l007lMoookJP008_oonfX3o`00OgGooo]Z0_l007l4o`0000Wooo]Z1ol007l[oookJPco0000=_oo
nfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX7o`00Oc;ooo]Z2ol0000goookJP?o001o7Ooo
nfX009cooo]Z1?l0000loookJQ3o0000<OoonfX5o`0007cooo]Z1?l0000loookJQ3o0000D_oonfX0
09cooo]Z1?l0000moookJQ3o0000<?oonfX5o`0007cooo]Z1?l0000moookJQ7o0000D?oonfX009co
oo]Z1?l00013oookJP_o000000?ooo]Zo`000?l000000_l0000ZoookJPGo0000O?oonfX4o`0004;o
oo]Z4Ol0001;oookJP00W?oonfX4o`0004Cooo]Z4Ol0000XoookJPGo0000O?oonfX4o`0004Cooo]Z
4Ol00019oookJP00W?oonfX4o`0004Cooo]Z6?l0000QoookJPGo0000O?oonfX4o`0004Cooo]Z5ol0
0013oookJP00W?oonfX4o`0004[ooo]Z6Ol0000JoookJPGo0000O?oonfX4o`0004_ooo]Z6?l0000k
oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP00
3_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[o
o`000?oo00009Ol0000?oookJP007?oonfX5o`0000;ooo]Z1_l000000ooonf[o0000o`00000Uo`00
04_ooo]Z1?l0001`oookJPGo00000_oonfX=o`000003oookJ_l0003o000000Co000000?ooo]Zo`00
0?l000001?l000000ooonf[o0000o`00000No`0004_ooo]Z1?l0001`oookJPGo00000_oonfX5o`00
00?ooo]Z00?o0000oookJ_oonfX07?oonfX003Wooo]Z1_l000000ooonf[o0000o`00000@o`0004[o
oo]Z1?l0001moookJPGo00006OoonfXHo`0004_ooo]Z1?l0002NoookJP00@?oonfXHo`0004Cooo]Z
1?l0001moookJPGo00008?oonfXHo`0004Cooo]Z1?l0002NoookJP00AooonfXAo`0004Cooo]Z1?l0
001moookJPGo00009ooonfXAo`0004Cooo]Z1?l0002NoookJP00B?oonfXBo`0004;ooo]Z1?l0001m
oookJPGo0000:OoonfX@o`0004?ooo]Z1?l0002NoookJP00C_oonfXAo`0003gooo]Z1?l0001moook
JPGo0000;_oonfXAo`0003gooo]Z1?l0002NoookJP00CooonfXAo`0003cooo]Z1?l0001moookJPGo
0000<?oonfX@o`0003cooo]Z1?l0002NoookJP00EOoonfX;o`0003cooo]Z1?l0001moookJPGo0000
=OoonfX;o`0003cooo]Z1?l0002NoookJP00E_oonfX<o`0003[ooo]Z1?l0001moookJPGo0000=_oo
nfX;o`0003[ooo]Z1Ol0002NoookJP00EooonfX4o`000003oookJ_l0003o000000Wo0000=OoonfX4
o`0007gooo]Z1Ol0000goookJQ3o0000=?oonfX5o`0009kooo]Z001LoookJPco0000=?oonfX4o`00
07gooo]Z1Ol0000loookJPco0000<ooonfX5o`0009kooo]Z001MoookJPco0000<ooonfX4o`0007go
oo]Z1Ol0000moookJPgo0000<OoonfX4o`0009oooo]Z001NoookJPco0000<_oonfX4o`0007gooo]Z
1Ol0000noookJPgo0000<?oonfX4o`0009oooo]Z001ToookJPSo0000<?oonfX4o`0007gooo]Z1Ol0
0014oookJPWo0000;_oonfX4o`0009oooo]Z001UoookJPSo0000;ooonfX4o`0007gooo]Z1Ol00015
oookJPWo0000;OoonfX4o`0009oooo]Z001VoookJPSo0000;_oonfX4o`0007gooo]Z1Ol00017oook
JPSo0000;?oonfX4o`0009oooo]Z001WoookJPSo0000;OoonfX4o`0007gooo]Z1Ol00018oookJPSo
0000:ooonfX4o`0009oooo]Z001YoookJPOo0000;?oonfX4o`0007gooo]Z1Ol0001:oookJPSo0000
:OoonfX4o`0009oooo]Z001ZoookJPSo0000:_oonfX4o`0007gooo]Z1Ol0001;oookJPSo0000:?oo
nfX4o`0009oooo]Z001[oookJPSo0000:OoonfX4o`0007gooo]Z1Ol0001<oookJPSo00009ooonfX4
o`0009oooo]Z001/oookJPSo0000:?oonfX4o`0007gooo]Z1Ol0001=oookJPSo00009_oonfX4o`00
09oooo]Z001]oookJPSo00009ooonfX4o`0007gooo]Z1Ol0001?oookJPOo00009OoonfX4o`0009oo
oo]Z001_oookJPOo00009_oonfX4o`0007gooo]Z1Ol0001@oookJPKo00009OoonfX4o`0009oooo]Z
001`oookJPOo00009OoonfX4o`0007gooo]Z1Ol0001AoookJPKo00009?oonfX4o`0009oooo]Z001a
oookJPKo00009OoonfX4o`0007gooo]Z1Ol0001BoookJPKo00008ooonfX4o`0009oooo]Z001boook
JPKo00009?oonfX4o`0007gooo]Z1Ol0001BoookJPOo00008_oonfX4o`0009oooo]Z001coookJPKo
00008_oonfX5o`0007gooo]Z1Ol0001CoookJPOo00008OoonfX4o`0009oooo]Z001coookJPOo0000
8OoonfX5o`0007gooo]Z1Ol0001DoookJPOo00008?oonfX4o`0009oooo]Z001doookJPOo00008?oo
nfX5o`0007gooo]Z1Ol0001EoookJPOo00007ooonfX4o`0009oooo]Z001eoookJPOo00007ooonfX4
o`0007kooo]Z1Ol0001FoookJPOo00007_oonfX4o`0009oooo]Z001foookJPOo00007_oonfX4o`00
07kooo]Z1Ol0001GoookJPOo00007OoonfX4o`0009oooo]Z001goookJPOo00007OoonfX4o`0007ko
oo]Z1Ol0001HoookJPOo00007?oonfX4o`0009oooo]Z001hoookJPOo00007?oonfX4o`0007kooo]Z
1Ol0001IoookJPWo00006OoonfX4o`0009oooo]Z001ioookJPOo00006ooonfX4o`0007kooo]Z1Ol0
001JoookJPWo00006?oonfX4o`0009oooo]Z001joookJPOo00006_oonfX4o`0007kooo]Z1Ol0001K
oookJPWo00005ooonfX4o`0009oooo]Z001koookJPOo00006OoonfX4o`00063ooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001LoookJPSo00005ooonfX4o`0009oooo]Z001loookJPKo
00006OoonfX4o`0005oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001MoookJPOo
00005ooonfX4o`0009oooo]Z001moookJPKo00006?oonfX4o`0005oooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oook
JPGo0000H?oonfX5o`0001Kooo]Z1?l0002OoookJP00O_oonfX6o`0001Oooo]Z1?l0001NoookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`00063ooo]Z1Ol0000FoookJPCo
0000WooonfX007kooo]Z1ol0000FoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX6o`0005oooo]Z1Ol0000FoookJPCo0000WooonfX007oooo]Z1ol0000EoookJPCo0000G_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`00067ooo]Z1?l0000FoookJPCo0000Wooo
nfX0083ooo]Z1ol0000DoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`Sooo]Z1Ol0001QoookJPWo00004OoonfX4o`0009oooo]Z0021oookJPOo00004ooonfX4o`00
05kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001QoookJPWo00004OoonfX4o`00
09oooo]Z0022oookJPOo00004_oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[o
oo]Z1Ol0001QoookJP[o00004?oonfX4o`0009oooo]Z0023oookJPOo00004OoonfX4o`0005kooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001RoookJPWo00004?oonfX4o`0009oooo]Z
0024oookJPOo00004?oonfX4o`0005oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o
3_oonfX5o`0006?ooo]Z2Ol0000?oookJPCo0000WooonfX008Gooo]Z1ol0000?oookJPCo0000Gooo
nfX7o`00O`Wooo]Z1ol007l8oookJPGo0000IooonfX5o`0000oooo]Z1?l0002OoookJP00Q_oonfX6
o`0000oooo]Z1?l0001PoookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001WoookJPGo00003ooonfX4
o`0009oooo]Z0027oookJPGo00003ooonfX4o`0007kooo]Z1Ol0001XoookJPGo00003_oonfX4o`00
09oooo]Z0028oookJPCo00003ooonfX4o`0007kooo]Z1Ol0001XoookJPGo00003_oonfX4o`0009oo
oo]Z0028oookJPWo00002_oonfX4o`0007kooo]Z1Ol0001XoookJPWo00002_oonfX4o`0009oooo]Z
0028oookJP[o00002OoonfX4o`0007kooo]Z1Ol0001YoookJPSo00002OoonfX5o`0009oooo]Z0028
oookJP[o00002?oonfX5o`0007kooo]Z1Ol0001YoookJPWo00002?oonfX5o`0009oooo]Z0029oook
JPWo00002?oonfX5o`0007kooo]Z1Ol0001YoookJPWo00002?oonfX5o`0009oooo]Z0029oookJPWo
00002?oonfX5o`0007kooo]Z1Ol0001YoookJP[o00001ooonfX4o`000:3ooo]Z002:oookJPWo0000
1ooonfX4o`0007oooo]Z1Ol0001ZoookJPWo00001ooonfX4o`000:3ooo]Z002:oookJPWo00001ooo
nfX4o`0007oooo]Z1Ol0001ZoookJPWo00001ooonfX4o`000:3ooo]Z002>oookJPGo00001ooonfX4
o`0007oooo]Z1Ol0001_oookJPCo00001ooonfX4o`000:3ooo]Z002?oookJPCo00000_oonfX4o`00
0003oookJ_l0003o000000;o0000OooonfX5o`0006oooo]Z1?l000000ooonf[o0000o`000002o`00
00;ooo]Z1?l0002PoookJP00SooonfX:o`000003oookJ_l0003o000000;o0000OooonfX5o`0006oo
oo]Z1?l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000;o0000X?oonfX008oooo]Z
2_l000000ooonf[o0000o`000002o`0007oooo]Z1Ol0001_oookJP[o000000?ooo]Zo`000?l00000
0_l0002PoookJP00SooonfX:o`000003oookJ_l0003o000000;o0000OooonfX5o`0006oooo]Z2_l0
00000ooonf[o0000o`000002o`000:3ooo]Z002@oookJPko0000OooonfX5o`0006oooo]Z3ol0002P
oookJP00T?oonfX>o`0007oooo]Z1Ol0001`oookJPko0000X?oonfX0093ooo]Z3_l0001ooookJPGo
0000L?oonfX>o`000:3ooo]Z002@oookJPko0000OooonfX5o`00073ooo]Z3_l0002PoookJP00T?oo
nfX>o`0007oooo]Z1Ol0001`oookJPko0000X?oonfX0093ooo]Z3_l0001ooookJPGo0000L?oonfX>
o`000:3ooo]Z002@oookJPko0000OooonfX5o`00073ooo]Z3_l0002PoookJP00TOoonfX=o`0007oo
oo]Z1Ol0001aoookJPgo0000X?oonfX009Kooo]Z2?l0001ooookJPGo0000M_oonfX8o`000:3ooo]Z
002FoookJPSo0000OooonfX5o`0007Kooo]Z2?l0002PoookJP00U_oonfX8o`0007oooo]Z1Ol0001f
oookJPSo0000X?oonfX009Kooo]Z2?l0001ooookJPGo0000M_oonfX8o`000:3ooo]Z002GoookJPOo
0000OooonfX5o`0007Kooo]Z2?l0002PoookJP00UooonfX7o`0007oooo]Z1Ol0001foookJPSo0000
X?oonfX009Oooo]Z1ol0001ooookJPGo0000MooonfX7o`000:3ooo]Z002GoookJPOo0000L_oonfX3
o`00O`[ooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0001boookJP?o001o2_oonfX5o`00
07Oooo]Z1ol0002PoookJP00UooonfX7o`0007;ooo]Z0ol007l:oookJPGo0000MooonfX7o`000:3o
oo]Z002GoookJPOo0000L_oonfX3o`00O`[ooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0
001boookJP?o001o2_oonfX6o`0007Kooo]Z1ol0002PoookJP00UooonfX7o`0007;ooo]Z0ol007l:
oookJPGo0000MooonfX7o`000:3ooo]Z002GoookJPOo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoook
JPKo0000X?oonfX009Oooo]Z1ol0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00
UooonfX7o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002GoookJPKo0000L?oo
nfX6o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Oooo]Z1_l0001`oookJPKo001o2_oonfX5
o`0007Sooo]Z1Ol0002QoookJP00V?oonfX5o`0007;ooo]Z1?l007l:oookJPGo0000N?oonfX5o`00
0:7ooo]Z002HoookJPGo0000LooonfX3o`00O`[ooo]Z1Ol0001hoookJPGo0000XOoonfX009Sooo]Z
1Ol00020oookJPGo0000N?oonfX5o`000:7ooo]Z002HoookJPGo0000P?oonfX5o`0007Sooo]Z1?l0
002RoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo
0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol0
07l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8
oookJPKo0000oooonfXNoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooook
JQoooo]Z003ooookJP;ooo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Wooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>
oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoook
JP00oooonfX1oookJPCo001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z
2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z3_oonfX4o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oook
JPKo0000oooonfXNoookJP00oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4_oonfX3o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003o
oookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00
Oooooo]Z;?oonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z
1ol007oooookJRgooo]Z003ooookJPoooo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30829 L
.02605 .30783 L
.02729 .30768 L
.02846 .30796 L
.02954 .30852 L
.03053 .30915 L
.03162 .30981 L
.03279 .31027 L
.03396 .31036 L
.03506 .31006 L
.03636 .30936 L
.03756 .3086 L
.0388 .30797 L
.0395 .30777 L
.04015 .30771 L
.04135 .30795 L
.04262 .30861 L
.04387 .30943 L
.04519 .31017 L
.04588 .31041 L
.04664 .31052 L
.04733 .31045 L
.04797 .31027 L
.04925 .30963 L
.05041 .3089 L
.05105 .30853 L
.05175 .3082 L
.05302 .30793 L
.05414 .30811 L
.05539 .30872 L
.0566 .30954 L
.05791 .31038 L
.05913 .31086 L
.06025 .31091 L
.06132 .3106 L
.06244 .31001 L
.0638 .30919 L
.06509 .30862 L
.06624 .30849 L
.06748 .30883 L
.06813 .30917 L
.06885 .30965 L
.07029 .31071 L
.07093 .31113 L
.07162 .31149 L
.07287 .31179 L
.07411 .31159 L
.07482 .3113 L
.07547 .31095 L
Mistroke
.07676 .31019 L
.07794 .30967 L
.07909 .30951 L
.08018 .30977 L
.08133 .31042 L
.08257 .31138 L
.08385 .31238 L
.08457 .31281 L
.08523 .31309 L
.08601 .31323 L
.08674 .31318 L
.08742 .313 L
.08815 .31267 L
.08964 .31185 L
.09045 .31146 L
.09121 .31123 L
.09186 .31116 L
.09256 .31125 L
.09333 .31155 L
.09404 .31198 L
.09533 .31304 L
.0967 .31425 L
.098 .3151 L
.09918 .31543 L
.09982 .3154 L
.10051 .31524 L
.10176 .31467 L
.10252 .31427 L
.10323 .31393 L
.10388 .3137 L
.10458 .31359 L
.10581 .3138 L
.10695 .31447 L
.10818 .31558 L
.10949 .31688 L
.11061 .31783 L
.11166 .31838 L
.11282 .31853 L
.11407 .31822 L
.11533 .31762 L
.11606 .31728 L
.11672 .31705 L
.11741 .31693 L
.11816 .31698 L
.11885 .31723 L
.11951 .31762 L
.12075 .31875 L
.1219 .32003 L
.12315 .32137 L
.12385 .32197 L
Mistroke
.12449 .32238 L
.12578 .32272 L
.12701 .32251 L
.12813 .32203 L
.12936 .32152 L
.13007 .32135 L
.13071 .32133 L
.13144 .32152 L
.13214 .32189 L
.13338 .32302 L
.13472 .32467 L
.13614 .32642 L
.13683 .32712 L
.13746 .32761 L
.13813 .32796 L
.13884 .32812 L
.13962 .32808 L
.14036 .32788 L
.14157 .32738 L
.14285 .32697 L
.14352 .32693 L
.14425 .32711 L
.14555 .32799 L
.16654 .3431 L
.16764 .34268 L
.16883 .34234 L
.16995 .34248 L
.17098 .34318 L
.17219 .34473 L
.17347 .347 L
.17456 .34912 L
.17573 .35116 L
.17701 .35271 L
.17821 .35333 L
.17894 .35335 L
.17963 .35317 L
.18093 .35265 L
.18214 .35239 L
.18325 .35274 L
.18447 .35399 L
.18577 .35628 L
.18823 .36169 L
.1889 .36296 L
.18961 .36404 L
.19088 .36517 L
.19206 .3653 L
.19317 .3649 L
.19438 .36434 L
.19567 .36427 L
.19683 .3651 L
Mistroke
.19809 .36711 L
.19927 .3699 L
.20037 .37282 L
.20143 .37554 L
.20244 .37759 L
.20348 .37894 L
.20463 .37942 L
.20586 .37902 L
.20655 .37857 L
.20719 .37817 L
.20837 .3778 L
.20963 .37849 L
.21086 .38055 L
.21202 .38363 L
.21419 .39055 L
.21545 .39377 L
.21677 .39563 L
.2179 .39583 L
.21913 .39495 L
.21982 .39425 L
.22047 .39364 L
.22122 .3932 L
.2219 .3932 L
.22314 .39451 L
.22383 .39608 L
.22448 .39802 L
.24314 .43925 L
.24563 .43231 L
.24628 .42944 L
.24698 .42669 L
.24825 .42406 L
.24897 .42468 L
.24962 .42688 L
.25039 .43159 L
.25112 .43796 L
.2524 .45233 L
.2531 .46074 L
.25376 .46804 L
.25494 .47736 L
.25625 .47747 L
.25736 .466 L
.25855 .44032 L
.25921 .42012 L
.25994 .39396 L
.26126 .3383 L
.26374 .22948 L
.26438 .20524 L
.26507 .18323 L
.26629 .15465 L
.26761 .14029 L
Mistroke
.26836 .1391 L
.26906 .14173 L
.27033 .15297 L
.27148 .16661 L
.27214 .17424 L
.27283 .18144 L
.27407 .19059 L
.27517 .19386 L
.27638 .19271 L
.27767 .18797 L
.27888 .18282 L
.28003 .17948 L
.28108 .17885 L
.28223 .18121 L
.28344 .18658 L
.28473 .19403 L
.28595 .20082 L
.28663 .20387 L
.28736 .20635 L
.28863 .20833 L
.28986 .20774 L
.29115 .20558 L
.29236 .20354 L
.29346 .20272 L
.29477 .20384 L
.29548 .20549 L
.29616 .20762 L
.29868 .21769 L
.29937 .22016 L
.30011 .2223 L
.30143 .22455 L
.30216 .22489 L
.30285 .22472 L
.30361 .22416 L
.30442 .22334 L
.30567 .2223 L
.30681 .22226 L
.30812 .22379 L
.30936 .22675 L
.3116 .23383 L
.31282 .2372 L
.31397 .23929 L
.31521 .2402 L
.31587 .24018 L
.31658 .23989 L
.31773 .23915 L
.31899 .23862 L
.31974 .23872 L
.32044 .2392 L
.32111 .24003 L
Mistroke
.32183 .2413 L
.32443 .24785 L
.32576 .25099 L
.32643 .25219 L
.32716 .25314 L
.32796 .2537 L
.32871 .25384 L
.32939 .2537 L
.33012 .25339 L
.33081 .25305 L
.33157 .25277 L
.33227 .2527 L
.33293 .25287 L
.33417 .25396 L
.33549 .25616 L
.33778 .26122 L
.33899 .26351 L
.34026 .26508 L
.34093 .26549 L
.34167 .26564 L
.34297 .26535 L
.34361 .26508 L
.34429 .26482 L
.34552 .26469 L
.34672 .26526 L
.34741 .26596 L
.34805 .26684 L
.3508 .27191 L
.35204 .27393 L
.35321 .27518 L
.35386 .27555 L
.35456 .27571 L
.35579 .27549 L
.35703 .27502 L
.35814 .27475 L
.35943 .27501 L
.36064 .276 L
.36177 .2775 L
.3628 .27919 L
.36402 .28121 L
.36513 .28274 L
.36635 .2838 L
.36765 .28415 L
.36886 .2839 L
.37 .28345 L
.37064 .28323 L
.37133 .2831 L
.37255 .28332 L
.37387 .2843 L
.37462 .28517 L
Mistroke
.37533 .28612 L
.3766 .28798 L
.37727 .2889 L
.37798 .28976 L
.37929 .29081 L
.38051 .29111 L
.38129 .291 L
.38203 .29074 L
.38276 .29044 L
.38342 .29017 L
.3847 .2899 L
.38537 .28998 L
.38608 .29026 L
.42403 .30263 L
.42882 .30529 L
.43014 .30629 L
.4308 .30663 L
.43153 .30684 L
.43282 .30675 L
.43404 .30625 L
.4352 .30561 L
.43642 .30503 L
.43746 .3048 L
.4386 .30496 L
.43983 .30557 L
.44115 .30658 L
.44238 .30755 L
.44352 .30822 L
.44421 .30845 L
.44494 .30852 L
.44567 .30842 L
.44647 .30813 L
.44716 .30778 L
.4479 .30734 L
.4486 .30694 L
.44925 .30662 L
.44992 .30638 L
.45064 .30625 L
.45129 .30628 L
.45197 .30646 L
.45327 .30715 L
.45446 .30801 L
.45566 .30885 L
.45693 .30943 L
.45759 .30954 L
.45832 .30951 L
.45959 .30907 L
.46081 .30837 L
.46211 .30761 L
.46321 .30719 L
Mistroke
.46443 .30713 L
.46573 .30756 L
.46695 .30831 L
.46837 .30928 L
.46968 .30992 L
.47085 .3101 L
.47207 .30983 L
.4733 .30919 L
.47465 .30836 L
.47587 .30775 L
.47698 .30752 L
.47827 .30772 L
.47948 .30831 L
.48051 .30898 L
.48161 .30967 L
.48283 .3102 L
.48396 .31031 L
.48464 .31019 L
.48529 .30995 L
.4865 .30928 L
.4879 .30841 L
.48919 .30782 L
.4903 .30766 L
.49149 .30791 L
.49281 .30859 L
.494 .30935 L
.49469 .30976 L
.49541 .3101 L
.4967 .31036 L
.49742 .31029 L
.49809 .31009 L
.49882 .30974 L
.49961 .30927 L
.50029 .30883 L
.50103 .30838 L
.50168 .30804 L
.50237 .30779 L
.50368 .3077 L
.50488 .30806 L
.50609 .30874 L
.5074 .30958 L
.50864 .31017 L
.5098 .31038 L
.51094 .31018 L
.51197 .3097 L
.5131 .30901 L
.51429 .30829 L
.5156 .30778 L
.5168 .30775 L
.51809 .3082 L
Mistroke
.51882 .30862 L
.5195 .30906 L
.52072 .30984 L
.52187 .31036 L
.52251 .31049 L
.5232 .3105 L
.52441 .31017 L
.52554 .30956 L
.5266 .3089 L
.52777 .30827 L
.52902 .30794 L
.53027 .30809 L
.53158 .30872 L
.53271 .30948 L
.53392 .31028 L
.53506 .31079 L
.53609 .31093 L
.53714 .31074 L
.53812 .3103 L
.53925 .30963 L
.54033 .309 L
.54158 .30855 L
.54271 .30852 L
.54386 .30891 L
.5451 .3097 L
.54628 .31057 L
.54734 .31126 L
.54862 .31174 L
.54932 .31178 L
.54998 .31169 L
.55116 .31122 L
.55243 .31049 L
.55368 .30984 L
.55438 .3096 L
.55504 .30951 L
.55574 .30957 L
.55637 .30977 L
.5571 .31014 L
.5578 .31062 L
.55903 .3116 L
.56019 .31247 L
.56139 .31308 L
.56203 .31322 L
.56272 .31321 L
.56389 .31288 L
.56512 .31225 L
.56626 .31163 L
.56732 .31125 L
.5683 .31117 L
.56935 .31146 L
Mistroke
.57051 .31219 L
.57157 .31309 L
.57272 .31411 L
.57394 .31497 L
.57458 .31526 L
.57528 .31542 L
.57651 .31529 L
.57767 .31481 L
.57892 .31416 L
.5801 .31369 L
.58117 .3136 L
.58235 .31396 L
.58345 .31473 L
.58477 .31598 L
.58597 .31715 L
.58716 .31806 L
.58842 .31852 L
.58969 .31842 L
.5904 .31816 L
.59107 .31785 L
.59226 .31728 L
.59339 .31695 L
.5944 .31699 L
.5955 .31749 L
.59669 .3185 L
.59796 .31989 L
.59913 .32116 L
.60023 .32211 L
.60152 .32267 L
.60269 .32265 L
.60395 .3222 L
.60468 .32187 L
.60533 .32159 L
.60653 .32132 L
.60781 .32159 L
.60899 .32243 L
.61011 .32365 L
.61142 .32533 L
.61265 .32677 L
.61393 .32778 L
.61461 .32805 L
.61533 .32813 L
.61612 .32801 L
.61687 .32775 L
.6176 .32744 L
.61828 .32717 L
.61957 .32693 L
.62026 .32704 L
.62098 .32738 L
.63058 .33435 L
Mistroke
.63189 .33393 L
.63312 .33399 L
.6338 .33432 L
.63453 .33493 L
.63582 .33658 L
.63819 .34045 L
.63938 .34205 L
.64069 .34308 L
.64181 .34329 L
.64301 .343 L
.64412 .34257 L
.64518 .34233 L
.64621 .34251 L
.64734 .34335 L
.64837 .3447 L
.64932 .34635 L
.65045 .34854 L
.65167 .35076 L
.65283 .35235 L
.65389 .35316 L
.65513 .35335 L
.65644 .35293 L
.65754 .35251 L
.65875 .35244 L
.66005 .35324 L
.66128 .35498 L
.66239 .35719 L
.66359 .3599 L
.6649 .36261 L
.66556 .3637 L
.66628 .3646 L
.66757 .36532 L
.66877 .36516 L
.66997 .36459 L
.67112 .36421 L
.67214 .36438 L
.67327 .3654 L
.67448 .36755 L
.67578 .37073 L
.67691 .37376 L
.67811 .3766 L
.67878 .37783 L
.67952 .37879 L
.68081 .37942 L
.68154 .37927 L
.68233 .37885 L
.68306 .37836 L
.68374 .37799 L
.68442 .37781 L
.68516 .37796 L
Mistroke
.68582 .37849 L
.68651 .37948 L
.68772 .38221 L
.68905 .38627 L
.69024 .39013 L
.69151 .3935 L
.69217 .39474 L
.69289 .39558 L
.69416 .39581 L
.69537 .39491 L
.69665 .39365 L
.69786 .39315 L
.69897 .39394 L
.70016 .39644 L
.70127 .40018 L
.7026 .40558 L
.70381 .41032 L
.70508 .41389 L
.70628 .41528 L
.70755 .41461 L
.70827 .41351 L
.70894 .41228 L
.71014 .41029 L
.71128 .40967 L
.7123 .41085 L
.7134 .41425 L
.7146 .42013 L
.71587 .42755 L
.71703 .43383 L
.71814 .43791 L
.71944 .4392 L
.72062 .43695 L
.72189 .43199 L
.72255 .42913 L
.72327 .42636 L
.72448 .42405 L
.72576 .42664 L
.72694 .43452 L
.72806 .44597 L
.72939 .46184 L
.73011 .46969 L
.73079 .47535 L
.73199 .47894 L
.73329 .46967 L
.73403 .45726 L
.73472 .44068 L
.73602 .39801 L
.73893 .27132 L
.74009 .2231 L
.74133 .18118 L
Mistroke
.7425 .15436 L
.74357 .14163 L
.74482 .13974 L
.74553 .14362 L
.74619 .14947 L
.74747 .16416 L
.74867 .17798 L
.74981 .18791 L
.75104 .19338 L
.75171 .19399 L
.75241 .1931 L
.75366 .18882 L
.75489 .18356 L
.7562 .17952 L
.75695 .17876 L
.75763 .17926 L
.75832 .18089 L
.75897 .18337 L
.76121 .19571 L
.76243 .2022 L
.76358 .20642 L
.76455 .20815 L
.7656 .20819 L
.76676 .20664 L
.76783 .20468 L
.76905 .203 L
.77018 .20288 L
.77143 .20484 L
.77212 .20684 L
.77275 .20907 L
.77392 .21382 L
.77517 .2188 L
.77636 .22244 L
.77743 .22436 L
.77863 .22487 L
.77976 .22419 L
.7804 .22355 L
.78108 .22287 L
.78231 .22215 L
.78348 .22261 L
.78478 .22474 L
.78544 .22643 L
.78616 .22857 L
.78746 .23278 L
.78867 .23636 L
.7898 .23877 L
.79098 .24005 L
.79227 .24012 L
.79339 .2395 L
.7944 .23888 L
Mistroke
.79558 .23863 L
.79668 .23925 L
.79789 .24104 L
.79921 .24408 L
.8005 .24752 L
.80121 .24933 L
.80188 .25085 L
.80317 .25294 L
.80436 .25377 L
.80547 .25374 L
.80667 .25321 L
.80741 .25288 L
.8081 .2527 L
.8094 .25302 L
.81012 .25366 L
.81079 .25456 L
.81152 .25585 L
.81229 .25745 L
.81358 .26035 L
.81425 .2618 L
.81497 .26317 L
.81629 .26494 L
.8175 .26561 L
.81872 .2655 L
.81987 .26505 L
.82113 .26468 L
.82183 .26471 L
.82248 .26496 L
.82353 .26588 L
.82469 .26755 L
.82701 .27193 L
.8277 .27313 L
.82835 .27409 L
.82956 .2753 L
.83087 .27571 L
.8316 .27561 L
.83228 .27539 L
.83351 .27492 L
.83466 .27474 L
.83586 .27515 L
.83718 .27642 L
.84597 .28353 L
.84712 .28316 L
.84836 .28318 L
.84953 .28381 L
.8506 .2849 L
.85294 .2882 L
.85359 .28907 L
.85428 .28987 L
.85553 .29083 L
Mistroke
.85679 .2911 L
.85751 .29099 L
.85817 .29077 L
.8595 .29021 L
.86025 .28998 L
.86095 .2899 L
.8622 .29022 L
.86283 .29063 L
.86353 .29126 L
.86597 .29424 L
.86723 .29563 L
.86843 .29646 L
.86909 .29667 L
.86981 .2967 L
.87108 .29635 L
.87228 .29581 L
.87356 .29537 L
.87477 .29538 L
.87586 .29586 L
.88488 .30031 L
.8861 .29975 L
.88726 .29949 L
.8879 .29954 L
.8886 .29975 L
.88981 .30053 L
.89204 .30267 L
.89326 .30372 L
.89441 .30431 L
.89559 .30443 L
.8969 .30405 L
.898 .30349 L
.89919 .30291 L
.89983 .3027 L
.90053 .3026 L
.90126 .30267 L
.90193 .3029 L
.90315 .30366 L
.90444 .30479 L
.90564 .30581 L
.90693 .30661 L
.90816 .30687 L
.90928 .30667 L
.9103 .30622 L
.91141 .30559 L
.91258 .30504 L
.91367 .3048 L
.91496 .30501 L
.91569 .30537 L
.91637 .30581 L
.91771 .30688 L
Mistroke
.91892 .30779 L
.92012 .30838 L
.92124 .30852 L
.92243 .30823 L
.92372 .30757 L
.9244 .30716 L
.92513 .30676 L
.92645 .3063 L
.92717 .30625 L
.92783 .30635 L
.9286 .30665 L
.92934 .30707 L
.93062 .30799 L
.93133 .30851 L
.932 .30894 L
.93331 .30948 L
.9345 .30951 L
.93564 .30913 L
.9367 .30855 L
.93794 .3078 L
.93911 .30727 L
.9404 .30711 L
.94157 .3074 L
.94283 .3081 L
.94419 .30904 L
.94543 .30975 L
.94613 .31 L
.94679 .3101 L
.94749 .31005 L
.94812 .30988 L
.94885 .30956 L
.94954 .30917 L
.95068 .30845 L
.9519 .30781 L
.95253 .30761 L
.95323 .30752 L
.95447 .30773 L
.96334 .30887 L
.9646 .30813 L
.96577 .30772 L
.96699 .30771 L
.96764 .30789 L
.96833 .3082 L
.96956 .30894 L
.97072 .30967 L
.97177 .31016 L
.9729 .31036 L
.97373 .31026 L
.97461 .30994 L
.97536 .30954 L
Mistroke
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
WooonfX4o`0007[ooo]Z1Ol00020oookJPCo0000V_oonfX009oooo]Z1Ol0001ioookJPGo0000Oooo
nfX5o`0009[ooo]Z002OoookJPGo0000NOoonfX5o`0007oooo]Z1Ol0002JoookJP00WooonfX5o`00
07Wooo]Z1Ol0001ooookJPGo0000V_oonfX009oooo]Z1Ol0001ioookJPGo0000OooonfX5o`0009[o
oo]Z002NoookJPOo0000JooonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1ol0
001[oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX7o`0006_ooo]Z0ol007l:
oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPOo0000FooonfX:o`00O`Kooo]Z0ol007l:oook
JPGo0000O_oonfX6o`0009[ooo]Z002NoookJPOo0000FooonfX:o`00O`Kooo]Z0ol007l:oookJPKo
0000OOoonfX6o`0009[ooo]Z002NoookJPOo0000JooonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000
V_oonfX009kooo]Z1ol0001[oookJP?o001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX7
o`0006_ooo]Z0ol007l:oookJPGo0000O_oonfX7o`0009Wooo]Z002NoookJPOo0000JooonfX3o`00
O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1ol0001XoookJPKo001o2_oonfX5o`0007ko
oo]Z1ol0002IoookJP00W_oonfX7o`0006Sooo]Z1_l007l:oookJPGo0000O_oonfX7o`0009Wooo]Z
002NoookJPOo0000J_oonfX4o`00O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1ol0001[
oookJP?o001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX8o`0007Oooo]Z1Ol0001noook
JPSo0000V?oonfX009kooo]Z2?l0001goookJPGo0000O_oonfX8o`0009Sooo]Z002NoookJPSo0000
MooonfX5o`0007kooo]Z2?l0002HoookJP00W_oonfX<o`0007?ooo]Z1Ol0001noookJPco0000U?oo
nfX009kooo]Z3?l0001coookJPGo0000O_oonfX=o`0009?ooo]Z002NoookJPgo0000L_oonfX5o`00
07kooo]Z3Ol0002CoookJP00W_oonfX=o`0007;ooo]Z1Ol0001noookJPgo0000TooonfX009kooo]Z
3_l0001aoookJPGo0000O_oonfX=o`0009?ooo]Z002NoookJPko0000LOoonfX5o`0007kooo]Z3Ol0
002CoookJP00W_oonfX>o`00077ooo]Z1Ol0001noookJPko0000T_oonfX009kooo]Z3_l0001aoook
JPGo0000O_oonfX>o`0009;ooo]Z002NoookJPCo000000?ooo]Zo`000?l000001ol0001aoookJPGo
0000O_oonfX>o`0009;ooo]Z002NoookJPCo000000?ooo]Zo`000?l000001ol0001aoookJPGo0000
O_oonfX?o`00097ooo]Z002MoookJPGo000000?ooo]Zo`000?l000001ol0001aoookJPGo0000O_oo
nfX4o`000003oookJ_l0003o000000So0000TOoonfX009gooo]Z1Ol000000ooonf[o0000o`000008
o`00073ooo]Z1Ol0001noookJPCo000000?ooo]Zo`000?l000002?l0002AoookJP00WOoonfX5o`00
0003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000ol0001`oookJPGo0000O_oonfX4o`00
0003oookJ_l0003o000000;o00000_oonfX4o`00097ooo]Z002MoookJPCo00001ooonfX9o`0006co
oo]Z1Ol0001noookJPCo00001ooonfX4o`00097ooo]Z002MoookJPCo00002?oonfX9o`0006_ooo]Z
1Ol0001moookJPGo00001ooonfX8o`0008gooo]Z002MoookJPCo00002?oonfX9o`0006_ooo]Z1Ol0
001moookJPGo00001ooonfX9o`0008cooo]Z002MoookJPCo00002?oonfX:o`0006[ooo]Z1Ol0001m
oookJPGo00001ooonfX9o`0008cooo]Z002MoookJPCo00002?oonfX:o`0006[ooo]Z1Ol0001moook
JPCo00002?oonfX:o`0008_ooo]Z002MoookJPCo00002OoonfX9o`0006[ooo]Z1Ol0001moookJPCo
00002OoonfX9o`0008_ooo]Z002MoookJPCo00002OoonfX9o`0006[ooo]Z1Ol0001moookJPCo0000
2OoonfX9o`0008_ooo]Z002MoookJPCo00003_oonfX5o`0006Wooo]Z1Ol0001moookJPCo00003_oo
nfX4o`0008_ooo]Z002MoookJPCo00003_oonfX5o`0006Wooo]Z1Ol0001moookJPCo00003_oonfX5
o`0008[ooo]Z002MoookJPCo00003_oonfX5o`0006Wooo]Z1Ol0001moookJPCo00003_oonfX5o`00
08[ooo]Z002MoookJPCo00003ooonfX4o`0006Wooo]Z1Ol0001moookJPCo00003_oonfX5o`0008[o
oo]Z002MoookJPCo00003ooonfX8o`0006Gooo]Z1Ol0001moookJPCo00003ooonfX9o`0008Gooo]Z
002MoookJPCo00003ooonfX9o`0006Cooo]Z1Ol0001moookJPCo00003ooonfX9o`0008Gooo]Z002M
oookJPCo00003ooonfX:o`0004Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001m
oookJPCo00003ooonfX:o`0008Cooo]Z002MoookJPCo00004?oonfX9o`0004Cooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001moookJPCo00004?oonfX9o`0008Cooo]Z002MoookJPCo
00004?oonfX9o`0004Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000OOoonfX4o`00013ooo]Z2Ol00024
oookJP00WOoonfX4o`0001Gooo]Z1Ol0000foookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001moookJPCo00005OoonfX5o`0008?ooo]Z002MoookJPCo
00005OoonfX5o`0003Kooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo
0000O?oonfX4o`0001Gooo]Z1Ol00023oookJP00WOoonfX4o`0001Gooo]Z1Ol00012oookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000OOoonfX4o`0001Gooo]Z1Ol00023oookJP00WOoo
nfX4o`0001Kooo]Z1Ol00011oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oo
nfX5o`0007gooo]Z1?l0000FoookJPCo0000PooonfX009gooo]Z1?l0000FoookJPWo0000?OoonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`0007gooo]Z1?l0000FoookJPWo0000O_oonfX0
09gooo]Z1?l0000FoookJPWo0000?OoonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`00
07gooo]Z1?l0000FoookJPWo0000O_oonfX009gooo]Z1?l0000GoookJPSo0000?OoonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o3_oonfX5o`0007gooo]Z1?l0000FoookJPWo0000O_oonfX009gooo]Z
1?l0000GoookJPWo0000?OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo
0000OOoonfX4o`0001Oooo]Z2Ol0001moookJP00WOoonfX4o`0001Sooo]Z2?l0000moookJPOo001o
2OoonfX7o`00O`Sooo]Z1Ol0001moookJPCo00006?oonfX8o`0007gooo]Z002MoookJPCo00006ooo
nfX6o`0003gooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0007cooo]Z1Ol0000KoookJPKo0000O?oo
nfX009gooo]Z1?l0000LoookJPGo0000FooonfX5o`0007cooo]Z1Ol0000LoookJPGo0000O?oonfX0
09gooo]Z1?l0000LoookJPKo0000F_oonfX5o`0007cooo]Z1Ol0000LoookJPKo0000NooonfX009go
oo]Z1?l0000MoookJPWo0000E_oonfX5o`0007cooo]Z1?l0000NoookJPWo0000MooonfX009gooo]Z
1?l0000MoookJP[o0000EOoonfX5o`0007cooo]Z1?l0000NoookJP[o0000M_oonfX009gooo]Z1?l0
000NoookJPWo0000EOoonfX5o`0007cooo]Z1?l0000OoookJPWo0000M_oonfX009gooo]Z1?l0000N
oookJP[o0000E?oonfX5o`0007cooo]Z1?l0000OoookJPWo0000M_oonfX009gooo]Z1?l0000Soook
JPGo0000E?oonfX5o`0007cooo]Z1?l0000SoookJPKo0000MOoonfX009gooo]Z1?l0000SoookJPKo
0000DooonfX5o`0007cooo]Z1?l0000ToookJPKo0000M?oonfX009gooo]Z1?l0000ToookJPWo0000
CooonfX5o`0007cooo]Z1?l0000ToookJP[o0000L?oonfX009gooo]Z1?l0000ToookJP[o0000C_oo
nfX5o`0007cooo]Z1?l0000UoookJPWo0000L?oonfX009gooo]Z1?l0000UoookJPWo0000C_oonfX5
o`0007cooo]Z1?l0000VoookJPWo0000KooonfX009gooo]Z1?l0000UoookJP[o0000COoonfX5o`00
07cooo]Z1?l0000VoookJPWo0000KooonfX002;ooo]Z0ol007meoookJP?o001o1?l00002oookJP?o
001o0ooonfX5o`00OaWooo]Z2Ol0001=oookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPGo
001o7ooonfX9o`0004kooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z1?l007l4o`0000;ooo]Z
0ol007l2oookJPOo001o7?oonfX9o`0004Wooo]Z1Ol0001coookJPOo001o0_oonfX4o`0000;ooo]Z
1ol007lRoookJPWo0000B_oonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`03oookJ_l0
003o000000;o00000_oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
7OoonfX9o`0004Sooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`000003
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o8_oonfX;o`0004Sooo]Z0ol007lMoook
JP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1?l00006oookJP?o
001o0ooonfX3o`00Oacooo]Z2_l00017oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o
0000o`000002o`000004oookJ_l007oo001oo`00O`?ooo]Z0ol007lRoookJP_o0000AooonfX3o`00
Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o0_oonfX4o`0000co
oo]Z0ol007lMoookJP[o0000A_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l0
00000_l00007oookJP?o001o8ooonfX;o`0004Kooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z
0ol007l2oookJPCo00003?oonfX3o`00Oagooo]Z2_l00016oookJPGo0000L_oonfX3o`00O`?ooo]Z
0ol007l00ooonf[o0000o`000002o`0000Oooo]Z0ol007lToookJP_o0000AOoonfX3o`00Oagooo]Z
000RoookJP?o001oLooonfX3o`00O`;ooo]Z1?l00007oookJP;o001o0_oonfX4o`00Ob;ooo]Z2_l0
0011oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l0
07l2oookJPCo001o:OoonfX9o`0004;ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l0
0ooonf[o0000o`000003o`0000Oooo]Z1ol007lToookJP[o0000@?oonfX5o`0007;ooo]Z0ol007l3
oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJPOo001o:ooonfX9o`00047ooo]Z0ol007lM
oookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000003o`0000Oooo]Z1_l007lUoook
JP[o0000@?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oook
JPKo001o;OoonfX8o`00047ooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l00ooonf[o
0000o`000003o`0000Oooo]Z0_l007lZoookJP[o0000?ooonfX5o`0007;ooo]Z0ol007l3oookJP?o
001o00?ooo]Zo`000?l000000_l00002oookJP;o001o<_oonfX9o`0003cooo]Z1_l007lMoookJP00
7ooonfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z0_l007l[oookJQ3o0000>?oonfX5o`0007?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l2oookJPCo00000_oonfX2o`00OcGooo]Z2ol0000goookJPKo
001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o1?l00009oookJPOo001o:OoonfX?o`0003Gooo]Z
1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z1ol007l_oookJP_o0000>OoonfX4o`00Oagooo]Z
000RoookJP?o001oMOoonfX2o`00O`Co00002OoonfX7o`00Ob[ooo]Z4Ol0000boookJPGo0000M?oo
nfX5o`00O`?ooo]Z1?l00003oookJPOo001o<?oonfX;o`0003Wooo]Z0ol007lMoookJP00W?oonfX4
o`0003_ooo]Z4ol0000_oookJPGo0000O?oonfX4o`0003_ooo]Z4Ol0001BoookJP00W?oonfX4o`00
04;ooo]Z3ol0000/oookJPGo0000O?oonfX4o`00043ooo]Z3ol0001?oookJP00W?oonfX4o`0004Go
oo]Z3ol0000YoookJPGo0000O?oonfX4o`00047ooo]Z4Ol0001<oookJP00W?oonfX4o`0004Sooo]Z
3ol0000VoookJPGo0000O?oonfX4o`0004;ooo]Z4?l0001<oookJP00W?oonfX4o`0004_ooo]Z3_l0
000ToookJPGo0000O?oonfX4o`0004Wooo]Z4?l00015oookJP00W?oonfX4o`0004kooo]Z4_l0000M
oookJPGo0000O?oonfX4o`0004cooo]Z5Ol0000moookJP003_oonf[oo`000?oo00009Ol0000?oook
JP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oo
nf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP007OoonfX00ol0
003ooo]ZoookJP05o`0000;ooo]Z1Ol000000ooonf[o0000o`00000So`0004[ooo]Z1?l0001]oook
JPCo00000ooonfX5o`0000;ooo]Z3?l00002oookJPGo000000?ooo]Zo`000?l000008ol0001:oook
JPCo0000KOoonfX5o`0000Wooo]Z1Ol0000NoookJP00=_oonfX4o`000003oookJ_l0003o000001Ko
0000BOoonfX4o`0007gooo]Z1Ol0000EoookJPGo00000_oonfXGo`0004Wooo]Z1?l0002NoookJP00
@_oonfXBo`0004Sooo]Z1?l0001moookJPGo00008_oonfXBo`0004Sooo]Z1?l0002NoookJP00A?oo
nfX4o`000003oookJ_l0003o000000oo0000@_oonfX4o`0007gooo]Z1Ol0000ToookJPCo000000?o
oo]Zo`000?l000003ol00012oookJPCo0000W_oonfX004[ooo]Z4?l00012oookJPCo0000OOoonfX5
o`0002[ooo]Z4Ol00011oookJPCo0000W_oonfX0053ooo]Z3?l00010oookJPCo0000OOoonfX5o`00
033ooo]Z2ol00011oookJPCo0000W_oonfX0057ooo]Z4Ol0000joookJPCo0000OOoonfX5o`00037o
oo]Z4Ol0000joookJPCo0000W_oonfX005Kooo]Z3Ol0000ioookJPCo0000OOoonfX5o`0003Oooo]Z
3?l0000ioookJPCo0000W_oonfX005Oooo]Z3Ol0000hoookJPCo0000OOoonfX5o`0003Oooo]Z3Ol0
000hoookJPCo0000W_oonfX005Sooo]Z3Ol0000goookJPCo0000OOoonfX5o`0003Sooo]Z3Ol0000g
oookJPCo0000W_oonfX005oooo]Z2?l0000eoookJPCo0000OOoonfX5o`0003oooo]Z2Ol0000doook
JPCo0000W_oonfX0063ooo]Z2?l0000doookJPCo0000OOoonfX5o`00043ooo]Z2Ol0000boookJPGo
0000W_oonfX0067ooo]Z2?l0000coookJPCo0000OOoonfX5o`00047ooo]Z2?l0000boookJPGo0000
W_oonfX006;ooo]Z2?l0000boookJPCo0000OOoonfX5o`0004;ooo]Z2?l0000aoookJPGo0000W_oo
nfX006Cooo]Z2_l0000^oookJPCo0000OOoonfX5o`0004Gooo]Z2Ol0000]oookJPCo0000WooonfX0
06Gooo]Z2_l0000]oookJPCo0000OOoonfX5o`0004Gooo]Z2_l0000/oookJPCo0000WooonfX006Ko
oo]Z2Ol0000]oookJPCo0000OOoonfX5o`0004Kooo]Z2_l0000[oookJPCo0000WooonfX006Oooo]Z
2Ol0000/oookJPCo0000OOoonfX5o`0004Oooo]Z2_l0000ZoookJPCo0000WooonfX006Sooo]Z2Ol0
000[oookJPCo0000OOoonfX5o`0004Sooo]Z2Ol0000ZoookJPCo0000WooonfX006_ooo]Z1_l0000[
oookJPCo0000OOoonfX5o`0004cooo]Z1Ol0000ZoookJPCo0000WooonfX006cooo]Z2_l0000Voook
JPCo0000OOoonfX5o`0004gooo]Z2Ol0000UoookJPCo0000WooonfX006gooo]Z2Ol0000VoookJPCo
0000OOoonfX5o`0004gooo]Z2Ol0000UoookJPCo0000WooonfX006gooo]Z2_l0000UoookJPCo0000
OOoonfX5o`0004gooo]Z2_l0000ToookJPCo0000WooonfX006kooo]Z2Ol0000UoookJPCo0000OOoo
nfX5o`0004kooo]Z2Ol0000ToookJPCo0000WooonfX007;ooo]Z1_l0000ToookJPCo0000OOoonfX5
o`0005;ooo]Z1_l0000SoookJPCo0000WooonfX007?ooo]Z1Ol0000ToookJPCo0000OOoonfX5o`00
05?ooo]Z1Ol0000SoookJPCo0000WooonfX007?ooo]Z2_l0000OoookJPCo0000OOoonfX5o`0005?o
oo]Z2Ol0000OoookJPCo0000WooonfX007Cooo]Z2Ol0000OoookJPCo0000OOoonfX5o`0005Cooo]Z
2Ol0000NoookJPCo0000WooonfX007Cooo]Z2Ol0000NoookJPGo0000OOoonfX5o`0005Cooo]Z2_l0
000MoookJPCo0000WooonfX007Gooo]Z2Ol0000MoookJPGo0000OOoonfX5o`0005Gooo]Z2Ol0000M
oookJPCo0000WooonfX007Kooo]Z2?l0000MoookJPGo0000OOoonfX5o`0005Kooo]Z2?l0000Moook
JPCo0000WooonfX007Wooo]Z1_l0000LoookJPCo0000O_oonfX5o`0005[ooo]Z1Ol0000LoookJPCo
0000WooonfX007[ooo]Z1Ol0000LoookJPCo0000O_oonfX5o`0005[ooo]Z1Ol0000LoookJPCo0000
WooonfX007[ooo]Z2Ol0000HoookJPCo0000O_oonfX5o`0005[ooo]Z2Ol0000HoookJPCo0000Wooo
nfX007_ooo]Z2Ol0000GoookJPCo0000O_oonfX5o`0005_ooo]Z2Ol0000GoookJPCo0000WooonfX0
07_ooo]Z2Ol0000GoookJPCo0000H?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`00
05_ooo]Z2Ol0000GoookJPCo0000WooonfX007cooo]Z2Ol0000FoookJPCo0000GooonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o2OoonfX5o`0005cooo]Z2Ol0000FoookJPCo0000WooonfX007cooo]Z
2Ol0000FoookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001LoookJPWo00005_oonfX4o`00
09oooo]Z0020oookJPGo00005_oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l8oookJPGo0000H?oonfX5o`0001Kooo]Z1?l0002OoookJP00POoonfX5o`0001Gooo]Z
1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000H?oonfX4o`0001Kooo]Z
1?l0002OoookJP00POoonfX5o`0001Gooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l8oookJPGo0000HOoonfX5o`0001Gooo]Z1?l0002OoookJP00POoonfX5o`0001Gooo]Z1?l0001N
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`00067ooo]Z1Ol0000E
oookJPCo0000WooonfX008;ooo]Z2Ol0000@oookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o2OoonfX5o`00067ooo]Z2_l0000@oookJPCo0000WooonfX008;ooo]Z2Ol0000@oookJPCo
0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0006;ooo]Z2Ol0000@oookJPCo
0000WooonfX008;ooo]Z2_l0000?oookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
3_oonfX5o`0006;ooo]Z2Ol0000@oookJPCo0000WooonfX008?ooo]Z2Ol0000?oookJPCo0000Gooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000HooonfX9o`0000oooo]Z
1?l0002OoookJP00Q?oonfX9o`0000kooo]Z1?l0001OoookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0
001ToookJPSo00003ooonfX4o`0009oooo]Z0028oookJPGo00003_oonfX4o`00063ooo]Z1Ol007l:
oookJPOo001o2?oonfX5o`0006Oooo]Z1_l0000>oookJPCo0000WooonfX008Sooo]Z1_l0000=oook
JPCo0000O_oonfX5o`0006Sooo]Z1Ol0000>oookJPCo0000WooonfX008Wooo]Z1Ol0000=oookJPCo
0000O_oonfX5o`0006Sooo]Z1Ol0000>oookJPCo0000WooonfX008Wooo]Z1Ol0000=oookJPCo0000
O_oonfX5o`0006Wooo]Z1?l0000>oookJPCo0000WooonfX008[ooo]Z1Ol0000<oookJPCo0000O_oo
nfX5o`0006Wooo]Z2Ol00009oookJPCo0000WooonfX008[ooo]Z1Ol0000<oookJPCo0000O_oonfX5
o`0006Wooo]Z2Ol00009oookJPCo0000WooonfX008[ooo]Z1_l0000;oookJPCo0000O_oonfX5o`00
06Wooo]Z2_l00008oookJPCo0000WooonfX008_ooo]Z1Ol0000;oookJPCo0000O_oonfX5o`0006Wo
oo]Z2_l00008oookJPCo0000WooonfX008_ooo]Z1_l0000:oookJPCo0000O_oonfX5o`0006Wooo]Z
2_l00008oookJPCo0000WooonfX008cooo]Z1Ol0000:oookJPCo0000O_oonfX5o`0006[ooo]Z2Ol0
0007oookJPGo0000WooonfX008cooo]Z1Ol0000:oookJPCo0000O_oonfX5o`0006_ooo]Z2?l00007
oookJPGo0000WooonfX008gooo]Z1Ol00003oookJPCo00000_oonfX4o`0007kooo]Z1Ol0001_oook
JPCo00000_oonfX4o`000003oookJ_l0003o000000?o0000WooonfX008gooo]Z1Ol00003oookJPCo
00000_oonfX4o`0007kooo]Z1Ol0001_oookJPGo000000?ooo]Zo`000?l000000_l000000ooonf[o
0000o`000002o`000:3ooo]Z002=oookJPKo000000?ooo]Zo`000?l000000ol00002oookJPCo0000
O_oonfX5o`0006oooo]Z2_l000000ooonf[o0000o`000002o`000:3ooo]Z002>oookJPGo000000?o
oo]Zo`000?l000000ol00002oookJPCo0000O_oonfX5o`0006oooo]Z2_l000000ooonf[o0000o`00
0002o`000:3ooo]Z002>oookJQ7o0000O_oonfX5o`00073ooo]Z2Ol000000ooonf[o0000o`000002
o`000:3ooo]Z002?oookJQ3o0000O_oonfX5o`00073ooo]Z3_l0002PoookJP00SooonfX@o`0007ko
oo]Z1Ol0001`oookJPko0000X?oonfX0093ooo]Z3_l0001ooookJPGo0000L?oonfX>o`000:3ooo]Z
002@oookJPko0000OooonfX5o`00077ooo]Z3Ol0002PoookJP00T?oonfX>o`0007oooo]Z1Ol0001a
oookJPgo0000X?oonfX0097ooo]Z3Ol0001ooookJPGo0000LOoonfX=o`000:3ooo]Z002AoookJPgo
0000OooonfX5o`00077ooo]Z3Ol0002PoookJP00T_oonfX<o`0007oooo]Z1Ol0001boookJPco0000
X?oonfX009Kooo]Z2?l0001ooookJPGo0000MooonfX7o`000:3ooo]Z002FoookJPSo0000OooonfX5
o`0007Oooo]Z1ol0002PoookJP00U_oonfX8o`0007oooo]Z1Ol0001goookJPOo0000X?oonfX009Oo
oo]Z1ol0001ooookJPGo0000MooonfX7o`000:3ooo]Z002GoookJPOo0000OooonfX5o`0007Oooo]Z
1ol0002PoookJP00UooonfX7o`0007oooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0001b
oookJP?o001o2_oonfX5o`0007Oooo]Z1ol0002PoookJP00UooonfX7o`0007;ooo]Z0ol007l:oook
JPGo0000MooonfX7o`000:3ooo]Z002GoookJPOo0000L_oonfX3o`00O`[ooo]Z1Ol0001goookJPOo
0000X?oonfX009Oooo]Z1ol0001boookJP?o001o2_oonfX5o`0007Oooo]Z1ol0002PoookJP00Uooo
nfX7o`0007;ooo]Z0ol007l:oookJPKo0000M_oonfX7o`000:3ooo]Z002GoookJPOo0000L_oonfX3
o`00O`[ooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0001boookJP?o001o2_oonfX5o`00
07Oooo]Z1_l0002QoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000MooonfX6o`000:7o
oo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPGo0000XOoonfX009Sooo]Z1_l0
001_oookJPKo001o2_oonfX5o`0007Sooo]Z1Ol0002QoookJP00V?oonfX6o`0006oooo]Z1_l007l:
oookJPGo0000N?oonfX5o`000:7ooo]Z002HoookJPGo0000L_oonfX4o`00O`[ooo]Z1Ol0001hoook
JPGo0000XOoonfX009Sooo]Z1Ol0001coookJP?o001o2_oonfX5o`0007Sooo]Z1Ol0002QoookJP00
V?oonfX5o`00083ooo]Z1Ol0001hoookJPGo0000XOoonfX00?oooo]Z7_oonfX5o`0007Wooo]Z1?l0
002QoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo
0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol0
07l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8
oookJPKo0000oooonfXNoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooook
JQoooo]Z003ooookJP;ooo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Wooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>
oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoook
JP00oooonfX1oookJPCo001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z
2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z3_oonfX4o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oook
JPKo0000oooonfXNoookJP00oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4_oonfX3o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003o
oookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00
Oooooo]Z;?oonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z
1ol007oooookJRgooo]Z003ooookJPoooo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30974 L
.02605 .31019 L
.02729 .31031 L
.02846 .31 L
.02954 .30942 L
.03053 .30878 L
.03162 .30815 L
.03279 .30776 L
.03396 .30778 L
.03506 .30817 L
.03636 .30895 L
.03756 .3097 L
.0388 .31025 L
.0395 .31037 L
.04015 .31035 L
.04135 .30997 L
.04262 .30925 L
.04387 .30847 L
.04519 .30792 L
.04588 .30782 L
.04664 .30789 L
.04733 .3081 L
.04797 .30842 L
.04933 .30929 L
.05061 .31009 L
.05176 .31054 L
.05302 .31057 L
.05416 .31019 L
.05538 .30949 L
.05643 .30885 L
.05757 .30833 L
.05876 .30816 L
.05989 .30842 L
.06054 .30874 L
.06122 .30917 L
.06244 .31004 L
.0631 .31047 L
.0638 .31085 L
.06509 .31118 L
.06633 .311 L
.06748 .31047 L
.06884 .30967 L
.0701 .30906 L
.07142 .30887 L
.07212 .30901 L
.07287 .30933 L
.07411 .31015 L
.07547 .31118 L
.07675 .31194 L
Mistroke
.07794 .31223 L
.07911 .31206 L
.08018 .31159 L
.08132 .31093 L
.08257 .31032 L
.08328 .31013 L
.08395 .31009 L
.08465 .31022 L
.08541 .31055 L
.08611 .311 L
.08678 .31151 L
.08802 .31256 L
.08873 .31309 L
.08949 .31354 L
.09013 .31378 L
.09084 .31389 L
.0916 .31381 L
.09243 .31354 L
.0932 .31316 L
.09391 .31276 L
.0952 .31216 L
.0964 .31195 L
.09771 .3123 L
.09844 .31275 L
.09911 .31328 L
.10046 .31452 L
.10117 .31515 L
.10193 .31571 L
.10258 .31606 L
.10331 .31628 L
.10458 .31621 L
.10588 .31568 L
.10708 .31507 L
.10841 .31463 L
.10907 .3146 L
.10981 .31476 L
.11104 .31548 L
.11173 .31609 L
.11237 .31672 L
.11361 .31801 L
.11477 .319 L
.11581 .31953 L
.11693 .31964 L
.11817 .3193 L
.1193 .31877 L
.12047 .31829 L
.12175 .31817 L
.12295 .31863 L
.12407 .31955 L
.12639 .32219 L
Mistroke
.1277 .3234 L
.1289 .32398 L
.12957 .32406 L
.13031 .32395 L
.131 .32372 L
.13164 .32344 L
.13289 .32292 L
.13359 .32277 L
.13422 .32277 L
.13489 .32294 L
.1356 .32335 L
.13688 .32457 L
.13837 .32649 L
.13909 .32743 L
.13976 .32821 L
.14096 .32923 L
.14224 .32966 L
.14291 .32961 L
.14364 .32941 L
.14433 .32914 L
.14497 .32887 L
.14615 .32854 L
.14739 .32872 L
.14845 .32943 L
.14961 .33076 L
.15203 .3343 L
.15272 .33518 L
.15338 .33584 L
.15461 .33654 L
.15578 .33657 L
.15686 .33623 L
.15802 .33579 L
.15929 .33564 L
.16039 .33607 L
.16141 .33704 L
.16249 .33856 L
.16365 .34053 L
.16493 .34265 L
.16563 .34362 L
.1663 .34432 L
.16708 .34486 L
.16779 .34507 L
.16846 .34506 L
.16918 .34488 L
.16987 .34461 L
.17051 .34437 L
.17118 .34419 L
.17191 .34418 L
.17312 .34476 L
.17442 .34631 L
Mistroke
.17707 .35131 L
.17837 .35351 L
.17957 .35479 L
.18066 .35521 L
.18182 .35503 L
.18298 .35455 L
.18426 .35425 L
.18555 .35474 L
.18674 .35616 L
.18805 .35867 L
.18945 .36189 L
.19009 .36331 L
.19078 .36468 L
.19204 .36646 L
.19326 .36715 L
.19439 .367 L
.1955 .36647 L
.19654 .36606 L
.19767 .36618 L
.19889 .36733 L
.20017 .36976 L
.20139 .37289 L
.20256 .37608 L
.20366 .37865 L
.20485 .3805 L
.20618 .38115 L
.20746 .38066 L
.20819 .38017 L
.20885 .37975 L
.20997 .3795 L
.21119 .38036 L
.21247 .38279 L
.21366 .38622 L
.21495 .39052 L
.21564 .39266 L
.21636 .39461 L
.21699 .39594 L
.21769 .39693 L
.21891 .3974 L
.21965 .39703 L
.22043 .39629 L
.22116 .39551 L
.22186 .3949 L
.22253 .39461 L
.22326 .39479 L
.22453 .39669 L
.22709 .40581 L
.22844 .41128 L
.22912 .41353 L
.22986 .41535 L
Mistroke
.23051 .41627 L
.23121 .41655 L
.23247 .41539 L
.23373 .41307 L
.23487 .41122 L
.23607 .4109 L
.23718 .41288 L
.23839 .4177 L
.23968 .42495 L
.24073 .43116 L
.24185 .43669 L
.24308 .43988 L
.24424 .43941 L
.24556 .43524 L
.24679 .42977 L
.24748 .42702 L
.24813 .42525 L
.24889 .42471 L
.24957 .42598 L
.25026 .42909 L
.25098 .43439 L
.25227 .44805 L
.25368 .46513 L
.25447 .47316 L
.25519 .47797 L
.25646 .47744 L
.25766 .46313 L
.25876 .4368 L
.25997 .39493 L
.26249 .28167 L
.26382 .22402 L
.26454 .19719 L
.26522 .17631 L
.26642 .1504 L
.26774 .139 L
.26886 .1413 L
.27005 .152 L
.27223 .17783 L
.27346 .18837 L
.2746 .19295 L
.27524 .19332 L
.27595 .19216 L
.27669 .18965 L
.27739 .18664 L
.27809 .18347 L
.27876 .18082 L
.28002 .17804 L
.28116 .17885 L
.2824 .18328 L
.28304 .18665 L
Mistroke
.28373 .19067 L
.28496 .19794 L
.28565 .20146 L
.28638 .20437 L
.28768 .20709 L
.28841 .20722 L
.28909 .20663 L
.28983 .20544 L
.29063 .2039 L
.29132 .20267 L
.29207 .20175 L
.29277 .20149 L
.29343 .20189 L
.29466 .20441 L
.29597 .2091 L
.29709 .21379 L
.29826 .21837 L
.29954 .22191 L
.30072 .22334 L
.30201 .2231 L
.30274 .22243 L
.30342 .2217 L
.30465 .22071 L
.30596 .22095 L
.30719 .22283 L
.30789 .22457 L
.30855 .22652 L
.30998 .23125 L
.31129 .23511 L
.3125 .23752 L
.31366 .23849 L
.31488 .23832 L
.31556 .23791 L
.3162 .23747 L
.3169 .23707 L
.31766 .23689 L
.31837 .23707 L
.31903 .23761 L
.32027 .23963 L
.32158 .24284 L
.3229 .24644 L
.32363 .24825 L
.32431 .2497 L
.32512 .25099 L
.32586 .2517 L
.32656 .252 L
.32731 .25197 L
.32856 .25144 L
.32973 .25094 L
.33101 .25102 L
Mistroke
.33173 .25153 L
.33239 .25232 L
.33371 .25471 L
.33516 .25799 L
.33653 .26095 L
.33778 .26284 L
.33903 .26371 L
.34021 .26369 L
.34145 .26322 L
.3421 .26297 L
.3428 .26282 L
.34398 .26308 L
.34523 .26424 L
.34638 .26605 L
.34746 .26815 L
.34872 .27059 L
.34941 .27175 L
.35006 .27264 L
.3512 .27362 L
.35246 .27387 L
.35312 .27373 L
.35382 .27347 L
.35508 .27303 L
.35577 .27294 L
.35642 .27305 L
.35714 .27341 L
.3579 .2741 L
.36779 .28151 L
.37248 .28474 L
.37372 .2866 L
.3744 .28754 L
.37504 .28829 L
.3763 .28926 L
.37744 .2895 L
.37849 .28929 L
.37947 .2889 L
.38054 .2885 L
.38168 .28839 L
.38294 .28886 L
.38413 .28991 L
.38519 .29121 L
.38635 .29274 L
.38758 .29416 L
.38828 .29474 L
.38894 .2951 L
.39026 .29526 L
.391 .29508 L
.39168 .29482 L
.39288 .29429 L
.39419 .29398 L
Mistroke
.39543 .29423 L
.39658 .29501 L
.39791 .29641 L
.39935 .29808 L
.40002 .29874 L
.40071 .29931 L
.40196 .29985 L
.40326 .29977 L
.40399 .29951 L
.40468 .29919 L
.40542 .29883 L
.40612 .29855 L
.40694 .29839 L
.40767 .29843 L
.40884 .2989 L
.41012 .29995 L
.41137 .30123 L
.41205 .30192 L
.41271 .3025 L
.41396 .30326 L
.4151 .30344 L
.41617 .3032 L
.41734 .30265 L
.418 .30232 L
.4187 .302 L
.41998 .30172 L
.42074 .30181 L
.42145 .30208 L
.4221 .30247 L
.42278 .303 L
.42402 .30414 L
.42468 .30474 L
.42537 .30529 L
.42664 .30596 L
.42782 .30607 L
.42904 .30571 L
.43019 .30511 L
.43089 .30473 L
.43155 .30443 L
.4328 .30414 L
.43385 .3043 L
.43499 .30488 L
.4362 .30582 L
.43734 .30676 L
.43797 .30723 L
.43867 .30762 L
.43992 .30795 L
.44114 .30775 L
.44226 .30723 L
.44358 .30647 L
Mistroke
.44482 .30594 L
.4461 .30583 L
.44679 .30599 L
.44752 .30632 L
.44988 .30802 L
.45052 .30847 L
.45121 .30884 L
.45245 .30916 L
.45359 .30901 L
.45467 .30854 L
.45586 .30783 L
.45712 .30717 L
.45817 .30687 L
.45931 .30694 L
.46036 .30736 L
.46133 .30797 L
.46246 .30877 L
.46352 .30943 L
.46475 .30984 L
.46587 .30981 L
.47559 .30947 L
.4768 .31005 L
.47795 .31021 L
.47859 .31013 L
.47928 .30989 L
.48049 .30923 L
.48119 .30879 L
.48193 .30833 L
.48264 .30798 L
.48327 .30776 L
.48392 .30766 L
.48462 .3077 L
.48588 .30813 L
.48705 .30883 L
.4883 .30962 L
.48948 .31016 L
.49056 .31032 L
.49177 .31006 L
.49291 .30948 L
.49417 .30868 L
.49485 .30828 L
.4955 .30798 L
.49654 .30772 L
.4977 .30783 L
.49868 .30822 L
.49973 .30884 L
.5009 .30958 L
.50213 .31016 L
.50318 .31033 L
.50433 .31012 L
Mistroke
.50498 .30984 L
.50566 .30946 L
.50688 .30868 L
.50819 .30799 L
.50894 .30777 L
.50963 .30772 L
.51089 .30801 L
.51204 .30862 L
.51339 .30949 L
.51463 .31013 L
.51574 .31038 L
.51693 .31022 L
.51812 .30967 L
.51943 .30885 L
.52056 .30822 L
.52177 .30784 L
.52292 .30791 L
.52398 .30832 L
.52633 .30982 L
.52765 .31046 L
.52885 .31061 L
.52953 .3105 L
.53027 .31022 L
.53097 .30986 L
.53161 .30946 L
.53225 .30907 L
.53294 .30868 L
.53418 .30822 L
.53548 .30823 L
.53667 .30871 L
.53734 .30912 L
.53807 .30964 L
.53941 .31054 L
.54014 .31091 L
.5408 .31112 L
.54156 .31119 L
.54228 .31108 L
.54356 .31054 L
.54494 .30972 L
.54618 .3091 L
.54732 .30887 L
.54862 .30912 L
.54986 .30982 L
.55101 .31069 L
.55209 .31147 L
.55321 .31204 L
.55445 .31222 L
.5557 .31191 L
.55641 .31157 L
.55705 .3112 L
Mistroke
.5583 .31052 L
.55945 .31013 L
.56072 .31019 L
.56139 .31044 L
.5621 .31086 L
.56355 .31201 L
.56419 .31254 L
.56489 .31307 L
.56557 .31349 L
.56621 .31375 L
.56689 .31388 L
.56762 .31385 L
.56841 .31362 L
.56916 .31328 L
.56984 .31291 L
.57057 .31251 L
.57127 .3122 L
.5719 .31201 L
.57314 .31202 L
.57383 .31226 L
.57458 .31271 L
.57593 .31385 L
.57725 .31505 L
.57847 .31592 L
.57975 .31631 L
.58043 .31628 L
.58116 .31609 L
.58226 .31559 L
.58344 .31499 L
.58474 .31461 L
.58596 .31475 L
.58665 .31507 L
.5873 .31554 L
.58853 .3167 L
.58995 .31815 L
.59126 .31919 L
.5924 .31962 L
.59361 .31956 L
.5943 .31933 L
.59495 .31903 L
.59617 .31846 L
.59681 .31825 L
.59751 .31815 L
.59825 .31823 L
.59894 .31851 L
.60017 .31946 L
.60149 .32092 L
.60223 .32179 L
.60304 .32266 L
.6038 .32333 L
Mistroke
.6045 .32377 L
.60514 .32399 L
.60583 .32405 L
.60656 .32393 L
.60725 .32369 L
.60853 .32313 L
.60971 .32277 L
.61095 .32289 L
.6116 .32322 L
.6123 .32377 L
.61355 .32516 L
.61473 .32672 L
.61578 .32803 L
.61694 .3291 L
.6182 .32963 L
.6189 .32964 L
.61955 .32951 L
.62071 .32906 L
.62195 .32861 L
.62265 .32853 L
.62341 .32865 L
.62413 .32902 L
.62479 .32957 L
.62605 .3311 L
.62739 .3331 L
.62804 .33406 L
.62874 .33497 L
.63 .33616 L
.63131 .33662 L
.63207 .33655 L
.63276 .33635 L
.63397 .33587 L
.63529 .33562 L
.63654 .33605 L
.63769 .33714 L
.63833 .33802 L
.63902 .33911 L
.64026 .34125 L
.64161 .34335 L
.64238 .34422 L
.64309 .34477 L
.6438 .34504 L
.64455 .34507 L
.64535 .34488 L
.64608 .3446 L
.64676 .34434 L
.6475 .34417 L
.64819 .34419 L
.64883 .34443 L
.64999 .34545 L
Mistroke
.65124 .34737 L
.6535 .35176 L
.65416 .3529 L
.65487 .35393 L
.65618 .35503 L
.65745 .35518 L
.65863 .35478 L
.65986 .35432 L
.66102 .35434 L
.66229 .35528 L
.663 .35627 L
.66366 .35745 L
.6651 .36063 L
.66646 .36368 L
.66768 .36581 L
.66837 .36659 L
.669 .36702 L
.6701 .36714 L
.6713 .36667 L
.67255 .3661 L
.67373 .36612 L
.675 .36721 L
.67616 .36931 L
.67751 .3727 L
.67878 .37617 L
.67988 .37871 L
.68104 .38049 L
.68214 .38113 L
.68314 .38095 L
.68431 .38021 L
.68559 .37954 L
.68679 .37977 L
.68789 .38115 L
.69054 .38853 L
.69185 .39272 L
.69306 .39571 L
.69373 .39676 L
.69444 .39734 L
.69516 .39739 L
.69595 .39694 L
.69661 .39631 L
.69731 .39555 L
.69859 .39463 L
.6998 .39511 L
.70049 .39618 L
.70113 .39773 L
.70242 .40221 L
.7038 .40801 L
.70509 .41287 L
.70631 .41579 L
Mistroke
.7074 .41655 L
.70858 .41552 L
.70975 .41339 L
.71085 .41149 L
.71205 .41079 L
.71334 .41279 L
.71398 .415 L
.71469 .41822 L
.71597 .42554 L
.71723 .4329 L
.71837 .43791 L
.71954 .44008 L
.72064 .43895 L
.72181 .435 L
.72306 .4294 L
.72416 .42559 L
.72533 .42496 L
.72632 .42837 L
.72741 .43657 L
.72868 .4507 L
.72935 .45897 L
.73006 .46728 L
.73137 .47791 L
.73257 .47786 L
.73328 .47171 L
.73395 .46129 L
.73468 .44453 L
.73546 .42054 L
.7381 .3088 L
.73942 .24883 L
.74064 .20056 L
.74191 .16366 L
.74259 .15081 L
.7433 .14229 L
.74459 .13924 L
.7458 .14736 L
.74689 .15967 L
.74807 .17395 L
.74931 .18596 L
.75044 .19209 L
.75174 .193 L
.75298 .18927 L
.75412 .18417 L
.7552 .18002 L
.75632 .17797 L
.75756 .17936 L
.75881 .18435 L
.75951 .18823 L
.76015 .19209 L
.7614 .19926 L
Mistroke
.76255 .20431 L
.76382 .20704 L
.76448 .20726 L
.7652 .20673 L
.76595 .20558 L
.76666 .20421 L
.76734 .20294 L
.76799 .20202 L
.7692 .20156 L
.76984 .20219 L
.77054 .20356 L
.77126 .20569 L
.77195 .20823 L
.77324 .21364 L
.77436 .21807 L
.77556 .22155 L
.77687 .22332 L
.77809 .22317 L
.77883 .22253 L
.77951 .22181 L
.78024 .22109 L
.78105 .22064 L
.78175 .22069 L
.7824 .2212 L
.78309 .22225 L
.78383 .22391 L
.78631 .23171 L
.78699 .23379 L
.78772 .2357 L
.78904 .23795 L
.7897 .23843 L
.79038 .23854 L
.79161 .238 L
.79229 .23753 L
.79302 .2371 L
.79434 .23697 L
.79556 .23805 L
.79667 .24009 L
.79799 .24342 L
.79923 .24679 L
.79992 .24849 L
.80057 .24983 L
.80125 .2509 L
.80199 .25166 L
.80322 .25201 L
.80454 .25155 L
.80528 .25118 L
.80609 .2509 L
.80685 .2509 L
.80755 .25123 L
Mistroke
.80825 .25189 L
.80888 .25278 L
.8103 .25558 L
.81156 .25848 L
.81273 .26096 L
.81395 .26281 L
.8146 .2634 L
.81529 .26372 L
.81604 .26376 L
.81676 .26358 L
.8174 .26332 L
.8181 .26304 L
.81875 .26285 L
.81944 .26283 L
.82067 .26343 L
.82183 .26481 L
.82307 .26699 L
.82414 .26913 L
.82531 .2713 L
.82602 .27236 L
.82668 .2731 L
.82798 .27384 L
.82917 .27377 L
.83043 .2733 L
.83167 .27296 L
.83237 .27299 L
.83303 .27323 L
.83372 .27373 L
.83436 .27441 L
.83578 .27653 L
.83702 .27867 L
.83834 .28069 L
.83947 .28186 L
.84071 .28239 L
.84139 .28238 L
.84212 .2822 L
.84281 .28194 L
.84344 .28169 L
.84414 .28148 L
.84489 .28141 L
.84568 .2816 L
.84642 .28203 L
.84712 .28269 L
.84779 .28349 L
.84904 .28529 L
.85037 .28725 L
.85107 .28812 L
.85183 .28884 L
.85309 .28946 L
.85428 .28941 L
Mistroke
.85497 .28919 L
.85563 .28891 L
.85687 .28847 L
.85802 .28841 L
.85909 .28883 L
.86026 .28984 L
.86151 .29138 L
.86287 .29316 L
.86359 .29398 L
.86434 .29465 L
.86501 .29505 L
.86574 .29526 L
.86701 .29514 L
.86826 .29464 L
.86895 .29434 L
.86959 .29411 L
.87085 .29401 L
.872 .29444 L
.88168 .2988 L
.88292 .29841 L
.88423 .29852 L
.88491 .29883 L
.88566 .29936 L
.88697 .30062 L
.88822 .3019 L
.8889 .30251 L
.88955 .30296 L
.8908 .30342 L
.89194 .30333 L
.89301 .30292 L
.89413 .30234 L
.89509 .30192 L
.89615 .30172 L
.89729 .30192 L
.89851 .30263 L
.89966 .30362 L
.90071 .3046 L
.90194 .30554 L
.90308 .30602 L
.90434 .30601 L
.90497 .30582 L
.90567 .3055 L
.90683 .30486 L
.90809 .3043 L
.90928 .30415 L
.91037 .30443 L
.9195 .30662 L
.92067 .30605 L
.92191 .3058 L
.92256 .30587 L
Mistroke
.92327 .3061 L
.92452 .30685 L
.92569 .30774 L
.92681 .30852 L
.92809 .30908 L
.92927 .30913 L
.92998 .30894 L
.93065 .30865 L
.93216 .30777 L
.93348 .3071 L
.93421 .30689 L
.93488 .30685 L
.93614 .30716 L
.93685 .30753 L
.9375 .30796 L
.93878 .30887 L
.93998 .30955 L
.94109 .30986 L
.94229 .30975 L
.94297 .30949 L
.94362 .30916 L
.94483 .30841 L
.94611 .30773 L
.94729 .30742 L
.94858 .30759 L
.94923 .30786 L
.94996 .30827 L
.95162 .30937 L
.95243 .30982 L
.95316 .3101 L
.95395 .31022 L
.95478 .31012 L
.95569 .30979 L
.95654 .30932 L
.95795 .30844 L
.95872 .30803 L
.95944 .30777 L
.96022 .30765 L
.96108 .30775 L
.9618 .308 L
.96258 .30841 L
.96433 .30953 L
.96532 .31003 L
.96623 .31029 L
.96711 .31029 L
.96791 .31008 L
.96883 .30964 L
.96969 .30911 L
.97048 .30861 L
.97121 .30819 L
Mistroke
.97198 .30787 L
.97282 .30771 L
.97367 .30777 L
.97458 .30808 L
.97542 .30853 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
WooonfX4o`0007[ooo]Z1Ol00020oookJPCo0000V_oonfX009oooo]Z1Ol0001ioookJPGo0000P?oo
nfX4o`0009[ooo]Z002OoookJPGo0000NOoonfX5o`0007oooo]Z1Ol0002JoookJP00WooonfX5o`00
07Wooo]Z1Ol0001ooookJPGo0000V_oonfX009kooo]Z1_l0001ioookJPGo0000OooonfX5o`0009[o
oo]Z002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1_l0
001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0006cooo]Z0ol007l:
oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPKo0000G?oonfX:o`00O`Kooo]Z0ol007l:oook
JPGo0000O_oonfX7o`0009Wooo]Z002NoookJPKo0000G?oonfX:o`00O`Kooo]Z0ol007l:oookJPKo
0000OOoonfX7o`0009Wooo]Z002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPOo0000
VOoonfX009kooo]Z1ol0001[oookJP?o001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX7
o`0006_ooo]Z0ol007l:oookJPGo0000O_oonfX7o`0009Wooo]Z002NoookJPOo0000JooonfX3o`00
O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1ol0001XoookJPKo001o2_oonfX5o`0007ko
oo]Z1ol0002IoookJP00W_oonfX7o`0006Sooo]Z1_l007l:oookJPGo0000O_oonfX7o`0009Wooo]Z
002NoookJPOo0000J_oonfX4o`00O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1ol0001[
oookJP?o001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX8o`0007Oooo]Z1Ol0001noook
JPOo0000VOoonfX009kooo]Z2?l0001goookJPGo0000O_oonfX7o`0009Wooo]Z002NoookJPSo0000
MooonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX<o`0007?ooo]Z1Ol0001noookJPOo000000?o
oo]Zo`000?l000000_l0002DoookJP00W_oonfX<o`0007?ooo]Z1Ol0001noookJPgo0000TooonfX0
09kooo]Z3Ol0001boookJPGo0000O_oonfX=o`0009?ooo]Z002NoookJPgo0000L_oonfX5o`0007go
oo]Z3_l0002CoookJP00W_oonfX=o`0007;ooo]Z1Ol0001moookJPko0000TooonfX009gooo]Z3_l0
001boookJPGo0000OOoonfX?o`0009;ooo]Z002MoookJPko0000L_oonfX5o`0007gooo]Z1?l00000
0ooonf[o0000o`000008o`0009;ooo]Z002MoookJPoo0000LOoonfX5o`0007gooo]Z1?l000000ooo
nf[o0000o`000008o`0009;ooo]Z002MoookJPCo000000?ooo]Zo`000?l000002?l0001aoookJPGo
0000OOoonfX4o`000003oookJ_l0003o000000So0000T_oonfX009gooo]Z1?l000000ooonf[o0000
o`000008o`00077ooo]Z1Ol0001moookJPCo000000?ooo]Zo`000?l000002?l0002BoookJP00WOoo
nfX4o`000003oookJ_l0003o000000So0000LOoonfX5o`0007gooo]Z1?l00002oookJPWo0000T_oo
nfX009gooo]Z1?l00002oookJPWo0000LOoonfX5o`0007gooo]Z1?l00002oookJPCo000000?ooo]Z
o`000?l000000ol0002AoookJP00WOoonfX4o`0000Oooo]Z1?l0001aoookJPGo0000OOoonfX4o`00
00Oooo]Z1Ol0002AoookJP00WOoonfX4o`0000Oooo]Z2Ol0001/oookJPGo0000OOoonfX4o`0000Oo
oo]Z2Ol0002=oookJP00WOoonfX4o`0000Oooo]Z2_l0001[oookJPGo0000OOoonfX4o`0000Sooo]Z
2Ol0002<oookJP00WOoonfX4o`0000Oooo]Z2_l0001[oookJPGo0000OOoonfX4o`0000Sooo]Z2Ol0
002<oookJP00WOoonfX4o`0000Sooo]Z2Ol0001[oookJPGo0000OOoonfX4o`0000Sooo]Z2Ol0002<
oookJP00WOoonfX4o`0000Sooo]Z2Ol0001[oookJPGo0000OOoonfX4o`0000Sooo]Z2Ol0002<oook
JP00WOoonfX4o`0000Sooo]Z2Ol0001[oookJPGo0000OOoonfX4o`0000Sooo]Z2_l0002;oookJP00
WOoonfX4o`0000Wooo]Z2Ol0001ZoookJPGo0000OOoonfX4o`0000Wooo]Z2Ol0002;oookJP00WOoo
nfX4o`0000gooo]Z1Ol0001ZoookJPGo0000OOoonfX4o`0000gooo]Z1Ol0002;oookJP00WOoonfX4
o`0000gooo]Z1_l0001YoookJPGo0000OOoonfX4o`0000kooo]Z1Ol0002:oookJP00WOoonfX4o`00
00kooo]Z1Ol0001YoookJPGo0000OOoonfX4o`0000kooo]Z1Ol0002:oookJP00WOoonfX4o`0000ko
oo]Z2Ol0001UoookJPGo0000OOoonfX4o`0000kooo]Z2Ol00026oookJP00WOoonfX4o`0000oooo]Z
2Ol0001ToookJPGo0000OOoonfX4o`0000oooo]Z2?l00026oookJP00WOoonfX4o`0000oooo]Z2Ol0
001ToookJPGo0000OOoonfX4o`0000oooo]Z2Ol00025oookJP00WOoonfX4o`0000oooo]Z2Ol00016
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000OOoonfX4o`0000oooo]Z2Ol00025
oookJP00WOoonfX4o`0000oooo]Z2Ol00015oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oook
JPGo0000OOoonfX4o`0000oooo]Z2Ol00025oookJP00WOoonfX4o`00013ooo]Z2Ol00014oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000@oookJPWo0000Q?oonfX009gooo]Z1?l0000Doook
JPGo0000=ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000OOoonfX4o`0001Cooo]Z1Ol00024oookJP00WOoonfX4o`0001Cooo]Z1Ol0000goookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007cooo]Z1?l0000DoookJPKo
0000PooonfX009gooo]Z1?l0000EoookJPGo0000@_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX5o`0007gooo]Z1?l0000EoookJPGo0000PooonfX009gooo]Z1?l0000EoookJPWo0000?_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001moookJPCo00005Ooo
nfX9o`0007oooo]Z002MoookJPCo00005OoonfX:o`0003gooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Wooo]Z1Ol0001moookJPCo00005_oonfX8o`0007oooo]Z002MoookJPCo00005_oonfX9o`00
03gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001moookJPCo00005_oonfX9o`00
07kooo]Z002MoookJPCo00005_oonfX9o`0003gooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`ko
oo]Z1Ol0001moookJPCo00005_oonfX9o`0007kooo]Z002MoookJPCo00005ooonfX8o`0003kooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007gooo]Z1?l0000GoookJPSo
0000O_oonfX009gooo]Z1?l0000KoookJPGo0000?OoonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000
OOoonfX4o`0001_ooo]Z1Ol0001moookJP00WOoonfX4o`0001_ooo]Z1Ol0000noookJPGo001o2_oo
nfX7o`00O`Sooo]Z1Ol0001moookJPCo00006ooonfX6o`0007cooo]Z002MoookJPCo00006ooonfX6
o`0005_ooo]Z1Ol0001moookJPCo00006ooonfX6o`0007cooo]Z002MoookJPCo00007?oonfX9o`00
05Oooo]Z1Ol0001moookJPCo00007?oonfX9o`0007Sooo]Z002LoookJPGo00007?oonfX9o`0005Oo
oo]Z1Ol0001moookJPCo00007OoonfX8o`0007Sooo]Z002LoookJPGo00007OoonfX9o`0005Kooo]Z
1Ol0001moookJPCo00007OoonfX9o`0007Oooo]Z002LoookJPGo00007OoonfX:o`0005Gooo]Z1Ol0
001moookJPCo00007OoonfX9o`0007Oooo]Z002LoookJPCo00008_oonfX6o`0005Gooo]Z1Ol0001m
oookJPCo00008OoonfX6o`0007Kooo]Z002LoookJPCo00008ooonfX5o`0005Gooo]Z1Ol0001moook
JPCo00008_oonfX5o`0007Kooo]Z002LoookJPCo00009?oonfX8o`00057ooo]Z1Ol0001moookJPCo
00008_oonfX:o`00077ooo]Z002LoookJPCo00009?oonfX9o`00053ooo]Z1Ol0001moookJPCo0000
8ooonfX9o`00077ooo]Z002LoookJPCo00009?oonfX:o`0004oooo]Z1Ol0001moookJPCo00008ooo
nfX:o`00073ooo]Z002LoookJPCo00009OoonfX9o`0004oooo]Z1Ol0001moookJPCo00009?oonfX:
o`0006oooo]Z002LoookJPCo0000:OoonfX6o`0004kooo]Z1Ol0001moookJPCo00009OoonfX9o`00
06oooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00000ooonfX3o`00O`?ooo]Z1Ol007lLoookJPWo
0000B_oonfX5o`0007Cooo]Z1Ol007l4oookJPCo00000_oonfX5o`00Ob;ooo]Z2Ol0001;oookJP?o
001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o1?l00003oookJP?o001o0_oonfX7o`00Oa_ooo]Z
2ol00018oookJPGo0000LooonfX7o`00O`?ooo]Z1?l000000ooonf[o001oo`00O`05o`00Ob;ooo]Z
2Ol0001:oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o1?l00003oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lLoookJP_o0000AooonfX5o`0007?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJPCo00001?l007l01?oonf[o001oo`00Ool007lRoook
JP[o0000BOoonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o
001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP04oookJP?o001o0ooonfX3o`00Oa_o
oo]Z3?l00016oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00000ol007l3oookJP?o
001o8OoonfX:o`0004Wooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o
0_oonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX02_oonfX3o`00Oacooo]Z
3?l00015oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000003o`0000Kooo]Z
0ol007lRoookJP[o0000B?oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0
003o000000;o000000?o001ooookJ_oonfX02_oonfX3o`00Ob;ooo]Z2?l00013oookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000003o`0000Kooo]Z0ol007lWoookJP[o0000@ooo
nfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001o
oookJ_oonfX01OoonfX2o`00O`;ooo]Z1?l007lSoookJPSo0000@_oonfX5o`0007;ooo]Z0ol007l3
oookJP?o001o00?ooo]Zo`000?l000000ol000000ooonf[o001oo`00O`02oookJPCo001o9ooonfX:
o`0004?ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`00
0003o`00Oooonf[ooo]Z00Gooo]Z1ol007lUoookJPSo0000@OoonfX5o`0007;ooo]Z0ol007l3oook
JP?o001o00?ooo]Zo`000?l000000_l00002oookJPOo001o:OoonfX:o`0004;ooo]Z0ol007lMoook
JP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Go
oo]Z1_l007lWoookJPSo0000@?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l0
00000_l00002oookJPKo001o:_oonfX;o`00047ooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z
0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l]oookJP_o0000
>ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP;o001o
<?oonfX>o`0003Wooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z0_l0
07l^oookJP_o0000>_oonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo0000
0_oonfX2o`00OcCooo]Z2ol0000hoookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o1?l0
0009oookJPOo001o:OoonfX:o`0003[ooo]Z1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z1ol0
07l_oookJP_o0000>OoonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00002OoonfX7
o`00ObWooo]Z4?l0000doookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPOo001o;ooonfXA
o`0003Cooo]Z0ol007lMoookJP00W?oonfX4o`0003kooo]Z3?l0000coookJPGo0000O?oonfX4o`00
03kooo]Z3ol0001AoookJP00W?oonfX4o`0003oooo]Z4?l0000^oookJPGo0000O?oonfX4o`00043o
oo]Z3ol0001?oookJP00W?oonfX4o`00043ooo]Z4?l0000]oookJPGo0000O?oonfX4o`00043ooo]Z
4Ol0001=oookJP00W?oonfX4o`0004;ooo]Z5Ol0000VoookJPGo0000O?oonfX4o`00047ooo]Z1Ol0
00000ooonf[o0000o`00000=o`0004Sooo]Z002LoookJPCo0000A_oonfXBo`000003oookJ_l0003o
000000;o00008?oonfX5o`0007cooo]Z1?l0001:oookJQ?o0000@OoonfX009cooo]Z1?l00017oook
JQOo000000?ooo]Zo`000?l000000ol0000IoookJPGo0000O?oonfX4o`0004cooo]Z6?l0000joook
JP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oo
nf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`00
0?oo00009Ol0000?oookJP007?oonfX5o`0000;ooo]Z1Ol000000ooonf[o0000o`000004o`000003
oookJ_l0003o000001go0000COoonfX4o`00073ooo]Z1_l000000ooonf[o0000o`00000:o`0000;o
oo]Z1Ol00002oookJPGo000000?ooo]Zo`000?l000007Ol0001=oookJPCo0000LOoonfX4o`0000;o
oo]Z1_l00002oookJP03o`000?oonf[ooo]Z01cooo]Z000hoookJPGo000000?ooo]Zo`000?l00000
5Ol00017oookJPCo0000OOoonfX5o`0001Sooo]Z7Ol00017oookJPCo0000W_oonfX003oooo]Z5ol0
0016oookJPCo0000OOoonfX5o`0001oooo]Z5ol00016oookJPCo0000W_oonfX004Gooo]Z5_l00011
oookJPCo0000OOoonfX5o`0002Kooo]Z5?l00012oookJPCo0000W_oonfX004cooo]Z4?l00010oook
JPCo0000OOoonfX5o`0002cooo]Z4?l00010oookJPCo0000W_oonfX004gooo]Z4?l0000ooookJPCo
0000OOoonfX5o`0002cooo]Z4Ol0000ooookJPCo0000W_oonfX005?ooo]Z2ol0000noookJPCo0000
OOoonfX5o`0003;ooo]Z3?l0000noookJPCo0000W_oonfX005?ooo]Z3ol0000joookJPCo0000OOoo
nfX5o`0003?ooo]Z4?l0000ioookJPCo0000W_oonfX005Wooo]Z2_l0000ioookJPCo0000OOoonfX5
o`0003Wooo]Z2_l0000ioookJPCo0000W_oonfX005Wooo]Z2_l0000ioookJPCo0000OOoonfX5o`00
03Wooo]Z2ol0000hoookJPCo0000W_oonfX005[ooo]Z3_l0000doookJPCo0000OOoonfX5o`0003[o
oo]Z3_l0000doookJPCo0000W_oonfX005oooo]Z2ol0000boookJPCo0000OOoonfX5o`0003oooo]Z
2ol0000boookJPCo0000W_oonfX005oooo]Z2ol0000boookJPCo0000OOoonfX5o`00043ooo]Z2_l0
000boookJPCo0000W_oonfX0063ooo]Z2ol0000`oookJPGo0000OOoonfX5o`00043ooo]Z2ol0000a
oookJPCo0000W_oonfX0067ooo]Z2_l0000`oookJPGo0000OOoonfX5o`00047ooo]Z2_l0000aoook
JPCo0000W_oonfX006Kooo]Z2_l0000[oookJPGo0000OOoonfX5o`0004Kooo]Z2_l0000/oookJPCo
0000W_oonfX006Oooo]Z2_l0000ZoookJPCo0000O_oonfX5o`0004Oooo]Z2Ol0000/oookJPCo0000
W_oonfX006Oooo]Z2_l0000ZoookJPCo0000O_oonfX5o`0004Oooo]Z2_l0000[oookJPCo0000W_oo
nfX006Sooo]Z2_l0000YoookJPCo0000O_oonfX5o`0004Sooo]Z2Ol0000[oookJPCo0000W_oonfX0
06Wooo]Z2Ol0000YoookJPCo0000O_oonfX5o`0004Wooo]Z2Ol0000ZoookJPCo0000W_oonfX006go
oo]Z1_l0000XoookJPCo0000O_oonfX5o`0004gooo]Z1_l0000YoookJPCo0000W_oonfX006kooo]Z
2Ol0000ToookJPCo0000O_oonfX5o`0004gooo]Z2_l0000UoookJPCo0000W_oonfX006kooo]Z2Ol0
000ToookJPCo0000O_oonfX5o`0004kooo]Z2_l0000ToookJPCo0000W_oonfX006oooo]Z2Ol0000S
oookJPCo0000O_oonfX5o`0004oooo]Z2Ol0000ToookJPCo0000W_oonfX006oooo]Z2Ol0000Soook
JPCo0000O_oonfX5o`00053ooo]Z2?l0000ToookJPCo0000W_oonfX007?ooo]Z1_l0000RoookJPCo
0000O_oonfX5o`0005?ooo]Z1Ol0000ToookJPCo0000W_oonfX007Cooo]Z1Ol0000RoookJPCo0000
O_oonfX5o`0005Cooo]Z1Ol0000SoookJPCo0000W_oonfX007Cooo]Z2Ol0000NoookJPCo0000O_oo
nfX5o`0005Cooo]Z2Ol0000NoookJPGo0000W_oonfX007Gooo]Z2Ol0000MoookJPCo0000O_oonfX5
o`0005Cooo]Z2_l0000MoookJPGo0000W_oonfX007Gooo]Z2_l0000LoookJPCo0000O_oonfX5o`00
05Gooo]Z2Ol0000MoookJPGo0000W_oonfX007Kooo]Z2Ol0000LoookJPCo0000O_oonfX5o`0005Ko
oo]Z2?l0000MoookJPCo0000WooonfX007Oooo]Z2?l0000LoookJPCo0000O_oonfX5o`0005Oooo]Z
2?l0000LoookJPCo0000WooonfX007_ooo]Z1Ol0000KoookJPCo0000O_oonfX5o`0005[ooo]Z1_l0
000KoookJPCo0000WooonfX007_ooo]Z1Ol0000KoookJPCo0000O_oonfX5o`0005[ooo]Z1_l0000K
oookJPCo0000WooonfX007_ooo]Z2Ol0000GoookJPCo0000O_oonfX5o`0005_ooo]Z2Ol0000Goook
JPCo0000WooonfX007cooo]Z2?l0000GoookJPCo0000H?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o2_oonfX5o`0005cooo]Z2Ol0000FoookJPCo0000WooonfX007cooo]Z2Ol0000FoookJPCo0000
GooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0005cooo]Z2Ol0000FoookJPCo0000
WooonfX007cooo]Z2Ol0000FoookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001LoookJPWo
00005_oonfX4o`0009oooo]Z001moookJPWo00005OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000GOoonfX9o`0001Gooo]Z1?l0002OoookJP00POoo
nfX5o`0001Gooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000H?oo
nfX5o`0001Gooo]Z1?l0002OoookJP00POoonfX6o`0001Cooo]Z1?l0001NoookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l8oookJPGo0000HOoonfX5o`0001Gooo]Z1?l0002OoookJP00P_oonfX5o`00
01Cooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`00
06;ooo]Z1Ol0000DoookJPCo0000WooonfX008;ooo]Z2Ol0000@oookJPCo0000G_oonfX3o`00O`?o
oo]Z0ol007l7oookJPOo001o2OoonfX5o`0006;ooo]Z2Ol0000@oookJPCo0000WooonfX008?ooo]Z
2?l0000@oookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0006;ooo]Z
2_l0000?oookJPCo0000WooonfX008?ooo]Z2Ol0000?oookJPCo0000G_oonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o3_oonfX5o`0006?ooo]Z2Ol0000?oookJPCo0000WooonfX008?ooo]Z2Ol0000?
oookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000Hooo
nfX9o`0000oooo]Z1?l0002OoookJP00Q?oonfX8o`0000oooo]Z1?l0001OoookJPOo001o2OoonfX7
o`00O`Sooo]Z1Ol0001ToookJPWo00003_oonfX4o`0009oooo]Z0024oookJPWo00003_oonfX4o`00
063ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0006Cooo]Z2Ol0000>oookJPCo0000WooonfX008So
oo]Z1Ol0000>oookJPCo0000O_oonfX5o`0006Sooo]Z1Ol0000>oookJPCo0000WooonfX008Sooo]Z
1Ol0000>oookJPCo0000O_oonfX5o`0006Wooo]Z1?l0000>oookJPCo0000WooonfX008Wooo]Z1Ol0
000=oookJPCo0000O_oonfX5o`0006Wooo]Z1?l0000>oookJPCo0000WooonfX008Wooo]Z2Ol00009
oookJPCo0000O_oonfX5o`0006Wooo]Z1?l000000ooonf[o0000o`000002o`0000Wooo]Z1?l0002O
oookJP00ROoonfX:o`0000Sooo]Z1?l0001noookJPGo0000JOoonfX:o`0000Sooo]Z1?l0002Ooook
JP00R_oonfX9o`0000Sooo]Z1?l0001noookJPGo0000JOoonfX:o`0000Sooo]Z1?l0002OoookJP00
R_oonfX9o`0000Sooo]Z1?l0001noookJPGo0000JOoonfX:o`0000Sooo]Z1?l0002OoookJP00R_oo
nfX9o`0000Oooo]Z1Ol0001noookJPGo0000J_oonfX9o`0000Sooo]Z1?l0002OoookJP00R_oonfX9
o`0000Oooo]Z1Ol0001noookJPGo0000J_oonfX9o`0000Sooo]Z1?l0002OoookJP00RooonfX8o`00
00Oooo]Z1Ol0001noookJPGo0000JooonfX8o`0000Sooo]Z1?l0002OoookJP00SooonfX5o`0000Ko
oo]Z1?l0001ooookJPGo0000KooonfX5o`0000Oooo]Z1?l0002OoookJP00SooonfX5o`000003oook
J_l0003o000000;o000000?ooo]Zo`000?l000000_l0001ooookJPGo0000KooonfX:o`0000;ooo]Z
1?l0002OoookJP00SooonfX:o`000003oookJ_l0003o000000;o0000OooonfX5o`0006oooo]Z2_l0
0002oookJPCo0000WooonfX0093ooo]Z3_l0001ooookJPGo0000L?oonfX:o`000003oookJ_l0003o
000000;o0000WooonfX0093ooo]Z3_l0001ooookJPGo0000L?oonfX:o`000003oookJ_l0003o0000
00;o0000WooonfX0093ooo]Z3_l0001ooookJPGo0000L?oonfX?o`0009oooo]Z002@oookJPko0000
OooonfX5o`00073ooo]Z3ol0002OoookJP00T?oonfX>o`0007oooo]Z1Ol0001aoookJPko0000Wooo
nfX0093ooo]Z3_l0001ooookJPGo0000LOoonfX=o`000:3ooo]Z002AoookJPgo0000OooonfX5o`00
077ooo]Z3Ol0002PoookJP00TOoonfX=o`0007oooo]Z1Ol0001aoookJPgo0000X?oonfX0097ooo]Z
3Ol0001ooookJPGo0000LOoonfX=o`000:3ooo]Z002BoookJPco0000OooonfX5o`0007;ooo]Z3?l0
002PoookJP00UooonfX7o`0007oooo]Z1Ol0001foookJPSo0000X?oonfX009Oooo]Z1ol0001ooook
JPGo0000M_oonfX8o`000:3ooo]Z002GoookJPOo0000OooonfX5o`0007Oooo]Z1ol0002PoookJP00
UooonfX7o`0007oooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0001ooookJPGo0000Mooo
nfX7o`000:3ooo]Z002GoookJPOo0000OooonfX5o`0007Oooo]Z1ol0002PoookJP00UooonfX7o`00
07;ooo]Z0ol007l:oookJPGo0000MooonfX7o`000:3ooo]Z002GoookJPOo0000L_oonfX3o`00O`[o
oo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0001boookJP?o001o2_oonfX5o`0007Oooo]Z
1ol0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000MooonfX7o`000:3ooo]Z002H
oookJPKo0000L_oonfX3o`00O`[ooo]Z1_l0001foookJPOo0000X?oonfX009Sooo]Z1_l0001boook
JP?o001o2_oonfX5o`0007Oooo]Z1ol0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo
0000N?oonfX6o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000
X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1Ol0002QoookJP00V?oonfX6
o`0006oooo]Z1_l007l:oookJPGo0000N?oonfX5o`000:7ooo]Z002HoookJPGo0000L?oonfX6o`00
O`[ooo]Z1Ol0001hoookJPGo0000XOoonfX009Sooo]Z1Ol0001boookJPCo001o2_oonfX5o`0007So
oo]Z1Ol0002QoookJP00V?oonfX5o`0007?ooo]Z0ol007l:oookJPGo0000N?oonfX5o`000:7ooo]Z
002HoookJPGo0000P?oonfX5o`0007Sooo]Z1Ol0002QoookJP00V?oonfX4o`00087ooo]Z1Ol0001h
oookJPGo0000XOoonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8
oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oook
JP?o001o2?oonfX6o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo
0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oook
JP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooo
nfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003o
oookJQoooo]Z003ooookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo
001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003ooookJQ;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/
oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?o
oo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooo
nfX>oookJPOo001ooooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .3083 L
.02605 .30786 L
.02729 .30777 L
.02846 .30812 L
.02954 .30873 L
.03053 .30937 L
.03163 .30997 L
.03279 .31029 L
.03395 .31019 L
.0352 .30964 L
.03628 .30897 L
.03746 .30827 L
.03818 .30796 L
.03884 .3078 L
.04016 .30791 L
.04135 .30845 L
.04262 .30926 L
.04327 .30968 L
.04396 .31005 L
.04519 .31041 L
.04588 .3104 L
.04652 .31026 L
.04722 .30997 L
.04797 .30955 L
.04933 .3087 L
.05061 .30811 L
.05176 .30797 L
.05302 .30831 L
.05414 .30896 L
.05539 .30981 L
.05669 .31052 L
.05791 .31078 L
.05905 .31058 L
.06009 .31009 L
.0613 .30936 L
.06244 .30875 L
.06373 .30844 L
.0649 .30862 L
.06616 .30928 L
.06752 .31026 L
.06872 .31103 L
.06998 .31147 L
.07106 .31144 L
.07225 .31099 L
.07296 .31059 L
.07364 .31018 L
.07492 .30954 L
.07563 .30935 L
.07629 .30932 L
Mistroke
.07702 .30945 L
.07779 .30979 L
.0791 .31071 L
.08049 .31179 L
.08167 .31248 L
.08297 .31274 L
.08367 .31264 L
.08442 .31237 L
.08513 .31201 L
.08578 .31164 L
.08653 .31123 L
.08734 .31089 L
.0881 .31073 L
.08881 .31076 L
.09008 .31126 L
.0908 .31176 L
.09148 .31232 L
.09286 .3135 L
.09361 .31403 L
.09431 .31439 L
.09554 .3146 L
.0962 .3145 L
.09689 .31426 L
.09813 .31363 L
.09926 .31307 L
.10057 .31279 L
.10131 .31289 L
.102 .31317 L
.10325 .31408 L
.10458 .31534 L
.1058 .31641 L
.10648 .31686 L
.10712 .31713 L
.10829 .31723 L
.10953 .31686 L
.11063 .31631 L
.11167 .31585 L
.11281 .31564 L
.11404 .31595 L
.1166 .3182 L
.11785 .3195 L
.11898 .32037 L
.12019 .32079 L
.12147 .32064 L
.12214 .32038 L
.12287 .32004 L
.12419 .31951 L
.12534 .31942 L
.12661 .31994 L
.12793 .32114 L
Mistroke
.12916 .32261 L
.1303 .32392 L
.13137 .32486 L
.13261 .32538 L
.13375 .32531 L
.1348 .32493 L
.13593 .32445 L
.13698 .32419 L
.13794 .3243 L
.13908 .32496 L
.1403 .32626 L
.14252 .32922 L
.14376 .3305 L
.1449 .33111 L
.1462 .33111 L
.14744 .33067 L
.14858 .33025 L
.14964 .33013 L
.1508 .33057 L
.15203 .33174 L
.15442 .33527 L
.15568 .33696 L
.157 .33805 L
.1577 .33827 L
.15847 .33826 L
.15917 .33808 L
.15982 .33783 L
.1611 .3374 L
.16182 .33735 L
.16247 .3375 L
.16379 .3385 L
.16445 .33934 L
.16518 .34048 L
.16648 .34278 L
.16768 .34474 L
.1684 .34568 L
.16908 .34633 L
.1698 .34673 L
.17059 .34686 L
.17127 .34675 L
.172 .34649 L
.17331 .34602 L
.17401 .34595 L
.17464 .34608 L
.17534 .34649 L
.17608 .34725 L
.17732 .3492 L
.17868 .35192 L
.1799 .35428 L
.1812 .35614 L
Mistroke
.18243 .35695 L
.18354 .35694 L
.18473 .35649 L
.18584 .3561 L
.18706 .35625 L
.18837 .35748 L
.18903 .35854 L
.18974 .35997 L
.19104 .363 L
.19233 .36588 L
.19349 .36782 L
.19468 .36882 L
.1958 .36888 L
.19698 .36836 L
.19826 .36781 L
.19938 .36794 L
.20056 .36912 L
.20157 .37102 L
.20268 .37383 L
.20407 .37771 L
.20539 .38078 L
.20658 .3824 L
.20787 .38278 L
.20853 .38252 L
.20927 .38204 L
.20998 .38154 L
.21075 .38117 L
.21147 .38116 L
.21213 .38155 L
.21343 .38359 L
.21592 .39121 L
.21715 .39508 L
.21828 .39765 L
.21958 .39888 L
.22027 .39879 L
.22099 .39827 L
.22218 .39698 L
.22346 .39602 L
.22472 .39661 L
.22587 .39899 L
.22703 .40299 L
.22812 .40765 L
.22931 .41256 L
.23058 .41634 L
.23131 .41746 L
.23197 .41773 L
.23326 .41651 L
.23443 .41423 L
.23551 .41237 L
.2367 .41192 L
Mistroke
.23795 .4143 L
.23905 .41888 L
.24006 .42467 L
.24126 .43198 L
.24237 .43757 L
.24366 .44078 L
.24434 .4407 L
.24506 .43931 L
.24627 .43467 L
.24697 .43141 L
.2476 .42862 L
.24879 .42542 L
.25006 .42715 L
.25119 .43426 L
.25237 .44668 L
.25365 .46267 L
.25436 .47062 L
.25502 .47633 L
.25631 .47905 L
.25748 .4682 L
.25816 .45515 L
.25888 .43589 L
.26017 .38887 L
.26307 .25408 L
.26429 .20385 L
.26561 .16378 L
.26686 .14314 L
.26802 .13847 L
.26905 .14371 L
.2702 .1559 L
.27133 .17007 L
.27253 .18295 L
.27384 .19124 L
.27504 .19259 L
.27634 .18886 L
.27707 .18553 L
.27776 .18237 L
.279 .17809 L
.28014 .17724 L
.28144 .18049 L
.28268 .18682 L
.28382 .19382 L
.28489 .19981 L
.28601 .20421 L
.28725 .20618 L
.28831 .20565 L
.28928 .204 L
.29034 .20191 L
.29146 .20044 L
.29268 .20077 L
Mistroke
.2938 .20314 L
.29449 .20545 L
.29514 .20804 L
.29635 .21326 L
.29744 .21748 L
.29858 .2206 L
.29984 .22201 L
.301 .22166 L
.30222 .2204 L
.30286 .21973 L
.30355 .21925 L
.3048 .21945 L
.30596 .2212 L
.30707 .22414 L
.30811 .22757 L
.30924 .23134 L
.31048 .23465 L
.31172 .23653 L
.31303 .23687 L
.31424 .23621 L
.31537 .23546 L
.31606 .23523 L
.31671 .23531 L
.31792 .23643 L
.31923 .23902 L
.32064 .24284 L
.32171 .24574 L
.32285 .24826 L
.3241 .24988 L
.32528 .25026 L
.32659 .2498 L
.32784 .24921 L
.32896 .24916 L
.33018 .25004 L
.33134 .25188 L
.33239 .25416 L
.33353 .25684 L
.33475 .25943 L
.33588 .26111 L
.33693 .26186 L
.33793 .26194 L
.33898 .26159 L
.3402 .26111 L
.3409 .26101 L
.34154 .26113 L
.34271 .262 L
.34395 .26383 L
.34614 .26817 L
.34734 .27026 L
.34849 .27156 L
Mistroke
.34979 .27208 L
.35098 .27186 L
.3521 .27143 L
.35333 .27118 L
.35403 .27131 L
.35466 .27166 L
.3554 .27234 L
.35609 .27323 L
.35866 .27761 L
.35981 .27929 L
.36089 .2803 L
.36202 .28069 L
.36325 .28049 L
.36431 .28007 L
.36529 .27978 L
.36641 .27983 L
.36747 .28042 L
.37701 .2871 L
.37817 .28684 L
.3794 .28712 L
.38004 .28753 L
.38075 .28818 L
.38198 .28971 L
.38314 .2913 L
.38424 .29261 L
.3855 .29358 L
.38665 .29385 L
.38786 .29359 L
.38917 .29303 L
.39039 .29266 L
.39152 .29273 L
.39276 .29342 L
.39347 .29408 L
.39413 .29481 L
.39546 .29641 L
.39616 .29719 L
.3969 .29787 L
.39813 .29854 L
.39928 .2986 L
.40046 .29822 L
.40154 .29771 L
.40259 .29733 L
.40372 .29725 L
.40479 .29764 L
.40578 .29837 L
.40693 .29954 L
.40818 .30086 L
.40935 .30184 L
.41042 .30232 L
.41162 .30233 L
Mistroke
.41275 .30193 L
.41399 .30132 L
.41463 .30103 L
.41531 .30084 L
.41655 .30087 L
.41769 .30139 L
.41875 .30224 L
.41991 .30336 L
.42118 .30446 L
.42189 .3049 L
.42254 .30515 L
.4238 .30519 L
.42498 .30477 L
.42623 .30411 L
.42755 .30355 L
.42867 .30344 L
.42991 .30383 L
.4306 .30427 L
.43124 .30477 L
.43267 .306 L
.4333 .30649 L
.43399 .30692 L
.43525 .30731 L
.4365 .30713 L
.43768 .30659 L
.43875 .30598 L
.43988 .30547 L
.44112 .3053 L
.44225 .30561 L
.44347 .30636 L
.44481 .30741 L
.44595 .3082 L
.44703 .30864 L
.44827 .30867 L
.4494 .30827 L
.45146 .3071 L
.45261 .30663 L
.45367 .30654 L
.45489 .3069 L
.45605 .3076 L
.45713 .30839 L
.45828 .30913 L
.45954 .30957 L
.46071 .30951 L
.46143 .30926 L
.4621 .30891 L
.46337 .30815 L
.46462 .30751 L
.46594 .30726 L
.46706 .30749 L
Mistroke
.4683 .30815 L
.46963 .30906 L
.47037 .30951 L
.47106 .30984 L
.47171 .31002 L
.47241 .31007 L
.47364 .30976 L
.47478 .30915 L
.47585 .30848 L
.47702 .30787 L
.47829 .30761 L
.47954 .30786 L
.48086 .30856 L
.482 .3093 L
.48322 .30997 L
.48437 .31025 L
.48541 .31014 L
.48646 .30971 L
.48745 .30911 L
.48853 .30844 L
.48967 .3079 L
.49093 .30774 L
.49208 .30802 L
.49329 .30868 L
.49461 .30952 L
.49586 .31012 L
.49701 .31029 L
.49816 .31005 L
.49919 .30953 L
.50032 .30881 L
.50152 .30813 L
.50282 .30775 L
.50403 .30788 L
.50532 .30848 L
.50674 .30938 L
.50797 .31003 L
.50928 .31031 L
.51052 .31006 L
.51165 .30949 L
.51278 .30877 L
.51384 .30817 L
.51494 .30782 L
.51616 .30786 L
.51739 .30836 L
.51871 .3092 L
.51983 .30989 L
.52106 .31036 L
.52224 .31038 L
.52333 .31001 L
.52448 .30935 L
Mistroke
.52571 .3086 L
.52686 .3081 L
.52794 .30797 L
.52891 .30819 L
.52996 .30872 L
.53118 .30954 L
.53233 .31026 L
.53297 .31056 L
.53366 .31074 L
.53487 .31069 L
.53602 .31024 L
.53725 .30951 L
.5384 .30886 L
.53945 .30849 L
.54068 .3085 L
.54132 .30871 L
.542 .30906 L
.54316 .30986 L
.5444 .31074 L
.54511 .31114 L
.54576 .31139 L
.54702 .31148 L
.54772 .3113 L
.54849 .31096 L
.54988 .31016 L
.55118 .30952 L
.55241 .30931 L
.55311 .30942 L
.55375 .30967 L
.55449 .31011 L
.55519 .31063 L
.5565 .31165 L
.55721 .31214 L
.55789 .31249 L
.55869 .31271 L
.55941 .31272 L
.56009 .31257 L
.56082 .31227 L
.56215 .31154 L
.56339 .31094 L
.56467 .31072 L
.56536 .31084 L
.56609 .31115 L
.56739 .31208 L
.56862 .31315 L
.56973 .31399 L
.57093 .31453 L
.57215 .31456 L
.57327 .31418 L
.57449 .31353 L
Mistroke
.57578 .31295 L
.57691 .31279 L
.57796 .31306 L
.57911 .3138 L
.58034 .31492 L
.58168 .31617 L
.58244 .31672 L
.58314 .31707 L
.58442 .31724 L
.58506 .3171 L
.58578 .31683 L
.58701 .31622 L
.58833 .31571 L
.58958 .31571 L
.59072 .31624 L
.61173 .32461 L
.63237 .33747 L
.64241 .34231 L
.64361 .34435 L
.64472 .34583 L
.64588 .34669 L
.64715 .34682 L
.64825 .34647 L
.64925 .34609 L
.65041 .34597 L
.6515 .34647 L
.65265 .34776 L
.65371 .34956 L
.6561 .35429 L
.65724 .35597 L
.6585 .35691 L
.65982 .35692 L
.66106 .35643 L
.66221 .35607 L
.66331 .35628 L
.6643 .35714 L
.66538 .35884 L
.66778 .36428 L
.66896 .36671 L
.67004 .36823 L
.67128 .36893 L
.67194 .36889 L
.67263 .36863 L
.67377 .36805 L
.67499 .36778 L
.67629 .36852 L
.6775 .37046 L
.67824 .37217 L
.67895 .37405 L
.68027 .37771 L
Mistroke
.68141 .38044 L
.68263 .38228 L
.68367 .38281 L
.68481 .38247 L
.68604 .38162 L
.68673 .38124 L
.68737 .38111 L
.68853 .38176 L
.68976 .38393 L
.70972 .41603 L
.71077 .41394 L
.7119 .41215 L
.71297 .41197 L
.71394 .4137 L
.71504 .41788 L
.71607 .42358 L
.71721 .43054 L
.71842 .43695 L
.71964 .44054 L
.72077 .44039 L
.72146 .43869 L
.72211 .43623 L
.72333 .43063 L
.72446 .42638 L
.7255 .42536 L
.72665 .42904 L
.72786 .43878 L
.73018 .46662 L
.73148 .47793 L
.73266 .47839 L
.73333 .47283 L
.73406 .46132 L
.73475 .44508 L
.73539 .4256 L
.73793 .31675 L
.73908 .26232 L
.74032 .20983 L
.74148 .17172 L
.74255 .1493 L
.74369 .13899 L
.74488 .14107 L
.74611 .15253 L
.74745 .16919 L
.74813 .17712 L
.74887 .18426 L
.74957 .18912 L
.75021 .1918 L
.75142 .19233 L
.7527 .18811 L
.75399 .18219 L
Mistroke
.75471 .1794 L
.75537 .17773 L
.75615 .17715 L
.75689 .17812 L
.75757 .18025 L
.75831 .18368 L
.76085 .1986 L
.76213 .204 L
.76286 .20565 L
.76355 .20621 L
.76476 .20527 L
.76588 .20317 L
.76711 .20099 L
.7684 .20037 L
.76963 .20217 L
.77032 .20418 L
.77096 .20654 L
.77211 .21142 L
.77338 .21661 L
.77452 .22005 L
.77559 .22175 L
.77671 .22195 L
.77792 .22095 L
.77922 .21958 L
.77996 .21917 L
.78065 .21923 L
.7819 .2207 L
.7826 .22228 L
.78324 .22408 L
.78447 .22816 L
.78577 .23237 L
.78688 .23509 L
.7881 .23667 L
.78924 .23687 L
.79045 .2362 L
.7915 .23549 L
.79264 .23524 L
.79396 .23622 L
.79521 .23853 L
.79643 .2417 L
.79756 .24484 L
.79854 .24727 L
.79961 .24915 L
.80078 .25016 L
.80187 .25019 L
.80304 .24966 L
.80426 .24914 L
.80531 .24921 L
.80646 .25015 L
.81739 .26104 L
Mistroke
.82771 .27166 L
.82883 .27126 L
.83004 .27125 L
.83117 .27191 L
.83221 .27313 L
.83338 .27501 L
.83448 .27698 L
.83569 .27889 L
.83698 .28023 L
.83828 .28069 L
.83948 .28047 L
.84022 .28019 L
.84091 .27993 L
.8422 .27975 L
.84341 .28023 L
.84452 .2813 L
.84574 .283 L
.84702 .285 L
.84827 .28665 L
.84946 .28762 L
.85052 .28791 L
.85168 .28771 L
.85294 .2872 L
.85357 .28698 L
.85427 .28685 L
.8555 .28707 L
.85666 .28791 L
.86565 .29291 L
.87081 .2954 L
.8721 .29693 L
.87332 .29805 L
.87442 .29857 L
.87561 .29858 L
.87686 .29812 L
.87803 .29758 L
.87928 .29724 L
.87991 .29725 L
.88061 .29745 L
.88132 .29785 L
.88197 .29837 L
.88343 .29987 L
.88471 .30118 L
.88536 .30171 L
.88607 .30214 L
.88671 .30235 L
.8874 .30239 L
.88865 .30206 L
.8899 .30145 L
.89104 .30096 L
.8923 .30079 L
Mistroke
.89301 .30095 L
.89368 .30127 L
.89438 .30176 L
.89502 .30231 L
.89645 .30369 L
.89772 .3047 L
.89888 .30519 L
.90016 .30515 L
.9008 .30494 L
.90151 .3046 L
.9027 .30396 L
.90398 .30349 L
.90519 .30349 L
.9063 .30394 L
.90744 .30477 L
.90865 .30583 L
.9097 .30664 L
.91084 .30719 L
.91153 .30731 L
.91218 .30727 L
.91344 .30682 L
.91458 .30618 L
.91579 .30557 L
.91687 .30531 L
.91802 .30544 L
.9191 .30597 L
.92009 .30669 L
.92125 .3076 L
.92252 .3084 L
.92371 .30872 L
.92481 .30858 L
.92599 .30806 L
.92723 .30733 L
.92829 .3068 L
.92945 .30653 L
.93071 .30674 L
.93141 .30707 L
.93204 .30746 L
.9333 .30837 L
.93445 .30912 L
.93554 .30954 L
.93668 .30955 L
.93784 .30916 L
.9391 .30842 L
.9402 .30778 L
.94137 .30733 L
.94248 .30728 L
.94349 .30759 L
.94477 .30833 L
.94612 .30925 L
Mistroke
.9474 .30989 L
.94855 .31007 L
.94927 .30996 L
.94992 .30972 L
.95064 .30935 L
.9514 .30888 L
.95269 .30811 L
.95341 .3078 L
.95407 .30764 L
.95534 .30773 L
.95655 .30825 L
.95765 .30895 L
.95886 .3097 L
.95949 .31 L
.96018 .3102 L
.9609 .31025 L
.96158 .31015 L
.9628 .30963 L
.9641 .30882 L
.96485 .30837 L
.96564 .30798 L
.96639 .30777 L
.96706 .30773 L
.96786 .30788 L
.96873 .30824 L
.96955 .30872 L
.9703 .3092 L
.97096 .30961 L
.97166 .30997 L
.97244 .31022 L
.97316 .31029 L
.97398 .31017 L
.97475 .30987 L
.97544 .30949 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
WooonfX4o`0007[ooo]Z1Ol0001ooookJPCo0000VooonfX009oooo]Z1?l0001joookJPGo0000Oooo
nfX5o`0009[ooo]Z002OoookJPGo0000NOoonfX5o`0007oooo]Z1Ol0002JoookJP00WooonfX5o`00
07Wooo]Z1Ol0001noookJPKo0000V_oonfX009oooo]Z1Ol0001ioookJPGo0000O_oonfX6o`0009[o
oo]Z002OoookJPGo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009oooo]Z1Ol0
001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00WooonfX5o`0006cooo]Z0ol007l:
oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPKo0000G?oonfX:o`00O`Kooo]Z0ol007l:oook
JPGo0000O_oonfX6o`0009[ooo]Z002NoookJPKo0000G?oonfX:o`00O`Kooo]Z0ol007l:oookJPKo
0000OOoonfX6o`0009[ooo]Z002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000
V_oonfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6
o`0006cooo]Z0ol007l:oookJPGo0000O_oonfX7o`0009Wooo]Z002NoookJPKo0000K?oonfX3o`00
O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1ol0001XoookJPKo001o2_oonfX5o`0007ko
oo]Z1ol0002IoookJP00W_oonfX7o`0006Sooo]Z1_l007l:oookJPGo0000O_oonfX7o`0009Wooo]Z
002NoookJPOo0000J_oonfX4o`00O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1ol0001[
oookJP?o001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX7o`0007Sooo]Z1Ol0001noook
JPOo0000VOoonfX009kooo]Z1ol0001hoookJPGo0000O_oonfX7o`0009Wooo]Z002NoookJPOo0000
N?oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX<o`0007?ooo]Z1Ol0001noookJPco0000U?oo
nfX009kooo]Z3Ol0001boookJPGo0000O_oonfX=o`0009?ooo]Z002NoookJPgo0000L_oonfX5o`00
07kooo]Z3Ol0002CoookJP00W_oonfX=o`0007;ooo]Z1Ol0001noookJPgo0000TooonfX009gooo]Z
3_l0001boookJPGo0000O_oonfX=o`0009?ooo]Z002MoookJPko0000L_oonfX5o`0007kooo]Z3Ol0
002CoookJP00WOoonfX>o`0007;ooo]Z1Ol0001noookJPgo0000TooonfX009gooo]Z1?l000000ooo
nf[o0000o`000007o`0007;ooo]Z1Ol0001noookJPgo0000TooonfX009gooo]Z1?l000000ooonf[o
0000o`000008o`00077ooo]Z1Ol0001moookJPoo0000T_oonfX009gooo]Z1?l000000ooonf[o0000
o`000008o`00077ooo]Z1Ol0001moookJPoo0000T_oonfX009gooo]Z1?l000000ooonf[o0000o`00
0008o`00077ooo]Z1Ol0001moookJPoo0000T_oonfX009gooo]Z1?l00002oookJPCo000000?ooo]Z
o`000?l000000_l0001aoookJPGo0000OOoonfX4o`0000;ooo]Z1?l000000ooonf[o0000o`000002
o`0009;ooo]Z002MoookJPCo00001ooonfX9o`0006cooo]Z1Ol0001moookJPCo00001ooonfX8o`00
08kooo]Z002MoookJPCo00001ooonfX9o`0006cooo]Z1Ol0001moookJPCo00001ooonfX9o`0008go
oo]Z002MoookJPCo00001ooonfX9o`0006cooo]Z1Ol0001moookJPCo00001ooonfX9o`0008gooo]Z
002MoookJPCo00001ooonfX:o`0006_ooo]Z1Ol0001moookJPCo00001ooonfX:o`0008cooo]Z002M
oookJPCo00001ooonfX:o`0006_ooo]Z1Ol0001moookJPCo00002?oonfX9o`0008cooo]Z002Moook
JPCo00002?oonfX9o`0006_ooo]Z1Ol0001moookJPCo00002?oonfX9o`0008cooo]Z002MoookJPCo
00002OoonfX9o`0006[ooo]Z1Ol0001moookJPCo00002?oonfX9o`0008cooo]Z002MoookJPCo0000
3OoonfX5o`0006[ooo]Z1Ol0001moookJPCo00003OoonfX4o`0008cooo]Z002MoookJPCo00003Ooo
nfX5o`0006[ooo]Z1Ol0001moookJPCo00003OoonfX5o`0008_ooo]Z002MoookJPCo00003_oonfX4
o`0006[ooo]Z1Ol0001moookJPCo00003OoonfX5o`0008_ooo]Z002MoookJPCo00003_oonfX8o`00
06Kooo]Z1Ol0001moookJPCo00003OoonfX9o`0008Oooo]Z002MoookJPCo00003_oonfX9o`0006Go
oo]Z1Ol0001moookJPCo00003_oonfX9o`0008Kooo]Z002MoookJPCo00003_oonfX9o`0006Gooo]Z
1Ol0001moookJPCo00003_oonfX9o`0008Kooo]Z002MoookJPCo00003_oonfX9o`0006Gooo]Z1Ol0
001moookJPCo00003_oonfX:o`0008Gooo]Z002MoookJPCo00003ooonfX8o`0004Oooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001moookJPCo00003ooonfX9o`0008Gooo]Z002Moook
JPCo00004?oonfX8o`0004Gooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001moook
JPCo00003ooonfX9o`0008Gooo]Z002MoookJPCo00004ooonfX5o`0004Gooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9
oookJPGo0000OOoonfX4o`0001Cooo]Z1?l00025oookJP00WOoonfX4o`0001?ooo]Z1_l0000goook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001moook
JPCo00005?oonfX5o`0008Cooo]Z002MoookJPCo00005?oonfX5o`0003Oooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000O?oonfX4o`0001Cooo]Z1Ol00024oookJP00
WOoonfX4o`0001Cooo]Z2Ol0000ooookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000
OOoonfX4o`0001Cooo]Z2Ol00020oookJP00WOoonfX4o`0001Gooo]Z2?l0000ooookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0007gooo]Z1?l0000EoookJPSo0000P?oo
nfX009gooo]Z1?l0000EoookJPWo0000?_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5
o`0007gooo]Z1?l0000EoookJPWo0000OooonfX009gooo]Z1?l0000EoookJPWo0000?_oonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0007gooo]Z1?l0000EoookJPWo0000OooonfX009go
oo]Z1?l0000FoookJPWo0000?OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0007go
oo]Z1?l0000FoookJPWo0000O_oonfX009gooo]Z1?l0000JoookJPGo0000?_oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000OOoonfX4o`0001[ooo]Z1Ol0001noookJP00
WOoonfX4o`0001[ooo]Z1Ol0000noookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001moookJPCo0000
6_oonfX5o`0007kooo]Z002MoookJPCo00006ooonfX5o`0003kooo]Z1Ol007l:oookJPOo001o2?oo
nfX5o`0007gooo]Z1?l0000KoookJPGo0000OOoonfX009gooo]Z1?l0000KoookJPWo0000F?oonfX5
o`0007gooo]Z1?l0000KoookJPWo0000NOoonfX009gooo]Z1?l0000KoookJP[o0000EooonfX5o`00
07gooo]Z1?l0000KoookJP[o0000N?oonfX009gooo]Z1?l0000LoookJPWo0000EooonfX5o`0007go
oo]Z1?l0000LoookJP[o0000MooonfX009gooo]Z1?l0000MoookJPSo0000EooonfX5o`0007gooo]Z
1?l0000LoookJP_o0000M_oonfX009gooo]Z1?l0000QoookJPGo0000E_oonfX5o`0007gooo]Z1?l0
000QoookJPOo0000MOoonfX009gooo]Z1?l0000QoookJPGo0000E_oonfX5o`0007gooo]Z1?l0000R
oookJPOo0000M?oonfX009gooo]Z1?l0000QoookJPWo0000D_oonfX5o`0007gooo]Z1?l0000Soook
JPOo0000LooonfX009gooo]Z1?l0000RoookJPWo0000DOoonfX5o`0007gooo]Z1?l0000ToookJPOo
0000L_oonfX009gooo]Z1?l0000RoookJPWo0000DOoonfX5o`0007gooo]Z1?l0000UoookJPOo0000
LOoonfX009gooo]Z1?l0000SoookJPWo0000D?oonfX5o`0007gooo]Z1?l0000VoookJPOo0000L?oo
nfX009gooo]Z1?l0000ToookJPWo0000CooonfX5o`0007gooo]Z1?l0000WoookJPOo0000KooonfX0
09gooo]Z1?l0000WoookJPKo0000CooonfX5o`0007gooo]Z1?l0000XoookJPOo0000K_oonfX002;o
oo]Z0ol007meoookJP?o001o1?l00002oookJP?o001o0ooonfX5o`00Oa_ooo]Z2_l0001:oookJPGo
0000M?oonfX5o`00O`Cooo]Z1?l00002oookJPGo001o8_oonfX8o`0004cooo]Z0ol007lMoookJP00
8_oonfX3o`00OgCooo]Z1?l007l4o`0000;ooo]Z0ol007l2oookJPOo001o6ooonfX9o`0004[ooo]Z
1Ol0001coookJPOo001o0ooonfX4o`000003oookJ_l007oo001o00Go001o8_oonfX8o`0004_ooo]Z
0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0001:oookJPGo0000
LooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1?l00004o`00O`04oookJ_l007oo001oo`00
Ob?ooo]Z2?l0001:oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l2oookJPCo00001_oonfX3o`00O`?ooo]Z0ol007lKoookJPWo0000BOoonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o0_oonfX4o`0000?o001o0ooonfX3o`00Ob?ooo]Z1ol0001:oookJP?o
001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l2oookJPCo0000
3?oonfX3o`00Oaoooo]Z2_l00014oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo0000
1_oonfX3o`00ObGooo]Z2_l00015oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oo
nfX4o`0000cooo]Z0ol007lOoookJP_o0000@ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oo
nfX4o`0000Kooo]Z0ol007lVoookJP[o0000A?oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3
o`00O`;ooo]Z1?l00007oookJP;o001o0_oonfX4o`00Ob3ooo]Z3?l00011oookJPGo0000L_oonfX3
o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Zo`00Ool007l00_oonfX4o`00ObKooo]Z2_l00014
oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o0_oonfX4o`0000Oooo]Z1ol007lRoook
JPco0000@?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`000003oookJ_l007oo001o
00Go001o:?oonfX:o`0004?ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo
00001ooonfX6o`00ObCooo]Z3_l0000moookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo
000000?ooo]Zo`00Ool007l01?l007lZoookJPko0000?_oonfX3o`00Oagooo]Z000OoookJPKo001o
LooonfX3o`00O`03oookJ_l0003o000000?o00001ooonfX2o`00Obgooo]Z2Ol0000moookJPGo0000
L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Zo`00Ool007l0<_oonfX;o`0003[ooo]Z
1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l5o`0000Oooo]Z0_l007l_oookJPWo0000>ooo
nfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPGo000000?ooo]Zo`00Ool007l0
<ooonfX=o`0003Oooo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z0ol007l5o`0000Sooo]Z1ol0
07lZoookJPco0000=ooonfX5o`0007?ooo]Z1ol007l2oookJPGo00000_oonfX7o`00Obkooo]Z3_l0
000goookJPCo001o7OoonfX002;ooo]Z0ol007meoookJP;o001o1?l00009oookJPOo001o;?oonfX<
o`0003Gooo]Z1Ol0001doookJPGo001o0ooonfX5o`0000;ooo]Z1ol007l_oookJPko0000=ooonfX3
o`00Oagooo]Z002LoookJPCo0000?OoonfX;o`0003Gooo]Z1Ol0001loookJPCo0000?_oonfX;o`00
05Gooo]Z002LoookJPCo0000?_oonfX@o`0002oooo]Z1Ol0001loookJPCo0000@OoonfX=o`00053o
oo]Z002LoookJPCo0000?ooonfX@o`0002kooo]Z1Ol0001loookJPCo0000@ooonfX<o`0004oooo]Z
002LoookJPCo0000A?oonfXAo`0002Sooo]Z1Ol0001loookJPCo0000A?oonfXAo`0004Wooo]Z002L
oookJPCo0000AOoonfXFo`0002;ooo]Z1Ol0001loookJPCo0000AOoonfXFo`0004?ooo]Z002Loook
JPCo0000BooonfXGo`0001_ooo]Z1Ol0001loookJPCo0000BooonfXGo`0003cooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`00
00oooo]Z000MoookJP03o`000?oonf[o000000Co00000_oonfX6o`000003oookJ_l0003o0000027o
0000C?oonfX4o`0006kooo]Z1?l00002oookJPGo00000_oonfX<o`000003oookJ_l0003o000000Co
000000?ooo]Zo`000?l000008ol0001:oookJPCo0000KOoonfX5o`0000;ooo]Z1Ol00002oookJPGo
00007_oonfX003[ooo]Z5ol0001;oookJPCo0000OOoonfX5o`0001[ooo]Z6ol00017oookJPCo0000
W_oonfX0047ooo]Z5_l00015oookJPCo0000OOoonfX5o`00027ooo]Z5ol00014oookJPCo0000W_oo
nfX004Oooo]Z4Ol00014oookJPCo0000OOoonfX5o`0002Oooo]Z5?l00011oookJPCo0000W_oonfX0
04gooo]Z4?l0000ooookJPCo0000OOoonfX5o`0002oooo]Z3_l0000ooookJPCo0000W_oonfX004ko
oo]Z4?l0000noookJPCo0000OOoonfX5o`0003;ooo]Z3?l0000noookJPCo0000W_oonfX005?ooo]Z
2ol0000noookJPCo0000OOoonfX5o`0003Gooo]Z2ol0000loookJPCo0000W_oonfX005Gooo]Z3_l0
000ioookJPCo0000OOoonfX5o`0003Sooo]Z2_l0000joookJPCo0000W_oonfX005Gooo]Z3ol0000h
oookJPCo0000OOoonfX5o`0003[ooo]Z2Ol0000ioookJPCo0000W_oonfX005[ooo]Z2ol0000goook
JPCo0000OOoonfX5o`0003_ooo]Z2_l0000goookJPCo0000W_oonfX005_ooo]Z2ol0000foookJPCo
0000OOoonfX5o`0003gooo]Z2Ol0000foookJPCo0000W_oonfX005cooo]Z3_l0000boookJPCo0000
OOoonfX5o`0003oooo]Z2Ol0000doookJPCo0000W_oonfX0067ooo]Z2_l0000aoookJPCo0000OOoo
nfX5o`00043ooo]Z2_l0000boookJPCo0000W_oonfX006;ooo]Z2_l0000`oookJPCo0000OOoonfX5
o`0004;ooo]Z2Ol0000aoookJPCo0000W_oonfX006;ooo]Z2_l0000`oookJPCo0000OOoonfX5o`00
04?ooo]Z2Ol0000`oookJPCo0000W_oonfX006?ooo]Z2_l0000_oookJPCo0000OOoonfX5o`0004Go
oo]Z2?l0000_oookJPCo0000W_oonfX006Sooo]Z2Ol0000[oookJPCo0000OOoonfX5o`0004Oooo]Z
2_l0000[oookJPCo0000W_oonfX006Sooo]Z2Ol0000[oookJPCo0000OOoonfX5o`0004Sooo]Z2_l0
000ZoookJPCo0000W_oonfX006Wooo]Z2Ol0000ZoookJPCo0000OOoonfX5o`0004Wooo]Z2Ol0000Z
oookJPCo0000W_oonfX006Wooo]Z2_l0000YoookJPCo0000OOoonfX5o`0004Wooo]Z2Ol0000Zoook
JPCo0000W_oonfX006[ooo]Z2Ol0000YoookJPCo0000OOoonfX5o`0004_ooo]Z2?l0000YoookJPCo
0000W_oonfX006kooo]Z1_l0000XoookJPCo0000OOoonfX5o`0004kooo]Z1_l0000XoookJPCo0000
W_oonfX006oooo]Z2Ol0000SoookJPGo0000OOoonfX5o`0004kooo]Z2_l0000ToookJPCo0000W_oo
nfX006oooo]Z2Ol0000SoookJPGo0000OOoonfX5o`0004oooo]Z2_l0000SoookJPCo0000W_oonfX0
073ooo]Z2Ol0000RoookJPGo0000OOoonfX5o`00053ooo]Z2Ol0000SoookJPCo0000W_oonfX0073o
oo]Z2_l0000QoookJPCo0000O_oonfX5o`00057ooo]Z2Ol0000RoookJPCo0000W_oonfX007Cooo]Z
1_l0000QoookJPCo0000O_oonfX5o`0005Gooo]Z1Ol0000RoookJPCo0000W_oonfX007Gooo]Z1Ol0
000QoookJPCo0000O_oonfX5o`0005Gooo]Z1_l0000QoookJPCo0000W_oonfX007Kooo]Z2?l0000M
oookJPCo0000O_oonfX5o`0005Kooo]Z2Ol0000MoookJPCo0000W_oonfX007Kooo]Z2Ol0000Loook
JPCo0000O_oonfX5o`0005Kooo]Z2Ol0000MoookJPCo0000W_oonfX007Kooo]Z2Ol0000LoookJPCo
0000O_oonfX5o`0005Oooo]Z2Ol0000KoookJPGo0000W_oonfX007Oooo]Z2Ol0000KoookJPCo0000
O_oonfX5o`0005Oooo]Z2Ol0000KoookJPGo0000W_oonfX007_ooo]Z1Ol0000KoookJPCo0000O_oo
nfX5o`0005_ooo]Z1Ol0000KoookJPGo0000W_oonfX007_ooo]Z1_l0000JoookJPCo0000O_oonfX5
o`0005cooo]Z1Ol0000JoookJPCo0000WooonfX007cooo]Z1Ol0000JoookJPCo0000O_oonfX5o`00
05cooo]Z1Ol0000JoookJPCo0000WooonfX007cooo]Z2Ol0000FoookJPCo0000H?oonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`0005cooo]Z2Ol0000FoookJPCo0000WooonfX007gooo]Z
2Ol0000EoookJPCo0000GooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0005gooo]Z
2?l0000FoookJPCo0000WooonfX007gooo]Z2Ol0000EoookJPCo0000GooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wo
oo]Z1Ol0001MoookJPWo00005OoonfX4o`0009oooo]Z001moookJPWo00005OoonfX4o`0005kooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000GOoonfX9o`0001Gooo]Z
1?l0002OoookJP00O_oonfX9o`0001Cooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l8oookJPKo0000GOoonfX9o`0001Cooo]Z1?l0002OoookJP00P_oonfX5o`0001Cooo]Z1?l0001N
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000H_oonfX6o`0001?ooo]Z1?l0002O
oookJP00P_oonfX5o`0001Cooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oook
JPCo001o2?oonfX5o`0006;ooo]Z1_l0000CoookJPCo0000WooonfX008?ooo]Z1?l0000DoookJPCo
0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`0006?ooo]Z1_l0000BoookJPCo
0000WooonfX008?ooo]Z2?l0000@oookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o
2_oonfX5o`0006Cooo]Z1_l0000AoookJPCo0000WooonfX008?ooo]Z2Ol0000?oookJPCo0000G_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0006Cooo]Z1_l0000AoookJPCo0000Wooo
nfX008?ooo]Z2Ol0000?oookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l0
07l>oookJPGo0000IOoonfX6o`00013ooo]Z1?l0002OoookJP00Q?oonfX8o`0000oooo]Z1?l0001O
oookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001VoookJPKo00003ooonfX4o`0009oooo]Z0024oook
JPWo00003_oonfX4o`00063ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0006Kooo]Z1_l0000?oook
JPCo0000WooonfX008Gooo]Z2?l0000>oookJPCo0000O_oonfX5o`0006Oooo]Z1_l0000>oookJPCo
0000WooonfX008Sooo]Z1_l0000=oookJPCo0000O_oonfX5o`0006Sooo]Z1Ol0000>oookJPCo0000
WooonfX008Wooo]Z1Ol0000=oookJPCo0000O_oonfX5o`0006Sooo]Z1_l0000=oookJPCo0000Wooo
nfX008Wooo]Z1Ol0000=oookJPCo0000O_oonfX5o`0006Wooo]Z1_l0000<oookJPCo0000WooonfX0
08[ooo]Z2?l00009oookJPCo0000O_oonfX5o`0006Wooo]Z2Ol00009oookJPCo0000WooonfX008[o
oo]Z2Ol00007oookJPGo0000O_oonfX5o`0006[ooo]Z2Ol00008oookJPCo0000WooonfX008[ooo]Z
2Ol00007oookJPGo0000O_oonfX5o`0006_ooo]Z2?l00008oookJPCo0000WooonfX008[ooo]Z2_l0
0006oookJPGo0000O_oonfX5o`0006_ooo]Z2Ol00007oookJPCo0000WooonfX008[ooo]Z2_l00006
oookJPCo0000OooonfX5o`0006cooo]Z2?l00007oookJPCo0000WooonfX008_ooo]Z2Ol00006oook
JPCo0000OooonfX5o`0006gooo]Z1ol00007oookJPCo0000WooonfX008_ooo]Z2Ol00006oookJPCo
0000OooonfX5o`00073ooo]Z1?l00007oookJPCo0000WooonfX0093ooo]Z1?l000000ooonf[o0000
o`000002o`000003oookJ_l0003o000000;o0000OooonfX5o`00073ooo]Z1?l000000ooonf[o0000
o`000002o`0000;ooo]Z1?l0002OoookJP00T?oonfX4o`000003oookJ_l0003o000000Oo0000Oooo
nfX5o`00073ooo]Z1?l000000ooonf[o0000o`000002o`0000;ooo]Z1?l0002OoookJP00T?oonfX>
o`0007oooo]Z1Ol0001`oookJP[o000000?ooo]Zo`000?l000000_l0002OoookJP00T?oonfX>o`00
07oooo]Z1Ol0001`oookJP[o000000?ooo]Zo`000?l000000_l0002OoookJP00T?oonfX>o`0007oo
oo]Z1Ol0001`oookJP[o000000?ooo]Zo`000?l000000_l0002OoookJP00T?oonfX>o`0007oooo]Z
1Ol0001aoookJPWo000000?ooo]Zo`000?l000000_l0002OoookJP00TOoonfX=o`0007oooo]Z1Ol0
001aoookJPko0000WooonfX0097ooo]Z3Ol0001ooookJPGo0000LOoonfX>o`0009oooo]Z002Aoook
JPgo0000OooonfX5o`00077ooo]Z3_l0002OoookJP00TOoonfX=o`0007oooo]Z1Ol0001aoookJPgo
0000X?oonfX0097ooo]Z3Ol0001ooookJPGo0000LOoonfX=o`000:3ooo]Z002BoookJPco0000Oooo
nfX5o`0007;ooo]Z3?l0002PoookJP00UooonfX7o`0007oooo]Z1Ol0001foookJPSo0000X?oonfX0
09Oooo]Z1ol0001ooookJPGo0000M_oonfX8o`000:3ooo]Z002GoookJPOo0000OooonfX5o`0007Ko
oo]Z2?l0002PoookJP00UooonfX7o`0007oooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0
001ooookJPGo0000MooonfX7o`000:3ooo]Z002GoookJPOo0000OooonfX5o`0007Oooo]Z1ol0002P
oookJP00UooonfX7o`0007;ooo]Z0ol007l:oookJPGo0000MooonfX7o`000:3ooo]Z002GoookJPOo
0000L_oonfX3o`00O`[ooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0001boookJP?o001o
2_oonfX5o`0007Oooo]Z1ol0002PoookJP00UooonfX7o`0007;ooo]Z0ol007l:oookJPGo0000Mooo
nfX7o`000:3ooo]Z002GoookJPOo0000L_oonfX3o`00O`[ooo]Z1_l0001goookJPKo0000X?oonfX0
09Oooo]Z1ol0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00UooonfX7o`0007;o
oo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002GoookJPOo0000L_oonfX3o`00O`[ooo]Z
1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0
002PoookJP00V?oonfX6o`0006oooo]Z1_l007l:oookJPGo0000N?oonfX5o`000:7ooo]Z002Hoook
JPKo0000KooonfX6o`00O`[ooo]Z1Ol0001hoookJPGo0000XOoonfX009Sooo]Z1_l0001aoookJPCo
001o2_oonfX5o`0007Sooo]Z1Ol0002QoookJP00V?oonfX5o`0007?ooo]Z0ol007l:oookJPGo0000
N?oonfX5o`000:7ooo]Z002HoookJPGo0000P?oonfX5o`0007Sooo]Z1Ol0002QoookJP00VOoonfX4
o`00083ooo]Z1Ol0001hoookJPGo0000XOoonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`ko
oo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z
1?l007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0
003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX0
0?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o
001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000
oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4
o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoook
JP00oooonfX?oookJPGo001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXC
oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oo
oo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001o
oooonfX/oookJP00oooonfX>oookJPOo001ooooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^
oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.06244 .31091 L
.06361 .31096 L
.06484 .31054 L
.06548 .31019 L
.06619 .30976 L
.06744 .30908 L
.06861 .30877 L
.06988 .30896 L
.07107 .3096 L
.07216 .3104 L
.07281 .31088 L
.07349 .31133 L
.07425 .31169 L
.07495 .31187 L
.07567 .31186 L
.07634 .31171 L
.0776 .31111 L
.07876 .31044 L
.07998 .30992 L
.08062 .30981 L
.08132 .30987 L
.08255 .31038 L
.08402 .31147 L
.0854 .31255 L
.08616 .313 L
.087 .31326 L
.08775 .31329 L
.08845 .31315 L
.08971 .31257 L
.09107 .31184 L
.09185 .31153 L
.09256 .31141 L
.09324 .31146 L
.09396 .31171 L
.09523 .31256 L
.09642 .31361 L
.09714 .31424 L
.09783 .31475 L
.09911 .31532 L
.10038 .31529 L
.10109 .31505 L
.10175 .31474 L
.10251 .31433 L
.10323 .31399 L
.10388 .31377 L
.10458 .31367 L
.10576 .31394 L
.10686 .31465 L
.10805 .31575 L
Mistroke
.10931 .31699 L
.1105 .31786 L
.11163 .31822 L
.11264 .31813 L
.11373 .31771 L
.11505 .31707 L
.11629 .31673 L
.11757 .31695 L
.11825 .31734 L
.11898 .31795 L
.1202 .31924 L
.12149 .32063 L
.12259 .32152 L
.1238 .32197 L
.12445 .32197 L
.12516 .3218 L
.12642 .32125 L
.12715 .32093 L
.12791 .32071 L
.12856 .32067 L
.12927 .32082 L
.13057 .32168 L
.1313 .32243 L
.13196 .32322 L
.13326 .32483 L
.13445 .32603 L
.13562 .32668 L
.13685 .32672 L
.13809 .3263 L
.1388 .32599 L
.13945 .32576 L
.14062 .32564 L
.14188 .32618 L
.14305 .32732 L
.14415 .32879 L
.14529 .33039 L
.14651 .3318 L
.14767 .33256 L
.14873 .33271 L
.14991 .33241 L
.15119 .3319 L
.15184 .33174 L
.15254 .33173 L
.15379 .3323 L
.15448 .33295 L
.15511 .33374 L
.15655 .33595 L
.15779 .33786 L
.15845 .33869 L
.15916 .33937 L
Mistroke
.16038 .33993 L
.16153 .33982 L
.16284 .33933 L
.16404 .33903 L
.16517 .33928 L
.16638 .34033 L
.16752 .34201 L
.16855 .34385 L
.16977 .34601 L
.17109 .34775 L
.17233 .34852 L
.17348 .34851 L
.17455 .34812 L
.17556 .34777 L
.17666 .34777 L
.17784 .34853 L
.17908 .35026 L
.18025 .35255 L
.1814 .35494 L
.18245 .35684 L
.18359 .35823 L
.18482 .35877 L
.1859 .35858 L
.18704 .35809 L
.1883 .35783 L
.18947 .35835 L
.19075 .36006 L
.19146 .36148 L
.19211 .36298 L
.19334 .36596 L
.19465 .36867 L
.19533 .36968 L
.19608 .37038 L
.19739 .37061 L
.19873 .37001 L
.2 .36949 L
.20113 .36974 L
.20237 .37123 L
.20353 .37374 L
.20476 .37715 L
.20582 .38011 L
.20697 .38267 L
.20766 .3837 L
.2083 .38424 L
.20955 .38428 L
.21069 .38355 L
.2119 .38279 L
.21296 .38279 L
.21409 .38401 L
.21517 .38642 L
Mistroke
.21614 .38944 L
.2173 .39344 L
.21855 .39727 L
.21972 .39961 L
.2208 .40031 L
.22198 .3997 L
.2231 .39845 L
.22431 .39741 L
.22563 .39789 L
.22691 .40066 L
.22763 .40315 L
.22828 .40582 L
.22957 .41144 L
.23075 .41586 L
.23185 .41834 L
.23302 .41876 L
.23419 .41722 L
.23548 .41458 L
.23659 .41298 L
.23778 .4134 L
.23891 .41651 L
.23994 .4215 L
.24121 .42932 L
.24241 .43629 L
.24366 .44088 L
.24433 .44165 L
.24505 .44107 L
.24578 .43909 L
.24655 .43588 L
.24727 .43244 L
.24793 .42938 L
.24921 .42591 L
.24988 .42626 L
.25061 .42878 L
.25191 .43912 L
.25265 .4476 L
.25333 .45628 L
.25455 .47105 L
.25525 .47704 L
.2559 .47978 L
.25703 .4756 L
.25824 .45572 L
.25953 .41616 L
.26072 .36638 L
.26318 .24781 L
.26438 .19789 L
.26549 .16413 L
.26678 .14247 L
.26745 .13844 L
.26816 .13894 L
Mistroke
.26932 .14763 L
.27058 .16307 L
.27176 .1774 L
.27287 .18728 L
.27415 .19209 L
.27532 .19071 L
.27641 .18621 L
.27743 .18136 L
.27855 .17742 L
.27973 .17653 L
.28101 .17994 L
.28218 .18614 L
.28344 .194 L
.28411 .19782 L
.28482 .2012 L
.28602 .20463 L
.28714 .2051 L
.28843 .20326 L
.28959 .20086 L
.29027 .19976 L
.29099 .19919 L
.29228 .20021 L
.29299 .20196 L
.29366 .20425 L
.29519 .21073 L
.29649 .21604 L
.29773 .21944 L
.29842 .2204 L
.29916 .22071 L
.30046 .21986 L
.3016 .21857 L
.30279 .21774 L
.3041 .21844 L
.3053 .22086 L
.30642 .2243 L
.30747 .22792 L
.30861 .23152 L
.30984 .23423 L
.31054 .23505 L
.31119 .23535 L
.31246 .23495 L
.31362 .23411 L
.31485 .23362 L
.31617 .23436 L
.3174 .23649 L
.31811 .23823 L
.31875 .24002 L
.32021 .2441 L
.3215 .24691 L
.32222 .2479 L
Mistroke
.32288 .24841 L
.32415 .24846 L
.32535 .24787 L
.32604 .24754 L
.32676 .24738 L
.32805 .2479 L
.32877 .24874 L
.32944 .24987 L
.33097 .25329 L
.3323 .25644 L
.33355 .25877 L
.33468 .25993 L
.33591 .26019 L
.33654 .26003 L
.33724 .25974 L
.33792 .25945 L
.33866 .25927 L
.33997 .25962 L
.3412 .26095 L
.36125 .27859 L
.36247 .27816 L
.36377 .27819 L
.36444 .27852 L
.36519 .27916 L
.3665 .28088 L
.36772 .28283 L
.36889 .28454 L
.36953 .28529 L
.37023 .28589 L
.37145 .28632 L
.37219 .28625 L
.37298 .286 L
.37367 .28572 L
.3744 .28546 L
.37515 .28532 L
.37585 .28538 L
.37716 .28611 L
.37848 .28759 L
.37987 .28953 L
.38117 .29117 L
.38235 .29211 L
.38356 .29241 L
.3847 .29216 L
.38591 .29165 L
.38723 .29127 L
.38837 .29142 L
.38959 .2922 L
.39063 .29329 L
.39177 .29472 L
.39309 .29622 L
Mistroke
.39434 .29713 L
.39503 .29734 L
.39578 .29734 L
.3971 .29691 L
.39835 .29635 L
.39905 .29612 L
.39969 .29605 L
.40093 .29635 L
.4021 .29719 L
.40433 .29958 L
.40545 .30062 L
.40669 .30124 L
.40774 .30128 L
.40888 .30091 L
.40994 .30039 L
.41092 .29998 L
.41215 .29981 L
.41279 .29995 L
.41348 .30027 L
.41464 .30117 L
.41591 .30243 L
.41704 .30346 L
.41826 .30419 L
.41941 .30435 L
.42047 .30409 L
.42163 .30352 L
.4229 .30291 L
.42409 .30265 L
.4252 .30287 L
.42648 .30365 L
.42713 .30419 L
.42785 .30484 L
.42911 .30588 L
.43026 .30649 L
.43142 .30661 L
.43253 .3063 L
.43369 .30569 L
.43496 .30503 L
.43607 .30474 L
.43725 .30488 L
.43836 .30545 L
.43937 .30621 L
.44067 .30726 L
.44138 .30773 L
.44204 .30804 L
.44321 .30822 L
.44449 .30788 L
.44598 .30706 L
.44671 .30665 L
.44739 .30636 L
Mistroke
.44866 .30615 L
.44932 .30626 L
.45003 .30655 L
.45123 .30732 L
.45253 .30829 L
.45375 .309 L
.45488 .30927 L
.45608 .30907 L
.45734 .30844 L
.45865 .30766 L
.45939 .30731 L
.46007 .3071 L
.46132 .30711 L
.46195 .30732 L
.46264 .30767 L
.46382 .30846 L
.46507 .3093 L
.4663 .3098 L
.46743 .30984 L
.46855 .30946 L
.46962 .30886 L
.47085 .30811 L
.47216 .30759 L
.47339 .30758 L
.47451 .30799 L
.47586 .30883 L
.47659 .30932 L
.47728 .30972 L
.4785 .31013 L
.47914 .31016 L
.47983 .31004 L
.48105 .30949 L
.48221 .30876 L
.48326 .30816 L
.48438 .30777 L
.48561 .30781 L
.48674 .30825 L
.48796 .309 L
.48864 .30944 L
.4893 .30981 L
.49045 .31021 L
.49151 .31021 L
.49265 .3098 L
.49389 .30907 L
.49498 .30839 L
.49613 .30789 L
.49722 .30778 L
.4982 .30801 L
.4994 .30864 L
.50052 .30935 L
Mistroke
.50175 .31 L
.50307 .31026 L
.50374 .31018 L
.50446 .30993 L
.50577 .30919 L
.50693 .30845 L
.50822 .30789 L
.50942 .3078 L
.51055 .30815 L
.51173 .30883 L
.51301 .30964 L
.51414 .31016 L
.51532 .3103 L
.51634 .31005 L
.51744 .30949 L
.51885 .3086 L
.51954 .30824 L
.52018 .308 L
.52137 .30788 L
.52266 .30829 L
.52394 .30906 L
.52531 .30994 L
.5261 .31031 L
.52682 .31049 L
.52754 .31049 L
.52823 .31034 L
.52944 .30976 L
.53056 .30906 L
.53179 .30842 L
.5331 .30816 L
.53377 .30825 L
.5345 .30851 L
.53581 .30931 L
.53709 .3102 L
.53826 .3108 L
.53949 .31099 L
.54064 .31072 L
.54187 .31007 L
.5425 .30969 L
.54319 .30929 L
.54435 .30884 L
.54558 .30882 L
.54672 .30927 L
.54779 .30998 L
.54907 .31094 L
.54977 .31138 L
.55042 .31168 L
.55157 .31189 L
.55282 .3116 L
.55416 .31089 L
Mistroke
.55486 .31048 L
.55561 .31011 L
.55626 .3099 L
.55698 .30981 L
.55824 .31011 L
.55893 .3105 L
.55957 .31096 L
.561 .31212 L
.56163 .31258 L
.56233 .31298 L
.56358 .31331 L
.5648 .31309 L
.5661 .31246 L
.56732 .31181 L
.56843 .31144 L
.56972 .31154 L
.57039 .31183 L
.5711 .3123 L
.57231 .31334 L
.5736 .31445 L
.57434 .31495 L
.57501 .31524 L
.57633 .31534 L
.57706 .31514 L
.57786 .31478 L
.57861 .31438 L
.57931 .31403 L
.58054 .31368 L
.58166 .31382 L
.58287 .31451 L
.58419 .31571 L
.58534 .31684 L
.58656 .31779 L
.58772 .31821 L
.58876 .31815 L
.58941 .31794 L
.5901 .31762 L
.59133 .31703 L
.59202 .3168 L
.59266 .31672 L
.59336 .31681 L
.59412 .31713 L
.59477 .31759 L
.59547 .31825 L
.59676 .31965 L
.59791 .32085 L
.59916 .32173 L
.60046 .32198 L
.60168 .32167 L
.60301 .32107 L
Mistroke
.60376 .32079 L
.60446 .32067 L
.60515 .32073 L
.60589 .32102 L
.60668 .3216 L
.6074 .32232 L
.6088 .32403 L
.61009 .32553 L
.6113 .32647 L
.61258 .32677 L
.61387 .32647 L
.6146 .32616 L
.61529 .32588 L
.61653 .32562 L
.61765 .32592 L
.61896 .327 L
.6202 .32859 L
.62145 .33034 L
.6221 .33117 L
.6228 .33188 L
.62407 .33263 L
.62524 .33267 L
.62637 .3323 L
.62743 .33188 L
.62858 .33171 L
.62981 .33218 L
.63114 .33352 L
.63188 .33459 L
.63257 .33568 L
.63381 .33761 L
.63447 .33849 L
.63517 .33922 L
.6364 .33989 L
.63754 .33987 L
.63885 .3394 L
.64005 .33905 L
.64118 .3392 L
.64239 .34013 L
.64353 .34171 L
.64456 .34352 L
.64578 .34571 L
.6471 .34756 L
.64834 .34847 L
.64949 .34855 L
.65056 .3482 L
.65156 .34782 L
.65267 .34773 L
.65385 .34835 L
.65508 .34995 L
.65626 .35216 L
Mistroke
.6574 .35456 L
.65846 .35654 L
.65959 .35806 L
.66082 .35875 L
.6619 .35865 L
.66304 .35817 L
.66429 .35782 L
.66546 .3582 L
.66673 .35972 L
.66745 .36106 L
.6681 .3625 L
.66933 .36547 L
.67063 .3683 L
.67131 .36941 L
.67206 .37023 L
.67337 .37065 L
.67461 .37018 L
.6753 .36981 L
.67595 .36955 L
.6772 .36967 L
.67835 .37088 L
.68716 .38334 L
.69677 .40028 L
.69933 .3984 L
.70003 .3977 L
.70077 .39733 L
.7014 .39749 L
.70209 .39828 L
.70334 .40143 L
.70405 .40404 L
.70469 .40674 L
.70594 .41222 L
.7071 .41636 L
.70822 .41855 L
.70941 .41861 L
.7106 .4168 L
.71191 .41412 L
.71305 .41284 L
.71426 .41394 L
.71541 .41784 L
.71647 .42348 L
.71769 .43111 L
.719 .43813 L
.72023 .44147 L
.72135 .44084 L
.72267 .43621 L
.72337 .43288 L
.7241 .42948 L
.72474 .42715 L
.72545 .42588 L
Mistroke
.72669 .42828 L
.72741 .43278 L
.72809 .43903 L
.72937 .45439 L
.7301 .46364 L
.73087 .47229 L
.73153 .47757 L
.73225 .47993 L
.73353 .47205 L
.73474 .44793 L
.73604 .40383 L
.73745 .3407 L
.73984 .22705 L
.74052 .1997 L
.74117 .17797 L
.74239 .14984 L
.74354 .13875 L
.7446 .14009 L
.74576 .15046 L
.747 .16597 L
.74823 .18041 L
.74893 .18639 L
.74957 .19006 L
.7508 .19211 L
.75197 .18904 L
.75263 .18609 L
.75333 .1827 L
.75459 .17778 L
.75537 .17646 L
.75609 .17673 L
.75675 .17825 L
.75745 .18109 L
.75879 .18871 L
.76022 .19737 L
.76091 .20077 L
.76156 .20316 L
.76279 .20518 L
.76408 .20424 L
.76481 .20287 L
.76548 .20145 L
.76622 .2001 L
.76691 .19932 L
.76764 .19923 L
.76844 .20015 L
.76967 .20357 L
.77097 .20894 L
.7721 .21381 L
.7733 .21798 L
.77459 .22039 L
.7758 .22058 L
Mistroke
.77654 .21999 L
.77724 .2192 L
.77854 .21792 L
.77969 .21787 L
.78093 .21954 L
.7821 .22263 L
.78317 .22623 L
.78442 .23041 L
.78508 .23227 L
.78578 .23381 L
.78707 .23525 L
.78826 .23518 L
.78896 .23474 L
.7896 .23426 L
.7903 .23382 L
.79105 .23362 L
.7923 .23428 L
.793 .23531 L
.79366 .23666 L
.79487 .23981 L
.79618 .24352 L
.79741 .24642 L
.79856 .24805 L
.79963 .24856 L
.80082 .24826 L
.80206 .24761 L
.80322 .24739 L
.80429 .24794 L
.80527 .24921 L
.80634 .25134 L
.80747 .25404 L
.80861 .25671 L
.80983 .25889 L
.81098 .25999 L
.81203 .2602 L
.81326 .25981 L
.81391 .25953 L
.81459 .25931 L
.81585 .25944 L
.81701 .26043 L
.82719 .26945 L
.83685 .27881 L
.83789 .27841 L
.83901 .2781 L
.84008 .27823 L
.84105 .27884 L
.84208 .28 L
.84317 .28163 L
.84439 .28356 L
.84552 .28508 L
Mistroke
.84665 .28603 L
.84785 .28632 L
.84854 .28622 L
.8492 .28599 L
.85042 .28551 L
.85155 .28531 L
.85259 .28559 L
.85374 .28648 L
.85495 .28797 L
.85614 .28964 L
.85726 .29106 L
.85856 .29212 L
.85974 .29241 L
.86085 .29218 L
.86189 .29174 L
.86302 .29134 L
.86423 .29132 L
.86492 .29158 L
.86555 .29201 L
.86625 .29266 L
.86699 .2935 L
.86833 .29517 L
.86958 .2965 L
.8707 .2972 L
.8719 .29735 L
.87258 .2972 L
.87323 .29694 L
.87444 .29639 L
.87564 .29606 L
.87632 .29608 L
.87696 .29627 L
.87825 .29716 L
.87898 .29788 L
.87964 .29862 L
.88086 .29993 L
.88199 .30085 L
.88317 .30129 L
.88446 .30115 L
.88514 .30088 L
.88588 .30052 L
.88653 .3002 L
.88722 .29994 L
.88852 .29983 L
.88972 .3003 L
.89039 .30079 L
.89111 .30143 L
.8924 .30272 L
.89319 .30343 L
.89394 .30395 L
.89461 .30424 L
Mistroke
.89535 .30436 L
.89791 .30348 L
.89861 .30312 L
.89926 .30285 L
.89994 .30268 L
.90068 .30268 L
.90195 .30314 L
.90266 .30363 L
.9033 .30417 L
.90455 .30529 L
.9057 .30614 L
.90682 .30658 L
.90801 .30654 L
.90921 .30606 L
.91052 .30534 L
.91165 .30486 L
.91287 .30475 L
.91402 .30513 L
.91507 .30582 L
.91637 .30687 L
.91707 .30741 L
.91774 .30782 L
.91904 .30822 L
.92022 .30806 L
.9209 .30777 L
.92162 .30738 L
.92292 .30665 L
.92364 .30634 L
.92431 .30617 L
.92504 .30617 L
.92584 .30637 L
.92715 .30712 L
.92858 .30819 L
.92924 .30863 L
.92994 .309 L
.93119 .30927 L
.93238 .30903 L
.93351 .30846 L
.93474 .30772 L
.93542 .30737 L
.93607 .30714 L
.93734 .30708 L
.9385 .30748 L
.93958 .30816 L
.94076 .30898 L
.94206 .30967 L
.94271 .30984 L
.94343 .30986 L
.9447 .30948 L
.94589 .30881 L
Mistroke
.94653 .30841 L
.94723 .30801 L
.9485 .30756 L
.94974 .30762 L
.95088 .30809 L
.95221 .30894 L
.95291 .3094 L
.95364 .3098 L
.95429 .31004 L
.955 .31016 L
.95624 .30996 L
.95742 .30938 L
.95867 .30859 L
.95986 .30798 L
.96094 .30773 L
.96199 .30786 L
.96313 .30837 L
.9642 .30904 L
.9652 .30966 L
.96635 .31015 L
.96761 .31022 L
.96884 .30981 L
.96953 .30942 L
.97016 .30902 L
.97132 .30831 L
.9724 .30787 L
.97352 .30779 L
.97474 .30817 L
.9755 .30858 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
WooonfX4o`0007[ooo]Z1Ol0001ooookJPGo0000V_oonfX009oooo]Z1?l0001joookJPGo0000Oooo
nfX5o`0009[ooo]Z002OoookJPCo0000N_oonfX5o`0007oooo]Z1Ol0002JoookJP00WooonfX5o`00
07Wooo]Z1Ol0001ooookJPGo0000V_oonfX009oooo]Z1Ol0001ioookJPGo0000O_oonfX6o`0009[o
oo]Z002OoookJPGo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009oooo]Z1Ol0
001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00WooonfX5o`0006cooo]Z0ol007l:
oookJPGo0000O_oonfX6o`0009[ooo]Z002OoookJPGo0000G?oonfX:o`00O`Kooo]Z0ol007l:oook
JPGo0000O_oonfX6o`0009[ooo]Z002NoookJPKo0000G?oonfX:o`00O`Kooo]Z0ol007l:oookJPKo
0000OOoonfX6o`0009[ooo]Z002NoookJPOo0000JooonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000
V_oonfX009kooo]Z1ol0001[oookJP?o001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX7
o`0006_ooo]Z0ol007l:oookJPGo0000O_oonfX7o`0009Wooo]Z002NoookJPOo0000JooonfX3o`00
O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1ol0001XoookJPKo001o2_oonfX5o`0007ko
oo]Z1ol0002IoookJP00W_oonfX7o`0006Sooo]Z1_l007l:oookJPGo0000O_oonfX7o`0009Wooo]Z
002NoookJPOo0000J_oonfX4o`00O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1ol0001[
oookJP?o001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX7o`0007Sooo]Z1Ol0001noook
JPOo0000VOoonfX009kooo]Z1ol0001hoookJPGo0000O_oonfX8o`0009Sooo]Z002NoookJPOo0000
00?ooo]Zo`000?l000000_l0001coookJPGo0000O_oonfX<o`0009Cooo]Z002NoookJPco0000Looo
nfX5o`0007kooo]Z3?l0002DoookJP00W_oonfX<o`0007?ooo]Z1Ol0001noookJPco0000U?oonfX0
09kooo]Z3?l0001coookJPGo0000O_oonfX=o`0009?ooo]Z002MoookJPko0000L_oonfX5o`0007ko
oo]Z3Ol0002CoookJP00WOoonfX>o`0007;ooo]Z1Ol0001noookJPgo0000TooonfX009gooo]Z3_l0
001boookJPGo0000O_oonfX=o`0009?ooo]Z002MoookJPCo000000?ooo]Zo`000?l000001ol0001b
oookJPGo0000O_oonfX=o`0009?ooo]Z002MoookJPCo000000?ooo]Zo`000?l000002?l0001aoook
JPGo0000OOoonfX>o`0009?ooo]Z002MoookJPCo000000?ooo]Zo`000?l000002?l0001aoookJPGo
0000OOoonfX>o`0009?ooo]Z002MoookJPCo000000?ooo]Zo`000?l000002?l0001aoookJPGo0000
OOoonfX?o`0009;ooo]Z002MoookJPCo00000_oonfX4o`000003oookJ_l0003o000000;o0000LOoo
nfX5o`0007gooo]Z1?l000000ooonf[o0000o`000008o`0009;ooo]Z002MoookJPCo00000_oonfX4
o`000003oookJ_l0003o000000;o0000LOoonfX5o`0007gooo]Z1?l00002oookJPWo0000T_oonfX0
09gooo]Z1?l00007oookJPSo0000KOoonfX5o`0007gooo]Z1?l00007oookJPSo0000S_oonfX009go
oo]Z1?l00007oookJPWo0000K?oonfX5o`0007gooo]Z1?l00007oookJPSo0000S_oonfX009gooo]Z
1?l00007oookJPWo0000K?oonfX5o`0007gooo]Z1?l00007oookJPWo0000SOoonfX009gooo]Z1?l0
0007oookJPWo0000K?oonfX5o`0007gooo]Z1?l00007oookJPWo0000SOoonfX009gooo]Z1?l00007
oookJPWo0000K?oonfX5o`0007gooo]Z1?l00007oookJP[o0000S?oonfX009gooo]Z1?l00008oook
JPWo0000JooonfX5o`0007gooo]Z1?l00008oookJPWo0000S?oonfX009gooo]Z1?l00009oookJPSo
0000JooonfX5o`0007gooo]Z1?l00008oookJPWo0000S?oonfX009gooo]Z1?l0000<oookJPGo0000
JooonfX5o`0007gooo]Z1?l0000=oookJPCo0000S?oonfX009gooo]Z1?l0000=oookJPGo0000J_oo
nfX5o`0007gooo]Z1?l0000=oookJPCo0000S?oonfX009gooo]Z1?l0000=oookJPGo0000J_oonfX5
o`0007gooo]Z1?l0000=oookJPGo0000RooonfX009gooo]Z1?l0000=oookJPWo0000I_oonfX5o`00
07gooo]Z1?l0000=oookJPWo0000QooonfX009gooo]Z1?l0000>oookJPSo0000I_oonfX5o`0007go
oo]Z1?l0000=oookJPWo0000QooonfX009gooo]Z1?l0000>oookJPSo0000I_oonfX5o`0007gooo]Z
1?l0000>oookJPWo0000Q_oonfX009gooo]Z1?l0000>oookJPWo0000IOoonfX5o`0007gooo]Z1?l0
000>oookJPWo0000Q_oonfX009gooo]Z1?l0000?oookJPSo0000AooonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o2_oonfX5o`0007gooo]Z1?l0000?oookJPSo0000Q_oonfX009gooo]Z1?l0000Boook
JPKo0000AOoonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0007gooo]Z1?l0000Coook
JPCo0000Q_oonfX009gooo]Z1?l0000CoookJPGo0000AOoonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001m
oookJPCo00004ooonfX5o`0008Gooo]Z002MoookJPCo00004ooonfX5o`0003Sooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0007gooo]Z1?l0000Coook
JPGo0000QOoonfX009gooo]Z1?l0000DoookJPSo0000=?oonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Sooo]Z1_l0001loookJPCo00004ooonfX9o`00087ooo]Z002MoookJPCo0000
5?oonfX8o`00043ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001moookJPCo0000
5?oonfX9o`00083ooo]Z002MoookJPCo00005?oonfX9o`0003oooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l8oookJPGo0000OOoonfX4o`0001Cooo]Z2Ol00020oookJP00WOoonfX4
o`0001Cooo]Z2Ol0000ooookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000OOoonfX4
o`0001Gooo]Z2?l00020oookJP00WOoonfX4o`0001Gooo]Z2Ol0000noookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007l:oookJPGo0000OOoonfX4o`0001Kooo]Z2?l0001ooookJP00WOoonfX4o`0001Wo
oo]Z1Ol0000noookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Wo
oo]Z1Ol0001ooookJP00WOoonfX4o`0001Wooo]Z1_l0000noookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00O`kooo]Z1Ol0001moookJPCo00006OoonfX6o`0007kooo]Z002MoookJPCo0000
6_oonfX5o`0003kooo]Z1ol007l9oookJPOo001o2?oonfX5o`0007gooo]Z1?l0000JoookJPGo0000
O_oonfX009gooo]Z1?l0000JoookJPWo0000>ooonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000OOoo
nfX4o`0001[ooo]Z2Ol0001joookJP00WOoonfX4o`0001_ooo]Z2Ol0001HoookJPGo0000OOoonfX4
o`0001_ooo]Z2?l0001joookJP00WOoonfX4o`0001_ooo]Z2Ol0001HoookJPGo0000OOoonfX4o`00
01_ooo]Z2Ol0001ioookJP00WOoonfX4o`0001cooo]Z2?l0001HoookJPGo0000OOoonfX4o`0001co
oo]Z2Ol0001hoookJP00WOoonfX4o`00023ooo]Z1?l0001HoookJPGo0000OOoonfX4o`0001oooo]Z
1_l0001hoookJP00WOoonfX4o`00023ooo]Z1Ol0001GoookJPGo0000OOoonfX4o`00023ooo]Z1Ol0
001hoookJP00WOoonfX4o`00023ooo]Z2Ol0001CoookJPGo0000OOoonfX4o`00027ooo]Z2?l0001d
oookJP00WOoonfX4o`00023ooo]Z2ol0001AoookJPGo0000OOoonfX4o`00027ooo]Z2Ol0001coook
JP00WOoonfX4o`00027ooo]Z2ol0001@oookJPGo0000OOoonfX4o`00027ooo]Z2_l0001boookJP00
WOoonfX4o`0002;ooo]Z2ol0001?oookJPGo0000OOoonfX4o`0002;ooo]Z2_l0001aoookJP00WOoo
nfX4o`0002?ooo]Z2ol0001>oookJPGo0000OOoonfX4o`0002?ooo]Z2_l0001`oookJP00WOoonfX4
o`0002Sooo]Z1ol0001=oookJPGo0000OOoonfX4o`0002Oooo]Z1ol0001_oookJP00WOoonfX4o`00
02Wooo]Z1ol0001<oookJPGo0000OOoonfX4o`0002Sooo]Z2?l0001]oookJP008_oonfX3o`00OgGo
oo]Z0ol007l4o`0000;ooo]Z0ol007l3oookJPGo001o7OoonfX7o`0004_ooo]Z1Ol0001doookJPGo
001o1?oonfX4o`0000;ooo]Z1Ol007lRoookJPSo0000C?oonfX3o`00Oagooo]Z000RoookJP?o001o
M?oonfX4o`00O`Co00000_oonfX3o`00O`;ooo]Z1ol007lMoookJPOo0000B_oonfX5o`0007?ooo]Z
1ol007l3oookJPCo000000?ooo]Zo`00Ool007l01Ol007lRoookJPSo0000BooonfX3o`00Oagooo]Z
000RoookJP?o001oM?oonfX3o`00O`03oookJ_l0003o000000;o00000_oonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o7_oonfX7o`0004Wooo]Z1Ol0001coookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX4o`0000Co001o00Cooo]Zo`00Ool007oo001o8ooonfX8o`00
04[ooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;o
oo]Z1?l00006oookJP?o001o0ooonfX3o`00Oakooo]Z2Ol00016oookJPGo0000L_oonfX3o`00O`?o
oo]Z0ol007l2oookJPCo00000ol007l3oookJP?o001o9?oonfX9o`0004Oooo]Z0ol007lMoookJP00
4ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`03oookJ_l0003o000000?o0000
3?oonfX3o`00Oaoooo]Z2Ol00015oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo0000
1_oonfX3o`00ObGooo]Z2Ol00016oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?o
oo]Zo`000?l000000ol0000<oookJP?o001o8?oonfX9o`0004Cooo]Z1Ol0001boookJP?o001o0ooo
nfX3o`00O`;ooo]Z1?l00006oookJP?o001o9_oonfX9o`0004Gooo]Z0ol007lMoookJP008_oonfX3
o`00Og?ooo]Z0ol007l00ooonf[o0000o`000003o`0000Oooo]Z0_l007l2oookJPCo001o8OoonfX8
o`0004Cooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02
oookJPCo001o9ooonfX9o`0004Cooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooo
nf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z1ol007lSoookJPco0000?ooonfX5o`00
07;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000ol000000ooonf[o001oo`00O`05o`00
ObWooo]Z3?l00010oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l0
00000_l000000ol007oooo]ZoookJP05oookJPKo001o9ooonfX:o`0003kooo]Z1Ol0001boookJP?o
001o0ooonfX3o`00O`03oookJ_l0003o000000?o000000?ooo]Zo`00Ool007l01?l007l]oookJP[o
0000?ooonfX3o`00Oagooo]Z000OoookJPKo001oLooonfX3o`00O`03oookJ_l0003o000000;o0000
00?o001ooookJ_oonfX01OoonfX2o`00Ob_ooo]Z2ol0000moookJPGo0000L_oonfX3o`00O`?ooo]Z
0ol007l00ooonf[o0000o`000003o`000003oookJ_l007oo001o03;ooo]Z2Ol0000loookJPKo001o
7OoonfX001oooo]Z1_l007mdoookJP?o001o1?l00008oookJP;o001o;?oonfX?o`0003Sooo]Z1Ol0
001coookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`0000;ooo]Z0_l007lboookJPko0000
=ooonfX6o`00Oagooo]Z000QoookJPCo001oM?oonfX3o`00O`Co00002OoonfX7o`00ObOooo]Z3_l0
000hoookJPGo0000LooonfX7o`00O`;ooo]Z1?l00003oookJPOo001o;OoonfX>o`0003Sooo]Z1?l0
07lMoookJP008_oonfX3o`00OgGooo]Z0_l007l4o`0000Wooo]Z1ol007l/oookJP[o0000=ooonfX5
o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX7o`00Oc7ooo]Z2ol0000hoookJP?o001o7OoonfX0
09cooo]Z1?l0000moookJPko0000<_oonfX5o`0007cooo]Z1?l0000loookJPoo0000DooonfX009co
oo]Z1?l0000moookJPoo0000<OoonfX5o`0007cooo]Z1?l0000moookJQ3o0000DOoonfX009cooo]Z
1?l00012oookJQ3o0000:ooonfX5o`0007cooo]Z1?l00012oookJQ3o0000C?oonfX009cooo]Z1?l0
0013oookJQ3o0000:_oonfX5o`0007cooo]Z1?l00013oookJQ3o0000BooonfX009cooo]Z1?l00014
oookJQKo00008ooonfX5o`0007cooo]Z1?l00014oookJQKo0000A?oonfX009cooo]Z1?l00019oook
JQOo000000?ooo]Zo`000?l000000_l0000HoookJPGo0000O?oonfX4o`0004Wooo]Z5ol000000ooo
nf[o0000o`000002o`0003Wooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000
ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000U
o`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000MoookJP03o`000?oonf[ooo]Z00Oo
oo]Z:ol0001:oookJPCo0000LOoonfX5o`0000;ooo]Z1?l000000ooonf[o0000o`000004o`0000;o
oo]Z1Ol000000ooonf[o0000o`000003o`000003oookJ_l0003o0000027o0000B_oonfX4o`00077o
oo]Z1Ol00002oookJPCo00000ooonfX00ol0003ooo]ZoookJP0LoookJP00=ooonfX4o`000003oook
J_l0003o000001Go0000BOoonfX4o`0007gooo]Z1Ol0000GoookJPCo000000?ooo]Zo`000?l00000
5Ol00019oookJPCo0000W_oonfX004;ooo]Z5_l00014oookJPCo0000OOoonfX5o`0002?ooo]Z5Ol0
0014oookJPCo0000W_oonfX004Wooo]Z4?l00013oookJPCo0000OOoonfX5o`0002Wooo]Z4?l00013
oookJPCo0000W_oonfX004[ooo]Z4?l00012oookJPCo0000OOoonfX5o`0002[ooo]Z4?l00012oook
JPCo0000W_oonfX004oooo]Z4?l0000moookJPCo0000OOoonfX5o`0002oooo]Z4?l0000moookJPCo
0000W_oonfX0053ooo]Z4?l0000loookJPCo0000OOoonfX5o`00037ooo]Z3_l0000moookJPCo0000
W_oonfX005Kooo]Z2_l0000loookJPCo0000OOoonfX5o`0003Kooo]Z2_l0000loookJPCo0000W_oo
nfX005Kooo]Z3ol0000goookJPCo0000OOoonfX5o`0003Oooo]Z3_l0000goookJPCo0000W_oonfX0
05Sooo]Z3_l0000foookJPCo0000OOoonfX5o`0003Sooo]Z3_l0000foookJPCo0000W_oonfX005co
oo]Z2_l0000foookJPCo0000OOoonfX5o`0003cooo]Z2ol0000eoookJPCo0000W_oonfX005gooo]Z
2_l0000eoookJPCo0000OOoonfX5o`0003gooo]Z2_l0000eoookJPCo0000W_oonfX005kooo]Z3_l0
000_oookJPGo0000OOoonfX5o`0003kooo]Z3_l0000`oookJPCo0000W_oonfX006;ooo]Z2_l0000_
oookJPGo0000OOoonfX5o`0004;ooo]Z2_l0000`oookJPCo0000W_oonfX006?ooo]Z2_l0000^oook
JPGo0000OOoonfX5o`0004?ooo]Z2_l0000_oookJPCo0000W_oonfX006Cooo]Z2Ol0000^oookJPCo
0000O_oonfX5o`0004Cooo]Z2Ol0000_oookJPCo0000W_oonfX006Gooo]Z2Ol0000]oookJPCo0000
O_oonfX5o`0004Gooo]Z2Ol0000^oookJPCo0000W_oonfX006Wooo]Z2Ol0000YoookJPCo0000O_oo
nfX5o`0004Wooo]Z2Ol0000ZoookJPCo0000W_oonfX006Wooo]Z2_l0000XoookJPCo0000O_oonfX5
o`0004Wooo]Z2_l0000YoookJPCo0000W_oonfX006[ooo]Z2Ol0000XoookJPCo0000O_oonfX5o`00
04[ooo]Z2_l0000XoookJPCo0000W_oonfX006_ooo]Z2Ol0000WoookJPCo0000O_oonfX5o`0004_o
oo]Z2Ol0000XoookJPCo0000W_oonfX006oooo]Z1Ol0000WoookJPCo0000O_oonfX5o`0004oooo]Z
1Ol0000XoookJPCo0000W_oonfX006oooo]Z2Ol0000SoookJPCo0000O_oonfX5o`00053ooo]Z2?l0
000ToookJPCo0000W_oonfX0073ooo]Z2Ol0000RoookJPCo0000O_oonfX5o`00053ooo]Z2Ol0000S
oookJPCo0000W_oonfX0073ooo]Z2_l0000QoookJPCo0000O_oonfX5o`00053ooo]Z2_l0000Roook
JPCo0000W_oonfX0077ooo]Z2Ol0000QoookJPCo0000O_oonfX5o`00057ooo]Z2Ol0000RoookJPCo
0000W_oonfX007;ooo]Z2?l0000QoookJPCo0000O_oonfX5o`00057ooo]Z2Ol0000RoookJPCo0000
W_oonfX007Gooo]Z1_l0000PoookJPCo0000O_oonfX5o`0005Gooo]Z1_l0000QoookJPCo0000W_oo
nfX007Kooo]Z1_l0000OoookJPCo0000O_oonfX5o`0005Kooo]Z1Ol0000QoookJPCo0000W_oonfX0
07Kooo]Z2Ol0000LoookJPCo0000O_oonfX5o`0005Kooo]Z2Ol0000MoookJPCo0000W_oonfX007Oo
oo]Z2Ol0000KoookJPCo0000O_oonfX5o`0005Oooo]Z2Ol0000LoookJPCo0000W_oonfX007Sooo]Z
2?l0000KoookJPCo0000O_oonfX5o`0005Oooo]Z2Ol0000KoookJPGo0000W_oonfX007Sooo]Z2?l0
000KoookJPCo0000O_oonfX5o`0005Sooo]Z2Ol0000JoookJPGo0000W_oonfX007cooo]Z1Ol0000J
oookJPCo0000O_oonfX5o`0005cooo]Z1_l0000IoookJPGo0000W_oonfX007cooo]Z1Ol0000Joook
JPCo0000O_oonfX5o`0005cooo]Z1_l0000IoookJPCo0000WooonfX007cooo]Z1_l0000IoookJPCo
0000H?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0005gooo]Z1_l0000HoookJPCo
0000WooonfX007gooo]Z2?l0000FoookJPCo0000GooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
2OoonfX5o`0005kooo]Z1_l0000GoookJPCo0000WooonfX007gooo]Z2Ol0000EoookJPCo0000Gooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Wooo]Z1Ol0001NoookJPKo00005ooonfX4o`0009oooo]Z001noookJPWo0000
5?oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000
GooonfX6o`0001Kooo]Z1?l0002OoookJP00O_oonfX9o`0001Cooo]Z1?l0001NoookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l8oookJPKo0000GooonfX6o`0001Gooo]Z1?l0002OoookJP00OooonfX8
o`0001Cooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000H?oonfX6
o`0001Gooo]Z1?l0002OoookJP00PooonfX4o`0001Cooo]Z1?l0001NoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`00067ooo]Z1_l0000DoookJPCo0000WooonfX008?o
oo]Z1Ol0000CoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`0006;o
oo]Z1_l0000CoookJPCo0000WooonfX008?ooo]Z1Ol0000CoookJPCo0000G_oonfX3o`00O`?ooo]Z
0ol007l7oookJPKo001o2_oonfX5o`0006;ooo]Z1_l0000CoookJPCo0000WooonfX008?ooo]Z2Ol0
000?oookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0006?ooo]Z2_l0
000>oookJPCo0000WooonfX008Cooo]Z2?l0000?oookJPCo0000GooonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0_l007l>oookJPGo0000I?oonfX9o`0000kooo]Z1?l0002OoookJP00Q?oonfX9
o`0000kooo]Z1?l0001OoookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001ToookJPWo00003_oonfX4
o`0009oooo]Z0024oookJPWo00003_oonfX4o`00063ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`00
06Gooo]Z2?l0000>oookJPCo0000WooonfX008Gooo]Z2Ol0000=oookJPCo0000O_oonfX5o`0006Ko
oo]Z2?l0000=oookJPCo0000WooonfX008Kooo]Z2?l0000=oookJPCo0000O_oonfX5o`0006Wooo]Z
1Ol0000=oookJPCo0000WooonfX008Wooo]Z1Ol0000=oookJPCo0000O_oonfX5o`0006Wooo]Z1Ol0
000=oookJPCo0000WooonfX008[ooo]Z1?l0000=oookJPCo0000O_oonfX5o`0006[ooo]Z1Ol0000<
oookJPCo0000WooonfX008[ooo]Z2?l00009oookJPCo0000O_oonfX5o`0006[ooo]Z2?l00009oook
JPCo0000WooonfX008[ooo]Z2Ol00008oookJPCo0000O_oonfX5o`0006[ooo]Z2Ol00008oookJPCo
0000WooonfX008[ooo]Z2_l00007oookJPCo0000O_oonfX5o`0006_ooo]Z2?l00008oookJPCo0000
WooonfX008[ooo]Z2_l00007oookJPCo0000O_oonfX5o`0006_ooo]Z2Ol00007oookJPCo0000Wooo
nfX008[ooo]Z2_l00007oookJPCo0000O_oonfX5o`0006_ooo]Z2Ol00007oookJPCo0000WooonfX0
08_ooo]Z2Ol00007oookJPCo0000O_oonfX5o`0006_ooo]Z2Ol00007oookJPCo0000WooonfX008co
oo]Z2?l00007oookJPCo0000O_oonfX5o`0006cooo]Z2?l00007oookJPCo0000WooonfX008cooo]Z
2?l000000ooonf[o0000o`000002o`0000;ooo]Z1?l0001noookJPGo0000L?oonfX4o`000003oook
J_l0003o000000;o00000_oonfX4o`0009oooo]Z002@oookJPWo00000_oonfX4o`0007kooo]Z1Ol0
001`oookJPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000003o`0009oooo]Z002@
oookJP[o000000?ooo]Zo`000?l000000_l0001noookJPGo0000L?oonfX?o`0009oooo]Z002@oook
JP[o000000?ooo]Zo`000?l000000_l0001noookJPGo0000L?oonfX?o`0009oooo]Z002AoookJPWo
000000?ooo]Zo`000?l000000_l0001noookJPGo0000L?oonfX>o`000:3ooo]Z002AoookJPWo0000
00?ooo]Zo`000?l000000_l0001noookJPGo0000LOoonfX=o`000:3ooo]Z002AoookJPko0000O_oo
nfX5o`00077ooo]Z3Ol0002PoookJP00TOoonfX>o`0007kooo]Z1Ol0001aoookJPgo0000X?oonfX0
097ooo]Z3_l0001noookJPGo0000LOoonfX=o`000:3ooo]Z002AoookJPko0000O_oonfX5o`0007;o
oo]Z3?l0002PoookJP00TOoonfX=o`0007oooo]Z1Ol0001boookJPco0000X?oonfX009;ooo]Z3?l0
001ooookJPGo0000L_oonfX<o`000:3ooo]Z002BoookJPco0000OooonfX5o`0007;ooo]Z1?l00000
0ooonf[o0000o`000005o`000:3ooo]Z002GoookJPOo0000OooonfX5o`0007Oooo]Z1ol0002Poook
JP00UooonfX7o`0007oooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0001ooookJPGo0000
MooonfX7o`000:3ooo]Z002GoookJPOo0000OooonfX5o`0007Oooo]Z1ol0002PoookJP00UooonfX7
o`0007oooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0001boookJP?o001o2_oonfX5o`00
07Oooo]Z1ol0002PoookJP00UooonfX7o`0007;ooo]Z0ol007l:oookJPGo0000MooonfX7o`000:3o
oo]Z002GoookJPOo0000L_oonfX3o`00O`[ooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0
001boookJP?o001o2_oonfX5o`0007Oooo]Z1ol0002PoookJP00UooonfX7o`0007;ooo]Z0ol007l:
oookJPKo0000MooonfX6o`000:3ooo]Z002GoookJPOo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoook
JPKo0000X?oonfX009Oooo]Z1ol0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00
V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002HoookJPGo0000Looo
nfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1Ol0001`oookJPKo001o2_oonfX5
o`0007Sooo]Z1_l0002PoookJP00V?oonfX5o`00073ooo]Z1_l007l:oookJPGo0000N?oonfX6o`00
0:3ooo]Z002HoookJPGo0000L_oonfX4o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z
1Ol0001coookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX5o`00083ooo]Z1Ol0
001hoookJPGo0000XOoonfX009Sooo]Z1Ol00020oookJPGo0000N?oonfX5o`000:7ooo]Z002Ioook
JPCo0000P?oonfX5o`0007Wooo]Z1?l0002QoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooo
nfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol007l3
oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oook
JPKo0000oooonfXNoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoooo]Z
003ooookJP;ooo]Z0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3
o`00O`Wooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oook
JPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00
oooonfX1oookJPCo001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol0
07l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z3_oonfX4o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oookJPKo
0000oooonfXNoookJP00oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4_oo
nfX3o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003ooook
JPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooo
oo]Z;?oonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z1ol0
07oooookJRgooo]Z003ooookJPoooo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX00?oo
oo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .3083 L
.02605 .30789 L
.02729 .30785 L
.02846 .30828 L
.03056 .30957 L
.03162 .31007 L
.03279 .31024 L
.03405 .30991 L
.03524 .30925 L
.0364 .30852 L
.0375 .308 L
.03879 .30785 L
.03997 .3082 L
.04123 .30894 L
.0419 .30938 L
.04262 .30981 L
.04332 .31013 L
.04396 .3103 L
.04523 .31023 L
.04638 .30974 L
.04759 .30899 L
.0489 .30828 L
.05012 .308 L
.05082 .30806 L
.05146 .30827 L
.0522 .30865 L
.0529 .3091 L
.05405 .30988 L
.05527 .31048 L
.05632 .31065 L
.05747 .3104 L
.05871 .30975 L
.05935 .30935 L
.06004 .30895 L
.06129 .30846 L
.06244 .30846 L
.0631 .30866 L
.0638 .30902 L
.06509 .30991 L
.06623 .31068 L
.06748 .31121 L
.06819 .31127 L
.06885 .31117 L
.06954 .31092 L
.07029 .31053 L
.07094 .31015 L
.07163 .30974 L
.07287 .30923 L
.07411 .30921 L
Mistroke
.07482 .30945 L
.07547 .3098 L
.07666 .31067 L
.07794 .31162 L
.07918 .31222 L
.08032 .3123 L
.08142 .31197 L
.08257 .31135 L
.08327 .31095 L
.08394 .31064 L
.08519 .31037 L
.08589 .31046 L
.08654 .31071 L
.08725 .31113 L
.088 .31172 L
.08916 .3127 L
.09041 .31356 L
.09113 .31384 L
.09178 .31393 L
.09307 .31367 L
.09448 .31296 L
.09525 .31256 L
.09598 .31227 L
.09666 .31215 L
.09739 .31221 L
.09868 .31281 L
.09939 .31337 L
.10015 .31405 L
.1015 .31526 L
.10226 .31578 L
.10297 .31609 L
.10375 .3162 L
.10458 .31607 L
.1059 .3155 L
.10714 .31489 L
.10843 .3146 L
.10911 .31469 L
.10985 .315 L
.11109 .31597 L
.1124 .3173 L
.11362 .31844 L
.11474 .31909 L
.11606 .31922 L
.11678 .31902 L
.11747 .31873 L
.11871 .31814 L
.12002 .31783 L
.1207 .31792 L
.12146 .31825 L
.12214 .31876 L
Mistroke
.12279 .31938 L
.12423 .32101 L
.12499 .32183 L
.12579 .32254 L
.1265 .32296 L
.12714 .32316 L
.12839 .32307 L
.12966 .32255 L
.13086 .32207 L
.13202 .32198 L
.13308 .3224 L
.13425 .32344 L
.13549 .32496 L
.13673 .32651 L
.13741 .32722 L
.13806 .32772 L
.13931 .32815 L
.14046 .32797 L
.14111 .32772 L
.14181 .32742 L
.14307 .32708 L
.14377 .32712 L
.14442 .32737 L
.14514 .32789 L
.14591 .32871 L
.18707 .36047 L
.20761 .38272 L
.21762 .39209 L
.21881 .39624 L
.21992 .39943 L
.22108 .40133 L
.22235 .40152 L
.22345 .4005 L
.22445 .39931 L
.22561 .39861 L
.22671 .39941 L
.22784 .4021 L
.22889 .40606 L
.23012 .41151 L
.23127 .41617 L
.23252 .41934 L
.23366 .41987 L
.23488 .41826 L
.2362 .41545 L
.23728 .41391 L
.23847 .41449 L
.23971 .41841 L
.24087 .42469 L
.24515 .44221 L
.2475 .43373 L
Mistroke
.24873 .42821 L
.25004 .42656 L
.25118 .43104 L
.25244 .44273 L
.2536 .45747 L
.25466 .4706 L
.25534 .47683 L
.25599 .47994 L
.25667 .47923 L
.25741 .47282 L
.25806 .46194 L
.25875 .44473 L
.25999 .40024 L
.2623 .2889 L
.26353 .23032 L
.26484 .17993 L
.26554 .16059 L
.26619 .14818 L
.26744 .13792 L
.26812 .13913 L
.26886 .14446 L
.26955 .15213 L
.27019 .16039 L
.27143 .17599 L
.27258 .1867 L
.27379 .1915 L
.27443 .19141 L
.27512 .18968 L
.27582 .18675 L
.27647 .18352 L
.27724 .17983 L
.27795 .17724 L
.27869 .17579 L
.27938 .17589 L
.28012 .17757 L
.28092 .18099 L
.28346 .19637 L
.28415 .19985 L
.2849 .20254 L
.2856 .20393 L
.28624 .20425 L
.28749 .20281 L
.2882 .20133 L
.28886 .19992 L
.29006 .19821 L
.29134 .19877 L
.29204 .20029 L
.2928 .20278 L
.29417 .20866 L
.29539 .21391 L
Mistroke
.29604 .21616 L
.29673 .21797 L
.298 .21941 L
.29919 .2189 L
.29988 .21812 L
.30054 .21732 L
.30178 .21639 L
.30293 .21691 L
.304 .21886 L
.30517 .22235 L
.30641 .22672 L
.30765 .23059 L
.3088 .23296 L
.31 .23385 L
.31131 .23337 L
.31245 .23251 L
.31348 .23207 L
.31468 .23262 L
.3158 .23441 L
.32591 .24587 L
.33463 .25835 L
.33576 .25785 L
.337 .25755 L
.33816 .258 L
.33924 .25924 L
.3405 .26154 L
.34184 .26439 L
.34297 .26654 L
.3442 .26807 L
.34543 .26861 L
.34659 .2684 L
.34788 .2679 L
.34853 .26776 L
.34924 .26781 L
.35051 .26862 L
.35169 .27022 L
.35394 .27431 L
.35459 .27536 L
.35528 .27627 L
.35655 .27721 L
.35778 .27728 L
.35892 .27689 L
.36015 .27649 L
.36085 .27647 L
.36151 .27666 L
.36283 .27775 L
.36357 .27874 L
.36425 .2798 L
.36538 .28167 L
.36659 .28339 L
Mistroke
.36774 .28442 L
.36877 .28475 L
.36999 .28454 L
.37132 .28402 L
.37256 .28379 L
.37371 .28416 L
.37479 .28509 L
.3758 .28637 L
.37699 .28811 L
.37809 .28954 L
.37923 .29057 L
.38032 .29096 L
.38146 .29081 L
.38271 .29031 L
.38393 .28992 L
.38504 .28998 L
.38627 .2907 L
.38756 .29209 L
.38869 .29355 L
.38976 .29481 L
.39099 .29579 L
.39211 .29608 L
.39334 .29583 L
.39404 .29553 L
.39468 .29524 L
.39584 .29487 L
.39707 .29497 L
.39771 .29528 L
.3984 .2958 L
.39965 .2971 L
.40112 .29876 L
.40184 .29942 L
.40249 .29986 L
.40379 .3002 L
.40451 .3001 L
.40518 .29986 L
.40593 .29951 L
.40671 .29914 L
.40738 .2989 L
.40812 .29879 L
.40876 .29885 L
.40945 .29912 L
.41069 .30003 L
.41202 .30137 L
.41272 .30207 L
.41347 .30271 L
.41413 .30313 L
.41487 .30339 L
.41617 .30332 L
.41748 .30276 L
Mistroke
.41872 .30215 L
.41992 .30184 L
.42102 .30201 L
.42229 .30275 L
.4235 .30382 L
.42474 .30493 L
.42544 .30542 L
.42608 .30573 L
.42727 .30587 L
.42852 .3055 L
.42964 .3049 L
.43071 .30437 L
.43195 .3041 L
.43307 .30433 L
.43428 .30505 L
.43559 .30613 L
.4367 .307 L
.43794 .30758 L
.43863 .30767 L
.43928 .30759 L
.43997 .30736 L
.44071 .30698 L
.44136 .30661 L
.44205 .30623 L
.44328 .30576 L
.44445 .30577 L
.44551 .30619 L
.44677 .30706 L
.44795 .30797 L
.44918 .30867 L
.45031 .30888 L
.45155 .3086 L
.45287 .30789 L
.45391 .30729 L
.45503 .30685 L
.45609 .30679 L
.45706 .30707 L
.45819 .30774 L
.45942 .30863 L
.46058 .30932 L
.46167 .30962 L
.46295 .30945 L
.4636 .30917 L
.46431 .30877 L
.46559 .308 L
.46675 .3075 L
.46746 .30739 L
.46812 .30744 L
.46883 .30766 L
.46959 .30806 L
Mistroke
.47086 .3089 L
.47153 .30933 L
.47225 .30972 L
.47354 .31004 L
.47476 .30982 L
.47544 .3095 L
.47615 .30908 L
.47742 .3083 L
.47861 .30779 L
.47971 .30771 L
.48092 .30808 L
.48221 .30885 L
.48338 .30959 L
.48462 .31011 L
.48527 .3102 L
.48598 .31013 L
.48723 .30962 L
.4884 .3089 L
.48951 .30824 L
.49079 .30782 L
.49196 .3079 L
.4931 .30838 L
.49416 .30904 L
.49541 .30979 L
.49654 .31018 L
.49761 .31018 L
.49862 .30983 L
.49968 .30923 L
.50082 .3085 L
.50207 .30793 L
.50321 .30782 L
.50452 .30821 L
.50576 .30894 L
.50683 .30962 L
.50797 .31012 L
.50922 .31021 L
.51037 .30985 L
.51159 .30914 L
.51276 .30842 L
.51341 .3081 L
.51411 .30789 L
.51534 .30791 L
.51605 .30815 L
.51681 .30855 L
.51817 .30943 L
.51889 .30985 L
.51956 .31015 L
.52082 .31033 L
.52204 .31001 L
.52274 .30965 L
Mistroke
.52339 .30925 L
.52411 .30879 L
.5248 .30841 L
.5261 .30801 L
.52722 .30812 L
.52844 .30868 L
.52973 .30954 L
.53095 .31027 L
.53226 .31064 L
.53296 .3106 L
.53371 .31038 L
.53445 .31001 L
.53524 .30954 L
.53592 .30912 L
.53664 .30874 L
.53794 .3084 L
.53915 .30861 L
.5399 .30897 L
.5406 .30942 L
.54191 .31036 L
.54306 .31101 L
.5443 .31127 L
.54547 .31103 L
.54653 .3105 L
.54778 .30976 L
.54849 .30942 L
.54915 .30922 L
.55035 .30922 L
.55162 .30978 L
.55296 .31076 L
.55367 .3113 L
.55441 .31179 L
.55506 .31211 L
.55577 .3123 L
.55703 .31219 L
.55825 .31165 L
.55956 .31091 L
.56079 .31043 L
.56192 .31042 L
.56306 .31089 L
.56428 .31179 L
.56533 .31268 L
.56646 .31348 L
.56767 .31391 L
.56881 .31382 L
.56947 .31359 L
.57016 .31324 L
.5714 .31258 L
.57247 .3122 L
.57362 .31222 L
Mistroke
.5747 .3127 L
.57568 .31345 L
.57685 .31454 L
.5781 .31557 L
.57929 .31612 L
.58037 .31616 L
.58156 .31577 L
.58268 .31519 L
.5839 .3147 L
.58459 .3146 L
.58523 .31467 L
.58641 .31524 L
.58772 .3164 L
.5891 .31782 L
.59037 .31882 L
.59149 .31923 L
.59266 .31912 L
.59383 .31864 L
.59512 .31805 L
.59624 .31783 L
.59743 .31813 L
.59856 .31896 L
.59959 .32005 L
.60088 .32153 L
.60159 .32222 L
.60226 .32273 L
.60343 .32317 L
.60472 .32302 L
.60544 .32274 L
.60612 .32243 L
.6074 .32199 L
.60812 .32197 L
.60878 .32214 L
.60951 .32257 L
.61029 .32327 L
.6116 .32486 L
.61229 .32575 L
.61302 .32663 L
.61366 .32727 L
.61436 .32779 L
.61559 .32815 L
.61679 .32793 L
.61808 .32739 L
.61929 .32707 L
.6204 .32727 L
.62158 .32813 L
.62268 .32947 L
.624 .33137 L
.62521 .33294 L
.62641 .33394 L
Mistroke
.62767 .33424 L
.62893 .33392 L
.62965 .33363 L
.63032 .3334 L
.63151 .33332 L
.63264 .33388 L
.63366 .33496 L
.63475 .33659 L
.63949 .34158 L
.66026 .35797 L
.66966 .36379 L
.67975 .37239 L
.69083 .38464 L
.70119 .39883 L
.70625 .41126 L
.70696 .41432 L
.70764 .41677 L
.70841 .41881 L
.70911 .41979 L
.71039 .41939 L
.7111 .41819 L
.71176 .41679 L
.71297 .41445 L
.71409 .41385 L
.71532 .41616 L
.71664 .42223 L
.72179 .44148 L
.72422 .4311 L
.72488 .42834 L
.72559 .42659 L
.72686 .42825 L
.72803 .43635 L
.72913 .44883 L
.73042 .46554 L
.73164 .47759 L
.73272 .47975 L
.7339 .46851 L
.73497 .44393 L
.73596 .40926 L
.73822 .30263 L
.73946 .24217 L
.74061 .19425 L
.74187 .15761 L
.74253 .14589 L
.74325 .1392 L
.74452 .14028 L
.74568 .15139 L
.74695 .16788 L
.74765 .1764 L
.74831 .18305 L
Mistroke
.74901 .1882 L
.74979 .1912 L
.75045 .19159 L
.75117 .19015 L
.75247 .1845 L
.75317 .18101 L
.75383 .17824 L
.755 .1757 L
.75628 .17746 L
.7575 .18313 L
.75862 .19008 L
.75983 .19738 L
.76112 .20263 L
.76226 .20424 L
.76351 .20314 L
.76464 .20077 L
.76571 .19878 L
.76696 .19817 L
.76811 .19997 L
.76943 .20455 L
.77069 .21013 L
.77177 .21461 L
.77293 .21797 L
.77402 .21935 L
.77501 .2192 L
.77618 .21799 L
.77744 .21665 L
.77863 .21649 L
.77972 .21784 L
.80017 .24611 L
.81015 .2585 L
.81133 .25813 L
.81244 .25767 L
.8136 .25761 L
.81488 .2585 L
.81597 .26014 L
.81698 .26215 L
.81806 .26447 L
.81924 .26667 L
.82039 .26807 L
.82145 .26859 L
.82257 .26848 L
.82376 .26801 L
.8244 .26781 L
.82509 .26775 L
.82634 .26829 L
.82755 .26971 L
.82867 .27161 L
.82975 .27364 L
.83091 .27556 L
Mistroke
.83201 .27679 L
.83301 .27729 L
.83413 .27724 L
.83519 .27686 L
.83634 .27649 L
.8376 .27662 L
.83881 .27752 L
.83994 .27902 L
.8413 .28122 L
.84254 .28309 L
.84377 .28432 L
.84507 .28475 L
.84637 .28447 L
.84711 .28417 L
.8478 .28393 L
.84903 .28382 L
.85019 .28435 L
.85123 .28538 L
.85237 .28692 L
.8536 .28869 L
.85491 .29018 L
.85602 .29086 L
.85725 .29091 L
.85854 .29046 L
.85974 .29 L
.86105 .28993 L
.86178 .29022 L
.86245 .29069 L
.86367 .29199 L
.86499 .29369 L
.86614 .295 L
.86739 .29588 L
.8686 .29607 L
.86974 .29575 L
.87104 .29517 L
.87222 .29485 L
.87332 .295 L
.87436 .29561 L
.87547 .29668 L
.87666 .29805 L
.87787 .29928 L
.87916 .30007 L
.87991 .3002 L
.88059 .30013 L
.88124 .29992 L
.88192 .2996 L
.88259 .29928 L
.8833 .29898 L
.88459 .2988 L
.88538 .29899 L
Mistroke
.88612 .29941 L
.88679 .29994 L
.88751 .30064 L
.88882 .30198 L
.89004 .30297 L
.89132 .30343 L
.892 .3034 L
.89273 .3032 L
.89403 .30257 L
.89526 .30201 L
.89635 .30183 L
.89754 .30215 L
.89819 .30254 L
.89887 .30308 L
.90009 .3042 L
.90138 .30527 L
.90212 .30567 L
.9028 .30586 L
.90403 .30576 L
.90515 .30527 L
.90638 .30461 L
.90767 .30415 L
.90835 .30411 L
.90909 .30426 L
.9104 .30499 L
.91182 .30617 L
.91256 .30676 L
.91335 .30727 L
.91404 .30756 L
.9148 .30767 L
.91548 .30759 L
.91612 .30737 L
.91738 .30671 L
.91802 .30635 L
.91872 .306 L
.91938 .30579 L
.92008 .30571 L
.92132 .306 L
.92203 .30639 L
.92278 .30693 L
.92414 .30797 L
.9248 .30839 L
.92552 .30872 L
.92682 .30886 L
.92809 .30844 L
.92926 .30777 L
.93032 .30718 L
.93146 .3068 L
.93272 .30688 L
.93389 .30742 L
Mistroke
.93512 .30827 L
.93628 .30906 L
.93692 .30938 L
.93761 .30959 L
.93882 .30955 L
.93996 .30909 L
.94116 .30837 L
.94228 .30775 L
.94332 .30742 L
.94428 .30744 L
.94531 .3078 L
.94646 .30849 L
.94751 .3092 L
.94872 .30983 L
.94984 .31004 L
.95107 .30977 L
.95239 .30905 L
.95364 .30828 L
.95482 .30779 L
.95587 .30771 L
.95702 .30804 L
.95822 .30873 L
.95934 .30946 L
.96056 .31004 L
.96188 .31018 L
.96254 .31002 L
.96326 .30971 L
.96456 .30892 L
.96572 .30823 L
.96701 .30782 L
.9682 .30791 L
.96932 .3084 L
.9706 .3092 L
.97178 .30987 L
.97281 .3102 L
.9739 .31016 L
.975 .30974 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00WooonfX4o`0007[ooo]Z1Ol0003ooookJQoo
oo]Z002OoookJPCo0000N_oonfX5o`0007oooo]Z1?l0002KoookJP00WooonfX4o`0007[ooo]Z1Ol0
001ooookJPGo0000V_oonfX009oooo]Z1Ol0001ioookJPGo0000OooonfX5o`0009[ooo]Z002Noook
JPKo0000NOoonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0007Wooo]Z1Ol0001noookJPKo
0000V_oonfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oo
nfX6o`0006cooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPKo0000K?oonfX3
o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1_l0001LoookJP[o001o1_oonfX3o`00
O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1_l0001LoookJP[o001o1_oonfX3o`00O`[o
oo]Z1_l0001moookJPKo0000V_oonfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z
1_l0002JoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002N
oookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1_l0001/oook
JP?o001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX6o`0006Wooo]Z1_l007l:oookJPGo
0000O_oonfX7o`0009Wooo]Z002NoookJPKo0000JOoonfX6o`00O`[ooo]Z1Ol0001noookJPOo0000
VOoonfX009kooo]Z1ol0001ZoookJPCo001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX7
o`0006_ooo]Z0ol007l:oookJPGo0000O_oonfX7o`0009Wooo]Z002NoookJPOo0000N?oonfX5o`00
07kooo]Z1ol0002IoookJP00W_oonfX7o`0007Sooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z
2ol0001doookJPGo0000O_oonfX;o`0009Gooo]Z002NoookJPco0000LooonfX5o`0007gooo]Z3Ol0
002DoookJP00W_oonfX<o`0007?ooo]Z1Ol0001moookJPgo0000U?oonfX009kooo]Z3?l0001coook
JPGo0000OOoonfX>o`0009?ooo]Z002NoookJPco0000LooonfX5o`0007gooo]Z3_l0002CoookJP00
W_oonfX<o`0007?ooo]Z1Ol0001moookJPko0000TooonfX009kooo]Z3Ol0001boookJPGo0000OOoo
nfX4o`000003oookJ_l0003o000000Oo0000TooonfX009kooo]Z3Ol0001boookJPGo0000OOoonfX4
o`000003oookJ_l0003o000000Oo0000TooonfX009kooo]Z3Ol0001boookJPGo0000OOoonfX4o`00
0003oookJ_l0003o000000Oo0000TooonfX009kooo]Z3Ol0001boookJPGo0000OOoonfX4o`000003
oookJ_l0003o000000Oo0000TooonfX009kooo]Z3_l0001aoookJPGo0000OOoonfX4o`000003oook
J_l0003o000000Oo0000TooonfX009kooo]Z3_l0001aoookJPGo0000OOoonfX4o`000003oookJ_l0
003o000000So0000T_oonfX009kooo]Z1?l00005oookJPWo0000KOoonfX5o`0007gooo]Z1?l00006
oookJPWo0000S_oonfX009kooo]Z1?l00006oookJPSo0000KOoonfX5o`0007gooo]Z1?l00006oook
JPWo0000S_oonfX009kooo]Z1?l00006oookJPWo0000K?oonfX5o`0007gooo]Z1?l00007oookJPSo
0000S_oonfX009kooo]Z1?l00006oookJPWo0000K?oonfX5o`0007gooo]Z1?l00007oookJPWo0000
SOoonfX009gooo]Z1Ol00006oookJPWo0000K?oonfX5o`0007gooo]Z1?l00007oookJPWo0000SOoo
nfX009gooo]Z1Ol00006oookJPWo0000K?oonfX5o`0007gooo]Z1?l00008oookJPWo0000S?oonfX0
09gooo]Z1Ol00007oookJPSo0000K?oonfX5o`0007gooo]Z1?l00008oookJPWo0000S?oonfX009go
oo]Z1?l0000<oookJPCo0000K?oonfX5o`0007gooo]Z1?l0000<oookJPGo0000S?oonfX009gooo]Z
1?l0000<oookJPGo0000JooonfX5o`0007gooo]Z1?l0000=oookJPCo0000S?oonfX009gooo]Z1?l0
000<oookJPGo0000JooonfX5o`0007gooo]Z1?l0000=oookJPCo0000S?oonfX009gooo]Z1?l0000<
oookJPWo0000IooonfX5o`0007gooo]Z1?l0000=oookJPSo0000R?oonfX009gooo]Z1?l0000=oook
JPWo0000I_oonfX5o`0007gooo]Z1?l0000=oookJPWo0000QooonfX009gooo]Z1?l0000=oookJPWo
0000I_oonfX5o`0007gooo]Z1?l0000=oookJPWo0000QooonfX009gooo]Z1?l0000=oookJPWo0000
I_oonfX5o`0007gooo]Z1?l0000=oookJP[o0000Q_oonfX009gooo]Z1?l0000>oookJPSo0000I_oo
nfX5o`0007gooo]Z1?l0000>oookJP[o0000QOoonfX009gooo]Z1?l0000BoookJPGo0000AooonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0007gooo]Z1?l0000BoookJPOo0000Q?oonfX0
09gooo]Z1?l0000BoookJPGo0000A_oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`00
07gooo]Z1?l0000CoookJPKo0000Q?oonfX009gooo]Z1?l0000BoookJPKo0000AOoonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001o
o`00O`Wooo]Z1Ol0001moookJPCo00005?oonfX6o`0008?ooo]Z002MoookJPCo00004ooonfX8o`00
03Gooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`00
07gooo]Z1?l0000EoookJPKo0000P_oonfX009gooo]Z1?l0000CoookJPWo0000=?oonfX:o`00O`;o
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001loookJPCo00005OoonfX7o`00087o
oo]Z002MoookJPCo00005?oonfX8o`00043ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z
1Ol0001moookJPCo00005_oonfX6o`00087ooo]Z002MoookJPCo00005?oonfX9o`0003oooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000OOoonfX4o`0001Oooo]Z1_l0
0020oookJP00WOoonfX4o`0001Cooo]Z2_l0000noookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9
oookJPGo0000OOoonfX4o`0001Sooo]Z1_l0001ooookJP00WOoonfX4o`0001Sooo]Z1ol0000moook
JP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000OOoonfX4o`0001Sooo]Z1_l0001ooook
JP00WOoonfX4o`0001Wooo]Z1ol0000loookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo
0000OOoonfX4o`0001Wooo]Z1_l0001noookJP00WOoonfX4o`0001[ooo]Z1ol0000loookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001moookJPCo00006_oonfX6o`0007go
oo]Z002MoookJPCo00006ooonfX7o`0003_ooo]Z1ol007l9oookJPOo001o2?oonfX5o`0007gooo]Z
1?l0000JoookJPOo0000O?oonfX009gooo]Z1?l0000LoookJPKo0000??oonfX5o`00O`[ooo]Z1ol0
07l8oookJPGo0000OOoonfX4o`0001_ooo]Z1_l0001loookJP00WOoonfX4o`0001gooo]Z1_l0001I
oookJPGo0000OOoonfX4o`0001cooo]Z1_l0001koookJP00WOoonfX4o`0001kooo]Z1Ol0001Ioook
JPGo0000OOoonfX4o`0001gooo]Z1_l0001joookJP00WOoonfX4o`0001kooo]Z1_l0001HoookJPGo
0000OOoonfX4o`0001gooo]Z1ol0001ioookJP00WOoonfX4o`0001oooo]Z1_l0001GoookJPGo0000
OOoonfX4o`0001kooo]Z1_l0001ioookJP00WOoonfX4o`0001oooo]Z2Ol0001DoookJPGo0000OOoo
nfX4o`0001oooo]Z2Ol0001eoookJP00WOoonfX4o`00023ooo]Z2Ol0001CoookJPGo0000OOoonfX4
o`00023ooo]Z2Ol0001doookJP00W?oonfX5o`00027ooo]Z2Ol0001BoookJPGo0000OOoonfX4o`00
023ooo]Z2Ol0001doookJP00W?oonfX5o`00027ooo]Z2Ol0001BoookJPGo0000OOoonfX4o`00027o
oo]Z2Ol0001coookJP00W?oonfX5o`0002;ooo]Z2?l0001BoookJPGo0000OOoonfX4o`0002;ooo]Z
2?l0001coookJP00W?oonfX4o`0002Oooo]Z1Ol0001AoookJPGo0000OOoonfX4o`0002Gooo]Z1_l0
001boookJP00W?oonfX4o`0002Oooo]Z2Ol0001=oookJPGo0000OOoonfX4o`0002Kooo]Z2Ol0001^
oookJP00W?oonfX4o`0002Oooo]Z2_l0001<oookJPGo0000OOoonfX4o`0002Kooo]Z2_l0001]oook
JP008_oonfX3o`00OgGooo]Z0_l007l4o`0000?ooo]Z0ol007l3oookJPGo001o6_oonfX9o`0004co
oo]Z1Ol0001doookJPGo001o1?oonfX4o`0000;ooo]Z1Ol007lPoookJPWo0000COoonfX3o`00Oago
oo]Z000RoookJP?o001oM?oonfX3o`00O`Co00000ooonfX3o`00O`;ooo]Z1ol007lJoookJPWo0000
BooonfX5o`0007?ooo]Z1ol007l2oookJPGo000000?ooo]Zo`00Ool007l01Ol007lPoookJPWo0000
C?oonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`Co00000ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o7_oonfX9o`0004Oooo]Z1Ol0001coookJP?o001o
00Cooo]Zo`00Ool007oo001o0_oonfX5o`0000Co001o00Cooo]Zo`00Ool007oo001o9?oonfX9o`00
04Sooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`03
oookJ_l0003o000000;o000000?o001ooookJ_oonfX01?oonfX3o`00O`?ooo]Z0ol007lMoookJP[o
0000A_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000ol00003o`00O`?o
oo]Z0ol007lSoookJP[o0000AooonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z
2_l007l2oookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o001o
7_oonfX9o`0004Kooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o0000
1ooonfX3o`00ObCooo]Z2Ol00017oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?o
oo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o001o7_oonfX:o`0004Gooo]Z1Ol0
001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00001ooonfX3o`00ObCooo]Z2_l0
0016oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l00000
0ol007oooo]ZoookJP05oookJP;o001o0_oonfX4o`00Oaoooo]Z3Ol00011oookJPGo0000L_oonfX3
o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l007l2oookJPCo001o9OoonfX=
o`0004;ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`00
0003o`00Oooonf[ooo]Z00Gooo]Z1ol007lToookJP[o0000@?oonfX5o`0007;ooo]Z0ol007l3oook
JP?o001o00?ooo]Zo`000?l000000_l00002oookJPOo001o:_oonfX:o`00047ooo]Z0ol007lMoook
JP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Go
oo]Z1_l007lVoookJP[o0000?ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l0
00000_l00002oookJPKo001o;?oonfX:o`00043ooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z
0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l[oookJP[o0000
?_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP;o001o
<OoonfX:o`0003cooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z0_l0
07l[oookJPko0000>_oonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo0000
0_oonfX2o`00Oc7ooo]Z3_l0000hoookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o1?l0
0009oookJPOo001o:_oonfX:o`0003Wooo]Z1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z1ol0
07l`oookJP[o0000>OoonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00002OoonfX7
o`00Ob[ooo]Z3ol0000doookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPOo001o<OoonfX>
o`0003Gooo]Z0ol007lMoookJP00W?oonfX4o`0003cooo]Z3_l0000coookJPGo0000O?oonfX4o`00
03_ooo]Z3ol0001DoookJP00W?oonfX4o`00043ooo]Z3ol0000^oookJPGo0000O?oonfX4o`00043o
oo]Z3ol0001?oookJP00W?oonfX4o`00047ooo]Z4?l0000/oookJPGo0000O?oonfX4o`00047ooo]Z
4?l0001=oookJP00W?oonfX4o`0004;ooo]Z5?l0000WoookJPGo0000O?oonfX4o`0004;ooo]Z5?l0
0018oookJP00W?oonfX4o`0004Oooo]Z5_l0000PoookJPGo0000O?oonfX4o`0004Oooo]Z5_l00011
oookJP00W?oonfX4o`0004Sooo]Z6ol0000JoookJPGo0000O?oonfX4o`0004Sooo]Z6ol0000koook
JP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oo
nf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`00
0?oo00009Ol0000?oookJP007OoonfX00ol0003ooo]Zo`000004o`0000;ooo]Z1Ol000000ooonf[o
0000o`00000Po`0004kooo]Z1?l0001_oookJPCo00000_oonfX4o`0000;ooo]Z2ol00002oookJPGo
000000?ooo]Zo`000?l000008Ol0001=oookJPCo0000KooonfX4o`0000;ooo]Z1Ol000000ooonf[o
0000o`000003o`0001kooo]Z000ioookJQ_o0000B?oonfX4o`0007gooo]Z1Ol0000HoookJQco0000
B?oonfX4o`0009kooo]Z000ooookJQKo0000AooonfX4o`0007gooo]Z1Ol0000PoookJQGo0000Aooo
nfX4o`0009kooo]Z0015oookJQGo0000@_oonfX4o`0007gooo]Z1Ol0000UoookJQGo0000@_oonfX4
o`0009kooo]Z001;oookJQ3o0000@OoonfX4o`0007gooo]Z1Ol0000[oookJQ3o0000@OoonfX4o`00
09kooo]Z001=oookJPko0000@OoonfX4o`0007gooo]Z1Ol0000]oookJPoo0000@?oonfX4o`0009ko
oo]Z001AoookJQ3o0000>ooonfX4o`0007gooo]Z1Ol0000boookJPoo0000>ooonfX4o`0009kooo]Z
001CoookJPoo0000>_oonfX4o`0007gooo]Z1Ol0000coookJPko0000>ooonfX4o`0009kooo]Z001G
oookJPco0000>OoonfX4o`0007gooo]Z1Ol0000goookJP_o0000>_oonfX4o`0009kooo]Z001Hoook
JPco0000>?oonfX4o`0007gooo]Z1Ol0000hoookJPko0000=_oonfX4o`0009kooo]Z001MoookJPWo
0000=_oonfX4o`0007gooo]Z1Ol0000moookJP[o0000=OoonfX4o`0009kooo]Z001OoookJPSo0000
=OoonfX4o`0007gooo]Z1Ol0000noookJP[o0000=?oonfX4o`0009kooo]Z001PoookJPSo0000=?oo
nfX4o`0007gooo]Z1Ol0000ooookJP[o0000<ooonfX4o`0009kooo]Z001QoookJPSo0000<ooonfX4
o`0007gooo]Z1Ol00010oookJP[o0000<_oonfX4o`0009kooo]Z001SoookJPSo0000<OoonfX4o`00
07gooo]Z1Ol00014oookJPSo0000<?oonfX4o`0009kooo]Z001ToookJPSo0000<?oonfX4o`0007go
oo]Z1Ol00015oookJPSo0000;ooonfX4o`0009kooo]Z001UoookJPSo0000;_oonfX5o`0007gooo]Z
1Ol00016oookJPSo0000;_oonfX4o`0009kooo]Z001VoookJPWo0000;?oonfX5o`0007gooo]Z1Ol0
0017oookJPSo0000;OoonfX4o`0009kooo]Z001XoookJPSo0000:ooonfX5o`0007gooo]Z1Ol00019
oookJPSo0000:ooonfX4o`0009kooo]Z001YoookJPSo0000:_oonfX4o`0007kooo]Z1Ol0001:oook
JPSo0000:_oonfX4o`0009kooo]Z001ZoookJPSo0000:OoonfX4o`0007kooo]Z1Ol0001;oookJPSo
0000:OoonfX4o`0009kooo]Z001/oookJPSo00009ooonfX4o`0007kooo]Z1Ol0001<oookJPSo0000
:?oonfX4o`0009kooo]Z001]oookJPSo00009_oonfX4o`0007kooo]Z1Ol0001>oookJPOo00009_oo
nfX5o`0009kooo]Z001^oookJPSo00009OoonfX4o`0007kooo]Z1Ol0001?oookJPSo00009?oonfX5
o`0009kooo]Z001_oookJPSo00009?oonfX4o`0007kooo]Z1Ol0001@oookJPWo00008_oonfX5o`00
09kooo]Z001aoookJPOo00008ooonfX4o`0007kooo]Z1Ol0001AoookJPWo00008OoonfX4o`0009oo
oo]Z001boookJPOo00008_oonfX4o`0007kooo]Z1Ol0001BoookJP[o00007ooonfX4o`0009oooo]Z
001coookJPOo00008OoonfX4o`0007kooo]Z1Ol0001DoookJPWo00007_oonfX4o`0009oooo]Z001d
oookJPOo00008?oonfX4o`0007kooo]Z1Ol0001FoookJPSo00007OoonfX4o`0009oooo]Z001eoook
JPOo00007ooonfX4o`0007kooo]Z1Ol0001GoookJPSo00007?oonfX4o`0009oooo]Z001foookJPOo
00007_oonfX4o`0007kooo]Z1Ol0001IoookJPOo00006ooonfX4o`0009oooo]Z001goookJPOo0000
7OoonfX4o`0007kooo]Z1Ol0001JoookJPKo00006ooonfX4o`0009oooo]Z001hoookJPOo00007?oo
nfX4o`0007kooo]Z1Ol0001KoookJPKo00006_oonfX4o`0009oooo]Z001ioookJPOo00006ooonfX4
o`0007kooo]Z1Ol0001LoookJPKo00006OoonfX4o`0009oooo]Z001joookJPOo00006_oonfX4o`00
07kooo]Z1Ol0001LoookJPOo00006?oonfX4o`0009oooo]Z001koookJPOo00006OoonfX4o`00063o
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001MoookJPOo00005ooonfX4o`0009oo
oo]Z001loookJPOo00006?oonfX4o`0005oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z
1Ol0001NoookJPOo00005_oonfX4o`0009oooo]Z001moookJPOo00005ooonfX4o`0005oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007l9oookJPGo0000GooonfX7o`0001Gooo]Z1?l0002OoookJP00O_oonfX7o`0001Kooo]Z
1?l0001NoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`00063ooo]Z
1_l0000EoookJPCo0000WooonfX007oooo]Z1ol0000EoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o2?oonfX6o`00063ooo]Z1_l0000DoookJPCo0000WooonfX0083ooo]Z1ol0000D
oookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0006;ooo]Z1_l0000C
oookJPCo0000WooonfX0087ooo]Z1ol0000CoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001RoookJPOo00004_oonfX4o`0009oooo]Z0022oookJPKo
00004ooonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001SoookJPKo
00004_oonfX4o`0009oooo]Z0023oookJPKo00004_oonfX4o`0005kooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00O`[ooo]Z1Ol0001ToookJPKo00004OoonfX4o`0009oooo]Z0024oookJPGo00004_oo
nfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001UoookJPKo00004?oo
nfX4o`0009oooo]Z0024oookJPWo00003_oonfX4o`0005oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJP;o001o3_oonfX5o`0006Gooo]Z1ol0000?oookJPCo0000WooonfX008Gooo]Z2Ol0000=
oookJPCo0000GooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000I_oonfX6o`0000oooo]Z1?l0002O
oookJP00QOoonfX9o`0000gooo]Z1?l0001PoookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001Woook
JPKo00003_oonfX4o`0009oooo]Z0025oookJPWo00003OoonfX4o`0007kooo]Z1Ol0001XoookJPGo
00003_oonfX4o`0009oooo]Z0026oookJPSo00003OoonfX4o`0007kooo]Z1Ol0001XoookJPKo0000
3OoonfX4o`0009oooo]Z002:oookJPCo00003OoonfX4o`0007kooo]Z1Ol0001YoookJPGo00003Ooo
nfX4o`0009oooo]Z002:oookJPGo00003?oonfX4o`0007kooo]Z1Ol0001YoookJPKo00003?oonfX4
o`0009oooo]Z002:oookJPGo00003?oonfX4o`0007kooo]Z1Ol0001ZoookJPGo00003?oonfX4o`00
09oooo]Z002:oookJPWo00002?oonfX4o`0007kooo]Z1Ol0001ZoookJPWo00002?oonfX4o`0009oo
oo]Z002;oookJPSo00002?oonfX4o`0007kooo]Z1Ol0001[oookJPWo00001ooonfX4o`0009oooo]Z
002;oookJPWo00001ooonfX4o`0007kooo]Z1Ol0001[oookJPWo00001ooonfX4o`0009oooo]Z002;
oookJPWo00001ooonfX4o`0007kooo]Z1Ol0001[oookJPWo00001ooonfX4o`0009oooo]Z002;oook
JPWo00001ooonfX4o`0007kooo]Z1Ol0001/oookJPSo00001ooonfX4o`0009oooo]Z002;oookJP[o
00001OoonfX5o`0007kooo]Z1Ol0001/oookJPSo00001ooonfX4o`0009oooo]Z002<oookJPWo0000
1OoonfX5o`0007kooo]Z1Ol0001/oookJPSo00001ooonfX4o`0009oooo]Z002@oookJPGo000000?o
oo]Zo`000?l000001ol0001noookJPGo0000L?oonfX9o`000003oookJ_l0003o000000?o0000Wooo
nfX0097ooo]Z3Ol0001ooookJPGo0000L?oonfX?o`0009oooo]Z002AoookJPgo0000OooonfX5o`00
073ooo]Z3ol0002OoookJP00TOoonfX=o`0007oooo]Z1Ol0001aoookJPgo0000X?oonfX0097ooo]Z
3Ol0001ooookJPGo0000LOoonfX=o`000:3ooo]Z002BoookJPco0000OooonfX5o`00077ooo]Z3Ol0
002PoookJP00T_oonfX<o`0007oooo]Z1Ol0001boookJPco0000X?oonfX009;ooo]Z3?l0001ooook
JPGo0000L_oonfX<o`000:3ooo]Z002BoookJPco0000OooonfX5o`0007;ooo]Z3?l0002PoookJP00
T_oonfX<o`0007oooo]Z1Ol0001boookJPco0000X?oonfX009?ooo]Z2ol0001ooookJPGo0000Looo
nfX;o`000:3ooo]Z002CoookJP_o0000OooonfX5o`0007?ooo]Z2ol0002PoookJP00UooonfX7o`00
07oooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0001ooookJPGo0000MooonfX7o`000:3o
oo]Z002GoookJPOo0000OooonfX5o`0007Oooo]Z1ol0002PoookJP00UooonfX7o`0007oooo]Z1Ol0
001goookJPOo0000X?oonfX009Oooo]Z1ol0001ooookJPGo0000MooonfX7o`000:3ooo]Z002Goook
JPOo0000L_oonfX3o`00O`[ooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0001boookJP?o
001o2_oonfX5o`0007Oooo]Z1ol0002PoookJP00UooonfX7o`0007;ooo]Z0ol007l:oookJPGo0000
MooonfX7o`000:3ooo]Z002GoookJPOo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oo
nfX009Oooo]Z1ol0001boookJP?o001o2_oonfX6o`0007Oooo]Z1_l0002PoookJP00UooonfX7o`00
07;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002GoookJPOo0000L_oonfX3o`00O`[o
oo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z
1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002H
oookJPKo0000KooonfX6o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0001_oook
JPKo001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX6o`00077ooo]Z1?l007l:oookJPGo
0000NOoonfX5o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001ioookJPCo0000
XOoonfX009Sooo]Z1Ol00020oookJPGo0000NOoonfX4o`000:7ooo]Z002HoookJPGo0000P?oonfX5
o`0007Wooo]Z1?l0002QoookJP00VOoonfX4o`00083ooo]Z1Ol0001ioookJPCo0000XOoonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`ko
oo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z
1?l007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0
003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX0
0?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o
001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000
oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4
o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoook
JP00oooonfX?oookJPGo001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXC
oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oo
oo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001o
oooonfX/oookJP00oooonfX>oookJPOo001ooooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^
oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30973 L
.02605 .31013 L
.02729 .31014 L
.02846 .30968 L
.02954 .30902 L
.03056 .3084 L
.03162 .30795 L
.03279 .30786 L
.03397 .30825 L
.03524 .309 L
.03632 .30968 L
.0375 .31016 L
.03821 .31024 L
.03887 .31016 L
.04017 .3096 L
.04145 .3088 L
.04262 .30818 L
.04386 .30791 L
.04452 .30799 L
.04521 .30823 L
.04637 .3089 L
.04765 .30974 L
.04879 .31027 L
.05001 .3104 L
.05116 .31005 L
.05221 .30946 L
.05343 .30872 L
.05473 .30822 L
.05541 .30817 L
.05615 .3083 L
.05747 .30896 L
.0587 .30982 L
.05935 .31023 L
.06003 .31058 L
.06129 .31083 L
.06244 .31058 L
.0631 .31027 L
.0638 .30986 L
.06509 .30911 L
.06633 .30871 L
.06748 .30881 L
.06873 .30943 L
.06944 .30993 L
.0701 .31042 L
.07078 .3109 L
.07144 .31127 L
.07218 .31153 L
.07287 .3116 L
.07404 .31134 L
Mistroke
.07528 .31069 L
.07635 .31007 L
.07751 .30964 L
.07822 .3096 L
.07888 .30972 L
.08016 .3104 L
.08133 .31131 L
.08257 .31222 L
.08327 .31259 L
.08394 .31279 L
.08519 .31271 L
.08589 .31244 L
.08654 .3121 L
.08729 .31167 L
.088 .31131 L
.08917 .31098 L
.09046 .31119 L
.09172 .31196 L
.09307 .31312 L
.09375 .31368 L
.09447 .31417 L
.09526 .31451 L
.096 .31461 L
.09683 .31448 L
.09761 .31417 L
.09832 .3138 L
.09908 .3134 L
.09973 .31312 L
.10045 .31294 L
.10172 .31312 L
.10243 .31349 L
.1032 .31408 L
.10458 .31539 L
.10579 .31642 L
.10649 .31682 L
.10714 .31702 L
.10844 .31693 L
.10918 .31665 L
.10985 .31631 L
.11099 .31578 L
.11223 .31556 L
.11353 .31599 L
.11474 .31698 L
.11605 .31837 L
.11675 .31907 L
.11748 .31968 L
.11813 .32006 L
.11884 .32027 L
.12008 .32016 L
.12083 .31987 L
Mistroke
.12163 .31949 L
.12237 .31917 L
.12307 .31899 L
.12375 .31899 L
.12449 .31922 L
.12579 .32019 L
.12704 .3216 L
.1277 .32238 L
.1284 .32314 L
.12967 .32413 L
.13085 .32442 L
.13154 .32432 L
.13219 .3241 L
.13296 .32376 L
.13367 .32347 L
.1349 .32326 L
.13558 .3234 L
.13623 .32375 L
.13844 .32618 L
.13961 .3277 L
.14083 .32893 L
.14148 .32933 L
.1422 .32952 L
.14345 .32935 L
.14472 .32884 L
.14591 .32852 L
.14717 .32878 L
.14836 .32977 L
.14943 .33116 L
.15058 .33289 L
.15184 .33455 L
.15248 .33515 L
.15318 .33558 L
.15442 .33573 L
.15557 .33537 L
.15621 .33512 L
.1569 .3349 L
.15816 .33496 L
.15938 .33582 L
.16052 .33731 L
.16583 .34318 L
.17476 .35022 L
.18426 .3561 L
.19458 .36423 L
.20573 .3754 L
.21536 .38575 L
.22591 .40005 L
.23091 .41277 L
.2316 .41574 L
.23235 .4184 L
Mistroke
.23306 .42012 L
.23371 .4209 L
.23495 .42028 L
.23626 .41764 L
.2374 .41537 L
.23863 .41486 L
.23979 .41741 L
.24085 .42237 L
.2459 .44234 L
.2484 .43148 L
.24912 .4285 L
.2498 .427 L
.25107 .42934 L
.2518 .43424 L
.25248 .44088 L
.254 .46043 L
.25532 .47566 L
.25598 .47977 L
.25671 .47982 L
.2574 .47455 L
.25805 .46419 L
.25928 .43024 L
.26059 .37517 L
.26203 .30275 L
.26327 .24013 L
.26396 .20979 L
.2646 .18539 L
.26574 .15426 L
.26699 .13869 L
.26816 .13991 L
.26942 .15244 L
.2705 .16687 L
.27168 .1808 L
.2724 .18674 L
.27306 .19001 L
.27437 .19043 L
.27556 .18581 L
.27681 .17947 L
.27804 .17544 L
.27936 .1759 L
.2806 .18098 L
.28174 .18801 L
.28307 .19628 L
.28382 .19988 L
.28452 .20212 L
.2858 .20327 L
.28651 .20251 L
.28716 .20126 L
.28832 .19869 L
.28955 .19709 L
Mistroke
.29059 .19765 L
.29174 .20055 L
.29413 .21086 L
.29482 .21363 L
.29547 .21573 L
.29669 .21795 L
.29785 .21801 L
.29892 .21692 L
.30007 .21556 L
.30133 .21512 L
.30242 .2163 L
.30343 .21876 L
.30451 .22234 L
.30566 .22646 L
.30692 .23013 L
.30807 .232 L
.30939 .23232 L
.31063 .23149 L
.31179 .2307 L
.31285 .2307 L
.31402 .23196 L
.31525 .23472 L
.31649 .23832 L
.31766 .24162 L
.31831 .24311 L
.31901 .24432 L
.32025 .24529 L
.32096 .24527 L
.32172 .24495 L
.32242 .24454 L
.32308 .24422 L
.32434 .24425 L
.32501 .24475 L
.32573 .24573 L
.34684 .2661 L
.35632 .27537 L
.36646 .28319 L
.37758 .28952 L
.38794 .2945 L
.38922 .29478 L
.39042 .29446 L
.39167 .29391 L
.39233 .2937 L
.39305 .29362 L
.39382 .29377 L
.39455 .29416 L
.39521 .2947 L
.39593 .29545 L
.39733 .2971 L
.39859 .29836 L
Mistroke
.3999 .29902 L
.40112 .29896 L
.40242 .29843 L
.40308 .29812 L
.40382 .29785 L
.40504 .29777 L
.40634 .29837 L
.40754 .29945 L
.40866 .30064 L
.40984 .30173 L
.41111 .3024 L
.41231 .30241 L
.41342 .30199 L
.41451 .30145 L
.41553 .30106 L
.41659 .301 L
.41776 .30145 L
.41896 .30239 L
.42021 .30359 L
.42129 .30448 L
.42246 .30504 L
.42373 .30502 L
.42444 .30478 L
.42508 .30446 L
.42634 .3038 L
.42752 .30344 L
.42863 .30355 L
.42983 .30418 L
.43051 .30471 L
.43116 .30528 L
.43237 .30628 L
.43364 .30695 L
.43483 .30703 L
.43612 .30657 L
.43685 .30617 L
.4375 .3058 L
.43869 .30531 L
.43978 .30523 L
.44098 .30566 L
.44225 .30654 L
.44327 .30736 L
.44438 .30808 L
.44558 .30844 L
.44671 .30828 L
.44738 .308 L
.4481 .3076 L
.44939 .30687 L
.45011 .30658 L
.45078 .30644 L
.45151 .30648 L
Mistroke
.4523 .30673 L
.45298 .30711 L
.45372 .30762 L
.45437 .30811 L
.45507 .3086 L
.45638 .30924 L
.4576 .30931 L
.45888 .30884 L
.4596 .30842 L
.46027 .30802 L
.4615 .3074 L
.46279 .30721 L
.46395 .30753 L
.46504 .30817 L
.46621 .30899 L
.46751 .30968 L
.46877 .30986 L
.46945 .30972 L
.4701 .30946 L
.47126 .30878 L
.47251 .30805 L
.47317 .30778 L
.47389 .30763 L
.47464 .30767 L
.47534 .30788 L
.4766 .30858 L
.4773 .30904 L
.47795 .30946 L
.47922 .31002 L
.4799 .31012 L
.48061 .31004 L
.48181 .30956 L
.48313 .30874 L
.4843 .3081 L
.48556 .30779 L
.48675 .30801 L
.48784 .30856 L
.48898 .3093 L
.4902 .30995 L
.49135 .3102 L
.49239 .31003 L
.49362 .30942 L
.49495 .30858 L
.4962 .30798 L
.49735 .30784 L
.49844 .30812 L
.49945 .30867 L
.50065 .30943 L
.50175 .30999 L
.5029 .3102 L
Mistroke
.50399 .30999 L
.50514 .3094 L
.50639 .3086 L
.50761 .30801 L
.50873 .30784 L
.50996 .30815 L
.51125 .30889 L
.5123 .30956 L
.51342 .31009 L
.51466 .31023 L
.5158 .30989 L
.51715 .30911 L
.51786 .30867 L
.5186 .30827 L
.51926 .30802 L
.51998 .30792 L
.52125 .30817 L
.52248 .30884 L
.5238 .30971 L
.52505 .31029 L
.52619 .3104 L
.52748 .30999 L
.52821 .30958 L
.52887 .30917 L
.53014 .30846 L
.53135 .30817 L
.53203 .30822 L
.53276 .30846 L
.53405 .30923 L
.53546 .31019 L
.53625 .31059 L
.53697 .3108 L
.53827 .31071 L
.5395 .31015 L
.54064 .30946 L
.54185 .30887 L
.54249 .30872 L
.54319 .30871 L
.54442 .30913 L
.54511 .30955 L
.54585 .3101 L
.54655 .31061 L
.5472 .31104 L
.54784 .31136 L
.54853 .31156 L
.54974 .3115 L
.55042 .31125 L
.55114 .31088 L
.55244 .31013 L
.55364 .30966 L
Mistroke
.55476 .30964 L
.55599 .31016 L
.5573 .31113 L
.55799 .31168 L
.55872 .3122 L
.55952 .31262 L
.56027 .31281 L
.56095 .3128 L
.5616 .31264 L
.56231 .31233 L
.56307 .31191 L
.56376 .31152 L
.56441 .31122 L
.56508 .31102 L
.56582 .31098 L
.56703 .31137 L
.56833 .31231 L
.56959 .31341 L
.57028 .31393 L
.57093 .31431 L
.57163 .31455 L
.57239 .3146 L
.57305 .31447 L
.57374 .31419 L
.57511 .31347 L
.57642 .31298 L
.57758 .31301 L
.57886 .31366 L
.58126 .31584 L
.58195 .3164 L
.5826 .31679 L
.58382 .31706 L
.58497 .31682 L
.58603 .31632 L
.58719 .31577 L
.58842 .31556 L
.58965 .31595 L
.59034 .31644 L
.59098 .31702 L
.59213 .31824 L
.59339 .31946 L
.59453 .32014 L
.59559 .32029 L
.59671 .32 L
.59792 .31944 L
.59916 .31901 L
.59986 .31898 L
.60051 .31914 L
.60183 .32004 L
.60256 .32081 L
Mistroke
.60323 .32159 L
.60443 .32298 L
.60573 .32406 L
.60696 .32442 L
.60809 .32421 L
.60915 .32376 L
.61029 .32334 L
.61136 .32329 L
.61234 .3237 L
.61349 .32474 L
.61474 .32632 L
.61591 .32784 L
.61701 .32893 L
.61814 .32948 L
.61938 .32943 L
.6206 .32897 L
.62191 .32854 L
.62306 .32865 L
.62427 .32948 L
.62531 .33072 L
.62644 .33239 L
.62767 .33412 L
.62897 .33537 L
.62965 .33568 L
.6304 .33575 L
.63171 .33539 L
.63295 .33494 L
.63365 .33484 L
.63429 .33494 L
.63552 .33576 L
.6367 .33729 L
.63885 .34084 L
.64006 .34237 L
.64116 .34308 L
.64246 .3431 L
.64368 .34266 L
.64481 .34235 L
.64602 .3426 L
.64733 .34387 L
.64855 .34588 L
.65 .34864 L
.65069 .34982 L
.65133 .35073 L
.65199 .35141 L
.65272 .35184 L
.65403 .35185 L
.6547 .35161 L
.65544 .35131 L
.65621 .35111 L
.65693 .35116 L
Mistroke
.65816 .35202 L
.65945 .35401 L
.66176 .35892 L
.66305 .36106 L
.66425 .36204 L
.66556 .36203 L
.6663 .36172 L
.66696 .36142 L
.66816 .36122 L
.66928 .36184 L
.6705 .36368 L
.67182 .36669 L
.67319 .37013 L
.6745 .37267 L
.67567 .3738 L
.67695 .3738 L
.67817 .37315 L
.67927 .37272 L
.68054 .37319 L
.68173 .375 L
.68284 .37776 L
.68386 .38077 L
.68506 .38414 L
.68616 .38636 L
.68737 .38742 L
.68866 .38708 L
.68986 .38615 L
.69099 .38563 L
.69231 .38648 L
.69353 .38906 L
.69416 .391 L
.69487 .39343 L
.69628 .39841 L
.69699 .40046 L
.69767 .40189 L
.69894 .40297 L
.69965 .40272 L
.7003 .40209 L
.70107 .40113 L
.7018 .40031 L
.70311 .39994 L
.70429 .4017 L
.70558 .40594 L
.70696 .41213 L
.70818 .4172 L
.70933 .42026 L
.70997 .42093 L
.71066 .42082 L
.71187 .41894 L
.71303 .41638 L
Mistroke
.71425 .41474 L
.7153 .41553 L
.71646 .41937 L
.71905 .43502 L
.71975 .43889 L
.7205 .44176 L
.72114 .44295 L
.72184 .44279 L
.7231 .43895 L
.72381 .43549 L
.72445 .43218 L
.7257 .42745 L
.72689 .42786 L
.7281 .43518 L
.72879 .44233 L
.72944 .4504 L
.73016 .46012 L
.73085 .4689 L
.73214 .47967 L
.73326 .47777 L
.73448 .45911 L
.73578 .41859 L
.73699 .36521 L
.7383 .2982 L
.73972 .22824 L
.74038 .20074 L
.74106 .17652 L
.7423 .14764 L
.74303 .13956 L
.74371 .1376 L
.74446 .14062 L
.74526 .14823 L
.74654 .1648 L
.74722 .17355 L
.74795 .18154 L
.74864 .18706 L
.74927 .19008 L
.75052 .19052 L
.75115 .18852 L
.75185 .18532 L
.75258 .18154 L
.75324 .17842 L
.75447 .17511 L
.75578 .17654 L
.75699 .18212 L
.75814 .18938 L
.75948 .19746 L
.76016 .20045 L
.76091 .20254 L
.76222 .20311 L
Mistroke
.76346 .20103 L
.76414 .19949 L
.76488 .19801 L
.76558 .19718 L
.76623 .19711 L
.76699 .198 L
.76779 .20008 L
.76847 .20257 L
.76921 .20583 L
.77048 .21154 L
.77117 .2142 L
.77182 .21614 L
.77296 .21801 L
.7742 .21789 L
.7749 .21717 L
.77557 .21633 L
.77681 .21516 L
.7775 .21511 L
.77814 .2156 L
.77884 .21676 L
.77959 .21866 L
.78183 .22637 L
.78308 .23005 L
.78423 .23197 L
.78488 .23237 L
.78558 .23232 L
.78687 .23146 L
.78815 .23064 L
.78934 .23089 L
.79063 .23275 L
.79128 .23428 L
.79199 .23625 L
.79326 .24002 L
.79442 .24295 L
.79512 .24421 L
.79579 .24496 L
.7965 .24531 L
.79726 .24524 L
.79793 .24494 L
.79864 .24453 L
.79991 .2441 L
.80109 .24464 L
.80235 .24651 L
.80355 .24924 L
.80464 .25202 L
.80586 .25468 L
.80655 .25577 L
.80719 .25643 L
.80848 .25682 L
.80921 .25662 L
Mistroke
.80987 .25633 L
.81103 .25591 L
.81226 .25615 L
.81331 .25719 L
.81446 .25917 L
.81569 .26183 L
.81686 .26425 L
.81751 .26533 L
.81821 .26621 L
.81944 .26691 L
.82061 .26678 L
.82186 .26628 L
.82304 .2661 L
.82411 .26655 L
.82519 .26775 L
.82636 .26971 L
.82745 .2718 L
.82848 .2736 L
.82972 .27512 L
.83086 .27567 L
.83208 .27553 L
.83277 .27527 L
.83341 .27503 L
.83447 .27485 L
.83564 .27526 L
.83686 .27651 L
.83801 .27827 L
.83929 .28042 L
.83999 .28146 L
.84063 .28223 L
.84178 .28305 L
.84304 .28314 L
.84375 .28293 L
.84441 .28267 L
.84566 .2823 L
.84636 .28232 L
.847 .28254 L
.84771 .28304 L
.84846 .28383 L
.85096 .28742 L
.85168 .28831 L
.85237 .28895 L
.85365 .28951 L
.85485 .28935 L
.85597 .28891 L
.8572 .28853 L
.8585 .2887 L
.8598 .28967 L
.86053 .2905 L
.8612 .29138 L
Mistroke
.86252 .29309 L
.86374 .29426 L
.86439 .29462 L
.86509 .29478 L
.86586 .29471 L
.86656 .29448 L
.8673 .29415 L
.8681 .29382 L
.86885 .29364 L
.86953 .29364 L
.87072 .29414 L
.87184 .29514 L
.87315 .29667 L
.87437 .29801 L
.87556 .29884 L
.87683 .29905 L
.87755 .29889 L
.87823 .29861 L
.8795 .29802 L
.88062 .29774 L
.8818 .29795 L
.88281 .29858 L
.88392 .29964 L
.88511 .30091 L
.88639 .30199 L
.8876 .30246 L
.8887 .30236 L
.88999 .30181 L
.89069 .30145 L
.89136 .30117 L
.89252 .30097 L
.89381 .30136 L
.89449 .30182 L
.89521 .30244 L
.89649 .30367 L
.89716 .30424 L
.89787 .30472 L
.89865 .30504 L
.89938 .3051 L
.90069 .30475 L
.90142 .30438 L
.9021 .30401 L
.90335 .30351 L
.90468 .30351 L
.90586 .30407 L
.90697 .30494 L
.90829 .30608 L
.90949 .30682 L
.91074 .30706 L
.91143 .30694 L
Mistroke
.91208 .30669 L
.91324 .30605 L
.91447 .30544 L
.91512 .30526 L
.91584 .30522 L
.91709 .30561 L
.91779 .30605 L
.91855 .30663 L
.91925 .3072 L
.91991 .30768 L
.92118 .30833 L
.92185 .30844 L
.92257 .30837 L
.92376 .3079 L
.92508 .30714 L
.92625 .30659 L
.92751 .30645 L
.9287 .30684 L
.92979 .30753 L
.93093 .30838 L
.93215 .30909 L
.9333 .30934 L
.93434 .30917 L
.93556 .30856 L
.93621 .30817 L
.93689 .30777 L
.93814 .30727 L
.9393 .30725 L
.94037 .30765 L
.94152 .30838 L
.94252 .30906 L
.9436 .30964 L
.94487 .30987 L
.94608 .30956 L
.94725 .30891 L
.94833 .30824 L
.94917 .30784 L
.95005 .30763 L
.9508 .30766 L
.95162 .30791 L
.95251 .30839 L
.95345 .30902 L
.95434 .30957 L
.95516 .30995 L
.95599 .31012 L
.95689 .31002 L
.95768 .30972 L
.95852 .30925 L
.95934 .30873 L
.96012 .30828 L
Mistroke
.96081 .30797 L
.96157 .3078 L
.96247 .30787 L
.96331 .30816 L
.96421 .30867 L
.96517 .30929 L
.96608 .30981 L
.96693 .31012 L
.9677 .31019 L
.96853 .31004 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000OooonfX4o`0009_o
oo]Z002OoookJPCo0000N_oonfX5o`0007oooo]Z1?l0002KoookJP00WooonfX4o`0007[ooo]Z1Ol0
001ooookJPCo0000VooonfX009oooo]Z1?l0001joookJPGo0000OooonfX4o`0009_ooo]Z002Ooook
JPCo0000N_oonfX5o`0007kooo]Z1Ol0002KoookJP00WooonfX5o`0007Wooo]Z1Ol0001noookJPKo
0000V_oonfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oo
nfX6o`0006cooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPKo0000K?oonfX3
o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1_l0001LoookJP[o001o1_oonfX3o`00
O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1_l0001LoookJP[o001o1_oonfX3o`00O`[o
oo]Z1_l0001moookJPKo0000V_oonfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z
1ol0002IoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000O_oonfX7o`0009Wooo]Z002N
oookJPOo0000JooonfX3o`00O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z1ol0001[oook
JP?o001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX7o`0006Sooo]Z1_l007l:oookJPGo
0000O_oonfX7o`0009Wooo]Z002NoookJPOo0000J?oonfX6o`00O`[ooo]Z1Ol0001noookJPOo0000
VOoonfX009kooo]Z1ol0001ZoookJPCo001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00WOoonfX8
o`0006_ooo]Z0ol007l:oookJPGo0000O_oonfX7o`0009Wooo]Z002MoookJPSo0000N?oonfX5o`00
07kooo]Z1ol0002IoookJP00WOoonfX8o`0007Sooo]Z1Ol0001noookJP_o0000UOoonfX009gooo]Z
3?l0001doookJPGo0000O_oonfX<o`0009Cooo]Z002MoookJPco0000M?oonfX5o`0007kooo]Z3?l0
002DoookJP00WOoonfX=o`0007?ooo]Z1Ol0001noookJPco0000U?oonfX009gooo]Z3Ol0001coook
JPGo0000O_oonfX<o`0009Cooo]Z002MoookJPgo0000LooonfX5o`0007kooo]Z3?l0002DoookJP00
WOoonfX>o`0007;ooo]Z1Ol0001noookJPco0000U?oonfX009gooo]Z3_l0001boookJPGo0000O_oo
nfX=o`0009?ooo]Z002MoookJPko0000L_oonfX5o`0007gooo]Z3_l0002CoookJP00WOoonfX4o`00
0003oookJ_l0003o000000Oo0000L_oonfX5o`0007gooo]Z3_l0002CoookJP00WOoonfX4o`000003
oookJ_l0003o000000Oo0000L_oonfX5o`0007gooo]Z3_l0002CoookJP00WOoonfX4o`000003oook
J_l0003o000000Oo0000L_oonfX5o`0007gooo]Z1?l000000ooonf[o0000o`000008o`0009;ooo]Z
002MoookJPCo000000?ooo]Zo`000?l000002ol0001^oookJPGo0000OOoonfX4o`000003oookJ_l0
003o000000_o0000SooonfX009gooo]Z1?l00006oookJPWo0000KOoonfX5o`0007gooo]Z1?l00006
oookJPWo0000S_oonfX009gooo]Z1?l00006oookJPWo0000KOoonfX5o`0007gooo]Z1?l00007oook
JPSo0000S_oonfX009gooo]Z1?l00006oookJPWo0000KOoonfX5o`0007gooo]Z1?l00007oookJPSo
0000S_oonfX009gooo]Z1?l00006oookJPWo0000KOoonfX5o`0007gooo]Z1?l00007oookJPSo0000
S_oonfX009gooo]Z1?l00007oookJPSo0000KOoonfX5o`0007gooo]Z1?l00007oookJPWo0000SOoo
nfX009gooo]Z1?l00007oookJPWo0000K?oonfX5o`0007gooo]Z1?l00007oookJPWo0000SOoonfX0
09gooo]Z1?l00008oookJPSo0000K?oonfX5o`0007gooo]Z1?l00008oookJPWo0000S?oonfX009go
oo]Z1?l0000;oookJPGo0000K?oonfX5o`0007gooo]Z1?l0000<oookJPGo0000S?oonfX009gooo]Z
1?l0000<oookJPGo0000JooonfX5o`0007gooo]Z1?l0000<oookJPGo0000S?oonfX009gooo]Z1?l0
000<oookJPSo0000J?oonfX5o`0007gooo]Z1?l0000=oookJPSo0000R?oonfX009gooo]Z1?l0000<
oookJPWo0000IooonfX5o`0007gooo]Z1?l0000=oookJPSo0000R?oonfX009gooo]Z1?l0000=oook
JPSo0000IooonfX5o`0007gooo]Z1?l0000=oookJPWo0000QooonfX009gooo]Z1?l0000=oookJPSo
0000IooonfX5o`0007gooo]Z1?l0000=oookJPWo0000QooonfX009gooo]Z1?l0000=oookJPWo0000
I_oonfX5o`0007gooo]Z1?l0000=oookJPWo0000QooonfX009gooo]Z1?l0000>oookJPSo0000I_oo
nfX5o`0007gooo]Z1?l0000>oookJPWo0000Q_oonfX009gooo]Z1?l0000AoookJPKo0000AooonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0007gooo]Z1?l0000BoookJPGo0000Q_oonfX0
09gooo]Z1?l0000BoookJPGo0000A_oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`00
07gooo]Z1?l0000BoookJPGo0000Q_oonfX009gooo]Z1?l0000BoookJPGo0000A_oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001o
o`00O`Wooo]Z1Ol0001moookJPCo00004ooonfX4o`0008Kooo]Z002MoookJPCo00004ooonfX8o`00
03Gooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`00
07gooo]Z1?l0000CoookJPSo0000P_oonfX009gooo]Z1?l0000CoookJPSo0000=OoonfX:o`00O`;o
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001loookJPCo00004ooonfX9o`00087o
oo]Z002MoookJPCo00004ooonfX9o`00043ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z
1Ol0001moookJPCo00004ooonfX9o`00087ooo]Z002MoookJPCo00005?oonfX8o`00043ooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000OOoonfX4o`0001Cooo]Z2?l0
0021oookJP00WOoonfX4o`0001Oooo]Z1_l0000ooookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9
oookJPGo0000OOoonfX4o`0001Sooo]Z1?l00021oookJP00WOoonfX4o`0001Sooo]Z1Ol0000ooook
JP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000OOoonfX4o`0001Sooo]Z1Ol00020oook
JP00WOoonfX4o`0001Sooo]Z1_l0000noookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo
0000OOoonfX4o`0001Sooo]Z1_l0001ooookJP00WOoonfX4o`0001Wooo]Z2?l0000loookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001moookJPCo00006?oonfX9o`0007co
oo]Z002MoookJPCo00006OoonfX9o`0003_ooo]Z1ol007l9oookJPOo001o2?oonfX5o`0007gooo]Z
1?l0000IoookJPWo0000NooonfX009gooo]Z1?l0000IoookJP[o0000>ooonfX5o`00O`[ooo]Z1ol0
07l8oookJPGo0000OOoonfX4o`0001[ooo]Z2?l0001koookJP00WOoonfX4o`0001[ooo]Z2_l0001H
oookJPGo0000OOoonfX4o`0001[ooo]Z2Ol0001joookJP00WOoonfX4o`0001kooo]Z1ol0001Goook
JPGo0000OOoonfX4o`0001_ooo]Z2?l0001joookJP00WOoonfX4o`0001oooo]Z1ol0001FoookJPGo
0000OOoonfX4o`0001kooo]Z1Ol0001joookJP00WOoonfX4o`00023ooo]Z1ol0001EoookJPGo0000
OOoonfX4o`0001oooo]Z2?l0001foookJP00WOoonfX4o`00027ooo]Z1ol0001DoookJPGo0000OOoo
nfX4o`0001oooo]Z2Ol0001eoookJP00WOoonfX4o`0002;ooo]Z1ol0001CoookJPGo0000OOoonfX4
o`0001oooo]Z2Ol0001eoookJP00WOoonfX4o`0002?ooo]Z1ol0001BoookJPGo0000OOoonfX4o`00
023ooo]Z2Ol0001doookJP00WOoonfX4o`0002Cooo]Z1ol0001AoookJPGo0000OOoonfX4o`00023o
oo]Z2Ol0001doookJP00WOoonfX4o`0002Gooo]Z1ol0001@oookJPGo0000O?oonfX5o`0002Cooo]Z
1_l0001coookJP00WOoonfX4o`0002Kooo]Z1ol0001?oookJPGo0000O?oonfX5o`0002Gooo]Z2Ol0
001_oookJP00WOoonfX4o`0002Oooo]Z1ol0001>oookJPGo0000O?oonfX5o`0002Gooo]Z2Ol0001_
oookJP00WOoonfX4o`0002Sooo]Z1ol0001=oookJPGo0000O?oonfX4o`0002Oooo]Z2Ol0001^oook
JP008_oonfX3o`00OgGooo]Z0ol007l4o`0000;ooo]Z0ol007l3oookJPGo001o7?oonfX7o`0004co
oo]Z1Ol0001doookJPGo001o0ooonfX4o`0000?ooo]Z1Ol007lOoookJPWo0000C_oonfX3o`00Oago
oo]Z000RoookJP?o001oM?oonfX3o`00O`Go00000_oonfX3o`00O`;ooo]Z1ol007lLoookJPOo0000
BooonfX5o`0007?ooo]Z1ol007l2oookJPCo00000_oonfX7o`00Ob;ooo]Z1_l0001=oookJP?o001o
7OoonfX002;ooo]Z0ol007mdoookJP?o001o1Ol00002oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007lMoookJPSo0000BOoonfX5o`0007?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l2oookJPCo000000?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lSoook
JP[o0000B?oonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o
001o00?ooo]Zo`000?l000000ol00006oookJP?o001o0ooonfX3o`00Oagooo]Z2?l00018oookJPGo
0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`000004oookJ_l007oo001oo`00
O`?ooo]Z0ol007lRoookJP[o0000B?oonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOo
oo]Z2_l007l2oookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o
001o7_oonfX9o`0004Kooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o
00001ooonfX3o`00Ob?ooo]Z2Ol00018oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o
00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o001o7ooonfX9o`0004Gooo]Z
1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00001ooonfX3o`00ObCooo]Z
2Ol00017oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l0
00000ol007oooo]ZoookJP05oookJP;o001o0_oonfX4o`00Ob7ooo]Z2Ol00013oookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l007l2oookJPCo001o:?oo
nfX:o`0004;ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002
o`000003o`00Oooonf[ooo]Z00Gooo]Z1ol007lSoookJP[o0000@OoonfX5o`0007;ooo]Z0ol007l3
oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJPOo001o:OoonfX:o`0004;ooo]Z0ol007lM
oookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z
00Gooo]Z1_l007lVoookJP[o0000?ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`00
0?l000000_l00002oookJPKo001o:ooonfX:o`00047ooo]Z0ol007lMoookJP007ooonfX6o`00Og?o
oo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l[oookJP_o
0000?OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP;o
001o<?oonfX=o`0003[ooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z
0_l007l]oookJP_o0000>ooonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo
00000_oonfX2o`00OcCooo]Z2ol0000hoookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o
1?l00009oookJPOo001o:OoonfX:o`0003[ooo]Z1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z
1ol007l_oookJP[o0000>_oonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00002Ooo
nfX7o`00Ob_ooo]Z3Ol0000eoookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPOo001o<?oo
nfX>o`0003Kooo]Z0ol007lMoookJP00W?oonfX4o`0003gooo]Z3?l0000doookJPGo0000O?oonfX4
o`0003kooo]Z2ol0001EoookJP00W?oonfX4o`0003oooo]Z3ol0000_oookJPGo0000O?oonfX4o`00
03oooo]Z3ol0001@oookJP00W?oonfX4o`00043ooo]Z4?l0000]oookJPGo0000O?oonfX4o`00043o
oo]Z3ol0001?oookJP00W?oonfX4o`0004Gooo]Z4?l0000XoookJPGo0000O?oonfX4o`0004Gooo]Z
4?l00019oookJP00W?oonfX4o`0004Gooo]Z5_l0000RoookJPGo0000O?oonfX4o`0004Kooo]Z5Ol0
0013oookJP00W?oonfX4o`0004Oooo]Z6_l0000LoookJPGo0000O?oonfX4o`0004Oooo]Z6_l0000m
oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP00
3_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[o
o`000?oo00009Ol0000?oookJP007?oonfX5o`000003oookJ_l0003o000000?o000000?ooo]Zo`00
0?l000009_l0001<oookJPCo0000L_oonfX4o`0000;ooo]Z2ol000000ooonf[o0000o`000004o`00
0003oookJ_l0003o000002Go0000C?oonfX4o`0007;ooo]Z1Ol000000ooonf[o0000o`000004o`00
0003oookJ_l0003ooo]Z01gooo]Z000koookJQ[o0000AooonfX4o`0007gooo]Z1Ol0000KoookJQ[o
0000AooonfX4o`0009kooo]Z0011oookJQGo0000A_oonfX4o`0007gooo]Z1Ol0000QoookJQKo0000
AOoonfX4o`0009kooo]Z0017oookJQ3o0000AOoonfX4o`0007gooo]Z1Ol0000WoookJQ3o0000AOoo
nfX4o`0009kooo]Z001=oookJPoo0000@?oonfX4o`0007gooo]Z1Ol0000]oookJPoo0000@?oonfX4
o`0009kooo]Z001>oookJPoo0000?ooonfX4o`0007gooo]Z1Ol0000^oookJPoo0000?ooonfX4o`00
09kooo]Z001CoookJP_o0000?_oonfX4o`0007gooo]Z1Ol0000coookJP_o0000?_oonfX4o`0009ko
oo]Z001DoookJPko0000>_oonfX4o`0007gooo]Z1Ol0000doookJPko0000>_oonfX4o`0009kooo]Z
001IoookJP[o0000>OoonfX4o`0007gooo]Z1Ol0000ioookJP[o0000>OoonfX4o`0009kooo]Z001J
oookJP[o0000>?oonfX4o`0007gooo]Z1Ol0000joookJP[o0000=ooonfX5o`0009kooo]Z001Joook
JPko0000=?oonfX4o`0007gooo]Z1Ol0000joookJPko0000<ooonfX5o`0009kooo]Z001OoookJP[o
0000<ooonfX4o`0007gooo]Z1Ol0000ooookJP[o0000<_oonfX5o`0009kooo]Z001PoookJPWo0000
<ooonfX4o`0007gooo]Z1Ol00010oookJPWo0000<_oonfX4o`0009oooo]Z001PoookJP[o0000<Ooo
nfX5o`0007gooo]Z1Ol00010oookJP[o0000<OoonfX4o`0009oooo]Z001RoookJPWo0000<?oonfX5
o`0007gooo]Z1Ol00012oookJPco0000;OoonfX4o`0009oooo]Z001UoookJPSo0000;_oonfX5o`00
07gooo]Z1Ol00015oookJP[o0000;?oonfX4o`0009oooo]Z001VoookJPWo0000;?oonfX4o`0007ko
oo]Z1Ol00016oookJP[o0000:ooonfX4o`0009oooo]Z001WoookJPWo0000:ooonfX4o`0007kooo]Z
1Ol00017oookJPWo0000:ooonfX4o`0009oooo]Z001XoookJP[o0000:OoonfX4o`0007kooo]Z1Ol0
0018oookJPWo0000:_oonfX4o`0009oooo]Z001ZoookJPWo0000:?oonfX4o`0007kooo]Z1Ol0001<
oookJPWo00009_oonfX4o`0009oooo]Z001/oookJPSo00009ooonfX4o`0007kooo]Z1Ol0001<oook
JPWo00009_oonfX4o`0009oooo]Z001]oookJPSo00009_oonfX4o`0007kooo]Z1Ol0001<oookJPWo
00009_oonfX4o`0009oooo]Z001_oookJPSo00009?oonfX4o`0007kooo]Z1Ol0001=oookJPWo0000
9OoonfX4o`0009oooo]Z001`oookJPSo00008ooonfX4o`0007kooo]Z1Ol0001AoookJPKo00009?oo
nfX4o`0009oooo]Z001aoookJPSo00008_oonfX4o`0007kooo]Z1Ol0001AoookJPWo00008OoonfX4
o`0009oooo]Z001boookJPSo00008OoonfX4o`0007kooo]Z1Ol0001BoookJPWo00008?oonfX4o`00
09oooo]Z001doookJPSo00007ooonfX4o`0007kooo]Z1Ol0001CoookJPSo00008?oonfX4o`0009oo
oo]Z001eoookJPSo00007_oonfX4o`0007kooo]Z1Ol0001CoookJPWo00007ooonfX4o`0009oooo]Z
001foookJPSo00007OoonfX4o`0007kooo]Z1Ol0001DoookJPSo00007ooonfX4o`0009oooo]Z001g
oookJPSo00007?oonfX4o`0007kooo]Z1Ol0001GoookJPKo00007_oonfX4o`0009oooo]Z001ioook
JPOo00006ooonfX4o`0007kooo]Z1Ol0001HoookJPGo00007_oonfX4o`0009oooo]Z001joookJPOo
00006_oonfX4o`0007kooo]Z1Ol0001HoookJPWo00006_oonfX4o`0009oooo]Z001koookJPOo0000
6OoonfX4o`0007kooo]Z1Ol0001IoookJPSo00006_oonfX4o`0009oooo]Z001loookJPKo00006Ooo
nfX4o`0007kooo]Z1Ol0001IoookJPWo00006OoonfX4o`0009oooo]Z001moookJPKo00006?oonfX4
o`0007kooo]Z1Ol0001JoookJPSo00006OoonfX4o`0009oooo]Z001noookJPKo00005ooonfX4o`00
063ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001MoookJPKo00006?oonfX4o`00
09oooo]Z001noookJPOo00005_oonfX4o`0005oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wo
oo]Z1Ol0001NoookJPGo00006?oonfX4o`0009oooo]Z001ooookJPOo00005OoonfX4o`0005oooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o
001oo`00Ool007l9oookJPGo0000G_oonfX5o`0001Sooo]Z1?l0002OoookJP00P?oonfX7o`0001Co
oo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0005oo
oo]Z2?l0000DoookJPCo0000WooonfX0087ooo]Z1_l0000DoookJPCo0000G_oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o2?oonfX6o`0005kooo]Z2Ol0000CoookJPCo0000WooonfX008;ooo]Z1_l0
000CoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0005oooo]Z2Ol0
000CoookJPCo0000WooonfX008?ooo]Z1_l0000BoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001PoookJPSo00004ooonfX4o`0009oooo]Z0023oook
JPOo00004OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001Qoook
JPSo00004_oonfX4o`0009oooo]Z0024oookJPKo00004OoonfX4o`0005kooo]Z0ol007l3oookJP?o
001o1ooonfX6o`00O`[ooo]Z1Ol0001ToookJPGo00004_oonfX4o`0009oooo]Z0025oookJPKo0000
4?oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001ToookJPGo0000
4_oonfX4o`0009oooo]Z0026oookJPKo00003ooonfX4o`0005oooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJP;o001o3_oonfX5o`0006Gooo]Z2?l0000>oookJPCo0000WooonfX008Kooo]Z1_l0
000?oookJPCo0000GooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000IOoonfX9o`0000gooo]Z1?l0
002OoookJP00QooonfX6o`0000kooo]Z1?l0001PoookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001U
oookJPWo00003OoonfX4o`0009oooo]Z0028oookJPGo00003_oonfX4o`0007kooo]Z1Ol0001Uoook
JPWo00003OoonfX4o`0009oooo]Z0028oookJPKo00003OoonfX4o`0007kooo]Z1Ol0001VoookJPSo
00003OoonfX4o`0009oooo]Z0029oookJPGo00003OoonfX4o`0007kooo]Z1Ol0001WoookJPOo0000
3OoonfX4o`0009oooo]Z0029oookJPGo00003OoonfX4o`0007kooo]Z1Ol0001ZoookJPGo00003?oo
nfX4o`0009oooo]Z002:oookJPGo00003?oonfX4o`0007kooo]Z1Ol0001ZoookJPGo00003?oonfX4
o`0009oooo]Z002:oookJPWo00002?oonfX4o`0007kooo]Z1Ol0001ZoookJPWo00002?oonfX4o`00
09oooo]Z002:oookJPWo00002?oonfX4o`0007kooo]Z1Ol0001[oookJPWo00001ooonfX4o`0009oo
oo]Z002;oookJPWo00001ooonfX4o`0007kooo]Z1Ol0001[oookJPWo00001ooonfX4o`0009oooo]Z
002;oookJPWo00001ooonfX4o`0007kooo]Z1Ol0001[oookJPWo00001ooonfX4o`0009oooo]Z002<
oookJPWo00001_oonfX4o`0007kooo]Z1Ol0001/oookJPSo00001ooonfX4o`0009oooo]Z002<oook
JPWo00001_oonfX4o`0007kooo]Z1Ol0001/oookJPSo00001ooonfX4o`0009oooo]Z002<oookJPWo
00001_oonfX4o`0007kooo]Z1Ol0001/oookJPWo00001_oonfX4o`0009oooo]Z002=oookJPco0000
0_oonfX4o`0007kooo]Z1Ol0001]oookJPgo000000?ooo]Zo`000?l000000_l0002OoookJP00TOoo
nfX9o`000003oookJ_l0003o000000;o0000O_oonfX5o`00073ooo]Z2_l000000ooonf[o0000o`00
0002o`0009oooo]Z002AoookJPWo000000?ooo]Zo`000?l000000_l0001noookJPGo0000LOoonfX9
o`000003oookJ_l0003o000000;o0000WooonfX0097ooo]Z2Ol000000ooonf[o0000o`000002o`00
07kooo]Z1Ol0001aoookJPko0000WooonfX009;ooo]Z2?l000000ooonf[o0000o`000002o`0007ko
oo]Z1Ol0001aoookJPko0000WooonfX009;ooo]Z2?l000000ooonf[o0000o`000002o`0007kooo]Z
1Ol0001aoookJPko0000WooonfX009;ooo]Z3Ol0001noookJPGo0000L_oonfX=o`0009oooo]Z002B
oookJPgo0000O_oonfX5o`0007;ooo]Z3Ol0002OoookJP00T_oonfX=o`0007kooo]Z1Ol0001boook
JPgo0000WooonfX009?ooo]Z3?l0001noookJPGo0000L_oonfX=o`0009oooo]Z002CoookJPco0000
O_oonfX5o`0007;ooo]Z3?l0002PoookJP00TooonfX<o`0007kooo]Z1Ol0001boookJPco0000X?oo
nfX009Oooo]Z2?l0001noookJPGo0000LooonfX;o`000:3ooo]Z002GoookJPSo0000O_oonfX5o`00
07Oooo]Z1ol0002PoookJP00UooonfX8o`0007kooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z
1ol0001ooookJPGo0000MooonfX7o`000:3ooo]Z002HoookJPKo0000OooonfX5o`0007Oooo]Z1ol0
002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000MooonfX7o`000:3ooo]Z002Hoook
JPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001goookJPOo0000X?oonfX009Sooo]Z1_l0001boookJP?o
001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000
N?oonfX6o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1_l0001goookJPKo0000X?oo
nfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX6o`00
07;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[o
oo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z
1_l0002PoookJP00V?oonfX6o`0006oooo]Z1_l007l:oookJPGo0000N?oonfX5o`000:7ooo]Z002H
oookJPKo0000KooonfX6o`00O`[ooo]Z1Ol0001hoookJPGo0000XOoonfX009Sooo]Z1_l0001aoook
JPCo001o2_oonfX5o`0007Sooo]Z1Ol0002QoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo
0000N?oonfX5o`000:7ooo]Z002HoookJPKo0000OooonfX5o`0007Wooo]Z1?l0002QoookJP00VOoo
nfX4o`00083ooo]Z1Ol0001ioookJPCo0000XOoonfX009Wooo]Z1?l00020oookJPGo0000NOoonfX4
o`000:7ooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJP;o
oo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooo
nfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z
003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00oooonfX>oookJPCo001o3?oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7o
oo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oo
oookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJPCo
001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooo
nfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30831 L
.02605 .30792 L
.02729 .30794 L
.02846 .30843 L
.02954 .3091 L
.03056 .30971 L
.03162 .31012 L
.03279 .31012 L
.03397 .30967 L
.03524 .30889 L
.03632 .30826 L
.0375 .3079 L
.03821 .30792 L
.03887 .30809 L
.04017 .30878 L
.04145 .3096 L
.04262 .31014 L
.04386 .31024 L
.04452 .31007 L
.04521 .30975 L
.04647 .30898 L
.04765 .30833 L
.0487 .30804 L
.04983 .30816 L
.05108 .30877 L
.05221 .30954 L
.05352 .31028 L
.05473 .31053 L
.05536 .31046 L
.05606 .31022 L
.05679 .30984 L
.05747 .30942 L
.05863 .30875 L
.05986 .30839 L
.06051 .30841 L
.06121 .3086 L
.06244 .3093 L
.06381 .31026 L
.06458 .31071 L
.06529 .31098 L
.06659 .31101 L
.06725 .31079 L
.06797 .31043 L
.06923 .30969 L
.06991 .30933 L
.07057 .30911 L
.07184 .3091 L
.073 .30961 L
.07434 .31058 L
Mistroke
.07561 .31147 L
.07631 .31181 L
.07707 .31198 L
.07839 .31177 L
.07917 .31141 L
.07998 .31094 L
.08074 .31052 L
.08144 .31023 L
.08209 .31009 L
.08279 .31012 L
.08357 .31038 L
.08427 .31079 L
.08552 .31178 L
.0867 .31269 L
.08792 .31328 L
.08857 .31337 L
.08927 .31329 L
.08999 .31303 L
.09075 .31265 L
.09145 .31226 L
.0921 .31194 L
.09334 .31162 L
.094 .31169 L
.09471 .31196 L
.09599 .31286 L
.09737 .3141 L
.09868 .31502 L
.09988 .31533 L
.10097 .31513 L
.10217 .31457 L
.10334 .314 L
.10458 .31375 L
.10588 .31415 L
.10708 .31508 L
.10849 .31646 L
.10981 .31753 L
.11094 .31795 L
.11217 .31782 L
.11283 .31755 L
.11352 .31721 L
.11477 .31668 L
.11588 .31657 L
.11707 .31704 L
.11819 .31799 L
.11921 .31909 L
.12041 .32034 L
.12171 .3212 L
.12293 .32135 L
.12407 .32101 L
.12527 .32046 L
Mistroke
.12656 .32013 L
.12778 .32042 L
.1289 .32128 L
.13023 .32281 L
.13097 .32371 L
.13166 .32447 L
.1323 .32504 L
.133 .32546 L
.13422 .32564 L
.13488 .3255 L
.13559 .32522 L
.13685 .3247 L
.13756 .32456 L
.13823 .32462 L
.13895 .32492 L
.13973 .32554 L
.14222 .32872 L
.14291 .32956 L
.14364 .33027 L
.14434 .33071 L
.14497 .3309 L
.14622 .33075 L
.14754 .33023 L
.14884 .32995 L
.14958 .33009 L
.15026 .33049 L
.1515 .33182 L
.15263 .33348 L
.15386 .33531 L
.15516 .33672 L
.15583 .33711 L
.15658 .33726 L
.15789 .33696 L
.15863 .33667 L
.15942 .33643 L
.16017 .3364 L
.16085 .33662 L
.16217 .33782 L
.16292 .33889 L
.16361 .34005 L
.16497 .34237 L
.16623 .34399 L
.1675 .34473 L
.16816 .34476 L
.16886 .34459 L
.17015 .3441 L
.17135 .34398 L
.17241 .34452 L
.17356 .3459 L
.17482 .34819 L
Mistroke
.17598 .35043 L
.17662 .35155 L
.17731 .3525 L
.17853 .35346 L
.17985 .35347 L
.18061 .35318 L
.18131 .3529 L
.18258 .35278 L
.18374 .35353 L
.18438 .35437 L
.18508 .35559 L
.18635 .35833 L
.18759 .361 L
.1889 .36301 L
.18959 .36357 L
.19034 .36377 L
.19166 .3634 L
.19291 .36288 L
.19361 .36283 L
.19425 .36308 L
.19549 .36452 L
.19666 .36698 L
.19884 .37242 L
.19993 .37442 L
.20114 .37544 L
.20245 .37524 L
.20367 .37454 L
.2048 .37425 L
.20602 .37508 L
.20733 .3776 L
.20856 .38108 L
.20931 .38336 L
.21002 .38535 L
.21071 .38696 L
.21134 .38804 L
.21265 .3889 L
.21333 .3887 L
.21406 .38818 L
.21472 .38763 L
.21544 .38716 L
.21622 .38706 L
.21695 .38755 L
.21824 .39001 L
.21897 .39221 L
.21964 .39458 L
.22098 .3994 L
.2222 .40273 L
.22339 .40417 L
.22452 .40383 L
.2257 .40241 L
Mistroke
.22699 .40111 L
.22823 .40158 L
.22937 .40416 L
.23067 .40935 L
.23191 .41509 L
.23306 .41948 L
.23412 .42169 L
.23528 .42165 L
.23651 .41942 L
.23774 .41667 L
.23844 .41574 L
.23907 .41566 L
.24024 .41802 L
.24148 .42395 L
.24274 .43217 L
.24344 .43658 L
.24409 .44007 L
.24487 .44284 L
.24558 .44373 L
.24624 .44307 L
.24695 .44088 L
.24827 .4344 L
.24949 .4288 L
.2502 .42741 L
.25084 .428 L
.25158 .43125 L
.25229 .43692 L
.25296 .44446 L
.25369 .45396 L
.25498 .47101 L
.2557 .47779 L
.25638 .48064 L
.25712 .47844 L
.25792 .46854 L
.25915 .43696 L
.25984 .41066 L
.26049 .38168 L
.26319 .24247 L
.26439 .1905 L
.26553 .1566 L
.26684 .13862 L
.26803 .13973 L
.26918 .1513 L
.27041 .16801 L
.27158 .18164 L
.27264 .18897 L
.27389 .1903 L
.2746 .18822 L
.27525 .18517 L
.27644 .17897 L
Mistroke
.27773 .17468 L
.27843 .17438 L
.27907 .17554 L
.28034 .18126 L
.28156 .18918 L
.2827 .19619 L
.28393 .20113 L
.28459 .20226 L
.28528 .20236 L
.28602 .20146 L
.28671 .20001 L
.28801 .19713 L
.28907 .19605 L
.29023 .19721 L
.29145 .20107 L
.2926 .20619 L
.29359 .2107 L
.29464 .21447 L
.29579 .2167 L
.29684 .21691 L
.29799 .21577 L
.29922 .21427 L
.30038 .21385 L
.30143 .21496 L
.30267 .21812 L
.30401 .22289 L
.30529 .22723 L
.30645 .22993 L
.30766 .23099 L
.30881 .23062 L
.31002 .22964 L
.31134 .22915 L
.31249 .23003 L
.31372 .23249 L
.31487 .2358 L
.31592 .23894 L
.31657 .24067 L
.31726 .24214 L
.3185 .24361 L
.31919 .24379 L
.31983 .24364 L
.32053 .24327 L
.32128 .24283 L
.32194 .24258 L
.32264 .24259 L
.32393 .24368 L
.32518 .24608 L
.32633 .24899 L
.32754 .25197 L
.32884 .25427 L
Mistroke
.33007 .25518 L
.33119 .25507 L
.3325 .25447 L
.33324 .25427 L
.33393 .25434 L
.3352 .25536 L
.3359 .25645 L
.33654 .25769 L
.33785 .26058 L
.33922 .26333 L
.33994 .26436 L
.34073 .26505 L
.34145 .26529 L
.34212 .26524 L
.3428 .26502 L
.34345 .26475 L
.34466 .26446 L
.34596 .26498 L
.3467 .26577 L
.34738 .2668 L
.34963 .27107 L
.35076 .27285 L
.352 .27391 L
.35265 .27408 L
.35335 .27402 L
.3546 .27357 L
.35585 .27326 L
.35699 .27358 L
.35815 .27468 L
.35922 .27629 L
.36037 .27828 L
.36164 .28021 L
.36274 .28128 L
.36377 .28165 L
.36485 .28148 L
.36602 .28103 L
.36669 .28083 L
.36739 .28079 L
.36866 .28132 L
.36944 .28208 L
.37017 .28303 L
.37154 .28511 L
.37277 .28679 L
.37406 .28786 L
.37474 .28807 L
.37548 .28804 L
.37678 .28759 L
.37807 .28716 L
.37924 .28723 L
.37989 .28756 L
Mistroke
.38059 .28815 L
.38187 .2897 L
.38307 .29133 L
.38434 .29273 L
.38542 .29337 L
.38662 .29342 L
.38784 .29298 L
.38897 .29252 L
.39022 .2924 L
.39091 .29262 L
.39154 .29302 L
.39282 .2943 L
.39421 .29599 L
.39552 .29729 L
.39673 .29787 L
.39783 .29782 L
.39887 .29743 L
.4001 .29688 L
.40123 .29666 L
.4024 .29697 L
.40352 .29781 L
.40479 .29915 L
.40599 .3004 L
.4073 .3013 L
.4085 .30147 L
.40978 .30107 L
.41051 .30071 L
.41117 .3004 L
.41228 .30008 L
.41351 .30026 L
.41478 .30108 L
.41597 .30222 L
.41665 .30289 L
.41739 .30352 L
.41808 .30397 L
.41872 .30422 L
.41994 .30421 L
.42123 .30368 L
.42252 .30303 L
.42324 .30278 L
.4239 .3027 L
.42468 .30283 L
.42542 .30317 L
.42611 .30365 L
.42685 .30429 L
.42809 .30539 L
.4294 .30622 L
.43009 .30639 L
.43084 .30637 L
.43216 .30588 L
Mistroke
.43341 .3052 L
.43411 .30488 L
.43475 .3047 L
.43599 .30478 L
.43716 .30538 L
.43934 .3071 L
.44043 .30774 L
.44165 .30795 L
.44295 .30757 L
.44418 .30689 L
.4453 .30631 L
.44652 .30605 L
.44784 .30637 L
.44906 .30715 L
.44981 .30773 L
.45052 .30824 L
.45116 .30862 L
.45185 .3089 L
.45253 .309 L
.45326 .30892 L
.45456 .30836 L
.45596 .30753 L
.45674 .30717 L
.45746 .30698 L
.45872 .30711 L
.45993 .30772 L
.46104 .30851 L
.46224 .30927 L
.46354 .30965 L
.46475 .30946 L
.46549 .30912 L
.46619 .30871 L
.46749 .30794 L
.46866 .30754 L
.46991 .30762 L
.47109 .30817 L
.47216 .30888 L
.47342 .30964 L
.47413 .30991 L
.47479 .31001 L
.476 .30977 L
.47728 .30909 L
.4785 .30834 L
.47981 .30782 L
.48105 .30785 L
.48219 .30833 L
.48356 .3092 L
.48483 .3099 L
.48547 .31009 L
.48616 .31014 L
Mistroke
.48691 .31 L
.4876 .30971 L
.48875 .30903 L
.48982 .30837 L
.49094 .30793 L
.49217 .30791 L
.49341 .30841 L
.49411 .30883 L
.49475 .30924 L
.49596 .30991 L
.49712 .31017 L
.4982 .31 L
.49935 .30943 L
.50034 .3088 L
.50141 .30819 L
.50256 .30787 L
.50363 .30798 L
.50491 .30858 L
.50609 .30933 L
.50736 .30999 L
.50856 .31018 L
.50964 .30992 L
.51082 .30928 L
.51209 .30848 L
.51274 .30816 L
.51345 .30794 L
.5147 .30798 L
.51587 .30848 L
.51695 .30917 L
.51812 .30987 L
.51923 .31024 L
.52026 .3102 L
.52146 .30972 L
.52273 .30894 L
.52391 .3083 L
.52499 .30803 L
.52628 .30826 L
.52694 .30858 L
.52765 .30903 L
.52894 .30988 L
.53011 .31042 L
.53082 .31053 L
.53149 .31047 L
.5322 .31024 L
.53297 .30984 L
.53424 .30907 L
.53491 .30871 L
.53564 .30845 L
.53695 .30846 L
.53817 .309 L
Mistroke
.53885 .30945 L
.53957 .30997 L
.54085 .31075 L
.54205 .31107 L
.54316 .3109 L
.54438 .31031 L
.54568 .30954 L
.54691 .30908 L
.54761 .30904 L
.54827 .30917 L
.54959 .30987 L
.55033 .31042 L
.55101 .31094 L
.55222 .31169 L
.55353 .31199 L
.55477 .31169 L
.55593 .31108 L
.55663 .31068 L
.55738 .31032 L
.55809 .31011 L
.55875 .31009 L
.55999 .3105 L
.56131 .31144 L
.56263 .31251 L
.56337 .31298 L
.56404 .31326 L
.56484 .31337 L
.56559 .31326 L
.56628 .31299 L
.56703 .3126 L
.5682 .31198 L
.56945 .31163 L
.57017 .31168 L
.57083 .31192 L
.57212 .31281 L
.57344 .314 L
.57414 .31457 L
.57488 .31503 L
.5756 .31528 L
.57625 .31533 L
.57751 .31499 L
.57876 .31436 L
.5799 .31387 L
.58116 .31379 L
.5818 .314 L
.58249 .31442 L
.58368 .31546 L
.58493 .3167 L
.586 .31753 L
.58719 .31795 L
Mistroke
.58848 .31777 L
.5897 .31722 L
.59101 .31666 L
.59175 .31655 L
.59242 .31664 L
.59358 .31727 L
.59484 .31848 L
.59617 .31993 L
.59738 .32094 L
.59858 .32137 L
.59971 .32122 L
.60091 .32071 L
.6022 .3202 L
.60333 .32018 L
.60453 .32079 L
.60556 .32178 L
.60669 .32314 L
.60735 .32394 L
.60808 .32469 L
.60877 .32523 L
.60941 .32554 L
.61061 .32561 L
.61189 .32517 L
.61262 .32485 L
.6134 .32461 L
.61415 .32457 L
.61483 .32476 L
.61612 .32574 L
.61677 .3265 L
.61749 .32745 L
.61878 .32919 L
.62001 .33041 L
.62069 .33078 L
.62143 .33092 L
.62272 .33065 L
.62395 .33015 L
.62525 .32996 L
.62637 .33043 L
.6276 .33169 L
.63783 .33721 L
.6486 .34451 L
.65779 .35281 L
.66783 .36341 L
.70656 .40798 L
.71666 .41886 L
.71907 .43308 L
.72039 .44055 L
.72162 .44368 L
.72267 .44248 L
.7238 .43787 L
Mistroke
.72495 .43187 L
.72619 .42761 L
.72693 .42777 L
.72761 .43028 L
.72826 .43491 L
.72895 .442 L
.73016 .45786 L
.73147 .47413 L
.7322 .47956 L
.73287 .48051 L
.73418 .46735 L
.73488 .4512 L
.73564 .42623 L
.73718 .35704 L
.73967 .22867 L
.74039 .19783 L
.74107 .17394 L
.74234 .14526 L
.74354 .13734 L
.74465 .14319 L
.74586 .1579 L
.74715 .175 L
.74836 .1864 L
.74967 .19066 L
.75092 .18768 L
.75207 .18184 L
.75321 .17653 L
.75425 .17434 L
.75544 .17609 L
.75657 .18148 L
.75779 .18942 L
.75893 .19638 L
.76012 .20112 L
.76143 .20238 L
.76275 .20035 L
.76349 .19861 L
.76417 .19719 L
.76546 .19606 L
.76669 .19784 L
.78499 .23063 L
.79465 .24358 L
.79719 .24299 L
.79789 .24265 L
.79862 .24255 L
.79994 .24344 L
.80116 .24562 L
.80231 .24843 L
.80364 .25178 L
.8049 .25411 L
.80597 .25507 L
Mistroke
.80712 .25515 L
.80817 .25471 L
.80914 .25432 L
.81018 .25436 L
.81133 .25529 L
.81253 .25728 L
.81366 .25973 L
.81491 .26242 L
.81609 .26431 L
.81716 .26517 L
.81832 .26524 L
.81958 .26477 L
.82028 .26453 L
.82092 .26446 L
.82216 .26499 L
.82332 .2664 L
.82558 .27063 L
.82684 .2727 L
.82799 .27381 L
.82865 .27406 L
.82936 .27406 L
.83064 .27363 L
.83193 .27327 L
.83311 .27354 L
.83434 .27469 L
.8355 .27644 L
.83687 .2788 L
.83813 .28057 L
.83937 .28152 L
.84069 .28158 L
.842 .28111 L
.84275 .28086 L
.84344 .28078 L
.8446 .28115 L
.84586 .28235 L
.84704 .28404 L
.84813 .28571 L
.84912 .28697 L
.8502 .28784 L
.85133 .28808 L
.85239 .28783 L
.85362 .28733 L
.85479 .28712 L
.85585 .28742 L
.85699 .28836 L
.85937 .29147 L
.86002 .29224 L
.8607 .29287 L
.86193 .29345 L
.86313 .29334 L
Mistroke
.86424 .29289 L
.86546 .29244 L
.86677 .29249 L
.86799 .29323 L
.86915 .29446 L
.87018 .29573 L
.87131 .29696 L
.87257 .29777 L
.87326 .29791 L
.8739 .29785 L
.87505 .29743 L
.87629 .29688 L
.87698 .29669 L
.87773 .29668 L
.87844 .2969 L
.87911 .29729 L
.88035 .29846 L
.88168 .29991 L
.88237 .30057 L
.8831 .3011 L
.88441 .30148 L
.88514 .30138 L
.88581 .30114 L
.88661 .30076 L
.88736 .3004 L
.888 .30017 L
.88871 .30007 L
.88994 .30037 L
.89063 .30081 L
.89137 .30144 L
.8927 .30275 L
.89388 .30374 L
.89515 .30426 L
.89635 .30415 L
.89745 .30367 L
.89877 .303 L
.9 .3027 L
.90128 .30299 L
.90196 .3034 L
.90268 .30398 L
.90402 .30518 L
.90527 .30607 L
.90658 .30641 L
.90727 .30632 L
.90802 .30605 L
.90934 .30534 L
.91059 .30478 L
.91171 .30468 L
.91294 .30511 L
.91438 .30617 L
Mistroke
.91573 .30724 L
.91648 .30768 L
.91729 .30793 L
.91803 .30793 L
.9187 .30776 L
.92004 .30709 L
.92077 .30666 L
.92147 .30632 L
.92212 .30611 L
.92282 .30605 L
.92405 .30638 L
.92523 .30713 L
.92648 .30808 L
.92755 .30872 L
.92873 .309 L
.93 .30873 L
.93072 .30838 L
.93138 .30799 L
.93265 .30728 L
.93386 .30696 L
.9351 .30718 L
.93579 .30752 L
.93642 .30793 L
.93766 .30881 L
.9388 .30944 L
.93945 .30962 L
.94014 .30965 L
.94083 .3095 L
.94158 .30917 L
.94294 .30836 L
.9442 .30771 L
.94517 .3075 L
.94619 .30765 L
.94721 .30813 L
.94835 .30888 L
.94932 .3095 L
.95037 .30993 L
.95137 .30999 L
.95228 .30974 L
.95316 .30928 L
.95399 .30876 L
.95497 .30819 L
.95586 .30785 L
.9568 .30778 L
.95769 .30799 L
.95862 .30847 L
.95964 .30913 L
.9606 .3097 L
.96163 .31009 L
.96276 .31009 L
Mistroke
.96382 .3097 L
.96491 .30905 L
.96609 .30833 L
.96721 .30791 L
.96825 .30789 L
.9693 .30825 L
.97026 .3088 L
.97129 .30946 L
.9724 .31 L
.97342 .31017 L
.97435 .31001 L
.97525 .3096 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000OooonfX4o`0009_o
oo]Z002OoookJPCo0000N_oonfX5o`0007oooo]Z1?l0002KoookJP00WooonfX4o`0007[ooo]Z1Ol0
001ooookJPGo0000V_oonfX009oooo]Z1?l0001joookJPGo0000O_oonfX6o`0009[ooo]Z002Ooook
JPCo0000N_oonfX5o`0007kooo]Z1_l0002JoookJP00WooonfX5o`0007Wooo]Z1Ol0001noookJPKo
0000V_oonfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oo
nfX6o`0006cooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPKo0000K?oonfX3
o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1_l0001LoookJP[o001o1_oonfX3o`00
O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1_l0001LoookJP[o001o1_oonfX3o`00O`[o
oo]Z1_l0001moookJPKo0000V_oonfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z
1_l0002JoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002N
oookJPOo0000JooonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1ol0001[oook
JP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX7o`0006Sooo]Z1_l007l:oookJPGo
0000O_oonfX6o`0009[ooo]Z002NoookJPOo0000J?oonfX6o`00O`[ooo]Z1Ol0001noookJPOo0000
VOoonfX009kooo]Z1ol0001ZoookJPCo001o2_oonfX5o`0007kooo]Z1ol0002IoookJP00W_oonfX7
o`0006_ooo]Z0ol007l:oookJPGo0000O_oonfX7o`0009Wooo]Z002NoookJPOo0000N?oonfX5o`00
07kooo]Z1ol0002IoookJP00WOoonfX<o`0007Cooo]Z1Ol0001noookJP_o0000UOoonfX009gooo]Z
3?l0001doookJPGo0000O_oonfX;o`0009Gooo]Z002MoookJPco0000M?oonfX5o`0007kooo]Z2ol0
002EoookJP00WOoonfX=o`0007?ooo]Z1Ol0001noookJPco0000U?oonfX009gooo]Z3Ol0001coook
JPGo0000O_oonfX<o`0009Cooo]Z002MoookJPgo0000LooonfX5o`0007kooo]Z3?l0002DoookJP00
WOoonfX=o`0007?ooo]Z1Ol0001noookJPco0000U?oonfX009gooo]Z3_l0001boookJPGo0000OOoo
nfX>o`0009?ooo]Z002MoookJPko0000L_oonfX5o`0007gooo]Z3_l0002CoookJP00WOoonfX>o`00
07;ooo]Z1Ol0001moookJPko0000TooonfX009gooo]Z1?l000000ooonf[o0000o`000007o`0007;o
oo]Z1Ol0001moookJPCo000000?ooo]Zo`000?l000001ol0002CoookJP00WOoonfX4o`000003oook
J_l0003o000000Oo0000L_oonfX5o`0007gooo]Z1?l000000ooonf[o0000o`000007o`0009?ooo]Z
002MoookJPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000006o`0006kooo]Z1Ol0
001moookJPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000006o`0008oooo]Z002M
oookJPCo00001_oonfX8o`0006kooo]Z1Ol0001moookJPCo00001_oonfX9o`0008kooo]Z002Moook
JPCo00001_oonfX9o`0006gooo]Z1Ol0001moookJPCo00001_oonfX9o`0008kooo]Z002MoookJPCo
00001_oonfX9o`0006gooo]Z1Ol0001moookJPCo00001_oonfX:o`0008gooo]Z002MoookJPCo0000
1_oonfX9o`0006gooo]Z1Ol0001moookJPCo00001_oonfX:o`0008gooo]Z002MoookJPCo00001ooo
nfX9o`0006cooo]Z1Ol0001moookJPCo00001ooonfX:o`0008cooo]Z002MoookJPCo00001ooonfX9
o`0006cooo]Z1Ol0001moookJPCo00001ooonfX:o`0008cooo]Z002MoookJPCo00002ooonfX5o`00
06cooo]Z1Ol0001moookJPCo00003?oonfX6o`0008_ooo]Z002MoookJPCo00003?oonfX4o`0006co
oo]Z1Ol0001moookJPCo00003OoonfX5o`0008_ooo]Z002MoookJPCo00003?oonfX8o`0006Sooo]Z
1Ol0001moookJPCo00003OoonfX6o`0008[ooo]Z002MoookJPCo00003?oonfX8o`0006Sooo]Z1Ol0
001moookJPCo00003_oonfX5o`0008[ooo]Z002MoookJPCo00003?oonfX8o`0006Sooo]Z1Ol0001m
oookJPCo00003_oonfX6o`0008Wooo]Z002MoookJPCo00003?oonfX9o`0006Oooo]Z1Ol0001moook
JPCo00003ooonfX5o`0008Wooo]Z002MoookJPCo00003OoonfX8o`0006Oooo]Z1Ol0001moookJPCo
00003ooonfX6o`0008Sooo]Z002MoookJPCo00003OoonfX9o`0006Kooo]Z1Ol0001moookJPCo0000
4?oonfX5o`0008Sooo]Z002MoookJPCo00004OoonfX5o`0006Kooo]Z1Ol0001moookJPCo00004?oo
nfX6o`0008Oooo]Z002MoookJPCo00004OoonfX5o`0004Sooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`[ooo]Z1Ol0001moookJPCo00004OoonfX5o`0008Oooo]Z002MoookJPCo00004_oonfX4o`00
04Oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001moookJPCo00004OoonfX6o`00
08Kooo]Z002MoookJPCo00004_oonfX8o`0004?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000OOoonfX4
o`0001;ooo]Z1Ol00026oookJP00WOoonfX4o`0001;ooo]Z2?l0000foookJP[o001o0_oonfX3o`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001moookJPCo00004_oonfX6o`00
08Gooo]Z002MoookJPCo00004_oonfX9o`0003Gooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l8oookJPKo0000O?oonfX4o`0001?ooo]Z1Ol00025oookJP00WOoonfX4o`0001?ooo]Z
2Ol00010oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000OOoonfX4o`0001?ooo]Z
1_l00024oookJP00WOoonfX4o`0001Cooo]Z2?l00010oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o2?oonfX5o`0007gooo]Z1?l0000DoookJPKo0000PooonfX009gooo]Z1?l0000G
oookJPGo0000@?oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`0007gooo]Z1?l0000D
oookJPOo0000P_oonfX009gooo]Z1?l0000HoookJPGo0000?ooonfX3o`00O`?ooo]Z0ol007l7oook
JPKo001o2_oonfX5o`0007gooo]Z1?l0000EoookJPOo0000POoonfX009gooo]Z1?l0000HoookJPSo
0000??oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0007gooo]Z1?l0000FoookJP_o
0000O?oonfX009gooo]Z1?l0000HoookJPWo0000??oonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Oooo]Z2_l0001loookJP00WOoonfX4o`0001Wooo]Z
2?l0000loookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001moookJPCo00006?oonfX9o`0007cooo]Z
002MoookJPCo00006OoonfX9o`0003cooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0007gooo]Z1?l0
000IoookJPWo0000NooonfX009gooo]Z1?l0000JoookJPSo0000F_oonfX5o`0007gooo]Z1?l0000J
oookJPSo0000NooonfX009gooo]Z1?l0000MoookJPKo0000FOoonfX5o`0007gooo]Z1?l0000Moook
JPKo0000N_oonfX009gooo]Z1?l0000NoookJPSo0000E_oonfX5o`0007gooo]Z1?l0000NoookJPSo
0000MooonfX009gooo]Z1?l0000NoookJPWo0000EOoonfX5o`0007gooo]Z1?l0000NoookJPWo0000
M_oonfX009gooo]Z1?l0000OoookJPSo0000EOoonfX5o`0007gooo]Z1?l0000OoookJPSo0000M_oo
nfX009gooo]Z1?l0000OoookJPSo0000EOoonfX5o`0007gooo]Z1?l0000OoookJPWo0000MOoonfX0
09gooo]Z1?l0000PoookJPSo0000E?oonfX5o`0007gooo]Z1?l0000PoookJPSo0000MOoonfX009go
oo]Z1?l0000SoookJPKo0000DooonfX5o`0007gooo]Z1?l0000SoookJPKo0000M?oonfX009gooo]Z
1?l0000SoookJP[o0000CooonfX5o`0007gooo]Z1?l0000ToookJPWo0000L?oonfX009gooo]Z1?l0
000ToookJPWo0000CooonfX5o`0007gooo]Z1?l0000ToookJPWo0000L?oonfX009gooo]Z1?l0000U
oookJPWo0000C_oonfX5o`0007gooo]Z1?l0000UoookJPSo0000L?oonfX009gooo]Z1?l0000Uoook
JP[o0000COoonfX5o`0007gooo]Z1?l0000UoookJPWo0000KooonfX002;ooo]Z0ol007meoookJP?o
001o1?l00002oookJP?o001o0ooonfX5o`00Oacooo]Z1_l0001=oookJPGo0000M?oonfX5o`00O`Co
oo]Z1?l00002oookJPGo001o8_oonfX6o`0004kooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z
1?l007l4o`0000;ooo]Z0ol007l2oookJPOo001o7?oonfX9o`0004Wooo]Z1Ol0001coookJPOo001o
0ooonfX4o`000003oookJ_l007oo001o00Go001o8OoonfX:o`0004[ooo]Z0ol007lMoookJP008_oo
nfX3o`00OgCooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00Oagooo]Z2Ol00018oookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z1?l00004o`00O`04oookJ_l007oo001oo`00Ob;ooo]Z2_l00019oook
JP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l2oookJPCo
00001_oonfX3o`00O`?ooo]Z0ol007lLoookJPWo0000B?oonfX5o`0007;ooo]Z0ol007l3oookJP?o
001o0_oonfX4o`0000?o001o0ooonfX3o`00Ob;ooo]Z2Ol00019oookJP?o001o7OoonfX001?ooo]Z
2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000003o`0000cooo]Z
0ol007lMoookJPWo0000AooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`0000Kooo]Z
0ol007lSoookJPWo0000B?oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0
003o000000?o00003?oonfX3o`00Ob7ooo]Z2Ol00013oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol0
07l2oookJPCo00001_oonfX3o`00ObOooo]Z2Ol00014oookJP?o001o7OoonfX002;ooo]Z0ol007mc
oookJP?o001o00?ooo]Zo`000?l000000ol00007oookJP;o001o0_oonfX4o`00Ob7ooo]Z2_l00012
oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo000000?ooo]Zo`00Ool007l00_oonfX4
o`00ObOooo]Z2_l00013oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`00
0?l000000_l000000ol007oooo]ZoookJP05oookJPOo001o8ooonfX9o`0004;ooo]Z1Ol0001boook
JP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`05o`00ObWooo]Z2_l00012oook
JP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oo
oo]ZoookJP05oookJPKo001o9OoonfX=o`0003gooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;o
oo]Z1?l000000ooonf[o001oo`00O`04o`00Ob[ooo]Z3_l0000noookJP?o001o7OoonfX001oooo]Z
1_l007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP05oookJP;o001o
;OoonfX9o`0003gooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001o
o`00O`0boookJP[o0000>ooonfX6o`00Oagooo]Z000OoookJPKo001oM?oonfX3o`00O`Co00002?oo
nfX2o`00Obgooo]Z2ol0000koookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
1?l000000ooonf[o001oo`00O`0doookJPWo0000>_oonfX6o`00Oagooo]Z000QoookJPCo001oM?oo
nfX3o`00O`Co00002OoonfX7o`00ObSooo]Z3_l0000goookJPGo0000LooonfX7o`00O`?ooo]Z1?l0
0002oookJPOo001o;_oonfX>o`0003Oooo]Z1?l007lMoookJP008_oonfX3o`00OgGooo]Z0_l007l4
o`0000Wooo]Z1ol007lYoookJPko0000=_oonfX5o`0007Cooo]Z1Ol007l3oookJPGo00000_oonfX7
o`00Oboooo]Z3_l0000goookJP?o001o7OoonfX009cooo]Z1?l0000moookJPko0000<_oonfX5o`00
07cooo]Z1Ol0000loookJPoo0000D_oonfX009cooo]Z1?l0000noookJPoo0000<?oonfX5o`0007co
oo]Z1Ol0000moookJPoo0000DOoonfX009cooo]Z1?l0000ooookJQ?o0000:ooonfX5o`0007cooo]Z
1?l0000ooookJQ?o0000C?oonfX009cooo]Z1?l00014oookJPoo0000:_oonfX5o`0007cooo]Z1?l0
0014oookJPoo0000BooonfX009cooo]Z1?l00014oookJQGo00009?oonfX5o`0007cooo]Z1?l00015
oookJQCo0000AOoonfX009cooo]Z1?l00019oookJQKo000000?ooo]Zo`000?l000000_l0000Ioook
JPGo0000O?oonfX4o`0004[ooo]Z6_l0000joookJP003_oonf[oo`000?oo00009Ol0000?oookJP00
3_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[o
o`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP007OoonfX00ol0003o
oo]Zo`000004o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000000ol000000ooonf[o
0000o`00000No`0004_ooo]Z1?l0001_oookJPCo00000_oonfX5o`000003oookJ_l0003o000000Wo
000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`00000To`0004_ooo]Z1?l0001_oookJPGo
000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000003o`0001kooo]Z000goookJQco0000
BOoonfX4o`0007gooo]Z1Ol0000HoookJPCo000000?ooo]Zo`000?l000004ol0001:oookJPCo0000
W_oonfX004?ooo]Z5?l00015oookJPCo0000OOoonfX5o`0002?ooo]Z5Ol00014oookJPCo0000W_oo
nfX004Wooo]Z3ol00014oookJPCo0000OOoonfX5o`0002Sooo]Z4?l00014oookJPCo0000W_oonfX0
04[ooo]Z4ol0000ooookJPCo0000OOoonfX5o`0002[ooo]Z4ol0000ooookJPCo0000W_oonfX004oo
oo]Z3ol0000noookJPCo0000OOoonfX5o`0002oooo]Z3ol0000noookJPCo0000W_oonfX0053ooo]Z
3_l0000noookJPCo0000OOoonfX5o`00033ooo]Z3ol0000moookJPCo0000W_oonfX005Gooo]Z3_l0
000ioookJPCo0000OOoonfX5o`0003Gooo]Z3_l0000ioookJPCo0000W_oonfX005Kooo]Z3_l0000h
oookJPCo0000OOoonfX5o`0003Kooo]Z3ol0000goookJPCo0000W_oonfX005[ooo]Z2ol0000goook
JPCo0000OOoonfX5o`0003[ooo]Z3Ol0000eoookJPCo0000W_oonfX005_ooo]Z2_l0000goookJPCo
0000OOoonfX5o`0003_ooo]Z3_l0000coookJPCo0000W_oonfX005cooo]Z3Ol0000coookJPCo0000
OOoonfX5o`0003cooo]Z3ol0000aoookJPCo0000W_oonfX0067ooo]Z2Ol0000boookJPCo0000OOoo
nfX5o`0004;ooo]Z2_l0000`oookJPCo0000W_oonfX0067ooo]Z2_l0000aoookJPCo0000OOoonfX5
o`0004Cooo]Z2_l0000^oookJPCo0000W_oonfX006;ooo]Z2Ol0000aoookJPCo0000OOoonfX5o`00
04Kooo]Z2Ol0000]oookJPCo0000W_oonfX006Kooo]Z2Ol0000]oookJPCo0000OOoonfX5o`0004So
oo]Z2?l0000/oookJPCo0000W_oonfX006Oooo]Z2Ol0000/oookJPCo0000OOoonfX5o`0004Wooo]Z
2?l0000[oookJPCo0000W_oonfX006Oooo]Z2_l0000ZoookJPGo0000OOoonfX5o`0004_ooo]Z1ol0
000ZoookJPCo0000W_oonfX006Sooo]Z2Ol0000ZoookJPGo0000OOoonfX5o`0004cooo]Z1ol0000Y
oookJPCo0000W_oonfX006cooo]Z1_l0000YoookJPGo0000OOoonfX5o`0004gooo]Z1ol0000Xoook
JPCo0000W_oonfX006gooo]Z2Ol0000UoookJPCo0000O_oonfX5o`0004kooo]Z1ol0000WoookJPCo
0000W_oonfX006gooo]Z2Ol0000UoookJPCo0000O_oonfX5o`0004oooo]Z1_l0000WoookJPCo0000
W_oonfX006kooo]Z2?l0000UoookJPCo0000O_oonfX5o`00053ooo]Z1_l0000VoookJPCo0000W_oo
nfX006kooo]Z2Ol0000ToookJPCo0000O_oonfX5o`00057ooo]Z1_l0000UoookJPCo0000W_oonfX0
07;ooo]Z1_l0000SoookJPCo0000O_oonfX5o`00057ooo]Z1ol0000ToookJPCo0000W_oonfX007;o
oo]Z2Ol0000PoookJPCo0000O_oonfX5o`0005;ooo]Z1ol0000SoookJPCo0000W_oonfX007?ooo]Z
2Ol0000OoookJPCo0000O_oonfX5o`0005?ooo]Z1ol0000RoookJPCo0000W_oonfX007Cooo]Z2Ol0
000NoookJPCo0000O_oonfX5o`0005Cooo]Z1_l0000RoookJPCo0000W_oonfX007Cooo]Z2Ol0000N
oookJPCo0000O_oonfX5o`0005Gooo]Z1_l0000QoookJPCo0000W_oonfX007Gooo]Z2Ol0000Moook
JPCo0000O_oonfX5o`0005Kooo]Z1_l0000PoookJPCo0000W_oonfX007Wooo]Z1Ol0000MoookJPCo
0000O_oonfX5o`0005Kooo]Z1ol0000OoookJPCo0000W_oonfX007Wooo]Z2?l0000JoookJPCo0000
O_oonfX5o`0005Oooo]Z1ol0000NoookJPCo0000W_oonfX007[ooo]Z2?l0000IoookJPCo0000O_oo
nfX5o`0005Sooo]Z1ol0000MoookJPCo0000W_oonfX007[ooo]Z2?l0000IoookJPCo0000O_oonfX5
o`0005Wooo]Z1ol0000LoookJPCo0000W_oonfX007[ooo]Z2?l0000IoookJPCo0000O_oonfX5o`00
05[ooo]Z1ol0000KoookJPCo0000W_oonfX007_ooo]Z2?l0000HoookJPCo0000H?oonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`0005_ooo]Z1_l0000KoookJPCo0000W_oonfX007kooo]Z
1Ol0000HoookJPCo0000GooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0005cooo]Z
1_l0000JoookJPCo0000W_oonfX007kooo]Z1_l0000GoookJPCo0000GooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wo
oo]Z1Ol0001MoookJPKo00006OoonfX4o`0009kooo]Z001ooookJPSo00005?oonfX4o`0005kooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000GOoonfX7o`0001Sooo]Z
1?l0002NoookJP00OooonfX9o`0001?ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l8oookJPKo0000GOoonfX7o`0001Oooo]Z1?l0002NoookJP00P?oonfX8o`0001?ooo]Z1?l0001N
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000GooonfX7o`0001Kooo]Z1?l0002N
oookJP00P?oonfX9o`0001;ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oook
JPCo001o2?oonfX5o`00063ooo]Z1ol0000EoookJPCo0000W_oonfX0087ooo]Z2?l0000BoookJPCo
0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`00067ooo]Z1ol0000CoookJPGo
0000W_oonfX008Cooo]Z1Ol0000BoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o
2_oonfX5o`0006;ooo]Z1_l0000CoookJPGo0000W_oonfX008Gooo]Z1Ol0000AoookJPCo0000G_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0006?ooo]Z1_l0000BoookJPGo0000W_oo
nfX008Gooo]Z1Ol0000AoookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l0
07l>oookJPGo0000I?oonfX6o`00017ooo]Z1?l0002OoookJP00QOoonfX9o`0000gooo]Z1?l0001O
oookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001ToookJPOo00004?oonfX4o`0009oooo]Z0026oook
JPSo00003OoonfX4o`00063ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0006Gooo]Z1ol0000?oook
JPCo0000WooonfX008Kooo]Z2?l0000=oookJPCo0000O_oonfX5o`0006Kooo]Z1ol0000>oookJPCo
0000WooonfX008Kooo]Z2?l0000=oookJPCo0000O_oonfX5o`0006Oooo]Z1ol0000=oookJPCo0000
WooonfX008Kooo]Z2Ol0000<oookJPCo0000O_oonfX5o`0006Sooo]Z1ol0000<oookJPCo0000Wooo
nfX008Oooo]Z2?l0000<oookJPCo0000O_oonfX5o`0006Wooo]Z1_l0000<oookJPCo0000WooonfX0
08[ooo]Z1Ol0000<oookJPCo0000O_oonfX5o`0006[ooo]Z1_l0000;oookJPCo0000WooonfX008_o
oo]Z1Ol0000;oookJPCo0000O_oonfX5o`0006_ooo]Z1_l0000:oookJPCo0000WooonfX008_ooo]Z
2Ol00007oookJPCo0000O_oonfX5o`0006_ooo]Z1ol00009oookJPCo0000WooonfX008_ooo]Z2Ol0
0007oookJPCo0000O_oonfX5o`0006cooo]Z1ol00008oookJPCo0000WooonfX008cooo]Z2?l00007
oookJPCo0000O_oonfX5o`0006gooo]Z1ol00007oookJPCo0000WooonfX008cooo]Z2Ol00006oook
JPCo0000O_oonfX5o`0006kooo]Z1_l00007oookJPCo0000WooonfX008cooo]Z2Ol00006oookJPCo
0000O_oonfX5o`0006oooo]Z1Ol00007oookJPCo0000WooonfX008cooo]Z2Ol00005oookJPGo0000
O_oonfX5o`00073ooo]Z1Ol00006oookJPCo0000WooonfX008gooo]Z2?l000000ooonf[o0000o`00
0007o`0007kooo]Z1Ol0001`oookJPGo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`00
0002o`0009oooo]Z002AoookJPko0000O_oonfX5o`00073ooo]Z1Ol000000ooonf[o0000o`000002
o`000003oookJ_l0003o000000;o0000WooonfX0097ooo]Z3Ol0001ooookJPGo0000LOoonfX9o`00
0003oookJ_l0003o000000;o0000WooonfX0097ooo]Z3Ol0001ooookJPGo0000LOoonfX9o`000003
oookJ_l0003o000000;o0000WooonfX009;ooo]Z3?l0001ooookJPGo0000LOoonfX>o`0009oooo]Z
002BoookJPco0000OooonfX5o`0007;ooo]Z3Ol0002OoookJP00T_oonfX<o`0007oooo]Z1Ol0001b
oookJPgo0000WooonfX009;ooo]Z3?l0001ooookJPGo0000L_oonfX=o`0009oooo]Z002BoookJPco
0000OooonfX5o`0007;ooo]Z3Ol0002OoookJP00T_oonfX<o`0007oooo]Z1Ol0001boookJPgo0000
WooonfX009;ooo]Z3?l0001ooookJPGo0000L_oonfX<o`000:3ooo]Z002BoookJPco0000OooonfX5
o`0007;ooo]Z3?l0002PoookJP00TooonfX;o`0007oooo]Z1Ol0001coookJP_o0000X?oonfX009Oo
oo]Z1ol0001ooookJPGo0000MooonfX7o`000:3ooo]Z002GoookJPOo0000OooonfX5o`0007Oooo]Z
1ol0002PoookJP00UooonfX7o`0007oooo]Z1Ol0001goookJPOo0000X?oonfX009Sooo]Z1_l0001o
oookJPGo0000N?oonfX6o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoook
JPKo0000X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00
V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002HoookJPKo0000L_oo
nfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX6
o`0007Oooo]Z1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`00
0:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z
1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol0
07l:oookJPGo0000N?oonfX6o`000:3ooo]Z002HoookJPKo0000KooonfX6o`00O`[ooo]Z1Ol0001h
oookJPKo0000X?oonfX009Sooo]Z1_l0001_oookJPKo001o2_oonfX5o`0007Sooo]Z1_l0002Poook
JP00V?oonfX6o`00077ooo]Z1?l007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002IoookJPCo0000
LooonfX3o`00O`[ooo]Z1Ol0001hoookJPGo0000XOoonfX009Wooo]Z1?l00020oookJPGo0000N?oo
nfX5o`000:7ooo]Z002IoookJPCo0000P?oonfX5o`0007Wooo]Z1?l0002QoookJP00VOoonfX4o`00
083ooo]Z1Ol0001ioookJPCo0000XOoonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3
o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`00
0?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9
oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`00
0?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2_oo
nfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooook
JPkooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX6o`000?oo
oo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol0
07l9oookJPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/oookJP00oooonfX=oook
JP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRco
oo]Z003ooookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooonfX>oookJPOo001ooooo
nfX]oookJP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30972 L
.02605 .3101 L
.02729 .31005 L
.02846 .30953 L
.02954 .30885 L
.03056 .30826 L
.03162 .30792 L
.03279 .308 L
.03397 .30853 L
.03524 .30934 L
.03642 .30997 L
.0375 .31018 L
.03875 .30991 L
.03946 .30954 L
.04012 .30913 L
.04142 .30836 L
.04262 .30798 L
.04386 .30812 L
.04452 .3084 L
.04521 .30881 L
.04647 .30964 L
.04765 .3102 L
.0487 .31033 L
.04983 .31002 L
.05108 .30931 L
.05221 .30863 L
.05352 .30819 L
.05473 .30833 L
.05536 .3086 L
.05606 .30902 L
.05747 .30998 L
.0587 .31058 L
.0594 .31069 L
.06003 .31064 L
.06121 .3102 L
.06244 .30946 L
.0631 .30909 L
.0638 .30879 L
.06509 .30866 L
.06633 .30912 L
.06748 .3099 L
.06814 .31038 L
.06884 .31084 L
.0701 .31133 L
.07142 .31121 L
.07218 .31089 L
.07287 .3105 L
.07402 .30984 L
.07525 .30944 L
Mistroke
.07596 .30944 L
.0766 .30962 L
.07784 .31036 L
.07901 .31127 L
.08028 .3121 L
.08147 .31242 L
.08257 .31224 L
.08384 .31161 L
.08455 .31121 L
.08521 .31088 L
.0865 .31062 L
.08768 .31093 L
.08835 .31135 L
.08907 .31191 L
.09036 .313 L
.09108 .31349 L
.09175 .31382 L
.09249 .31397 L
.09328 .31389 L
.09477 .31324 L
.0955 .31285 L
.09615 .31254 L
.09685 .31235 L
.0976 .31234 L
.09841 .3126 L
.09918 .31307 L
.10053 .31426 L
.10127 .31494 L
.10197 .31549 L
.10262 .31586 L
.10333 .31607 L
.10458 .31595 L
.10575 .31543 L
.10699 .31483 L
.10805 .3146 L
.10922 .31489 L
.11049 .31582 L
.11186 .3172 L
.11314 .31833 L
.11433 .31886 L
.12463 .32214 L
.13356 .3244 L
.1431 .3275 L
.14436 .32922 L
.14503 .33014 L
.14573 .33102 L
.14703 .33207 L
.14822 .33229 L
.14937 .33197 L
.15044 .33155 L
Mistroke
.15162 .33139 L
.15289 .33198 L
.162 .33791 L
.18269 .35469 L
.20384 .37674 L
.22393 .40518 L
.23353 .41986 L
.24376 .43662 L
.24492 .44246 L
.24614 .44431 L
.24678 .44323 L
.24749 .44065 L
.24872 .43415 L
.24989 .42894 L
.25114 .42858 L
.25233 .4356 L
.2534 .44784 L
.25445 .46231 L
.25556 .47564 L
.25677 .48078 L
.25789 .4708 L
.25894 .44607 L
.25992 .40962 L
.26215 .2958 L
.26333 .23445 L
.26458 .18144 L
.26577 .14974 L
.26685 .13781 L
.26812 .14119 L
.26883 .14875 L
.26949 .15755 L
.27078 .17498 L
.27199 .18636 L
.27314 .19018 L
.27439 .18736 L
.27509 .18384 L
.27576 .18017 L
.27702 .17481 L
.27834 .17411 L
.27957 .1786 L
.28027 .18281 L
.28091 .1871 L
.2816 .19166 L
.28235 .19605 L
.28351 .20052 L
.28474 .20151 L
.28587 .19973 L
.28693 .1972 L
.28818 .1952 L
.28932 .19573 L
Mistroke
.29064 .19951 L
.29188 .2051 L
.29297 .21007 L
.29412 .21401 L
.2951 .21567 L
.29619 .21568 L
.29735 .21436 L
.2986 .21287 L
.29978 .21278 L
.30085 .2144 L
.32144 .24114 L
.33146 .25271 L
.34055 .26357 L
.35006 .27239 L
.35903 .27824 L
.37873 .28782 L
.3971 .2957 L
.40753 .29953 L
.41727 .30301 L
.41842 .30242 L
.41963 .30198 L
.42027 .30194 L
.42097 .30209 L
.42221 .30282 L
.4233 .30379 L
.42446 .30483 L
.42573 .30557 L
.42689 .3057 L
.42757 .30552 L
.42822 .30524 L
.42898 .30483 L
.42967 .30447 L
.43093 .30408 L
.43162 .3041 L
.43228 .30431 L
.43351 .30509 L
.43464 .30604 L
.43588 .30696 L
.4372 .30741 L
.4385 .30719 L
.4397 .30658 L
.44098 .3059 L
.44171 .30567 L
.44238 .30562 L
.44358 .30596 L
.44487 .30682 L
.4461 .30777 L
.44723 .30842 L
.44792 .3086 L
.44866 .30858 L
Mistroke
.4494 .30837 L
.45021 .30797 L
.45157 .30718 L
.45232 .30684 L
.45302 .30669 L
.45368 .3067 L
.45441 .30691 L
.45573 .3077 L
.45705 .30865 L
.45826 .30927 L
.4594 .30938 L
.4606 .309 L
.46181 .3083 L
.46312 .30759 L
.46426 .30734 L
.46548 .30759 L
.46663 .30825 L
.46768 .30897 L
.46833 .30937 L
.46901 .30968 L
.47025 .30985 L
.47093 .30969 L
.47157 .30942 L
.47302 .30854 L
.4743 .30789 L
.47546 .3077 L
.4761 .30781 L
.47679 .30809 L
.47806 .30887 L
.47927 .30962 L
.48058 .31006 L
.48132 .31004 L
.48201 .30984 L
.48266 .30953 L
.48335 .30911 L
.48465 .30832 L
.48538 .30801 L
.48604 .30787 L
.48682 .3079 L
.48756 .30814 L
.48824 .30849 L
.48898 .30895 L
.49029 .30975 L
.49153 .31013 L
.49281 .30995 L
.4935 .30964 L
.49423 .30921 L
.49553 .3084 L
.49677 .30793 L
.49787 .30796 L
Mistroke
.49908 .30845 L
.50032 .30923 L
.50164 .30993 L
.50232 .31012 L
.50307 .31013 L
.50376 .30996 L
.5044 .30967 L
.50564 .30891 L
.50681 .30823 L
.50746 .30799 L
.50817 .30789 L
.5094 .30815 L
.51053 .30876 L
.51176 .30955 L
.51305 .3101 L
.51427 .31012 L
.51539 .30969 L
.51643 .30906 L
.51765 .30834 L
.51876 .30798 L
.51998 .3081 L
.52129 .30874 L
.52251 .30955 L
.52364 .31013 L
.52496 .31032 L
.52565 .31016 L
.52639 .30984 L
.52774 .30901 L
.52898 .30837 L
.53026 .30819 L
.53096 .30834 L
.53163 .30864 L
.53281 .3094 L
.5341 .31024 L
.53485 .31056 L
.53552 .31069 L
.5363 .31063 L
.53703 .31038 L
.53833 .30965 L
.53905 .30922 L
.53974 .30888 L
.54098 .30863 L
.54212 .30891 L
.54334 .30965 L
.54467 .31061 L
.54583 .31121 L
.54706 .31134 L
.54811 .31102 L
.54927 .31038 L
.54996 .30997 L
Mistroke
.55063 .30965 L
.55187 .30942 L
.55256 .30954 L
.5532 .30982 L
.55391 .31027 L
.55466 .31084 L
.55532 .31136 L
.55603 .31185 L
.55731 .31238 L
.55857 .3123 L
.55972 .31179 L
.56094 .3111 L
.56224 .31064 L
.56348 .31077 L
.5646 .31139 L
.56595 .3125 L
.56669 .3131 L
.56739 .31356 L
.56861 .31396 L
.56926 .31393 L
.56997 .31373 L
.57064 .31341 L
.57136 .31302 L
.57263 .31244 L
.57335 .31232 L
.57401 .31238 L
.57474 .31267 L
.57553 .3132 L
.5808 .31594 L
.60069 .32207 L
.62227 .33138 L
.63144 .33511 L
.64129 .34029 L
.65211 .34804 L
.66223 .35578 L
.68209 .37574 L
.70312 .40305 L
.71324 .42043 L
.72428 .43764 L
.72553 .43105 L
.72623 .42854 L
.72688 .42786 L
.72807 .43206 L
.72933 .4444 L
.73067 .46278 L
.73138 .47188 L
.73215 .4788 L
.73347 .47829 L
.7347 .45798 L
.73595 .41628 L
Mistroke
.73665 .38463 L
.7373 .35168 L
.73847 .28844 L
.73976 .22267 L
.74092 .17655 L
.742 .14902 L
.74314 .13745 L
.74438 .14177 L
.74562 .15662 L
.74627 .16578 L
.74696 .17485 L
.74823 .1867 L
.7494 .19019 L
.7501 .18912 L
.75074 .18661 L
.75151 .18258 L
.75222 .1788 L
.75345 .17425 L
.75477 .17462 L
.756 .17996 L
.75715 .18738 L
.75784 .19203 L
.7585 .19588 L
.75973 .20059 L
.76083 .20156 L
.76201 .19985 L
.76327 .19688 L
.76444 .19517 L
.76566 .19599 L
.7663 .19764 L
.767 .20018 L
.76838 .20657 L
.76969 .21214 L
.77091 .21521 L
.77222 .21577 L
.77342 .21452 L
.77452 .21311 L
.77583 .21269 L
.77707 .21445 L
.77777 .21638 L
.77842 .21856 L
.77987 .22392 L
.78054 .22611 L
.78126 .22793 L
.78205 .22919 L
.78278 .22964 L
.78352 .22951 L
.78423 .22901 L
.78554 .22796 L
.7867 .22785 L
Mistroke
.78795 .22933 L
.78912 .23219 L
.7902 .23545 L
.79145 .23907 L
.79216 .24063 L
.79282 .24163 L
.79402 .2423 L
.7953 .24181 L
.79652 .24113 L
.79783 .24126 L
.79907 .24277 L
.80021 .24525 L
.80157 .24883 L
.80284 .25169 L
.80348 .2527 L
.80417 .25337 L
.80493 .25364 L
.80562 .25355 L
.80677 .25303 L
.80799 .25268 L
.80903 .25307 L
.81018 .25449 L
.81141 .25695 L
.81273 .25996 L
.81398 .26228 L
.81512 .26345 L
.82409 .27 L
.83408 .27635 L
.84472 .28287 L
.86385 .29126 L
.87279 .29589 L
.87767 .29806 L
.8789 .29938 L
.88006 .30022 L
.8811 .30046 L
.88223 .30023 L
.88347 .29965 L
.88461 .29921 L
.88585 .29921 L
.88716 .29993 L
.88851 .30121 L
.88921 .30193 L
.88996 .3026 L
.89061 .30306 L
.89132 .30335 L
.89258 .30334 L
.89371 .30289 L
.89492 .30228 L
.89606 .30195 L
.8971 .30206 L
Mistroke
.89833 .30277 L
.89903 .30336 L
.89967 .30396 L
.90093 .30504 L
.90209 .30563 L
.90332 .30565 L
.90401 .30543 L
.90465 .30511 L
.90582 .30449 L
.90705 .30408 L
.9077 .30408 L
.90841 .30428 L
.90967 .30506 L
.91115 .30631 L
.9118 .30679 L
.91251 .30719 L
.9132 .30739 L
.91384 .30741 L
.91452 .30725 L
.91524 .30694 L
.91597 .30653 L
.91676 .30609 L
.91751 .30577 L
.91819 .30562 L
.91884 .30564 L
.91955 .30586 L
.92029 .30626 L
.92099 .30677 L
.92231 .30779 L
.92353 .30846 L
.92478 .30859 L
.92544 .30843 L
.92614 .30811 L
.92741 .30737 L
.92861 .30681 L
.92978 .30669 L
.93105 .30713 L
.9322 .3079 L
.93326 .30866 L
.93451 .30929 L
.93568 .30937 L
.93697 .30891 L
.93769 .30849 L
.93834 .30809 L
.93967 .30747 L
.94041 .30734 L
.9411 .30741 L
.94237 .30795 L
.94301 .30837 L
.94372 .30886 L
Mistroke
.94463 .30943 L
.94561 .3098 L
.94669 .30981 L
.94769 .30945 L
.94872 .30885 L
.94984 .30818 L
.9509 .30777 L
.95187 .30773 L
.95278 .30799 L
.95377 .30855 L
.95475 .30919 L
.95579 .30978 L
.95675 .31006 L
.95763 .31002 L
.95851 .30971 L
.95935 .30924 L
.96039 .30858 L
.96137 .30808 L
.96251 .30785 L
.96353 .30805 L
.9645 .30853 L
.96539 .3091 L
.96637 .30969 L
.96741 .31008 L
.96846 .3101 L
.96945 .30977 L
.97062 .30908 L
.97168 .30842 L
.97279 .30797 L
.974 .30794 L
.97514 .30838 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00WooonfX4o`0007[ooo]Z1Ol0001ooookJPCo
0000VooonfX009oooo]Z1?l0001joookJPGo0000OooonfX4o`0009_ooo]Z002OoookJPCo0000N_oo
nfX5o`0007oooo]Z1?l0002KoookJP00WooonfX4o`0007[ooo]Z1Ol0001ooookJPCo0000VooonfX0
09kooo]Z1Ol0001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPKo0000NOoonfX5o`0007ko
oo]Z1Ol0002KoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z
002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1_l0001/
oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0005cooo]Z2_l007l6oook
JP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0005cooo]Z2_l007l6oookJP?o
001o2_oonfX6o`0007gooo]Z1_l0002JoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000
O_oonfX6o`0009[ooo]Z002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oo
nfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`00
06cooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPKo0000JOoonfX6o`00O`[o
oo]Z1Ol0001noookJPKo0000V_oonfX009gooo]Z2?l0001XoookJPKo001o2_oonfX5o`0007kooo]Z
1_l0002JoookJP00WOoonfX8o`0006[ooo]Z1?l007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002M
oookJPSo0000JooonfX3o`00O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009gooo]Z2?l0001hoook
JPGo0000O_oonfX7o`0009Wooo]Z002MoookJPco0000M?oonfX5o`0007kooo]Z2ol0002EoookJP00
WOoonfX<o`0007Cooo]Z1Ol0001noookJP_o0000UOoonfX009gooo]Z3Ol0001coookJPGo0000O_oo
nfX<o`0009Cooo]Z002MoookJPgo0000LooonfX5o`0007kooo]Z3?l0002DoookJP00WOoonfX=o`00
07?ooo]Z1Ol0001noookJPco0000U?oonfX009gooo]Z3Ol0001coookJPGo0000O_oonfX<o`0009Co
oo]Z002MoookJPgo0000LooonfX5o`0007kooo]Z3?l0002DoookJP00WOoonfX=o`0007?ooo]Z1Ol0
001noookJPco0000U?oonfX009gooo]Z3Ol0001coookJPGo0000O_oonfX<o`0009Cooo]Z002Moook
JPko0000L_oonfX5o`0007kooo]Z3Ol0002CoookJP00WOoonfX>o`0007;ooo]Z1Ol0001noookJPgo
0000TooonfX009gooo]Z4Ol0001_oookJPGo0000O_oonfX@o`00093ooo]Z002MoookJPCo000000?o
oo]Zo`000?l000000_l000000ooonf[o0000o`000006o`0006kooo]Z1Ol0001noookJPSo000000?o
oo]Zo`000?l000001_l0002?oookJP00WOoonfX4o`0000Kooo]Z2?l0001^oookJPGo0000O_oonfX4
o`0000Gooo]Z2?l0002?oookJP00WOoonfX4o`0000Kooo]Z2Ol0001]oookJPGo0000OOoonfX5o`00
00Gooo]Z2Ol0002>oookJP00WOoonfX4o`0000Kooo]Z2Ol0001]oookJPGo0000OOoonfX5o`0000Go
oo]Z2Ol0002>oookJP00WOoonfX4o`0000Kooo]Z2Ol0001]oookJPGo0000OOoonfX5o`0000Gooo]Z
2Ol0002>oookJP00WOoonfX4o`0000Oooo]Z2?l0001]oookJPGo0000OOoonfX4o`0000Oooo]Z2?l0
002>oookJP00WOoonfX4o`0000Oooo]Z2?l0001]oookJPGo0000OOoonfX4o`0000Oooo]Z2?l0002>
oookJP00WOoonfX4o`0000_ooo]Z1Ol0001/oookJPGo0000OOoonfX4o`0000_ooo]Z1?l0002>oook
JP00WOoonfX4o`0000_ooo]Z1Ol0001/oookJPGo0000OOoonfX4o`0000_ooo]Z1Ol0002=oookJP00
WOoonfX4o`0000_ooo]Z2?l0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2?l0002:oookJP00WOoo
nfX4o`0000cooo]Z2?l0001XoookJPGo0000OOoonfX4o`0000_ooo]Z2Ol00029oookJP00WOoonfX4
o`0000cooo]Z2?l0001XoookJPGo0000OOoonfX4o`0000cooo]Z2Ol00028oookJP00WOoonfX4o`00
00cooo]Z2Ol0001WoookJPGo0000OOoonfX4o`0000cooo]Z2Ol00028oookJP00WOoonfX4o`0000co
oo]Z2_l0001VoookJPGo0000OOoonfX4o`0000gooo]Z2?l00028oookJP00WOoonfX4o`00013ooo]Z
1ol0001UoookJPGo0000OOoonfX4o`00017ooo]Z1Ol00027oookJP00WOoonfX4o`00017ooo]Z1ol0
001ToookJPGo0000OOoonfX4o`00017ooo]Z1Ol00027oookJP00WOoonfX4o`0001;ooo]Z1_l00016
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000OOoonfX4o`00017ooo]Z1Ol00027
oookJP00WOoonfX4o`0001?ooo]Z1_l00014oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oook
JPGo0000OOoonfX4o`0001;ooo]Z1ol00024oookJP00WOoonfX4o`0001Cooo]Z1_l00013oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000BoookJPSo0000PooonfX009gooo]Z1?l0000Doook
JPOo0000=OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000OOoonfX4o`0001;ooo]Z2Ol00022oookJP00WOoonfX4o`0001Gooo]Z1_l0000eoookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007cooo]Z1?l0000BoookJPWo
0000P_oonfX009gooo]Z1?l0000FoookJPKo0000@?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX5o`0007gooo]Z1?l0000CoookJPSo0000P_oonfX009gooo]Z1?l0000GoookJPKo0000?ooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001moookJPCo00005ooo
nfX4o`0008;ooo]Z002MoookJPCo00005ooonfX7o`0003kooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Wooo]Z1Ol0001moookJPCo00005ooonfX5o`00087ooo]Z002MoookJPCo00006?oonfX7o`00
03gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001moookJPCo00005ooonfX8o`00
07kooo]Z002MoookJPCo00006OoonfX6o`0003gooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`ko
oo]Z1Ol0001moookJPCo00005ooonfX9o`0007gooo]Z002MoookJPCo00006_oonfX6o`0003gooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007gooo]Z1?l0000HoookJPWo
0000O?oonfX009gooo]Z1?l0000KoookJPKo0000??oonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000
OOoonfX4o`0001Sooo]Z2Ol0001loookJP00WOoonfX4o`0001_ooo]Z1ol0000loookJPGo001o2_oo
nfX7o`00O`Sooo]Z1Ol0001moookJPCo00006OoonfX8o`0007cooo]Z002MoookJPCo00007?oonfX7
o`0005Wooo]Z1Ol0001moookJPCo00007OoonfX4o`0007cooo]Z002MoookJPCo00007OoonfX7o`00
05Sooo]Z1Ol0001moookJPCo00007OoonfX8o`0007Sooo]Z002MoookJPCo00007_oonfX7o`0005Oo
oo]Z1Ol0001moookJPCo00007OoonfX9o`0007Oooo]Z002MoookJPCo00007ooonfX7o`0005Kooo]Z
1Ol0001moookJPCo00007OoonfX9o`0007Oooo]Z002MoookJPCo00008?oonfX7o`0005Gooo]Z1Ol0
001loookJPGo00007_oonfX9o`0007Kooo]Z002MoookJPCo00008OoonfX7o`0005Cooo]Z1Ol0001l
oookJPGo00007_oonfX9o`0007Kooo]Z002MoookJPCo00008_oonfX7o`0005?ooo]Z1Ol0001loook
JPGo00008_oonfX5o`0007Kooo]Z002MoookJPCo00008ooonfX7o`0005;ooo]Z1Ol0001loookJPCo
00009?oonfX7o`0007?ooo]Z002MoookJPCo00009?oonfX7o`00057ooo]Z1Ol0001loookJPCo0000
9?oonfX8o`0007;ooo]Z002LoookJPGo00009OoonfX7o`00053ooo]Z1Ol0001loookJPCo00009?oo
nfX9o`00077ooo]Z002LoookJPGo00009_oonfX7o`0004oooo]Z1Ol0001loookJPCo00009OoonfX9
o`00073ooo]Z002LoookJPGo00009ooonfX7o`0004kooo]Z1Ol0001loookJPCo0000:?oonfX8o`00
06kooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00000ooonfX3o`00O`?ooo]Z1Ol007lKoookJPSo
0000C?oonfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX5o`00Ob7ooo]Z2Ol0001<oookJP?o
001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o1?l00003oookJP?o001o0_oonfX7o`00Oa_ooo]Z
2Ol0001:oookJPGo0000LooonfX7o`00O`;ooo]Z1?l00002oookJPOo001o8OoonfX9o`0004_ooo]Z
0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00Oacooo]Z2Ol00019oookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
Ob;ooo]Z2_l00019oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Cooo]Z0ol007l3oookJP?o
001o7?oonfX:o`0004Oooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o
000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ob?ooo]Z2Ol00018oookJP?o001o7OoonfX001?o
oo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000002o`000003
o`00Oooonf[ooo]Z00[ooo]Z0ol007lNoookJP[o0000AOoonfX5o`0007;ooo]Z0ol007l3oookJP?o
001o00?ooo]Zo`000?l000000_l00007oookJP?o001o9OoonfX9o`0004Kooo]Z0ol007lMoookJP00
8_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00[ooo]Z
0ol007lPoookJPWo0000A?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l00000
0_l00007oookJP?o001o9_oonfX9o`0004Gooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol0
07l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l2oookJPCo001o8Ooo
nfX:o`0004;ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oo
nfX2o`00O`;ooo]Z1?l007lXoookJPWo0000@ooonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3
o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX7o`00ObCooo]Z2_l00010
oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1ol007lZ
oookJP_o0000@?oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o0000
00;o000000?o001ooookJ_oonfX01OoonfX6o`00ObOooo]Z2Ol0000ooookJPGo0000L_oonfX3o`00
O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1_l007l]oookJP_o0000?_oonfX3o`00
Oagooo]Z000OoookJPKo001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oo
nfX01OoonfX2o`00Obcooo]Z2_l0000moookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o
0000o`000002o`0000;ooo]Z0_l007lboookJPgo0000>?oonfX6o`00Oagooo]Z000OoookJPKo001o
M?oonfX3o`00O`Co00002?oonfX2o`00Obkooo]Z2ol0000joookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l00002oookJP;o001o=?oonfX=o`0003Kooo]Z1_l007lMoookJP00
8OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol007lZoookJP_o0000>?oonfX5o`0007?ooo]Z
1ol007l2oookJPCo00000ooonfX7o`00Oc7ooo]Z3?l0000foookJPCo001o7OoonfX002;ooo]Z0ol0
07meoookJP;o001o1?l00009oookJPOo001o:ooonfX=o`0003Gooo]Z1Ol0001doookJPGo001o0ooo
nfX4o`0000?ooo]Z1ol007lcoookJP_o0000=_oonfX3o`00Oagooo]Z002LoookJPCo0000?OoonfX>
o`0003;ooo]Z1Ol0001loookJPCo0000@?oonfX;o`0005?ooo]Z002LoookJPCo0000@?oonfX>o`00
02oooo]Z1Ol0001loookJPCo0000@_oonfX:o`0005;ooo]Z002LoookJPCo0000@_oonfX>o`0002go
oo]Z1Ol0001loookJPCo0000A?oonfX=o`0004gooo]Z002LoookJPCo0000AOoonfXAo`0002Oooo]Z
1Ol0001loookJPCo0000AOoonfXAo`0004Sooo]Z002LoookJPCo0000B?oonfX?o`000003oookJ_l0
003o000000;o00008OoonfX5o`0007cooo]Z1?l00018oookJQCo0000@_oonfX009cooo]Z1?l0001;
oookJQOo00006ooonfX5o`0007cooo]Z1?l00018oookJQ[o0000??oonfX000kooo]Zool0003oo`00
02Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go0000
3ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX0
01cooo]Z1Ol000000ooonf[o0000o`000003o`000003oookJ_l0003o000002Go0000COoonfX4o`00
07;ooo]Z1Ol000000ooonf[o0000o`000009o`000003oookJ_l0003o000000?o000000?ooo]Zo`00
0?l000008ol0001?oookJPCo0000LooonfX4o`000003oookJ_l0003o000000?o00000_oonfX00ol0
003ooo]ZoookJP0LoookJP00>_oonfXHo`0004[ooo]Z1?l0001moookJPGo00006OoonfXHo`0004_o
oo]Z1?l0002NoookJP00@?oonfXEo`0004Oooo]Z1?l0001moookJPGo00008?oonfX5o`000003oook
J_l0003o000000co0000B?oonfX4o`0009kooo]Z0015oookJQ?o0000A?oonfX4o`0007gooo]Z1Ol0
000WoookJQ3o0000AOoonfX4o`0009kooo]Z001;oookJQ7o0000@?oonfX4o`0007gooo]Z1Ol0000Z
oookJPoo0000@ooonfX4o`0009kooo]Z001?oookJQ3o0000?OoonfX4o`0007gooo]Z1Ol0000^oook
JPko0000@?oonfX4o`0009kooo]Z001BoookJPko0000??oonfX4o`0007gooo]Z1Ol0000aoookJPgo
0000?_oonfX4o`0009kooo]Z001EoookJPco0000>ooonfX4o`0007gooo]Z1Ol0000doookJPco0000
??oonfX4o`0009kooo]Z001IoookJPgo0000=_oonfX4o`0007gooo]Z1Ol0000foookJPco0000>_oo
nfX4o`0009kooo]Z001LoookJP_o0000=OoonfX4o`0007gooo]Z1Ol0000ioookJPco0000=ooonfX4
o`0009kooo]Z001LoookJPco0000=?oonfX4o`0007gooo]Z1Ol0000koookJPco0000=OoonfX4o`00
09kooo]Z001MoookJPco0000<ooonfX4o`0007gooo]Z1Ol0000moookJPco0000<ooonfX4o`0009ko
oo]Z001NoookJPCo000000?ooo]Zo`000?l000001_l0000aoookJPCo0000OOoonfX5o`0003oooo]Z
3?l0000aoookJPCo0000W_oonfX006Cooo]Z2?l0000`oookJPCo0000OOoonfX5o`0004;ooo]Z2ol0
000_oookJPCo0000W_oonfX006Gooo]Z2?l0000_oookJPCo0000OOoonfX5o`0004Cooo]Z2_l0000^
oookJPCo0000W_oonfX006Kooo]Z2?l0000^oookJPCo0000OOoonfX5o`0004Kooo]Z2Ol0000]oook
JPCo0000W_oonfX006Sooo]Z2?l0000/oookJPCo0000OOoonfX5o`0004Sooo]Z2?l0000/oookJPCo
0000W_oonfX006Wooo]Z2?l0000[oookJPCo0000OOoonfX5o`0004[ooo]Z2?l0000ZoookJPCo0000
W_oonfX006[ooo]Z2?l0000ZoookJPCo0000OOoonfX5o`0004_ooo]Z2?l0000YoookJPCo0000W_oo
nfX006_ooo]Z2?l0000YoookJPCo0000OOoonfX5o`0004cooo]Z2Ol0000WoookJPCo0000W_oonfX0
06gooo]Z1ol0000XoookJPCo0000OOoonfX5o`0004gooo]Z2Ol0000VoookJPCo0000W_oonfX006ko
oo]Z1ol0000VoookJPGo0000OOoonfX5o`0004oooo]Z2?l0000UoookJPCo0000W_oonfX006oooo]Z
1ol0000UoookJPGo0000OOoonfX5o`00053ooo]Z2?l0000ToookJPCo0000W_oonfX0073ooo]Z1ol0
000ToookJPGo0000OOoonfX5o`0005;ooo]Z1ol0000SoookJPCo0000W_oonfX0077ooo]Z1ol0000S
oookJPCo0000O_oonfX5o`0005?ooo]Z1ol0000RoookJPCo0000W_oonfX007;ooo]Z1ol0000Roook
JPCo0000O_oonfX5o`0005Cooo]Z1ol0000QoookJPCo0000W_oonfX007?ooo]Z1ol0000QoookJPCo
0000O_oonfX5o`0005Gooo]Z1ol0000PoookJPCo0000W_oonfX007Cooo]Z1ol0000PoookJPCo0000
O_oonfX5o`0005Kooo]Z1ol0000OoookJPCo0000W_oonfX007Gooo]Z1ol0000OoookJPCo0000O_oo
nfX5o`0005Oooo]Z1ol0000NoookJPCo0000W_oonfX007Kooo]Z1ol0000NoookJPCo0000O_oonfX5
o`0005Sooo]Z1ol0000LoookJPGo0000W_oonfX007Oooo]Z1ol0000MoookJPCo0000O_oonfX5o`00
05Wooo]Z1ol0000KoookJPGo0000W_oonfX007Sooo]Z1ol0000LoookJPCo0000O_oonfX5o`0005[o
oo]Z1ol0000JoookJPGo0000W_oonfX007Wooo]Z1ol0000KoookJPCo0000O_oonfX5o`0005_ooo]Z
1ol0000IoookJPCo0000WooonfX007[ooo]Z1ol0000JoookJPCo0000O_oonfX5o`0005cooo]Z1_l0
000IoookJPCo0000WooonfX007_ooo]Z1_l0000JoookJPCo0000O_oonfX5o`0005gooo]Z1_l0000H
oookJPCo0000WooonfX007cooo]Z1_l0000IoookJPCo0000H?oonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o2_oonfX5o`0005kooo]Z1_l0000GoookJPCo0000WooonfX007gooo]Z1_l0000HoookJPCo
0000GooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0005kooo]Z1ol0000FoookJPCo
0000WooonfX007gooo]Z1_l0000HoookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001Ooook
JPKo00005_oonfX4o`0009oooo]Z001noookJPKo00005ooonfX4o`0005kooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000H?oonfX6o`0001Gooo]Z1?l0002OoookJP00
OooonfX6o`0001Kooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000
H?oonfX6o`0001Cooo]Z1?l0002OoookJP00OooonfX6o`0001Kooo]Z1?l0001NoookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l8oookJPGo0000HOoonfX7o`0001?ooo]Z1?l0002OoookJP00P?oonfX6
o`0001Gooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5
o`0006;ooo]Z1_l0000CoookJPCo0000WooonfX0087ooo]Z1_l0000DoookJPCo0000G_oonfX3o`00
O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`0006?ooo]Z1_l0000BoookJPCo0000WooonfX0087o
oo]Z1_l0000DoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0006Co
oo]Z1_l0000AoookJPCo0000WooonfX008;ooo]Z1_l0000CoookJPCo0000G_oonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o3_oonfX5o`0006Cooo]Z1_l0000AoookJPCo0000WooonfX008?ooo]Z1_l0
000BoookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000
IOoonfX6o`00013ooo]Z1?l0002OoookJP00PooonfX6o`0001;ooo]Z1?l0001OoookJPOo001o2Ooo
nfX7o`00O`Sooo]Z1Ol0001VoookJPKo00003ooonfX4o`0009oooo]Z0024oookJPKo00004OoonfX4
o`00063ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0006Kooo]Z1ol0000>oookJPCo0000WooonfX0
08Gooo]Z1_l0000@oookJPCo0000O_oonfX5o`0006Oooo]Z1_l0000>oookJPCo0000WooonfX008Go
oo]Z1_l0000@oookJPCo0000O_oonfX5o`0006Sooo]Z1_l0000=oookJPCo0000WooonfX008Kooo]Z
1_l0000?oookJPCo0000O_oonfX5o`0006Wooo]Z1_l0000<oookJPCo0000WooonfX008Oooo]Z1_l0
000>oookJPCo0000O_oonfX5o`0006Wooo]Z1_l0000<oookJPCo0000WooonfX008Oooo]Z1ol0000=
oookJPCo0000O_oonfX5o`0006[ooo]Z1_l0000;oookJPCo0000WooonfX008Sooo]Z1_l0000=oook
JPCo0000O_oonfX5o`0006_ooo]Z1_l0000:oookJPCo0000WooonfX008Wooo]Z1_l0000<oookJPCo
0000O_oonfX5o`0006_ooo]Z1_l0000:oookJPCo0000WooonfX008[ooo]Z1_l0000;oookJPCo0000
O_oonfX5o`0006cooo]Z1_l00009oookJPCo0000WooonfX008[ooo]Z1ol0000:oookJPCo0000O_oo
nfX5o`0006gooo]Z1_l00008oookJPCo0000WooonfX008_ooo]Z1_l0000:oookJPCo0000O_oonfX5
o`0006gooo]Z1_l00008oookJPCo0000WooonfX008cooo]Z1_l00009oookJPCo0000O_oonfX5o`00
06kooo]Z1_l00007oookJPCo0000WooonfX008gooo]Z1Ol00009oookJPCo0000O_oonfX5o`0006oo
oo]Z1_l00006oookJPCo0000WooonfX008gooo]Z1_l00008oookJPCo0000O_oonfX5o`0006oooo]Z
1_l000000ooonf[o0000o`000002o`000003oookJ_l0003o000000;o0000WooonfX008kooo]Z1_l0
00000ooonf[o0000o`000008o`0007kooo]Z1Ol0001`oookJP[o000000?ooo]Zo`000?l000000_l0
002OoookJP00S_oonfX6o`000003oookJ_l0003o000000So0000O_oonfX5o`00077ooo]Z3_l0002O
oookJP00SooonfX@o`0007kooo]Z1Ol0001aoookJPko0000WooonfX0093ooo]Z3_l0001ooookJPGo
0000L_oonfX=o`0009oooo]Z002@oookJPko0000OooonfX5o`0007;ooo]Z3Ol0002OoookJP00TOoo
nfX=o`0007oooo]Z1Ol0001coookJPco0000WooonfX0097ooo]Z3Ol0001ooookJPGo0000M?oonfX;
o`0009oooo]Z002BoookJPco0000OooonfX5o`0007Cooo]Z2ol0002OoookJP00T_oonfX<o`0007oo
oo]Z1Ol0001eoookJPWo0000X?oonfX009?ooo]Z2ol0001ooookJPGo0000MooonfX7o`000:3ooo]Z
002CoookJP_o0000OooonfX5o`0007Oooo]Z1ol0002PoookJP00TooonfX;o`0007oooo]Z1Ol0001g
oookJPOo0000X?oonfX009Oooo]Z1ol0001ooookJPGo0000MooonfX7o`000:3ooo]Z002GoookJPOo
0000OooonfX5o`0007Oooo]Z1ol0002PoookJP00UooonfX7o`0007oooo]Z1Ol0001goookJPOo0000
X?oonfX009Oooo]Z1ol0001ooookJPGo0000MooonfX7o`000:3ooo]Z002GoookJPOo0000L_oonfX3
o`00O`[ooo]Z1Ol0001goookJPOo0000X?oonfX009Oooo]Z1ol0001boookJP?o001o2_oonfX5o`00
07Sooo]Z1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3o
oo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0
001boookJP?o001o2_oonfX6o`0007Oooo]Z1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:
oookJPGo0000N?oonfX6o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoook
JPKo0000X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00
V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002IoookJPGo0000Kooo
nfX6o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Wooo]Z1Ol0001_oookJPKo001o2_oonfX5
o`0007Sooo]Z1_l0002PoookJP00VOoonfX5o`00077ooo]Z1?l007l:oookJPGo0000N?oonfX6o`00
0:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Wooo]Z
1?l00020oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPCo0000P?oonfX5o`0007Wooo]Z1Ol0
002PoookJP00VOoonfX4o`00083ooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[o
oo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oo
nfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3
o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2
o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooook
JQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooo
nfXOoookJP00oooonfX>oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00
O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00
oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oo
nfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oook
JP?o001ooooonfX/oookJP00oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z
3_oonfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2
oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30831 L
.02605 .30795 L
.02729 .30803 L
.02846 .30857 L
.02946 .30922 L
.03053 .30982 L
.0317 .31013 L
.03279 .30996 L
.03395 .30939 L
.0352 .3086 L
.03638 .30805 L
.03746 .30795 L
.03873 .30837 L
.03944 .30879 L
.04011 .30923 L
.04132 .30992 L
.04262 .31021 L
.04327 .31011 L
.04396 .30986 L
.04519 .30914 L
.04583 .30874 L
.04652 .30838 L
.04727 .30812 L
.04797 .30806 L
.04862 .30818 L
.04933 .30847 L
.05061 .30927 L
.05175 .30999 L
.05302 .31042 L
.05424 .31028 L
.05539 .30972 L
.05671 .30891 L
.05791 .30842 L
.05898 .30841 L
.06009 .30885 L
.06122 .30959 L
.06244 .31041 L
.06315 .31074 L
.06381 .31089 L
.06453 .31087 L
.06529 .31064 L
.06657 .30994 L
.0673 .3095 L
.06797 .30917 L
.06923 .30893 L
.06991 .30906 L
.07057 .30934 L
.07173 .31012 L
.073 .31105 L
Mistroke
.07376 .31146 L
.07448 .31167 L
.07513 .31169 L
.07583 .31152 L
.0766 .31118 L
.0774 .31071 L
.0781 .31032 L
.07885 .31 L
.07955 .30985 L
.08019 .30989 L
.08144 .31043 L
.08213 .31093 L
.08289 .31154 L
.08356 .31206 L
.08427 .31252 L
.08553 .3129 L
.08671 .3127 L
.08739 .31239 L
.08811 .31199 L
.08939 .31136 L
.09004 .31121 L
.09074 .31123 L
.09199 .31176 L
.09276 .31234 L
.09348 .31298 L
.09412 .31353 L
.09483 .31406 L
.09601 .31457 L
.09727 .31449 L
.09843 .31398 L
.09951 .31341 L
.10079 .31305 L
.10196 .31328 L
.1026 .31366 L
.1033 .31422 L
.10458 .31544 L
.10579 .31642 L
.10691 .31687 L
.10813 .31677 L
.10942 .31619 L
.11047 .3157 L
.11159 .31549 L
.11282 .31589 L
.11396 .31681 L
.1153 .31821 L
.11601 .31889 L
.11676 .31945 L
.11741 .31976 L
.11813 .31987 L
.11939 .31957 L
Mistroke
.12062 .31899 L
.12194 .31861 L
.12319 .3189 L
.12433 .31979 L
.12561 .32123 L
.12682 .32255 L
.12749 .3231 L
.12822 .32347 L
.12948 .32353 L
.13022 .3233 L
.131 .32295 L
.13172 .32265 L
.13239 .32249 L
.13368 .32274 L
.13437 .3232 L
.1351 .32393 L
.13642 .32559 L
.13711 .32647 L
.13785 .32726 L
.13849 .32777 L
.1392 .32809 L
.14045 .32807 L
.14166 .32761 L
.14297 .3272 L
.1442 .32742 L
.14533 .32832 L
.15526 .33336 L
.16587 .34 L
.18497 .35605 L
.20496 .3783 L
.2231 .40281 L
.2423 .42488 L
.24361 .43364 L
.24433 .43836 L
.24502 .44199 L
.24566 .44417 L
.24635 .44497 L
.24756 .4423 L
.24823 .43911 L
.24894 .43513 L
.25021 .42927 L
.251 .42834 L
.25174 .43035 L
.25241 .4348 L
.25313 .44222 L
.25444 .4601 L
.25566 .47552 L
.25693 .4809 L
.25761 .47629 L
.25833 .46434 L
Mistroke
.25961 .42435 L
.26083 .36774 L
.2631 .24394 L
.26425 .19154 L
.26548 .15364 L
.26665 .13803 L
.26771 .13896 L
.26896 .15215 L
.27032 .17122 L
.2716 .18483 L
.27279 .18968 L
.27344 .18917 L
.27414 .18673 L
.2754 .17991 L
.27663 .17437 L
.27777 .1732 L
.27899 .17701 L
.27969 .18102 L
.28034 .1854 L
.28165 .19399 L
.28239 .19766 L
.28307 .19984 L
.28423 .20069 L
.28546 .19859 L
.28663 .19574 L
.28772 .19422 L
.28869 .19477 L
.28974 .19756 L
.2909 .20259 L
.29197 .20769 L
.29311 .21216 L
.29418 .21441 L
.29536 .21461 L
.29661 .21314 L
.29793 .2116 L
.29918 .21183 L
.30029 .214 L
.30151 .21802 L
.30271 .22257 L
.30386 .22611 L
.30518 .22818 L
.30639 .22815 L
.30753 .22722 L
.30858 .22648 L
.30973 .22671 L
.31096 .22864 L
.32137 .24104 L
.34241 .26206 L
.36385 .27838 L
.38403 .28987 L
Mistroke
.40414 .29859 L
.40521 .29821 L
.40634 .29826 L
.40758 .29895 L
.40873 .30006 L
.40972 .3011 L
.41079 .30202 L
.41197 .30252 L
.41307 .30243 L
.41434 .30187 L
.41503 .30152 L
.41568 .30127 L
.41682 .30115 L
.41807 .30164 L
.41922 .30259 L
.42027 .3036 L
.42148 .30456 L
.42262 .30497 L
.42381 .30482 L
.42506 .30423 L
.42615 .30369 L
.42731 .30342 L
.42856 .30373 L
.42972 .30453 L
.431 .30564 L
.43167 .30617 L
.43238 .30659 L
.43365 .30684 L
.43482 .30651 L
.43592 .30592 L
.43714 .30532 L
.43821 .30513 L
.43937 .30543 L
.44047 .30614 L
.44148 .30695 L
.44268 .30779 L
.44397 .30818 L
.44518 .30796 L
.44628 .30739 L
.44758 .30667 L
.44831 .30641 L
.44899 .30633 L
.45023 .30665 L
.45154 .3075 L
.4528 .30843 L
.45351 .30882 L
.45415 .30904 L
.4554 .30901 L
.45659 .30848 L
.45788 .30772 L
Mistroke
.4586 .30737 L
.45925 .30717 L
.46003 .30715 L
.46076 .30733 L
.46143 .30766 L
.46215 .30813 L
.46337 .30898 L
.46453 .30955 L
.46516 .30967 L
.46586 .30962 L
.46707 .30914 L
.46812 .3085 L
.46925 .30788 L
.4705 .3076 L
.47166 .30785 L
.47233 .3082 L
.47303 .30865 L
.47429 .30946 L
.47498 .30979 L
.47562 .30995 L
.47633 .30995 L
.47708 .30975 L
.47835 .30906 L
.47904 .30863 L
.47969 .30826 L
.48084 .30786 L
.4821 .30797 L
.48341 .30862 L
.48482 .30952 L
.48561 .3099 L
.48637 .31008 L
.48704 .31007 L
.48778 .30986 L
.48911 .30912 L
.49037 .30836 L
.49107 .30806 L
.49182 .30791 L
.49314 .30815 L
.49446 .30889 L
.49518 .30935 L
.49585 .30973 L
.49704 .31011 L
.49834 .30993 L
.49956 .3093 L
.50067 .30859 L
.50195 .30801 L
.50316 .30796 L
.50431 .30838 L
.50554 .30914 L
.50661 .30976 L
Mistroke
.50777 .31012 L
.50847 .31009 L
.50913 .30991 L
.51042 .30921 L
.51159 .30848 L
.51285 .30799 L
.51354 .30794 L
.51419 .30806 L
.51545 .30868 L
.51667 .30947 L
.51782 .31004 L
.51904 .31019 L
.5197 .31004 L
.52039 .30973 L
.52181 .30887 L
.52312 .30821 L
.52427 .30807 L
.52549 .30845 L
.52671 .30921 L
.52742 .30968 L
.52807 .31006 L
.52923 .31042 L
.53049 .31026 L
.53159 .30971 L
.53276 .30899 L
.53381 .3085 L
.53493 .30838 L
.53599 .30869 L
.53696 .30927 L
.53809 .31007 L
.53932 .31073 L
.54048 .3109 L
.54155 .3106 L
.5427 .30998 L
.54395 .30927 L
.54512 .30894 L
.54622 .3091 L
.54749 .3098 L
.54884 .31081 L
.5501 .31152 L
.55123 .31169 L
.5524 .31137 L
.55348 .31078 L
.55463 .31015 L
.5559 .30985 L
.55701 .31009 L
.55804 .31071 L
.55921 .31165 L
.5603 .31243 L
.56158 .31289 L
Mistroke
.56226 .31287 L
.56298 .31267 L
.56418 .31205 L
.56487 .31167 L
.56551 .31139 L
.56669 .3112 L
.56796 .31163 L
.56908 .31246 L
.57026 .31349 L
.57154 .31435 L
.57225 .31458 L
.5729 .3146 L
.57417 .31421 L
.57536 .31358 L
.57603 .31327 L
.57675 .31307 L
.57803 .31323 L
.57875 .31363 L
.57941 .31415 L
.58093 .31559 L
.58219 .31654 L
.58289 .31683 L
.58352 .3169 L
.58476 .3166 L
.58592 .31603 L
.58658 .31573 L
.58728 .31553 L
.58853 .31565 L
.58923 .31603 L
.58988 .31655 L
.59135 .31806 L
.59264 .31925 L
.59385 .31982 L
.59494 .31979 L
.59613 .31932 L
.59742 .31875 L
.59807 .31862 L
.59879 .31867 L
.60005 .31936 L
.60124 .32056 L
.60238 .3219 L
.60363 .32307 L
.60481 .32357 L
.6059 .32347 L
.60699 .32304 L
.60797 .32263 L
.6091 .32249 L
.61017 .32291 L
.61978 .32721 L
.62954 .33285 L
Mistroke
.63986 .33953 L
.65833 .35655 L
.6963 .39233 L
.7158 .41733 L
.71711 .41863 L
.71776 .42103 L
.71849 .42488 L
.72001 .43507 L
.72075 .43965 L
.72142 .44284 L
.72274 .44488 L
.72343 .44346 L
.72416 .44043 L
.72674 .42853 L
.73672 .38321 L
.73911 .25361 L
.74042 .19248 L
.74164 .15436 L
.74228 .14313 L
.74297 .13746 L
.74373 .13797 L
.74442 .14331 L
.74574 .16041 L
.74698 .17711 L
.74815 .18712 L
.74939 .18959 L
.75056 .18561 L
.75162 .17975 L
.75287 .17423 L
.75358 .17308 L
.75423 .1736 L
.75542 .17825 L
.75668 .1864 L
.75779 .1937 L
.75884 .19865 L
.76005 .20079 L
.76116 .19968 L
.7622 .1972 L
.76318 .19503 L
.7642 .19417 L
.76533 .1957 L
.76647 .19973 L
.76769 .20552 L
.76874 .21017 L
.76988 .21363 L
.77114 .21478 L
.77246 .21363 L
.77359 .21208 L
.77482 .21146 L
.77551 .212 L
Mistroke
.77615 .21315 L
.7774 .21692 L
.77861 .22148 L
.77974 .22527 L
.78095 .22777 L
.78159 .22829 L
.78229 .22829 L
.78301 .22785 L
.7837 .22724 L
.78498 .22642 L
.78612 .22689 L
.78733 .22905 L
.78836 .23196 L
.7895 .23554 L
.79072 .23876 L
.79204 .24062 L
.79328 .24075 L
.79443 .24009 L
.79564 .23956 L
.79695 .24018 L
.79818 .24224 L
.7993 .24504 L
.80061 .2485 L
.8013 .25002 L
.80204 .2512 L
.80268 .25184 L
.80338 .25211 L
.80463 .2518 L
.80534 .25144 L
.80602 .25119 L
.8073 .25143 L
.80801 .25213 L
.80868 .25315 L
.81018 .25638 L
.81147 .2593 L
.81269 .26128 L
.81337 .26188 L
.8141 .26213 L
.81538 .26185 L
.8166 .26138 L
.81775 .26144 L
.81839 .26185 L
.81908 .26264 L
.8203 .26472 L
.82135 .26687 L
.82248 .26899 L
.82372 .27051 L
.82489 .27095 L
.82556 .27086 L
.82626 .27061 L
Mistroke
.82752 .27019 L
.82821 .2702 L
.82885 .27046 L
.82956 .27106 L
.83031 .27203 L
.83158 .2742 L
.83292 .27654 L
.83407 .27798 L
.83533 .27862 L
.836 .27858 L
.83673 .27836 L
.83805 .27789 L
.83884 .27783 L
.8396 .27807 L
.84027 .27858 L
.84101 .27942 L
.84234 .28146 L
.8436 .28341 L
.8443 .28427 L
.84505 .2849 L
.84637 .28523 L
.84769 .28484 L
.84841 .28455 L
.84908 .28438 L
.85027 .28453 L
.85157 .28556 L
.85391 .28878 L
.85509 .29013 L
.85639 .29082 L
.85704 .29083 L
.85774 .29066 L
.85901 .29014 L
.86027 .28987 L
.86142 .29021 L
.86211 .29074 L
.86276 .29141 L
.86422 .29327 L
.86551 .29472 L
.86623 .29525 L
.86688 .2955 L
.8692 .295 L
.87046 .29451 L
.87164 .29452 L
.87292 .29525 L
.8736 .29591 L
.87433 .29674 L
.87561 .29819 L
.8768 .29913 L
.87803 .29942 L
.87868 .29931 L
Mistroke
.87936 .29905 L
.88062 .29846 L
.8818 .29817 L
.88284 .29837 L
.88397 .29912 L
.88521 .30037 L
.88636 .30153 L
.88744 .30229 L
.88845 .30254 L
.88956 .30232 L
.89075 .30176 L
.89199 .30123 L
.89317 .30117 L
.89422 .30162 L
.89537 .30255 L
.89658 .3037 L
.89772 .30459 L
.89905 .30499 L
.90025 .30473 L
.90139 .30415 L
.90247 .30364 L
.90371 .30343 L
.90483 .30377 L
.90607 .30466 L
.90741 .30583 L
.90866 .30662 L
.9098 .30684 L
.91106 .30649 L
.91178 .30611 L
.91245 .30573 L
.91314 .3054 L
.91379 .30519 L
.91455 .30514 L
.91523 .30529 L
.91644 .30597 L
.91777 .30703 L
.91844 .30753 L
.91917 .30794 L
.92047 .30818 L
.9217 .30781 L
.923 .30708 L
.92411 .30653 L
.92531 .30634 L
.92606 .3065 L
.92675 .30683 L
.92806 .30775 L
.92875 .30826 L
.92947 .30871 L
.93026 .30902 L
.93099 .3091 L
Mistroke
.93229 .30874 L
.93351 .30805 L
.93419 .30765 L
.93484 .30735 L
.93559 .30715 L
.93627 .30715 L
.93741 .30754 L
.93863 .30833 L
.93969 .30906 L
.94085 .30958 L
.94213 .3096 L
.94283 .30936 L
.94348 .30901 L
.94464 .3083 L
.9459 .30771 L
.94659 .3076 L
.94723 .30766 L
.94849 .30818 L
.94964 .30893 L
.95085 .30966 L
.95215 .30998 L
.95337 .30971 L
.95407 .30935 L
.95471 .30896 L
.95546 .30849 L
.95614 .30813 L
.95728 .30783 L
.95848 .30803 L
.9596 .30862 L
.96066 .3093 L
.96189 .30993 L
.96302 .31009 L
.96427 .30973 L
.96558 .30894 L
.96665 .30831 L
.96779 .30793 L
.96887 .308 L
.96986 .30841 L
.97095 .30908 L
.97211 .30976 L
.97338 .31012 L
.97455 .30992 L
.97533 .30955 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00WooonfX4o`0007[ooo]Z1Ol0001ooookJPCo
0000VooonfX009oooo]Z1?l0001joookJPGo0000OooonfX4o`0009_ooo]Z002OoookJPCo0000N_oo
nfX5o`0007kooo]Z1Ol0002KoookJP00WooonfX4o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX0
09oooo]Z1?l0001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPKo0000NOoonfX5o`0007ko
oo]Z1Ol0002KoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z
002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1_l0001/
oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0005cooo]Z2_l007l6oook
JP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0005cooo]Z2_l007l6oookJP?o
001o2_oonfX6o`0007gooo]Z1_l0002JoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000
O_oonfX6o`0009[ooo]Z002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oo
nfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX7o`00
06_ooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPOo0000J?oonfX6o`00O`[o
oo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1ol0001XoookJPKo001o2_oonfX5o`0007kooo]Z
1_l0002JoookJP00W_oonfX7o`0006[ooo]Z1?l007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002N
oookJPOo0000JooonfX3o`00O`[ooo]Z1Ol0001noookJPOo0000VOoonfX009kooo]Z2ol0001doook
JPGo0000O_oonfX:o`0009Kooo]Z002MoookJPco0000M?oonfX5o`0007gooo]Z3?l0002EoookJP00
WOoonfX<o`0007Cooo]Z1Ol0001moookJPco0000UOoonfX009gooo]Z3?l0001doookJPGo0000OOoo
nfX<o`0009Gooo]Z002MoookJPgo0000LooonfX5o`0007gooo]Z3?l0002EoookJP00WOoonfX=o`00
07?ooo]Z1Ol0001moookJPco0000UOoonfX009gooo]Z3Ol0001coookJPGo0000OOoonfX=o`0009Co
oo]Z002MoookJPgo0000LooonfX5o`0007gooo]Z3Ol0002DoookJP00WOoonfX=o`0007?ooo]Z1Ol0
001moookJPgo0000U?oonfX009gooo]Z3Ol0001coookJPGo0000OOoonfX=o`0009Cooo]Z002Moook
JPko0000L_oonfX5o`0007gooo]Z3Ol0002DoookJP00WOoonfX>o`0007;ooo]Z1Ol0001moookJPko
0000TooonfX009gooo]Z1?l000000ooonf[o0000o`00000:o`0006oooo]Z1Ol0001moookJPCo0000
00?ooo]Zo`000?l000002_l0002@oookJP00WOoonfX4o`0000Kooo]Z1ol0001_oookJPGo0000OOoo
nfX4o`0000Gooo]Z2Ol0002?oookJP00WOoonfX4o`0000Kooo]Z2?l0001^oookJPGo0000OOoonfX4
o`0000Kooo]Z2?l0002?oookJP00WOoonfX4o`0000Kooo]Z2?l0001^oookJPGo0000OOoonfX4o`00
00Kooo]Z2?l0002?oookJP00WOoonfX4o`0000Kooo]Z2Ol0001]oookJPGo0000OOoonfX4o`0000Ko
oo]Z2?l0002?oookJP00WOoonfX4o`0000Kooo]Z2Ol0001]oookJPGo0000OOoonfX4o`0000Kooo]Z
2Ol0002>oookJP00WOoonfX4o`0000Kooo]Z2Ol0001]oookJPGo0000OOoonfX4o`0000Oooo]Z2?l0
002>oookJP00WOoonfX4o`0000_ooo]Z1?l0001]oookJPGo0000OOoonfX4o`0000[ooo]Z1Ol0002>
oookJP00WOoonfX4o`0000_ooo]Z1?l0001]oookJPGo0000OOoonfX4o`0000_ooo]Z1Ol0002=oook
JP00WOoonfX4o`0000_ooo]Z2?l0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2?l0002:oookJP00
WOoonfX4o`0000_ooo]Z2?l0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2Ol00029oookJP00WOoo
nfX4o`0000_ooo]Z2Ol0001XoookJPGo0000OOoonfX4o`0000cooo]Z2?l00029oookJP00WOoonfX4
o`0000cooo]Z2?l0001XoookJPGo0000OOoonfX4o`0000cooo]Z2?l00029oookJP00WOoonfX4o`00
00cooo]Z2?l0001XoookJPGo0000OOoonfX4o`0000cooo]Z2?l00029oookJP00WOoonfX4o`0000co
oo]Z2?l0001XoookJPGo0000OOoonfX4o`0000gooo]Z2?l00028oookJP00WOoonfX4o`00013ooo]Z
1Ol0001WoookJPGo0000OOoonfX4o`00013ooo]Z1Ol00028oookJP00WOoonfX4o`00013ooo]Z1Ol0
001WoookJPGo0000OOoonfX4o`00013ooo]Z1Ol00028oookJP00WOoonfX4o`00013ooo]Z2Ol00015
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000OOoonfX4o`00017ooo]Z1ol00025
oookJP00WOoonfX4o`00017ooo]Z2Ol00013oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oook
JPGo0000OOoonfX4o`00017ooo]Z2?l00024oookJP00WOoonfX4o`00017ooo]Z2Ol00013oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000AoookJPWo0000PooonfX009gooo]Z1?l0000Boook
JPWo0000=OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000OOoonfX4o`0001;ooo]Z2?l00023oookJP00WOoonfX4o`0001;ooo]Z2_l0000doookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007cooo]Z1?l0000BoookJPSo
0000PooonfX009gooo]Z1?l0000FoookJPOo0000?ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX5o`0007gooo]Z1?l0000FoookJPGo0000P_oonfX009gooo]Z1?l0000GoookJPKo0000?ooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001moookJPCo00005_oo
nfX5o`0008;ooo]Z002MoookJPCo00006?oonfX6o`0003kooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Wooo]Z1Ol0001moookJPCo00005_oonfX8o`0007oooo]Z002MoookJPCo00006OoonfX6o`00
03gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001moookJPCo00005ooonfX8o`00
07kooo]Z002MoookJPCo00006OoonfX7o`0003cooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`ko
oo]Z1Ol0001moookJPCo00005ooonfX9o`0007gooo]Z002MoookJPCo00006_oonfX7o`0003cooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007gooo]Z1?l0000HoookJPSo
0000OOoonfX009gooo]Z1?l0000KoookJPOo0000>ooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000
OOoonfX4o`0001Sooo]Z2?l0001moookJP00WOoonfX4o`0001cooo]Z1ol0000koookJPGo001o2_oo
nfX7o`00O`Sooo]Z1Ol0001moookJPCo00007?oonfX5o`0007cooo]Z002MoookJPCo00007OoonfX7
o`0005Sooo]Z1Ol0001moookJPCo00007?oonfX5o`0007cooo]Z002MoookJPCo00007_oonfX7o`00
05Oooo]Z1Ol0001moookJPCo00007?oonfX9o`0007Sooo]Z002MoookJPCo00007ooonfX7o`0005Ko
oo]Z1Ol0001moookJPCo00007OoonfX8o`0007Sooo]Z002MoookJPCo00008?oonfX7o`0005Gooo]Z
1Ol0001moookJPCo00007OoonfX8o`0007Sooo]Z002MoookJPCo00008OoonfX7o`0005Cooo]Z1Ol0
001moookJPCo00007_oonfX8o`0007Oooo]Z002MoookJPCo00008_oonfX7o`0005?ooo]Z1Ol0001m
oookJPCo00008OoonfX6o`0007Kooo]Z002MoookJPCo00008ooonfX7o`0005;ooo]Z1Ol0001moook
JPCo00008OoonfX:o`0007;ooo]Z002MoookJPCo00009?oonfX8o`00053ooo]Z1Ol0001moookJPCo
00008_oonfX9o`0007;ooo]Z002MoookJPCo00009OoonfX8o`0004oooo]Z1Ol0001moookJPCo0000
8ooonfX9o`00077ooo]Z002MoookJPCo00009_oonfX8o`0004kooo]Z1Ol0001moookJPCo00008ooo
nfX9o`00077ooo]Z002MoookJPCo00009ooonfX9o`0004cooo]Z1Ol0001moookJPCo00009?oonfX9
o`00073ooo]Z002MoookJPCo0000:OoonfX8o`0004_ooo]Z1Ol0001moookJPCo0000:?oonfX9o`00
06cooo]Z000RoookJP?o001oMOoonfX3o`00O`Co00000_oonfX3o`00O`?ooo]Z1Ol007lMoookJPWo
0000BOoonfX5o`0007Cooo]Z1Ol007l4oookJPCo00000_oonfX5o`00Ob7ooo]Z2Ol0001<oookJP?o
001o7OoonfX002;ooo]Z0ol007mdoookJPCo001o1?l00002oookJP?o001o0_oonfX7o`00Oagooo]Z
2Ol00018oookJPGo0000LooonfX7o`00O`?ooo]Z1?l000000ooonf[o001oo`00O`05o`00Ob7ooo]Z
2Ol0001;oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o00?ooo]Zo`000?l000000_l0
0002oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lOoookJPSo0000
AooonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJPCo00001?l007l01?oonf[o
001oo`00Ool007lQoookJPWo0000BooonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOo
oo]Z2_l007l2oookJP?o001o00?ooo]Zo`000?l000000ol00006oookJP?o001o0ooonfX3o`00Oaoo
oo]Z2Ol00015oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00000ol007l3oookJP?o
001o9?oonfX9o`0004Oooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o
0_oonfX3o`00O`03oookJ_l0003o000000?o00003?oonfX3o`00Ob7ooo]Z2?l00014oookJPGo0000
L_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00001_oonfX3o`00ObGooo]Z2Ol00016oookJP?o001o
7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000ol0000<oookJP?o001o8_oo
nfX9o`0004;ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00006oookJP?o001o9Ooo
nfX:o`0004Gooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002
o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l2oookJPCo001o8ooonfX:o`00043ooo]Z1Ol0001b
oookJP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02oookJPCo001o9_oonfX9
o`0004Gooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`00
0003o`00Oooonf[ooo]Z00Gooo]Z1ol007lVoookJPWo0000?ooonfX5o`0007;ooo]Z0ol007l3oook
JP?o001o0_oonfX4o`000003oookJ_l007oo001o00Go001o:?oonfX=o`00043ooo]Z0ol007lMoook
JP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Go
oo]Z1_l007lXoookJP[o0000?OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l0
00000ol000000ooonf[o001oo`00O`04o`00Obgooo]Z2Ol00010oookJP?o001o7OoonfX001oooo]Z
1_l007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP05oookJP;o001o
;_oonfX9o`0003cooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000?o0000
00?ooo]Zo`00Ool007l0<OoonfX:o`0003cooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol0
07l4o`0000Sooo]Z0_l007l`oookJPWo0000>_oonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l2oookJPGo000000?ooo]Zo`00Ool007l0<_oonfX>o`0003Oooo]Z1_l007lMoookJP008Ooo
nfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol007l[oookJP_o0000=ooonfX5o`0007?ooo]Z1ol0
07l2oookJPCo00000ooonfX7o`00Oc3ooo]Z2_l0000ioookJPCo001o7OoonfX002;ooo]Z0ol007me
oookJP;o001o1?l00009oookJPOo001o;OoonfX<o`0003Cooo]Z1Ol0001doookJPGo001o0ooonfX4
o`0000?ooo]Z1ol007laoookJPgo0000=_oonfX3o`00Oagooo]Z002LoookJPCo0000?_oonfX>o`00
037ooo]Z1Ol0001loookJPCo0000>ooonfX?o`0005Cooo]Z002LoookJPCo0000@?oonfX>o`0002oo
oo]Z1Ol0001loookJPCo0000@?oonfX>o`00053ooo]Z002LoookJPCo0000@ooonfX=o`0002gooo]Z
1Ol0001loookJPCo0000@OoonfX?o`0004kooo]Z002LoookJPCo0000A_oonfX?o`0002Sooo]Z1Ol0
001loookJPCo0000@OoonfXDo`0004Wooo]Z002LoookJPCo0000BOoonfXAo`0002?ooo]Z1Ol0001l
oookJPCo0000AooonfXCo`0004Cooo]Z002LoookJPCo0000BooonfXFo`0001cooo]Z1Ol0001loook
JPCo0000AooonfXJo`0003gooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000
ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000U
o`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000MoookJP03o`000?oonf[o000000Wo
000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`00000No`0004cooo]Z1?l0001`oookJPCo
000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000009o`000003oookJ_l0003o000002Wo
0000C?oonfX4o`00073ooo]Z1?l000000ooonf[o0000o`000003o`0000;ooo]Z1?l0000NoookJP00
>ooonfXJo`0004Oooo]Z1?l0001moookJPGo00007?oonfXIo`0004Oooo]Z1?l0002NoookJP00@Ooo
nfXDo`0004Oooo]Z1?l0001moookJPGo00008_oonfXDo`0004Kooo]Z1?l0002NoookJP00AooonfXC
o`0004;ooo]Z1?l0001moookJPGo00009ooonfXCo`0004;ooo]Z1?l0002NoookJP00COoonfX>o`00
047ooo]Z1?l0001moookJPGo0000;OoonfX?o`00043ooo]Z1?l0002NoookJP00COoonfX?o`00043o
oo]Z1?l0001moookJPGo0000;OoonfXBo`0003gooo]Z1?l0002NoookJP00D_oonfX@o`0003[ooo]Z
1?l0001moookJPGo0000<_oonfX?o`0003_ooo]Z1?l0002NoookJP00DooonfXAo`0003Sooo]Z1?l0
001moookJPGo0000<ooonfX@o`0003Wooo]Z1?l0002NoookJP00F?oonfX=o`0003Oooo]Z1?l0001m
oookJPGo0000>OoonfX;o`0003Sooo]Z1?l0002NoookJP00FOoonfX>o`0003Gooo]Z1?l0001moook
JPGo0000??oonfX:o`0003Kooo]Z1?l0002NoookJP00GooonfX9o`0003Cooo]Z1?l0001moookJPGo
0000?_oonfX9o`0003Gooo]Z1?l0002NoookJP00HOoonfX9o`0003;ooo]Z1?l0001moookJPGo0000
@?oonfX9o`0003?ooo]Z1?l0002NoookJP00H_oonfX9o`00033ooo]Z1Ol0001moookJPGo0000@Ooo
nfX9o`0003;ooo]Z1?l0002NoookJP00I?oonfX9o`0002kooo]Z1Ol0001moookJPGo0000@ooonfX9
o`00033ooo]Z1?l0002NoookJP00IOoonfX9o`0002gooo]Z1Ol0001moookJPGo0000A?oonfX9o`00
02oooo]Z1?l0002NoookJP00IooonfX8o`0002cooo]Z1?l0001noookJPGo0000A_oonfX8o`0002ko
oo]Z1?l0002NoookJP00J?oonfX8o`0002_ooo]Z1?l0001noookJPGo0000AooonfX8o`0002gooo]Z
1?l0002NoookJP00J_oonfX7o`0002[ooo]Z1?l0001noookJPGo0000BOoonfX7o`0002cooo]Z1?l0
002NoookJP00JooonfX7o`0002Wooo]Z1?l0001noookJPGo0000B_oonfX7o`0002_ooo]Z1?l0002N
oookJP00K?oonfX7o`0002Sooo]Z1?l0001noookJPGo0000BooonfX7o`0002Wooo]Z1Ol0002Noook
JP00KOoonfX7o`0002Oooo]Z1?l0001noookJPGo0000C?oonfX7o`0002Sooo]Z1Ol0002NoookJP00
K_oonfX7o`0002Kooo]Z1?l0001noookJPGo0000COoonfX7o`0002Oooo]Z1Ol0002NoookJP00Kooo
nfX7o`0002Gooo]Z1?l0001noookJPGo0000C_oonfX8o`0002Gooo]Z1?l0002OoookJP00L?oonfX6
o`0002Gooo]Z1?l0001noookJPGo0000CooonfX8o`0002Cooo]Z1?l0002OoookJP00LOoonfX6o`00
02Cooo]Z1?l0001noookJPGo0000D?oonfX8o`0002?ooo]Z1?l0002OoookJP00L_oonfX6o`0002?o
oo]Z1?l0001noookJPGo0000DOoonfX8o`0002;ooo]Z1?l0002OoookJP00L_oonfX7o`0002;ooo]Z
1?l0001noookJPGo0000DooonfX7o`00027ooo]Z1?l0002OoookJP00LooonfX7o`00027ooo]Z1?l0
001noookJPGo0000E?oonfX7o`00023ooo]Z1?l0002OoookJP00M?oonfX7o`00023ooo]Z1?l0001n
oookJPGo0000EOoonfX7o`0001oooo]Z1?l0002OoookJP00MOoonfX7o`0001oooo]Z1?l0001noook
JPGo0000E_oonfX7o`0001kooo]Z1?l0002OoookJP00M_oonfX7o`0001kooo]Z1?l0001noookJPGo
0000EooonfX7o`0001gooo]Z1?l0002OoookJP00MooonfX7o`0001gooo]Z1?l0001noookJPGo0000
F?oonfX7o`0001cooo]Z1?l0002OoookJP00N?oonfX7o`0001cooo]Z1?l0001noookJPGo0000FOoo
nfX7o`0001_ooo]Z1?l0002OoookJP00NOoonfX7o`0001_ooo]Z1?l0001noookJPGo0000F_oonfX7
o`0001[ooo]Z1?l0002OoookJP00N_oonfX7o`0001[ooo]Z1?l0001noookJPGo0000FooonfX7o`00
01Wooo]Z1?l0002OoookJP00NooonfX6o`0001[ooo]Z1?l0001PoookJPGo001o1?oonfX3o`00O`?o
oo]Z1Ol007l:oookJPGo0000G?oonfX7o`0001Sooo]Z1?l0002OoookJP00O?oonfX6o`0001Wooo]Z
1?l0001OoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000GOoonfX7o`0001Oooo]Z
1?l0002OoookJP00OOoonfX6o`0001Sooo]Z1?l0001OoookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005ko
oo]Z1ol0000FoookJPCo0000WooonfX007gooo]Z1ol0000GoookJPCo0000G_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001OoookJPOo00005OoonfX4o`0009oooo]Z
001noookJPKo00005ooonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0
001OoookJPOo00004ooonfX5o`0009oooo]Z001ooookJPKo00005_oonfX4o`0005kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001QoookJPOo00004_oonfX5o`0009oooo]Z0020oook
JPKo00005OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oook
JPGo0000H_oonfX7o`00017ooo]Z1Ol0002OoookJP00P?oonfX7o`0001Cooo]Z1?l0001NoookJP?o
001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000HooonfX6o`00017ooo]Z1?l0002PoookJP00
POoonfX7o`0001?ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000
I?oonfX6o`00013ooo]Z1?l0002PoookJP00P_oonfX6o`0001?ooo]Z1?l0001NoookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l>oookJPGo0000IOoonfX6o`0000kooo]Z1Ol0002PoookJP00PooonfX6
o`0001;ooo]Z1?l0001OoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0
001UoookJPOo00003OoonfX5o`000:3ooo]Z0024oookJPKo00004OoonfX4o`0005oooo]Z1ol007l9
oookJPOo001o2?oonfX5o`0006Kooo]Z1ol0000<oookJPGo0000X?oonfX008Cooo]Z1ol0000@oook
JPCo0000H?oonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000IooonfX6o`0000cooo]Z1?l0002Qoook
JP00QOoonfX6o`00013ooo]Z1?l0001noookJPGo0000J?oonfX6o`0000_ooo]Z1?l0002QoookJP00
Q_oonfX6o`0000oooo]Z1?l0001noookJPGo0000JOoonfX6o`0000Wooo]Z1Ol0002QoookJP00Qooo
nfX6o`0000kooo]Z1?l0001noookJPGo0000JOoonfX7o`0000Sooo]Z1Ol0002QoookJP00QooonfX7
o`0000gooo]Z1?l0001noookJPGo0000J_oonfX6o`0000Sooo]Z1Ol0002QoookJP00R?oonfX7o`00
00cooo]Z1?l0001noookJPGo0000JooonfX6o`0000Oooo]Z1?l0002RoookJP00ROoonfX7o`0000_o
oo]Z1?l0001noookJPGo0000K?oonfX6o`0000Kooo]Z1?l0002RoookJP00R_oonfX6o`0000_ooo]Z
1?l0001noookJPGo0000K?oonfX7o`0000Cooo]Z1Ol0002RoookJP00RooonfX6o`0000[ooo]Z1?l0
001noookJPGo0000KOoonfX8o`0000;ooo]Z1Ol0002RoookJP00S?oonfX6o`0000Wooo]Z1?l0001n
oookJPGo0000K_oonfX7o`0000;ooo]Z1Ol0002RoookJP00S?oonfX7o`0000Sooo]Z1?l0001noook
JPGo0000KooonfX6o`0000;ooo]Z1?l0002SoookJP00SOoonfX7o`0000Oooo]Z1?l0001noookJPGo
0000L?oonfX5o`0000;ooo]Z1?l0002SoookJP00S_oonfX7o`0000Kooo]Z1?l0001noookJPGo0000
LOoonfX4o`000003oookJ_l0003o000000?o0000XooonfX008oooo]Z1_l00006oookJPCo0000O_oo
nfX5o`00077ooo]Z1?l000000ooonf[o0000o`000003o`000:?ooo]Z002@oookJPGo000000?ooo]Z
o`000?l000000_l000000ooonf[o0000o`000002o`0007kooo]Z1Ol0001aoookJPCo000000?ooo]Z
o`000?l000000ol0002SoookJP00TOoonfX9o`000003oookJ_l0003o000000;o0000O_oonfX5o`00
077ooo]Z2Ol0002ToookJP00TOoonfX9o`000003oookJ_l0003o000000;o0000O_oonfX5o`00077o
oo]Z2Ol0002ToookJP00TOoonfX>o`0007kooo]Z1Ol0001aoookJPWo0000Y?oonfX009;ooo]Z3Ol0
001noookJPGo0000L_oonfX8o`000:Cooo]Z002BoookJPgo0000O_oonfX5o`0007;ooo]Z1ol0002U
oookJP00T_oonfX=o`0007kooo]Z1Ol0001boookJPOo0000YOoonfX009;ooo]Z3Ol0001noookJPGo
0000L_oonfX7o`000:Gooo]Z002BoookJPgo0000O_oonfX5o`0007?ooo]Z1Ol0002VoookJP00T_oo
nfX=o`0007kooo]Z1Ol0001coookJPGo0000Y_oonfX009?ooo]Z3?l0001noookJPGo0000LooonfX5
o`000:Kooo]Z002CoookJPco0000O_oonfX5o`0007?ooo]Z1Ol0002VoookJP00U?oonfX:o`0007oo
oo]Z1Ol0001doookJPCo0000Y_oonfX009Oooo]Z1ol0001ooookJPGo0000oooonfXOoookJP00Uooo
nfX7o`0007oooo]Z1Ol0003ooookJQoooo]Z002GoookJPOo0000OooonfX5o`000?oooo]Z7ooonfX0
09Sooo]Z1_l0001boookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX009Sooo]Z1_l0001boookJP?o
001o2_oonfX5o`000?oooo]Z7ooonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`000?oooo]Z
7ooonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX009Sooo]Z1_l0001b
oookJP?o001o2_oonfX6o`000?oooo]Z7_oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`00
0?oooo]Z7ooonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX009Sooo]Z
1_l0001boookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX009Sooo]Z1_l0001boookJP?o001o2_oo
nfX5o`000?oooo]Z7ooonfX009Wooo]Z1Ol0001_oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX0
09Wooo]Z1Ol0001_oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX009Wooo]Z1Ol0001aoookJPCo
001o2_oonfX5o`000?oooo]Z7ooonfX009Wooo]Z1Ol0001boookJP?o001o2_oonfX5o`000?oooo]Z
7ooonfX009Wooo]Z1Ol0001ooookJPGo0000oooonfXOoookJP00VOoonfX5o`0007oooo]Z1Ol0003o
oookJQoooo]Z002IoookJPCo0000P?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8
oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oook
JP?o001o2?oonfX6o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo
0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oook
JP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooo
nfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003o
oookJQoooo]Z003ooookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo
001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003ooookJQ;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/
oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?o
oo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooo
nfX>oookJPOo001ooooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30972 L
.02605 .31007 L
.02729 .30996 L
.02846 .30939 L
.02946 .30875 L
.03053 .30818 L
.0317 .30794 L
.03279 .30818 L
.03395 .30882 L
.0352 .30961 L
.03638 .31007 L
.03746 .31007 L
.03873 .30954 L
.03944 .3091 L
.04011 .30868 L
.04132 .30811 L
.04262 .30805 L
.04327 .30826 L
.04396 .30862 L
.04519 .30942 L
.04583 .3098 L
.04652 .31011 L
.04727 .31026 L
.04797 .3102 L
.04862 .30999 L
.04933 .30962 L
.05061 .30883 L
.05186 .30827 L
.05302 .30824 L
.05414 .30868 L
.05519 .30936 L
.05644 .31016 L
.05759 .31056 L
.05873 .31045 L
.05993 .30989 L
.06113 .30916 L
.06244 .30863 L
.06315 .3086 L
.0638 .30874 L
.06509 .30944 L
.06632 .31033 L
.06748 .31097 L
.06873 .31114 L
.06939 .31099 L
.0701 .31068 L
.07142 .3099 L
.07217 .30952 L
.07287 .30931 L
.07413 .30941 L
Mistroke
.07483 .30973 L
.07547 .31015 L
.07666 .31106 L
.07794 .31185 L
.07918 .31208 L
.08032 .31176 L
.08142 .31117 L
.08257 .31057 L
.08327 .31036 L
.08394 .31033 L
.08519 .31079 L
.08589 .31127 L
.08654 .3118 L
.08729 .31243 L
.088 .31293 L
.08917 .3134 L
.09046 .31328 L
.09172 .31268 L
.09237 .31232 L
.09307 .312 L
.09379 .31182 L
.09447 .31185 L
.09527 .31213 L
.096 .3126 L
.09748 .3139 L
.09825 .31455 L
.09908 .31505 L
.09978 .31527 L
.10055 .31526 L
.10125 .31506 L
.10191 .31475 L
.1032 .3141 L
.10386 .31388 L
.10458 .31382 L
.10522 .31396 L
.10592 .31432 L
.10717 .31538 L
.10832 .31651 L
.10958 .31745 L
.11029 .3177 L
.11096 .31773 L
.11166 .31757 L
.11241 .31725 L
.11307 .31692 L
.11377 .31661 L
.11501 .31642 L
.11629 .31695 L
.11695 .3175 L
.11768 .31824 L
.11889 .31955 L
Mistroke
.1202 .32057 L
.12147 .32085 L
.12263 .32054 L
.12382 .31998 L
.12491 .31968 L
.12605 .31988 L
.12727 .32078 L
.12839 .32206 L
.12946 .32331 L
.1307 .32438 L
.13184 .32473 L
.13309 .32446 L
.13373 .32418 L
.13442 .32389 L
.1356 .32368 L
.13668 .32404 L
.13792 .32519 L
.13909 .32672 L
.14011 .32801 L
.14118 .32901 L
.14236 .32943 L
.14346 .32924 L
.1446 .32878 L
.14584 .32849 L
.14714 .32896 L
.14835 .33021 L
.14946 .3318 L
.15066 .3335 L
.15179 .33463 L
.15284 .33504 L
.15408 .33484 L
.1554 .33434 L
.15651 .33423 L
.15772 .33488 L
.15902 .3365 L
.16042 .33879 L
.16174 .34065 L
.16294 .34155 L
.18123 .35425 L
.22101 .39351 L
.24109 .41871 L
.2433 .42927 L
.24437 .43675 L
.24535 .44241 L
.24638 .44542 L
.24749 .44425 L
.24869 .4387 L
.24983 .43229 L
.25106 .42873 L
.25219 .43201 L
Mistroke
.25344 .44401 L
.25475 .46261 L
.25586 .47644 L
.2569 .48134 L
.25804 .47158 L
.25927 .43938 L
.26199 .30395 L
.26333 .2307 L
.26458 .17711 L
.2657 .14749 L
.2669 .1367 L
.26759 .13873 L
.26823 .1446 L
.26944 .16102 L
.2706 .1768 L
.27183 .18721 L
.27288 .18923 L
.27403 .18546 L
.27527 .17846 L
.27595 .17511 L
.2766 .17307 L
.27785 .1734 L
.279 .17848 L
.2803 .18731 L
.28153 .19502 L
.28281 .19949 L
.28349 .20001 L
.28422 .19931 L
.28545 .19646 L
.28674 .19371 L
.28784 .19352 L
.28905 .19636 L
.29999 .2145 L
.31959 .2389 L
.34054 .26043 L
.36187 .27717 L
.38202 .28872 L
.40203 .29722 L
.41092 .30103 L
.42048 .30399 L
.42172 .30338 L
.42238 .30305 L
.42307 .30281 L
.42435 .30284 L
.42554 .30348 L
.42662 .3044 L
.42776 .3054 L
.42902 .30611 L
.43017 .30619 L
.43133 .30577 L
Mistroke
.43262 .30507 L
.43381 .30464 L
.43492 .3047 L
.43601 .30524 L
.437 .30601 L
.43806 .30687 L
.43923 .30755 L
.44051 .30768 L
.44121 .30748 L
.44187 .30716 L
.44306 .30648 L
.44431 .306 L
.44498 .30596 L
.4457 .30611 L
.44697 .30684 L
.44774 .30743 L
.44847 .30798 L
.44913 .30838 L
.44983 .30867 L
.45114 .30868 L
.45235 .30815 L
.45363 .3074 L
.45436 .30706 L
.45504 .3069 L
.45617 .30701 L
.45738 .30764 L
.45866 .30855 L
.45987 .30924 L
.46108 .30944 L
.46173 .30931 L
.46242 .30901 L
.46374 .30823 L
.46447 .30783 L
.46514 .30756 L
.46635 .3075 L
.467 .30769 L
.46768 .30805 L
.4689 .30886 L
.47002 .30954 L
.47071 .30978 L
.47145 .30984 L
.47218 .30969 L
.473 .30932 L
.47435 .30849 L
.4751 .30809 L
.47581 .30784 L
.47649 .30777 L
.47723 .3079 L
.47853 .30855 L
.47975 .30935 L
Mistroke
.48044 .30973 L
.48107 .30996 L
.48174 .31004 L
.48244 .30993 L
.48372 .30934 L
.48488 .30861 L
.48612 .30802 L
.48682 .30791 L
.48745 .30796 L
.48869 .30847 L
.49015 .3094 L
.49079 .30975 L
.4915 .31001 L
.49266 .31004 L
.49389 .30956 L
.49453 .30917 L
.49522 .30872 L
.49648 .30809 L
.49767 .30795 L
.49893 .30837 L
.50001 .30902 L
.50119 .30972 L
.50251 .3101 L
.50372 .30987 L
.50436 .30956 L
.50506 .30913 L
.5058 .30866 L
.50647 .30829 L
.50772 .30794 L
.5084 .308 L
.50905 .30821 L
.51021 .30886 L
.51146 .30965 L
.5127 .3101 L
.51381 .31003 L
.5151 .30944 L
.51631 .30868 L
.51743 .30814 L
.51847 .30801 L
.5196 .30833 L
.5208 .30904 L
.52209 .30984 L
.5233 .31024 L
.52397 .31023 L
.5247 .31003 L
.52598 .30934 L
.52719 .30861 L
.52848 .3082 L
.52958 .30834 L
.5308 .30897 L
Mistroke
.53146 .30942 L
.53219 .30991 L
.53288 .31029 L
.53352 .31051 L
.53426 .31057 L
.53505 .31041 L
.53579 .31008 L
.53645 .30969 L
.53776 .30893 L
.5385 .30866 L
.53918 .30859 L
.54043 .30893 L
.54175 .30978 L
.54297 .31062 L
.54366 .31096 L
.54429 .31113 L
.54546 .31103 L
.5467 .31044 L
.54774 .30983 L
.54885 .30936 L
.55007 .30934 L
.55122 .30985 L
.55255 .31084 L
.5538 .31169 L
.5551 .31208 L
.55578 .31202 L
.55651 .31176 L
.55782 .31104 L
.55906 .31046 L
.56017 .31034 L
.56137 .31078 L
.56251 .31162 L
.56358 .3125 L
.56475 .31322 L
.566 .31342 L
.56732 .313 L
.56856 .31232 L
.56968 .31188 L
.57091 .3119 L
.57206 .31251 L
.57311 .31339 L
.57425 .31439 L
.57547 .31513 L
.5766 .31528 L
.57765 .31497 L
.57865 .31446 L
.5797 .31398 L
.58092 .31384 L
.58161 .31404 L
.58225 .31442 L
Mistroke
.58342 .31544 L
.58467 .31665 L
.58578 .31745 L
.58682 .31774 L
.58796 .31753 L
.58919 .31695 L
.59043 .31647 L
.59113 .31641 L
.59178 .31656 L
.59309 .31745 L
.59383 .3182 L
.5945 .31893 L
.5957 .32011 L
.597 .3208 L
.59823 .32075 L
.59936 .32029 L
.60042 .31983 L
.60155 .31968 L
.60263 .32009 L
.6036 .32093 L
.60478 .3223 L
.60603 .3237 L
.60721 .32454 L
.60827 .32472 L
.60947 .32438 L
.61059 .3239 L
.6118 .32368 L
.61311 .32421 L
.61427 .32539 L
.6155 .32701 L
.61665 .32839 L
.6177 .3292 L
.61893 .32942 L
.61958 .32927 L
.62026 .329 L
.62141 .32857 L
.62268 .32861 L
.62381 .32937 L
.62502 .33088 L
.62616 .33256 L
.62722 .33394 L
.62852 .33492 L
.62921 .33505 L
.62994 .33495 L
.63064 .3347 L
.6313 .33444 L
.63253 .33421 L
.63375 .33474 L
.63487 .336 L
.63609 .33793 L
Mistroke
.6374 .33999 L
.63855 .34123 L
.6396 .34166 L
.64065 .34151 L
.64165 .34113 L
.64281 .34089 L
.64389 .34126 L
.64507 .34255 L
.64632 .34468 L
.64743 .34673 L
.64863 .34847 L
.64977 .34928 L
.6508 .34932 L
.65196 .3489 L
.65321 .3486 L
.65453 .34921 L
.65575 .35089 L
.69479 .39104 L
.70503 .40479 L
.71613 .41824 L
.7174 .41896 L
.71811 .42132 L
.71877 .42464 L
.71994 .43246 L
.72123 .44084 L
.72254 .44539 L
.72379 .44388 L
.7245 .44078 L
.72526 .43653 L
.72597 .43258 L
.72662 .42985 L
.72787 .42962 L
.72853 .43302 L
.72923 .43934 L
.7304 .45473 L
.73169 .47256 L
.73284 .48117 L
.73407 .47417 L
.73523 .44729 L
.73629 .40565 L
.73877 .27065 L
.73999 .20846 L
.74111 .16627 L
.74228 .14181 L
.74354 .13746 L
.74485 .14987 L
.7455 .15918 L
.74622 .16951 L
.74743 .18325 L
.74852 .18896 L
Mistroke
.74979 .18742 L
.75098 .18121 L
.75201 .17567 L
.75311 .17259 L
.7543 .17419 L
.7554 .17981 L
.75667 .18854 L
.75787 .19578 L
.75854 .1984 L
.75926 .19984 L
.76052 .19912 L
.76161 .19652 L
.76279 .1939 L
.76409 .19358 L
.7653 .19658 L
.766 .19947 L
.76673 .203 L
.76804 .20907 L
.76876 .21156 L
.76943 .21305 L
.77016 .21372 L
.77095 .21344 L
.77162 .21266 L
.77236 .21158 L
.77305 .21072 L
.77369 .21032 L
.7749 .21118 L
.77618 .2145 L
.77738 .219 L
.7787 .2237 L
.77994 .22645 L
.7811 .22709 L
.78224 .22638 L
.78328 .22545 L
.78447 .22515 L
.7856 .22634 L
.79572 .23883 L
.81403 .26017 L
.83412 .27704 L
.84304 .28366 L
.85259 .28886 L
.85385 .28951 L
.85456 .28951 L
.85521 .28933 L
.85639 .28885 L
.85769 .28861 L
.85885 .28905 L
.85994 .29009 L
.86111 .29159 L
.86234 .29313 L
Mistroke
.86343 .29405 L
.86462 .29436 L
.86571 .2941 L
.86671 .29366 L
.86791 .29332 L
.86899 .2935 L
.87025 .29441 L
.87143 .29576 L
.87273 .29724 L
.87394 .29815 L
.8752 .29834 L
.87587 .29817 L
.87659 .29786 L
.87787 .29731 L
.87908 .29721 L
.88016 .29768 L
.88135 .29873 L
.88274 .30024 L
.88405 .3013 L
.88478 .30158 L
.88556 .3016 L
.88627 .30141 L
.88693 .30112 L
.88823 .30051 L
.88944 .3003 L
.89071 .30075 L
.89138 .30125 L
.8921 .30192 L
.89274 .30256 L
.89343 .30321 L
.89467 .30403 L
.89597 .30419 L
.89672 .30397 L
.8974 .30364 L
.8986 .30304 L
.89992 .30274 L
.90115 .3031 L
.9023 .30394 L
.903 .30457 L
.90375 .30524 L
.90446 .30575 L
.90512 .30608 L
.90636 .30619 L
.90767 .30569 L
.90898 .30498 L
.90972 .3047 L
.9104 .3046 L
.91119 .30472 L
.91194 .30507 L
.91264 .30555 L
Mistroke
.91339 .30617 L
.91455 .30708 L
.9158 .30766 L
.91651 .3077 L
.91717 .30756 L
.91846 .30694 L
.91912 .30656 L
.91982 .30621 L
.92108 .30595 L
.9224 .30635 L
.92316 .30683 L
.92385 .30736 L
.92501 .3082 L
.92623 .30872 L
.92688 .30875 L
.92758 .3086 L
.92882 .30799 L
.92999 .30731 L
.93125 .30689 L
.93244 .30704 L
.93353 .3076 L
.93482 .30853 L
.93603 .30923 L
.93712 .30945 L
.9383 .30916 L
.93958 .30844 L
.94078 .30777 L
.94202 .30746 L
.94268 .30753 L
.94339 .30778 L
.94467 .30857 L
.94588 .30937 L
.94697 .30979 L
.94815 .30976 L
.94926 .30928 L
.95043 .30856 L
.95143 .30803 L
.95254 .30777 L
.95385 .30807 L
.95451 .30842 L
.95522 .30889 L
.95652 .30967 L
.95769 .31003 L
.9584 .30999 L
.95908 .30978 L
.95979 .30941 L
.96056 .30893 L
.96124 .30851 L
.96195 .30815 L
.96323 .30791 L
Mistroke
.96443 .30824 L
.96571 .30899 L
.96681 .30966 L
.96802 .31007 L
.96875 .31006 L
.96942 .30987 L
.97007 .30956 L
.97076 .30914 L
.97197 .3084 L
.97327 .30795 L
.97405 .30798 L
.97478 .30821 L
.97546 .30856 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00WooonfX4o`0007[ooo]Z1Ol0001ooookJPCo
0000VooonfX009oooo]Z1?l0001joookJPGo0000OooonfX4o`0009_ooo]Z002OoookJPCo0000N_oo
nfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX0
09kooo]Z1Ol0001joookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPGo0000N_oonfX5o`0007ko
oo]Z1_l0002JoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z
002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1Ol0001]
oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0005cooo]Z2_l007l6oook
JP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0005cooo]Z2_l007l6oookJP?o
001o2_oonfX6o`0007gooo]Z1_l0002JoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000
O_oonfX6o`0009[ooo]Z002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oo
nfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00WOoonfX7o`00
06cooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002MoookJPOo0000JOoonfX6o`00O`[o
oo]Z1Ol0001noookJPKo0000V_oonfX009gooo]Z1ol0001YoookJPKo001o2_oonfX5o`0007kooo]Z
1_l0002JoookJP00WOoonfX7o`0006_ooo]Z1?l007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002M
oookJPSo0000JooonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009gooo]Z2ol0001eoook
JPGo0000O_oonfX:o`0009Kooo]Z002MoookJPco0000M?oonfX5o`0007kooo]Z2ol0002EoookJP00
WOoonfX<o`0007Cooo]Z1Ol0001noookJP_o0000UOoonfX009gooo]Z3?l0001doookJPGo0000O_oo
nfX;o`0009Gooo]Z002MoookJPco0000M?oonfX5o`0007kooo]Z2ol0002EoookJP00WOoonfX<o`00
07Cooo]Z1Ol0001noookJP_o0000UOoonfX009gooo]Z3Ol0001coookJPGo0000O_oonfX;o`0009Go
oo]Z002MoookJPgo0000LooonfX5o`0007kooo]Z3?l0002DoookJP00WOoonfX=o`0007?ooo]Z1Ol0
001noookJPco0000U?oonfX009gooo]Z3Ol0001coookJPGo0000OOoonfX=o`0009Cooo]Z002Moook
JPgo0000LooonfX5o`0007gooo]Z3Ol0002DoookJP00WOoonfXAo`0006oooo]Z1Ol0001moookJQ7o
0000T?oonfX009gooo]Z1?l000000ooonf[o0000o`00000:o`0006oooo]Z1Ol0001moookJPCo0000
00?ooo]Zo`000?l000002_l0002@oookJP00WOoonfX4o`0000Gooo]Z2Ol0001^oookJPGo0000OOoo
nfX4o`0000Gooo]Z2Ol0002?oookJP00WOoonfX4o`0000Kooo]Z2?l0001^oookJPGo0000OOoonfX4
o`0000Gooo]Z2Ol0002?oookJP00WOoonfX4o`0000Kooo]Z2Ol0001]oookJPGo0000OOoonfX4o`00
00Kooo]Z2?l0002?oookJP00WOoonfX4o`0000Kooo]Z2_l0001/oookJPGo0000OOoonfX4o`0000Ko
oo]Z2?l0002?oookJP00WOoonfX4o`0000Kooo]Z2_l0001/oookJPGo0000OOoonfX4o`0000Kooo]Z
2Ol0002>oookJP00WOoonfX4o`0000Kooo]Z2ol0001[oookJPGo0000OOoonfX4o`0000Oooo]Z2?l0
002>oookJP00WOoonfX4o`0000cooo]Z1Ol0001[oookJPGo0000OOoonfX4o`0000[ooo]Z1Ol0002>
oookJP00WOoonfX4o`0000cooo]Z1_l0001ZoookJPGo0000OOoonfX4o`0000_ooo]Z1?l0002>oook
JP00WOoonfX4o`0000gooo]Z1_l0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2?l0002:oookJP00
WOoonfX4o`0000gooo]Z1_l0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2?l0002:oookJP00WOoo
nfX4o`0000kooo]Z1_l0001XoookJPGo0000OOoonfX4o`0000_ooo]Z2Ol00029oookJP00WOoonfX4
o`0000oooo]Z1Ol0001XoookJPGo0000OOoonfX4o`0000cooo]Z2?l00029oookJP00WOoonfX4o`00
00oooo]Z1_l0001WoookJPGo0000OOoonfX4o`0000cooo]Z2?l00029oookJP00WOoonfX4o`00013o
oo]Z1_l0001VoookJPGo0000OOoonfX4o`00013ooo]Z1?l00029oookJP00WOoonfX4o`00013ooo]Z
1ol0001UoookJPGo0000OOoonfX4o`00013ooo]Z1Ol00028oookJP00WOoonfX4o`00017ooo]Z1_l0
001UoookJPGo0000OOoonfX4o`00013ooo]Z1Ol00028oookJP00WOoonfX4o`0001;ooo]Z1_l00016
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000OOoonfX4o`00013ooo]Z2Ol00024
oookJP00WOoonfX4o`0001?ooo]Z1_l00014oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oook
JPGo0000OOoonfX4o`00017ooo]Z2?l00024oookJP00WOoonfX4o`0001?ooo]Z1ol00013oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000AoookJPWo0000PooonfX009gooo]Z1?l0000Doook
JPOo0000=OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000OOoonfX4o`0001;ooo]Z2Ol00022oookJP00WOoonfX4o`0001Gooo]Z1_l0000eoookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007cooo]Z1?l0000BoookJP[o
0000POoonfX009gooo]Z1?l0000FoookJPKo0000@?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX5o`0007gooo]Z1?l0000FoookJPKo0000POoonfX009gooo]Z1?l0000GoookJPKo0000?ooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001moookJPCo00005ooo
nfX6o`00083ooo]Z002MoookJPCo00005ooonfX7o`0003kooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Wooo]Z1Ol0001moookJPCo00006?oonfX6o`0007oooo]Z002MoookJPCo00006?oonfX7o`00
03gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001loookJPGo00006?oonfX6o`00
07oooo]Z002MoookJPCo00006OoonfX7o`0003cooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`ko
oo]Z1Ol0001loookJPGo00006OoonfX6o`0007kooo]Z002MoookJPCo00006_oonfX7o`0003cooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007cooo]Z1Ol0000JoookJPKo
0000OOoonfX009gooo]Z1?l0000KoookJPOo0000>ooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000
O?oonfX4o`0001_ooo]Z1ol0001loookJP00WOoonfX4o`0001cooo]Z1ol0000koookJPGo001o2_oo
nfX7o`00O`Sooo]Z1Ol0001loookJPCo00007?oonfX7o`0007_ooo]Z002MoookJPCo00007OoonfX7
o`0005Sooo]Z1Ol0001loookJPCo00007OoonfX7o`0007[ooo]Z002MoookJPCo00007_oonfX7o`00
05Oooo]Z1Ol0001loookJPCo00007_oonfX6o`0007[ooo]Z002MoookJPCo00007ooonfX7o`0005Ko
oo]Z1Ol0001loookJPCo00007ooonfX6o`0007Wooo]Z002MoookJPCo00008?oonfX7o`0005Gooo]Z
1Ol0001loookJPCo00008?oonfX6o`0007Sooo]Z002MoookJPCo00008OoonfX7o`0005Cooo]Z1Ol0
001loookJPCo00008?oonfX7o`0007Oooo]Z002MoookJPCo00008_oonfX7o`0005?ooo]Z1Ol0001l
oookJPCo00008OoonfX7o`0007Kooo]Z002MoookJPCo00008ooonfX8o`00057ooo]Z1Ol0001loook
JPCo00008_oonfX8o`0007Cooo]Z002MoookJPCo00009?oonfX8o`00053ooo]Z1Ol0001loookJPCo
00008ooonfX8o`0007?ooo]Z002MoookJPCo00009OoonfX8o`0004oooo]Z1Ol0001loookJPCo0000
9?oonfX8o`0007;ooo]Z002MoookJPCo00009_oonfX8o`0004kooo]Z1Ol0001loookJPCo00009Ooo
nfX8o`00077ooo]Z002LoookJPGo0000:?oonfX8o`0004cooo]Z1Ol0001loookJPCo00009ooonfX8
o`0006oooo]Z002LoookJPGo0000:OoonfX8o`0004_ooo]Z1Ol0001loookJPCo0000:?oonfX8o`00
06kooo]Z000RoookJP?o001oMOoonfX2o`00O`Go00000_oonfX3o`00O`?ooo]Z1Ol007lMoookJPSo
0000B_oonfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX5o`00Ob7ooo]Z2?l0001=oookJP?o
001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o1?l00003oookJP?o001o0_oonfX7o`00Oagooo]Z
2?l00019oookJPGo0000LooonfX7o`00O`;ooo]Z1?l00002oookJPOo001o8OoonfX8o`0004cooo]Z
0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00Oaoooo]Z1ol00018oookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
Ob?ooo]Z1ol0001;oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Cooo]Z0ol007l3oookJP?o
001o7ooonfX8o`0004Kooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o
000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ob?ooo]Z2?l00019oookJP?o001o7OoonfX001?o
oo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000002o`000003
o`00Oooonf[ooo]Z00[ooo]Z0ol007lPoookJPWo0000A?oonfX5o`0007;ooo]Z0ol007l3oookJP?o
001o00?ooo]Zo`000?l000000_l00007oookJP?o001o9?oonfX9o`0004Oooo]Z0ol007lMoookJP00
8_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00[ooo]Z
0ol007lQoookJP[o0000@_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l00000
0_l00007oookJP?o001o9OoonfX9o`0004Kooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol0
07l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l2oookJPCo001o8_oo
nfX:o`00047ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oo
nfX2o`00O`;ooo]Z1?l007lVoookJP[o0000A?oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3
o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX7o`00ObGooo]Z2_l0000o
oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1ol007lY
oookJP[o0000@_oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o0000
00;o000000?o001ooookJ_oonfX01OoonfX6o`00ObSooo]Z2_l0000moookJPGo0000L_oonfX3o`00
O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1_l007l/oookJPWo0000@OoonfX3o`00
Oagooo]Z000OoookJPKo001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oo
nfX01OoonfX2o`00Obkooo]Z2_l0000koookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o
0000o`000002o`0000;ooo]Z0_l007laoookJPco0000>_oonfX6o`00Oagooo]Z000OoookJPKo001o
M?oonfX3o`00O`Co00002?oonfX2o`00Oboooo]Z2ol0000ioookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l00002oookJP;o001o<ooonfX;o`0003Wooo]Z1_l007lMoookJP00
8OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol007l[oookJPco0000=_oonfX5o`0007?ooo]Z
1ol007l2oookJPCo00000ooonfX7o`00Oboooo]Z2_l0000joookJPCo001o7OoonfX002;ooo]Z0ol0
07meoookJP;o001o1?l00009oookJPOo001o;OoonfX<o`0003Cooo]Z1Ol0001doookJPGo001o0ooo
nfX4o`0000?ooo]Z1ol007l`oookJPko0000=_oonfX3o`00Oagooo]Z002LoookJPCo0000?ooonfX<
o`0003;ooo]Z1Ol0001loookJPCo0000?_oonfX:o`0005Kooo]Z002LoookJPCo0000@OoonfX<o`00
033ooo]Z1Ol0001loookJPCo0000?ooonfX?o`00053ooo]Z002LoookJPCo0000A?oonfX<o`0002go
oo]Z1Ol0001loookJPCo0000@?oonfXBo`0004cooo]Z002LoookJPCo0000A_oonfX>o`0002Wooo]Z
1Ol0001loookJPCo0000A?oonfX?o`0004_ooo]Z002LoookJPCo0000B?oonfXAo`0002Cooo]Z1Ol0
001loookJPCo0000AOoonfXDo`0004Gooo]Z002LoookJPCo0000B_oonfXJo`0001Wooo]Z1Ol0001l
oookJPCo0000B_oonfXIo`0003_ooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000LoookJPGo000000?ooo]Zo`00
0?l000000_l000000ooonf[o0000o`000003o`000003oookJ_l0003o000002;o0000BooonfX4o`00
07?ooo]Z1?l000000ooonf[o0000o`000008o`0000;ooo]Z1?l00002oookJRWo0000BooonfX4o`00
07?ooo]Z1?l00002oookJPCo00000_oonfX00ol0003ooo]ZoookJP0LoookJP00>?oonfXJo`0004[o
oo]Z1?l0001moookJPGo00006OoonfXIo`0004[ooo]Z1?l0002NoookJP00@ooonfXDo`0004Gooo]Z
1?l0001moookJPGo00008ooonfXDo`0004Gooo]Z1?l0002NoookJP00BOoonfX?o`0004Cooo]Z1?l0
001moookJPGo0000:?oonfX@o`0004Cooo]Z1?l0002NoookJP00BOoonfXCo`00043ooo]Z1?l0001m
oookJPGo0000:OoonfXCo`00043ooo]Z1?l0002NoookJP00C_oonfX?o`0003oooo]Z1?l0001moook
JPGo0000;ooonfX>o`0003oooo]Z1?l0002NoookJP00E?oonfX:o`0003kooo]Z1?l0001moookJPGo
0000=?oonfX:o`0003kooo]Z1?l0002NoookJP00E?oonfX>o`0003[ooo]Z1?l0001moookJPGo0000
=?oonfX>o`0003[ooo]Z1?l0002NoookJP00EOoonfX>o`0003Wooo]Z1?l0001moookJPGo0000=_oo
nfX=o`0003Wooo]Z1?l0002NoookJP00FOoonfX;o`0003Sooo]Z1?l0001moookJPGo0000>_oonfX9
o`0003Wooo]Z1?l0002NoookJP00FooonfX=o`0003Cooo]Z1?l0001moookJPGo0000>_oonfX=o`00
03Gooo]Z1?l0002NoookJP00G_oonfX:o`0003Cooo]Z1?l0001moookJPGo0000?ooonfX9o`0003Co
oo]Z1?l0002NoookJP00H?oonfX9o`0003?ooo]Z1?l0001moookJPGo0000?ooonfX:o`0003;ooo]Z
1Ol0002NoookJP00H?oonfX:o`0003;ooo]Z1?l0001moookJPGo0000@?oonfX<o`0002oooo]Z1Ol0
002NoookJP00I?oonfX7o`00037ooo]Z1?l0001moookJPGo0000A?oonfX:o`0002gooo]Z1Ol0002N
oookJP00IOoonfX7o`00033ooo]Z1?l0001moookJPGo0000AOoonfX9o`0002gooo]Z1?l0002Ooook
JP00I_oonfX8o`0002kooo]Z1?l0001moookJPGo0000AOoonfX:o`0002cooo]Z1?l0002OoookJP00
I_oonfX9o`0002gooo]Z1?l0001moookJPGo0000AooonfX;o`0002Wooo]Z1?l0002OoookJP00J?oo
nfX8o`0002cooo]Z1?l0001moookJPGo0000B_oonfX9o`0002Sooo]Z1?l0002OoookJP00JOoonfX9
o`0002[ooo]Z1?l0001moookJPGo0000BooonfX9o`0002Oooo]Z1?l0002OoookJP00JooonfX8o`00
02Wooo]Z1?l0001moookJPGo0000C?oonfX9o`0002Kooo]Z1?l0002OoookJP00K?oonfX9o`0002Oo
oo]Z1?l0001moookJPGo0000C?oonfX:o`0002Gooo]Z1?l0002OoookJP00KOoonfX9o`0002Kooo]Z
1?l0001moookJPGo0000CooonfX8o`0002Cooo]Z1?l0002OoookJP00KooonfX8o`0002Gooo]Z1?l0
001moookJPGo0000DOoonfX7o`0002?ooo]Z1?l0002OoookJP00L?oonfX8o`0002Cooo]Z1?l0001m
oookJPGo0000D_oonfX7o`0002;ooo]Z1?l0002OoookJP00L_oonfX7o`0002?ooo]Z1?l0001moook
JPGo0000DooonfX7o`00027ooo]Z1?l0002OoookJP00LooonfX7o`0002;ooo]Z1?l0001moookJPGo
0000E?oonfX7o`00023ooo]Z1?l0002OoookJP00M?oonfX7o`00027ooo]Z1?l0001moookJPGo0000
EOoonfX7o`0001oooo]Z1?l0002OoookJP00MOoonfX7o`00023ooo]Z1?l0001moookJPGo0000E_oo
nfX7o`0001kooo]Z1?l0002OoookJP00M_oonfX7o`0001oooo]Z1?l0001moookJPGo0000EooonfX7
o`0001gooo]Z1?l0002OoookJP00MooonfX7o`0001kooo]Z1?l0001moookJPGo0000F?oonfX7o`00
01cooo]Z1?l0002OoookJP00N?oonfX7o`0001cooo]Z1Ol0001moookJPGo0000FOoonfX7o`0001_o
oo]Z1?l0002OoookJP00NOoonfX7o`0001_ooo]Z1Ol0001moookJPGo0000F_oonfX7o`0001[ooo]Z
1?l0002OoookJP00N_oonfX7o`0001[ooo]Z1Ol0001moookJPGo0000FooonfX7o`0001Wooo]Z1?l0
002OoookJP00NooonfX7o`0001Wooo]Z1?l0001noookJPGo0000G?oonfX7o`0001Sooo]Z1?l0002O
oookJP00O?oonfX7o`0001Sooo]Z1?l0001PoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oook
JPGo0000GOoonfX7o`0001Oooo]Z1?l0002OoookJP00OOoonfX7o`0001Oooo]Z1?l0001OoookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000G_oonfX7o`0001Kooo]Z1?l0002OoookJP00
O_oonfX7o`0001Kooo]Z1?l0001OoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005oooo]Z1ol0000Eoook
JPCo0000WooonfX007oooo]Z1ol0000EoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Sooo]Z1Ol0001PoookJPOo00005?oonfX4o`0009oooo]Z0020oookJPOo0000
5?oonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001PoookJPOo0000
4ooonfX4o`0009oooo]Z0021oookJPOo00004ooonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Sooo]Z1Ol0001RoookJPOo00004_oonfX4o`0009oooo]Z0022oookJPOo00004_oonfX4
o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000HooonfX6
o`0001;ooo]Z1?l0002OoookJP00PooonfX7o`00017ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l9oookJPGo0000I?oonfX6o`00017ooo]Z1?l0002OoookJP00Q?oonfX6o`00017o
oo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000IOoonfX6o`00013o
oo]Z1?l0002OoookJP00QOoonfX6o`00013ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l>oookJPGo0000IOoonfX6o`00013ooo]Z1?l0002OoookJP00Q_oonfX6o`0000oooo]Z1?l0
001OoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001VoookJPKo0000
3ooonfX4o`0009oooo]Z0026oookJPOo00003_oonfX4o`0005oooo]Z1ol007l9oookJPOo001o2?oo
nfX5o`0006Oooo]Z1Ol0000?oookJPCo0000WooonfX008Oooo]Z1ol0000=oookJPCo0000H?oonfX5
o`00O`[ooo]Z1ol007l8oookJPGo0000IooonfX6o`0000kooo]Z1?l0002OoookJP00R?oonfX7o`00
00cooo]Z1?l0001noookJPGo0000J?oonfX6o`0000gooo]Z1?l0002OoookJP00ROoonfX7o`0000_o
oo]Z1?l0001noookJPGo0000J?oonfX6o`0000gooo]Z1?l0002OoookJP00R_oonfX6o`0000_ooo]Z
1?l0001noookJPGo0000JOoonfX6o`0000cooo]Z1?l0002OoookJP00RooonfX6o`0000[ooo]Z1?l0
001noookJPGo0000J_oonfX6o`0000_ooo]Z1?l0002OoookJP00S?oonfX6o`0000Wooo]Z1?l0001n
oookJPGo0000J_oonfX7o`0000[ooo]Z1?l0002OoookJP00S?oonfX7o`0000Sooo]Z1?l0001noook
JPGo0000JooonfX7o`0000Wooo]Z1?l0002OoookJP00SOoonfX7o`0000Oooo]Z1?l0001noookJPGo
0000K?oonfX7o`0000Sooo]Z1?l0002OoookJP00S_oonfX7o`0000Kooo]Z1?l0001noookJPGo0000
KOoonfX7o`0000Oooo]Z1?l0002OoookJP00SooonfX6o`0000Kooo]Z1?l0001noookJPGo0000K_oo
nfX7o`0000Kooo]Z1?l0002OoookJP00T?oonfX5o`0000Kooo]Z1?l0001noookJPGo0000KooonfX6
o`0000Kooo]Z1?l0002OoookJP00TOoonfX4o`0000Kooo]Z1?l0001noookJPGo0000L?oonfX5o`00
00Kooo]Z1?l0002OoookJP00TOoonfX5o`0000Gooo]Z1?l0001noookJPGo0000LOoonfX5o`0000Go
oo]Z1?l0002OoookJP00TOoonfX5o`0000Gooo]Z1?l0001noookJPGo0000LOoonfX5o`0000Cooo]Z
1Ol0002OoookJP00TOoonfX9o`000003oookJ_l0003o000000;o0000O_oonfX5o`00077ooo]Z3_l0
002OoookJP00T_oonfX8o`000003oookJ_l0003o000000;o0000O_oonfX5o`0007;ooo]Z3Ol0002O
oookJP00T_oonfX=o`0007kooo]Z1Ol0001boookJPco0000X?oonfX009;ooo]Z3Ol0001noookJPGo
0000L_oonfX<o`000:3ooo]Z002BoookJPgo0000O_oonfX5o`0007;ooo]Z3?l0002PoookJP00T_oo
nfX=o`0007kooo]Z1Ol0001boookJPco0000X?oonfX009;ooo]Z3Ol0001noookJPGo0000L_oonfX<
o`000:3ooo]Z002BoookJPgo0000O_oonfX5o`0007;ooo]Z3?l0002PoookJP00T_oonfX=o`0007ko
oo]Z1Ol0001coookJP_o0000X?oonfX009?ooo]Z3?l0001noookJPGo0000LooonfX;o`000:3ooo]Z
002CoookJPco0000O_oonfX5o`0007?ooo]Z2ol0002PoookJP00TooonfX<o`0007kooo]Z1Ol0001d
oookJP[o0000X?oonfX009Cooo]Z2ol0001noookJPGo0000M?oonfX:o`000:3ooo]Z002GoookJPSo
0000O_oonfX5o`0007Oooo]Z1ol0002PoookJP00UooonfX8o`0007kooo]Z1Ol0001hoookJPKo0000
X?oonfX009Oooo]Z2?l0001noookJPGo0000N?oonfX6o`000:3ooo]Z002GoookJPSo0000LOoonfX3
o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1ol0001aoookJP?o001o2_oonfX5o`00
07Sooo]Z1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3o
oo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0
001boookJP?o001o2_oonfX6o`0007Oooo]Z1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:
oookJPGo0000N?oonfX6o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoook
JPKo0000X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00
V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002HoookJPKo0000Kooo
nfX6o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001_oookJPKo001o2_oonfX5
o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`00077ooo]Z1?l007l:oookJPGo0000NOoonfX5o`00
0:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z
1?l00020oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPCo0000P?oonfX5o`0007Wooo]Z1?l0
002QoookJP00VOoonfX4o`00083ooo]Z1Ol0001ioookJPCo0000XOoonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo
001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o
2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>
oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oook
JPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo
0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003ooookJP;ooo]Z0ol007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9
oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00
oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0
003ooookJQoooo]Z003ooookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oook
JPGo001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQ;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooo
nfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00
O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00
oooonfX>oookJPOo001ooooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.04262 .31 L
.0522 .31034 L
.05472 .30923 L
.05542 .30882 L
.05615 .3085 L
.05746 .3084 L
.05869 .3089 L
.05983 .30968 L
.06109 .31045 L
.0618 .3107 L
.06244 .31076 L
.06314 .31063 L
.06378 .31037 L
.06449 .30998 L
.06524 .30952 L
.06596 .30914 L
.06663 .30891 L
.0679 .30896 L
.06914 .30959 L
.07028 .31043 L
.07153 .3112 L
.07216 .31141 L
.07286 .31145 L
.07412 .31105 L
.07528 .31039 L
.07591 .31004 L
.07661 .30977 L
.07787 .30972 L
.07905 .31025 L
.0803 .3112 L
.0814 .31201 L
.08255 .31248 L
.0832 .3125 L
.08391 .31234 L
.08515 .31173 L
.08585 .31133 L
.0866 .311 L
.08731 .31084 L
.08795 .31088 L
.08921 .31146 L
.08991 .312 L
.09056 .31256 L
.09176 .31349 L
.09302 .31399 L
.09374 .31397 L
.09439 .31378 L
.09515 .31342 L
.09587 .31302 L
.09714 .31252 L
Mistroke
.09786 .31248 L
.09853 .31264 L
.09932 .31309 L
.10007 .3137 L
.10146 .31498 L
.10224 .31557 L
.10296 .3159 L
.10375 .31601 L
.10458 .31584 L
.1058 .31527 L
.10645 .31494 L
.10714 .3147 L
.10839 .3147 L
.10955 .31534 L
.11173 .31746 L
.11296 .31835 L
.11408 .31861 L
.1153 .31829 L
.11658 .31768 L
.1177 .31736 L
.11892 .3176 L
.11962 .31806 L
.12026 .31865 L
.12169 .32023 L
.12301 .32143 L
.12426 .32187 L
.1426 .3291 L
.16266 .3403 L
.18112 .35202 L
.19084 .36021 L
.19992 .36901 L
.22058 .39238 L
.23919 .42151 L
.24046 .41896 L
.24117 .41891 L
.24182 .42011 L
.24302 .42552 L
.24429 .43417 L
.24552 .4421 L
.24622 .44499 L
.24687 .44609 L
.24759 .44537 L
.24824 .44308 L
.249 .43908 L
.24971 .43484 L
.25089 .42968 L
.25214 .43095 L
.25321 .43944 L
.25438 .4551 L
.25565 .4729 L
Mistroke
.25635 .4796 L
.257 .48154 L
.25826 .46933 L
.25945 .43485 L
.26198 .30441 L
.26322 .23475 L
.26437 .1828 L
.26569 .14624 L
.26638 .13805 L
.26711 .13681 L
.2683 .14679 L
.2696 .1655 L
.27034 .17552 L
.27103 .18285 L
.27184 .18779 L
.27257 .18886 L
.27326 .18731 L
.2739 .18432 L
.27464 .17996 L
.27534 .17604 L
.27657 .17206 L
.27722 .17221 L
.27792 .17422 L
.27862 .17781 L
.27936 .1827 L
.28067 .19179 L
.28193 .19776 L
.28308 .19925 L
.28371 .19859 L
.2844 .1971 L
.28565 .19388 L
.28682 .19243 L
.28806 .19414 L
.28911 .19813 L
.29028 .20384 L
.29098 .20715 L
.29165 .20976 L
.2929 .21248 L
.29359 .2127 L
.29424 .21223 L
.29495 .21126 L
.29571 .21013 L
.29637 .20943 L
.29708 .20925 L
.29837 .21101 L
.29963 .21503 L
.30078 .21954 L
.30205 .22369 L
.30325 .22567 L
.30433 .22575 L
Mistroke
.3055 .22475 L
.30678 .22386 L
.30742 .22395 L
.30813 .22465 L
.30938 .2274 L
.31055 .23109 L
.31173 .23471 L
.31284 .23712 L
.31385 .23804 L
.31494 .23788 L
.31612 .2371 L
.31739 .23678 L
.31858 .23782 L
.31966 .24001 L
.32095 .2435 L
.32215 .24659 L
.3234 .24864 L
.32406 .2491 L
.32477 .24916 L
.32555 .24887 L
.32628 .24848 L
.32694 .24823 L
.32766 .24824 L
.32832 .24862 L
.32903 .24947 L
.33031 .252 L
.33143 .2547 L
.3326 .25722 L
.33389 .25883 L
.33508 .2591 L
.33637 .25861 L
.33711 .25835 L
.33779 .25832 L
.33902 .25913 L
.34034 .26124 L
.34168 .26407 L
.34293 .2664 L
.34423 .26774 L
.34492 .26794 L
.34567 .26783 L
.34698 .26733 L
.34823 .26724 L
.34936 .268 L
.35058 .26977 L
.35202 .27247 L
.35272 .27369 L
.35337 .27461 L
.35412 .27533 L
.35493 .27567 L
.35561 .27565 L
Mistroke
.35634 .27543 L
.35766 .27497 L
.35888 .27512 L
.35959 .27562 L
.36023 .27634 L
.36168 .27862 L
.36293 .28065 L
.36356 .28145 L
.36426 .28207 L
.36549 .28243 L
.36664 .28212 L
.3673 .28186 L
.36799 .28166 L
.36924 .28181 L
.36993 .28228 L
.37057 .28295 L
.37203 .28505 L
.37331 .28687 L
.37451 .28796 L
.3756 .28823 L
.37677 .28793 L
.37805 .28744 L
.37869 .28734 L
.3794 .28745 L
.38066 .28832 L
.38183 .28975 L
.38308 .29144 L
.38377 .29222 L
.38442 .29276 L
.38556 .29316 L
.38682 .2929 L
.38809 .29236 L
.38873 .29219 L
.38943 .29219 L
.3902 .29247 L
.39091 .29299 L
.39156 .29366 L
.39226 .2945 L
.39353 .29603 L
.39425 .2967 L
.39492 .2971 L
.39614 .29726 L
.39743 .29681 L
.39851 .29634 L
.39968 .29618 L
.40095 .29671 L
.40215 .29783 L
.40329 .29911 L
.40452 .30022 L
.40522 .30057 L
Mistroke
.40586 .30069 L
.40711 .30041 L
.40828 .29985 L
.40954 .29944 L
.41073 .29963 L
.41183 .30036 L
.41291 .30141 L
.41406 .30253 L
.41515 .30324 L
.41614 .30342 L
.41725 .30314 L
.41831 .30261 L
.41945 .30212 L
.42069 .30209 L
.42191 .3027 L
.42303 .30366 L
.42423 .30474 L
.42554 .30548 L
.42669 .30551 L
.42776 .30511 L
.42888 .3045 L
.43009 .30406 L
.4308 .30405 L
.43145 .30422 L
.43272 .30503 L
.43396 .30608 L
.43511 .30688 L
.43635 .3072 L
.43701 .3071 L
.43772 .30682 L
.43841 .30645 L
.43915 .30604 L
.43984 .30572 L
.44047 .30555 L
.44114 .30554 L
.44186 .30574 L
.44317 .30656 L
.4446 .30767 L
.44532 .3081 L
.4461 .30835 L
.4468 .30835 L
.44755 .30815 L
.44825 .3078 L
.44889 .30743 L
.45021 .30676 L
.45145 .30659 L
.45266 .30703 L
.45395 .30792 L
.45506 .30869 L
.45626 .30915 L
Mistroke
.45754 .30902 L
.45874 .30841 L
.45948 .30796 L
.46018 .30759 L
.46148 .30727 L
.4627 .30757 L
.46401 .30838 L
.46533 .30925 L
.46599 .30954 L
.46671 .30968 L
.46802 .3094 L
.46924 .30871 L
.47036 .30806 L
.47157 .30769 L
.47231 .30774 L
.473 .30798 L
.47366 .30833 L
.47435 .30879 L
.47556 .30955 L
.47625 .30983 L
.47689 .30994 L
.47759 .30988 L
.47832 .30962 L
.47964 .30885 L
.48032 .30843 L
.48105 .30808 L
.48185 .30789 L
.4826 .30795 L
.48325 .30816 L
.48395 .30853 L
.48519 .30933 L
.48584 .3097 L
.48653 .30996 L
.48729 .31005 L
.48801 .30993 L
.48866 .30966 L
.48938 .30925 L
.49068 .30844 L
.49194 .30798 L
.49312 .30808 L
.49437 .30869 L
.49555 .30944 L
.4966 .30994 L
.49775 .31006 L
.499 .30963 L
.50032 .30881 L
.50144 .3082 L
.50268 .30796 L
.50399 .30834 L
.5052 .30907 L
Mistroke
.50588 .3095 L
.50652 .30982 L
.50719 .31003 L
.50793 .31007 L
.50918 .30967 L
.51032 .30898 L
.51158 .30826 L
.5129 .30798 L
.51401 .30827 L
.51521 .30896 L
.51623 .30961 L
.51735 .31008 L
.51866 .31005 L
.5199 .30948 L
.52101 .30878 L
.52221 .30821 L
.52351 .30814 L
.52473 .30865 L
.52606 .30952 L
.52676 .30994 L
.5275 .31024 L
.52828 .31035 L
.529 .31023 L
.52975 .30992 L
.53043 .30953 L
.53111 .30911 L
.53182 .30871 L
.5331 .30836 L
.53429 .30859 L
.53559 .30937 L
.53688 .31024 L
.53761 .31059 L
.53827 .31075 L
.53956 .31055 L
.54079 .30991 L
.54201 .3092 L
.54313 .30886 L
.54428 .30903 L
.54551 .30972 L
.54667 .31058 L
.54775 .31121 L
.54899 .31145 L
.54965 .31133 L
.55035 .31103 L
.55164 .31029 L
.55283 .30976 L
.55347 .30966 L
.55416 .30974 L
.55485 .31002 L
.5556 .3105 L
Mistroke
.55686 .3115 L
.55756 .31199 L
.55822 .31232 L
.55954 .31248 L
.56074 .31206 L
.56186 .31143 L
.5631 .31091 L
.56425 .31091 L
.56533 .31141 L
.56646 .31231 L
.56769 .31332 L
.56877 .31389 L
.5699 .31397 L
.57087 .31365 L
.57193 .31309 L
.57319 .31255 L
.57434 .31252 L
.57566 .3132 L
.57691 .31431 L
.57799 .31526 L
.57913 .3159 L
.58039 .31595 L
.58154 .3155 L
.58275 .3149 L
.58407 .31461 L
.58532 .31504 L
.58647 .31599 L
.5876 .31714 L
.58865 .31806 L
.58987 .31858 L
.59098 .31848 L
.5922 .31795 L
.59335 .31746 L
.59454 .31739 L
.59585 .31809 L
.59654 .31875 L
.59717 .31944 L
.59785 .3202 L
.59859 .32095 L
.59989 .32176 L
.60111 .3218 L
.60225 .32137 L
.60331 .32091 L
.60447 .32076 L
.60573 .32132 L
.60698 .32258 L
.60829 .32419 L
.60941 .3253 L
.61063 .32585 L
.61942 .3298 L
Mistroke
.63907 .34067 L
.65006 .3493 L
.66003 .3575 L
.68087 .37923 L
.70006 .40181 L
.70974 .41428 L
.71878 .42314 L
.71999 .43069 L
.72131 .43983 L
.72256 .44539 L
.72371 .44552 L
.72475 .44153 L
.72589 .43488 L
.72709 .42967 L
.72821 .43044 L
.72947 .4402 L
.73062 .45575 L
.73127 .46534 L
.73196 .47435 L
.73321 .48153 L
.73446 .46915 L
.73517 .45111 L
.73582 .42775 L
.73724 .35824 L
.73858 .28105 L
.73973 .21907 L
.74096 .16865 L
.74213 .14241 L
.74319 .13657 L
.74444 .1462 L
.74515 .15595 L
.7458 .16567 L
.747 .18079 L
.74828 .18851 L
.74897 .18862 L
.74961 .18666 L
.75032 .18304 L
.75106 .17863 L
.7523 .17294 L
.75301 .17192 L
.75367 .17274 L
.75491 .17839 L
.75603 .18618 L
.75726 .19412 L
.75856 .19878 L
.75968 .19892 L
.76092 .19623 L
.76206 .19343 L
.7631 .19244 L
.76433 .19437 L
Mistroke
.76565 .19974 L
.76688 .20585 L
.76803 .21039 L
.76904 .21244 L
.77012 .21252 L
.77132 .21099 L
.77241 .20955 L
.77354 .20939 L
.77477 .21155 L
.77593 .21547 L
.77701 .21967 L
.77826 .22373 L
.77945 .22568 L
.78052 .22575 L
.78168 .22476 L
.78295 .22386 L
.78365 .22397 L
.78429 .22461 L
.78554 .2273 L
.78671 .23097 L
.78781 .23442 L
.78898 .23703 L
.78998 .23802 L
.79107 .23791 L
.79225 .23714 L
.79351 .23677 L
.7947 .23772 L
.79578 .23984 L
.79705 .24327 L
.79825 .24639 L
.79949 .24854 L
.80016 .24906 L
.80087 .24917 L
.80163 .24892 L
.80237 .24854 L
.80302 .24826 L
.80374 .24821 L
.8044 .24853 L
.80511 .24931 L
.80639 .25175 L
.80769 .25488 L
.80838 .25642 L
.8091 .25773 L
.80973 .25854 L
.81043 .25902 L
.81165 .25899 L
.81284 .25849 L
.81412 .25835 L
.81532 .25926 L
.81642 .26103 L
Mistroke
.81762 .26353 L
.8189 .26605 L
.82011 .26754 L
.82123 .26794 L
.82241 .26763 L
.82365 .26721 L
.82493 .26747 L
.82565 .26812 L
.82633 .26903 L
.82742 .27097 L
.82861 .27319 L
.82973 .2748 L
.83076 .27557 L
.83197 .27561 L
.83324 .27515 L
.83431 .27493 L
.8355 .27538 L
.83616 .27602 L
.83688 .27699 L
.8382 .27918 L
.83949 .28115 L
.84066 .2822 L
.84138 .28242 L
.84206 .28237 L
.84277 .28215 L
.84355 .28184 L
.84422 .28165 L
.84494 .28165 L
.84622 .28237 L
.85625 .2878 L
.87614 .29623 L
.88482 .29969 L
.88596 .29943 L
.88719 .29976 L
.88834 .30065 L
.8894 .30172 L
.89053 .30275 L
.89171 .30336 L
.89293 .30332 L
.89362 .30306 L
.89426 .30273 L
.89558 .30214 L
.89678 .30206 L
.89745 .30229 L
.89817 .30275 L
.89947 .30391 L
.90069 .30495 L
.90198 .30554 L
.90309 .30546 L
.9043 .30492 L
Mistroke
.90551 .3043 L
.90666 .30403 L
.9073 .30411 L
.90799 .30439 L
.90921 .30527 L
.91036 .30625 L
.91159 .30701 L
.91264 .30719 L
.91379 .30688 L
.91511 .30616 L
.91583 .3058 L
.9165 .30558 L
.91768 .30561 L
.91898 .30628 L
.92037 .30737 L
.92169 .30818 L
.92241 .30836 L
.9232 .30832 L
.92392 .30807 L
.92458 .30772 L
.92571 .30707 L
.92692 .30661 L
.92762 .30659 L
.92825 .30675 L
.9295 .30745 L
.93078 .30839 L
.9315 .30883 L
.93218 .30909 L
.93341 .30911 L
.93472 .30854 L
.93537 .30815 L
.93606 .30774 L
.93732 .3073 L
.93863 .30746 L
.93938 .30783 L
.94006 .30828 L
.94127 .30911 L
.94259 .30964 L
.94383 .30954 L
.94498 .30899 L
.94621 .30824 L
.9469 .3079 L
.94754 .30772 L
.94824 .3077 L
.94899 .30789 L
.94964 .30821 L
.95036 .30867 L
.95109 .30916 L
.95179 .30957 L
.95259 .30987 L
Mistroke
.95332 .30994 L
.95464 .30955 L
.95539 .30913 L
.95607 .30869 L
.95723 .30808 L
.95848 .3079 L
.95965 .30826 L
.96073 .30891 L
.96198 .30967 L
.96269 .30995 L
.96335 .31005 L
.96456 .3098 L
.96585 .30907 L
.9665 .30866 L
.96719 .30828 L
.96795 .30801 L
.96864 .30796 L
.9699 .30832 L
.97061 .30872 L
.97127 .30915 L
.97252 .30984 L
.97365 .31007 L
.97495 .30974 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00W_oonfX5o`0007[ooo]Z1Ol0001ooookJPCo
0000VooonfX009kooo]Z1Ol0001joookJPGo0000OooonfX4o`0009_ooo]Z002NoookJPGo0000N_oo
nfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX0
09kooo]Z1Ol0001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000N_oonfX5o`0007ko
oo]Z1Ol0002KoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z
002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001]
oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX5o`0005gooo]Z2_l007l6oook
JP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX5o`0005gooo]Z2_l007l6oookJP?o
001o2_oonfX6o`0007gooo]Z1_l0002JoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000
O_oonfX6o`0009[ooo]Z002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oo
nfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`00
06cooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPKo0000JOoonfX6o`00O`[o
oo]Z1Ol0001noookJPKo0000V_oonfX009gooo]Z1ol0001YoookJPKo001o2_oonfX5o`0007kooo]Z
1_l0002JoookJP00WOoonfX7o`0006_ooo]Z1?l007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002M
oookJPOo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009gooo]Z2ol0001eoook
JPGo0000O_oonfX:o`0009Kooo]Z002MoookJPco0000M?oonfX5o`0007kooo]Z2_l0002FoookJP00
WOoonfX<o`0007Cooo]Z1Ol0001noookJP_o0000UOoonfX009gooo]Z3?l0001doookJPGo0000O_oo
nfX;o`0009Gooo]Z002MoookJPco0000M?oonfX5o`0007kooo]Z2ol0002EoookJP00WOoonfX<o`00
07Cooo]Z1Ol0001noookJP_o0000UOoonfX009gooo]Z3?l0001doookJPGo0000O_oonfX<o`0009Co
oo]Z002MoookJPco0000M?oonfX5o`0007kooo]Z3?l0002DoookJP00WOoonfX<o`0007Cooo]Z1Ol0
001noookJPco0000U?oonfX009gooo]Z3Ol0001coookJPGo0000O_oonfX<o`0009Cooo]Z002Moook
JPgo0000LooonfX5o`0007kooo]Z3?l0002DoookJP00WOoonfX@o`00073ooo]Z1Ol0001noookJQ3o
0000T?oonfX009gooo]Z1?l000000ooonf[o0000o`00000:o`0006oooo]Z1Ol0001moookJQ7o0000
T?oonfX009gooo]Z1?l00005oookJPSo0000KooonfX5o`0007gooo]Z1Ol00004oookJPSo0000T?oo
nfX009gooo]Z1?l00005oookJPWo0000K_oonfX5o`0007gooo]Z1Ol00004oookJPWo0000SooonfX0
09gooo]Z1?l00005oookJPWo0000K_oonfX5o`0007gooo]Z1?l00005oookJPWo0000SooonfX009go
oo]Z1?l00006oookJPSo0000K_oonfX5o`0007gooo]Z1?l00005oookJPWo0000SooonfX009gooo]Z
1?l00006oookJPSo0000K_oonfX5o`0007gooo]Z1?l00006oookJPWo0000S_oonfX009gooo]Z1?l0
0006oookJPSo0000K_oonfX5o`0007gooo]Z1?l0000:oookJPGo0000S_oonfX009gooo]Z1?l0000:
oookJPGo0000KOoonfX5o`0007gooo]Z1?l0000:oookJPGo0000S_oonfX009gooo]Z1?l0000:oook
JPSo0000J_oonfX5o`0007gooo]Z1?l0000;oookJPOo0000RooonfX009gooo]Z1?l0000:oookJPWo
0000JOoonfX5o`0007gooo]Z1?l0000;oookJPSo0000R_oonfX009gooo]Z1?l0000;oookJPSo0000
JOoonfX5o`0007gooo]Z1?l0000;oookJPSo0000R_oonfX009gooo]Z1?l0000;oookJPSo0000JOoo
nfX5o`0007gooo]Z1?l0000;oookJPWo0000ROoonfX009gooo]Z1?l0000;oookJPSo0000JOoonfX5
o`0007gooo]Z1?l0000;oookJPWo0000ROoonfX009gooo]Z1?l0000<oookJPSo0000J?oonfX5o`00
07gooo]Z1?l0000<oookJPSo0000ROoonfX009gooo]Z1?l0000?oookJPGo0000J?oonfX5o`0007go
oo]Z1?l0000@oookJPCo0000ROoonfX009gooo]Z1?l0000?oookJPGo0000J?oonfX5o`0007gooo]Z
1?l0000@oookJPCo0000ROoonfX009gooo]Z1?l0000@oookJPSo0000I?oonfX5o`0007gooo]Z1?l0
000@oookJPSo0000QOoonfX009gooo]Z1?l0000@oookJPSo0000A_oonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o2_oonfX5o`0007gooo]Z1?l0000@oookJPSo0000QOoonfX009gooo]Z1?l0000@oook
JPWo0000A?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0007gooo]Z1?l0000@oook
JPWo0000Q?oonfX009gooo]Z1?l0000AoookJPSo0000A?oonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001m
oookJPCo00004OoonfX8o`0008Cooo]Z002MoookJPCo00004OoonfX8o`0003Oooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0007gooo]Z1?l0000Aoook
JPSo0000Q?oonfX009gooo]Z1?l0000EoookJPCo0000=ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Sooo]Z1_l0001loookJPCo00005OoonfX4o`0008Cooo]Z002MoookJPCo0000
5OoonfX5o`0004;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001moookJPCo0000
5OoonfX5o`0008?ooo]Z002MoookJPCo00005OoonfX9o`0003kooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l8oookJPGo0000OOoonfX4o`0001Gooo]Z2Ol0001ooookJP00WOoonfX4
o`0001Gooo]Z2Ol0000noookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000OOoonfX4
o`0001Gooo]Z2Ol0001ooookJP00WOoonfX4o`0001Kooo]Z2?l0000noookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007l:oookJPGo0000OOoonfX4o`0001Kooo]Z2?l0001ooookJP00WOoonfX4o`0001Oo
oo]Z1ol0000noookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Oo
oo]Z2?l0001noookJP00WOoonfX4o`0001Oooo]Z2?l0000noookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00O`kooo]Z1Ol0001moookJPCo00005ooonfX8o`0007kooo]Z002MoookJPCo0000
6_oonfX6o`0003gooo]Z1ol007l9oookJPOo001o2?oonfX5o`0007gooo]Z1?l0000JoookJPKo0000
OOoonfX009gooo]Z1?l0000JoookJPWo0000>ooonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000OOoo
nfX4o`0001_ooo]Z2?l0001joookJP00WOoonfX4o`0001_ooo]Z2?l0001IoookJPGo0000OOoonfX4
o`0001_ooo]Z2?l0001joookJP00WOoonfX4o`0001cooo]Z2?l0001HoookJPGo0000O?oonfX5o`00
01cooo]Z2?l0001ioookJP00WOoonfX4o`0001cooo]Z2?l0001HoookJPGo0000O?oonfX5o`0001co
oo]Z2?l0001ioookJP00WOoonfX4o`0001gooo]Z2?l0001GoookJPGo0000O?oonfX5o`0001gooo]Z
2?l0001hoookJP00WOoonfX4o`00023ooo]Z1Ol0001GoookJPGo0000O?oonfX4o`00027ooo]Z1_l0
001goookJP00WOoonfX4o`00023ooo]Z2Ol0001CoookJPGo0000O?oonfX4o`00027ooo]Z2Ol0001d
oookJP00WOoonfX4o`00027ooo]Z2?l0001CoookJPGo0000O?oonfX4o`0002;ooo]Z2?l0001doook
JP00WOoonfX4o`00027ooo]Z2?l0001CoookJPGo0000O?oonfX4o`0002;ooo]Z2Ol0001coookJP00
WOoonfX4o`0002;ooo]Z2?l0001BoookJPGo0000O?oonfX4o`0002?ooo]Z2?l0001coookJP00WOoo
nfX4o`0002Gooo]Z2Ol0001>oookJPGo0000O?oonfX4o`0002Kooo]Z2?l0001`oookJP00WOoonfX4
o`0002Gooo]Z2Ol0001>oookJPGo0000O?oonfX4o`0002Oooo]Z2Ol0001^oookJP00WOoonfX4o`00
02Kooo]Z2Ol0001=oookJPGo0000O?oonfX4o`0002Oooo]Z2Ol0001^oookJP008_oonfX3o`00OgGo
oo]Z0_l007l5o`0000;ooo]Z0ol007l3oookJPGo001o6_oonfX9o`0004cooo]Z1Ol0001doookJPGo
001o0ooonfX4o`0000?ooo]Z1Ol007lPoookJPSo0000C_oonfX3o`00Oagooo]Z000RoookJP?o001o
M?oonfX3o`00O`Go00000_oonfX3o`00O`;ooo]Z1ol007lJoookJPWo0000BooonfX5o`0007?ooo]Z
1ol007l2oookJPCo00000_oonfX7o`00Oaoooo]Z2_l0001<oookJP?o001o7OoonfX002;ooo]Z0ol0
07mdoookJP?o001o1Ol00002oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007lMoookJPWo0000B?oonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo
000000?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lSoookJPWo0000BOoonfX3o`00
Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o00?ooo]Zo`000?l0
00000_l000000ol007oooo]ZoookJP04oookJP?o001o0ooonfX3o`00Oagooo]Z2?l00018oookJPGo
0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`000004oookJ_l007oo001oo`00
O`?ooo]Z0ol007lRoookJP[o0000B?oonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOo
oo]Z2_l007l2oookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o
001o7OoonfX9o`0004Oooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o
00001ooonfX3o`00Ob?ooo]Z2Ol00018oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o
00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o001o7_oonfX<o`0004?ooo]Z
1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00001ooonfX3o`00ObCooo]Z
3?l00014oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l0
00000ol007oooo]ZoookJP05oookJP;o001o0_oonfX4o`00Ob7ooo]Z2_l00012oookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l007l2oookJPCo001o:?oo
nfX:o`0004;ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002
o`000003o`00Oooonf[ooo]Z00Gooo]Z1ol007lSoookJP[o0000@OoonfX5o`0007;ooo]Z0ol007l3
oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJPOo001o:OoonfX<o`00043ooo]Z0ol007lM
oookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z
00Gooo]Z1_l007lUoookJPgo0000?OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`00
0?l000000_l00002oookJPKo001o:ooonfX<o`0003oooo]Z0ol007lMoookJP007ooonfX6o`00Og?o
oo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007lZoookJPco
0000?OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP;o
001o<?oonfX=o`0003[ooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z
0_l007l^oookJPWo0000??oonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo
00000_oonfX2o`00OcGooo]Z2ol0000goookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o
1?l00009oookJPOo001o:?oonfX>o`0003Oooo]Z1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z
1ol007laoookJPco0000=_oonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00002Ooo
nfX7o`00ObWooo]Z3_l0000foookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPOo001o<_oo
nfX>o`0003Cooo]Z0ol007lMoookJP00W?oonfX4o`0003gooo]Z3_l0000boookJPGo0000O?oonfX4
o`0003kooo]Z3_l0001BoookJP00W?oonfX4o`0003kooo]Z3_l0000aoookJPGo0000O?oonfX4o`00
047ooo]Z3_l0001?oookJP00W?oonfX4o`0004;ooo]Z3ol0000/oookJPGo0000O?oonfX4o`0004Co
oo]Z3Ol0001=oookJP00W?oonfX4o`0004?ooo]Z4ol0000WoookJPGo0000O?oonfX4o`0004Oooo]Z
3ol00018oookJP00W?oonfX4o`0004Cooo]Z6?l0000QoookJPGo0000O?oonfX4o`0004Wooo]Z4ol0
0012oookJP00W?oonfX4o`0004Wooo]Z6?l0000LoookJPGo0000O?oonfX4o`0004cooo]Z5Ol0000m
oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP00
3_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[o
o`000?oo00009Ol0000?oookJP007OoonfX01?l0003ooo]ZoookJ_oonfX=o`000003oookJ_l0003o
000001go0000C_oonfX4o`00073ooo]Z1?l00002oookJPoo000000?ooo]Zo`000?l000000ol00000
0ooonf[o0000o`00000Ro`0004kooo]Z1?l0001aoookJPCo000000?ooo]Zo`000?l000000_l00002
oookJPCo00007_oonfX003[ooo]Z6Ol00019oookJPCo0000OOoonfX5o`0001[ooo]Z6Ol00019oook
JPCo0000W_oonfX0043ooo]Z5?l00018oookJPCo0000OOoonfX5o`00023ooo]Z6?l00014oookJPCo
0000W_oonfX004Gooo]Z4Ol00016oookJPCo0000OOoonfX5o`0002Kooo]Z4ol00013oookJPCo0000
W_oonfX004_ooo]Z3_l00013oookJPCo0000OOoonfX5o`0002_ooo]Z3ol00012oookJPCo0000W_oo
nfX0053ooo]Z2ol00011oookJPCo0000OOoonfX5o`00033ooo]Z3?l00010oookJPCo0000W_oonfX0
057ooo]Z3Ol0000noookJPCo0000OOoonfX5o`00037ooo]Z3_l0000moookJPCo0000W_oonfX005?o
oo]Z3Ol0000loookJPCo0000OOoonfX5o`0003Kooo]Z2ol0000koookJPCo0000W_oonfX005Kooo]Z
3?l0000joookJPCo0000OOoonfX5o`0003Kooo]Z3Ol0000ioookJPCo0000W_oonfX005Sooo]Z3?l0
000hoookJPCo0000OOoonfX5o`0003Wooo]Z2ol0000hoookJPCo0000W_oonfX005_ooo]Z2_l0000g
oookJPCo0000OOoonfX5o`0003cooo]Z2_l0000foookJPCo0000W_oonfX005gooo]Z2_l0000eoook
JPCo0000OOoonfX5o`0003kooo]Z2_l0000doookJPCo0000W_oonfX005oooo]Z2_l0000coookJPCo
0000OOoonfX5o`00043ooo]Z2Ol0000coookJPCo0000W_oonfX0067ooo]Z2_l0000aoookJPCo0000
OOoonfX5o`00047ooo]Z2_l0000aoookJPCo0000W_oonfX006;ooo]Z2ol0000_oookJPCo0000OOoo
nfX5o`0004?ooo]Z2Ol0000`oookJPCo0000W_oonfX006Cooo]Z2_l0000^oookJPCo0000OOoonfX5
o`0004Gooo]Z2?l0000_oookJPCo0000W_oonfX006Kooo]Z2_l0000/oookJPCo0000OOoonfX5o`00
04Kooo]Z2?l0000^oookJPCo0000W_oonfX006Sooo]Z2_l0000ZoookJPCo0000OOoonfX5o`0004So
oo]Z1ol0000]oookJPCo0000W_oonfX006[ooo]Z2Ol0000YoookJPCo0000OOoonfX5o`0004Wooo]Z
2?l0000[oookJPCo0000W_oonfX006_ooo]Z2Ol0000XoookJPCo0000OOoonfX5o`0004[ooo]Z2?l0
000ZoookJPCo0000W_oonfX006gooo]Z2?l0000WoookJPCo0000OOoonfX5o`0004_ooo]Z2Ol0000X
oookJPCo0000W_oonfX006oooo]Z1ol0000VoookJPCo0000OOoonfX5o`0004cooo]Z2Ol0000Woook
JPCo0000W_oonfX0073ooo]Z1ol0000UoookJPCo0000OOoonfX5o`0004kooo]Z2?l0000VoookJPCo
0000W_oonfX0077ooo]Z1ol0000ToookJPCo0000OOoonfX5o`0004oooo]Z1ol0000VoookJPCo0000
W_oonfX007;ooo]Z1ol0000SoookJPCo0000OOoonfX5o`00057ooo]Z1_l0000UoookJPCo0000W_oo
nfX007?ooo]Z1ol0000RoookJPCo0000OOoonfX5o`0005;ooo]Z1_l0000ToookJPCo0000W_oonfX0
07Cooo]Z1ol0000QoookJPCo0000OOoonfX5o`0005;ooo]Z1ol0000SoookJPCo0000W_oonfX007Go
oo]Z1ol0000PoookJPCo0000OOoonfX5o`0005?ooo]Z1ol0000RoookJPCo0000W_oonfX007Kooo]Z
1ol0000OoookJPCo0000OOoonfX5o`0005Cooo]Z1ol0000QoookJPCo0000W_oonfX007Oooo]Z1ol0
000NoookJPCo0000OOoonfX5o`0005Gooo]Z1ol0000PoookJPCo0000W_oonfX007Sooo]Z1ol0000L
oookJPGo0000OOoonfX5o`0005Kooo]Z1ol0000OoookJPCo0000W_oonfX007Wooo]Z1ol0000Koook
JPGo0000OOoonfX5o`0005Oooo]Z1ol0000NoookJPCo0000W_oonfX007[ooo]Z1ol0000JoookJPGo
0000OOoonfX5o`0005Sooo]Z1ol0000MoookJPCo0000W_oonfX007_ooo]Z1ol0000IoookJPCo0000
O_oonfX5o`0005Wooo]Z1ol0000LoookJPCo0000W_oonfX007cooo]Z1ol0000HoookJPCo0000O_oo
nfX5o`0005[ooo]Z1ol0000KoookJPCo0000W_oonfX007gooo]Z1ol0000GoookJPCo0000H?oonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0005_ooo]Z1_l0000KoookJPCo0000W_oonfX0
07kooo]Z1ol0000FoookJPCo0000GooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`00
05cooo]Z1_l0000JoookJPCo0000W_oonfX007oooo]Z1ol0000EoookJPCo0000GooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001o
o`00O`Wooo]Z1Ol0001MoookJPKo00006OoonfX4o`0009kooo]Z0020oookJPOo00005?oonfX4o`00
05kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000GOoonfX7o`00
01Sooo]Z1?l0002NoookJP00POoonfX7o`0001?ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l8oookJPKo0000GOoonfX7o`0001Oooo]Z1?l0002NoookJP00P_oonfX7o`0001;ooo]Z
1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000GooonfX7o`0001Kooo]Z
1?l0002NoookJP00PooonfX7o`00017ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o2?oonfX5o`00063ooo]Z1_l0000FoookJPCo0000W_oonfX008Cooo]Z1_l0000A
oookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`00067ooo]Z1_l0000D
oookJPGo0000W_oonfX008Gooo]Z1_l0000@oookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oook
JPKo001o2_oonfX5o`0006;ooo]Z1_l0000CoookJPGo0000W_oonfX008Kooo]Z1_l0000?oookJPCo
0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0006;ooo]Z1ol0000BoookJPGo
0000W_oonfX008Kooo]Z1_l0000?oookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0_l007l>oookJPGo0000HooonfX7o`00017ooo]Z1?l0002OoookJP00QooonfX6o`0000kooo]Z
1?l0001OoookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001ToookJPOo00004?oonfX4o`0009oooo]Z
0028oookJPGo00003_oonfX4o`00063ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0006Gooo]Z1_l0
000@oookJPCo0000WooonfX008Sooo]Z1_l0000=oookJPCo0000O_oonfX5o`0006Kooo]Z1_l0000?
oookJPCo0000WooonfX008Wooo]Z1_l0000<oookJPCo0000O_oonfX5o`0006Oooo]Z1_l0000>oook
JPCo0000WooonfX008Wooo]Z1_l0000<oookJPCo0000O_oonfX5o`0006Oooo]Z1ol0000=oookJPCo
0000WooonfX008[ooo]Z1_l0000;oookJPCo0000O_oonfX5o`0006Sooo]Z1ol0000<oookJPCo0000
WooonfX008_ooo]Z1_l0000:oookJPCo0000O_oonfX5o`0006Wooo]Z1ol0000;oookJPCo0000Wooo
nfX008_ooo]Z1_l0000:oookJPCo0000O_oonfX5o`0006[ooo]Z1ol0000:oookJPCo0000WooonfX0
08cooo]Z1_l00009oookJPCo0000O_oonfX5o`0006_ooo]Z1ol00009oookJPCo0000WooonfX008go
oo]Z1Ol00009oookJPCo0000O_oonfX5o`0006cooo]Z1ol00008oookJPCo0000WooonfX008gooo]Z
2?l00006oookJPCo0000O_oonfX5o`0006gooo]Z1ol00007oookJPCo0000WooonfX008kooo]Z1ol0
0006oookJPCo0000O_oonfX5o`0006kooo]Z1ol00006oookJPCo0000WooonfX008kooo]Z2?l00005
oookJPCo0000O_oonfX5o`0006oooo]Z1ol00005oookJPCo0000WooonfX008oooo]Z1ol00005oook
JPCo0000O_oonfX5o`00073ooo]Z1_l00005oookJPCo0000WooonfX0093ooo]Z1_l00005oookJPCo
0000O_oonfX5o`00077ooo]Z1Ol00005oookJPCo0000WooonfX009;ooo]Z2?l000000ooonf[o0000
o`000002o`0007kooo]Z1Ol0001boookJPSo000000?ooo]Zo`000?l000000_l0002OoookJP00T_oo
nfX=o`0007kooo]Z1Ol0001boookJPgo0000WooonfX009;ooo]Z3Ol0001noookJPGo0000L_oonfX=
o`0009oooo]Z002BoookJPgo0000O_oonfX5o`0007;ooo]Z3Ol0002OoookJP00T_oonfX=o`0007ko
oo]Z1Ol0001boookJPgo0000WooonfX009;ooo]Z3Ol0001noookJPGo0000L_oonfX=o`0009oooo]Z
002BoookJPgo0000O_oonfX5o`0007;ooo]Z3Ol0002OoookJP00T_oonfX=o`0007kooo]Z1Ol0001c
oookJPco0000WooonfX009;ooo]Z3Ol0001noookJPGo0000LooonfX<o`0009oooo]Z002CoookJPco
0000O_oonfX5o`0007?ooo]Z2ol0002PoookJP00TooonfX<o`0007kooo]Z1Ol0001coookJP_o0000
X?oonfX009?ooo]Z3?l0001noookJPGo0000M?oonfX:o`000:3ooo]Z002CoookJPco0000O_oonfX5
o`0007Cooo]Z2_l0002PoookJP00UooonfX8o`0007kooo]Z1Ol0001goookJPOo0000X?oonfX009So
oo]Z1ol0001noookJPGo0000N?oonfX6o`000:3ooo]Z002HoookJPOo0000O_oonfX5o`0007Sooo]Z
1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002H
oookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0001boook
JP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo
0000N?oonfX6o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1_l0001goookJPKo0000
X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX6
o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00
O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Wooo]Z1Ol0001boookJP?o001o2_oonfX5o`0007So
oo]Z1_l0002PoookJP00VOoonfX5o`0006oooo]Z1_l007l:oookJPGo0000N?oonfX6o`000:3ooo]Z
002IoookJPGo0000KooonfX6o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001a
oookJPCo001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007;ooo]Z0ol007l:oook
JPGo0000NOoonfX5o`000:3ooo]Z002IoookJPCo0000P?oonfX5o`0007Wooo]Z1?l0002QoookJP00
VOoonfX4o`00083ooo]Z1Ol0001ioookJPCo0000XOoonfX009Wooo]Z1?l00020oookJPGo0000NOoo
nfX4o`000:7ooo]Z002IoookJPCo0000P?oonfX5o`0007Wooo]Z1?l0002QoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000oooonfXOoook
JP00oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o
2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooo
nfXNoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooook
JP;ooo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;o
oo]Z0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1_l007l:oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooo
nfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00oooonfX1oook
JPCo001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo
0000oooonfXOoookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oo
nfX4o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oookJPKo0000oooonfXN
oookJP00oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wo
oo]Z1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol0
07l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX0
0?oooo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z1ol007oooookJRgo
oo]Z003ooookJPoooo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2
oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30971 L
.02605 .31004 L
.02729 .30987 L
.02846 .30925 L
.02946 .30861 L
.03053 .30811 L
.0317 .30801 L
.03279 .30839 L
.03394 .3091 L
.03504 .30975 L
.03631 .31008 L
.03746 .30984 L
.03874 .30913 L
.03941 .3087 L
.04012 .30832 L
.04142 .30804 L
.04262 .30836 L
.04387 .30912 L
.04519 .3099 L
.04588 .31014 L
.04664 .31018 L
.04733 .31003 L
.04797 .30974 L
.04922 .30897 L
.05041 .30837 L
.05106 .30822 L
.05177 .30825 L
.05302 .30876 L
.05414 .30951 L
.05539 .31024 L
.05669 .31046 L
.05791 .31008 L
.05905 .30941 L
.06026 .30877 L
.06141 .30856 L
.06244 .30883 L
.06371 .30961 L
.06491 .31044 L
.0662 .31096 L
.06693 .31096 L
.0676 .31077 L
.06885 .31011 L
.06957 .30968 L
.07023 .30937 L
.07093 .30918 L
.07167 .3092 L
.07237 .30942 L
.07302 .30979 L
.07419 .31066 L
Mistroke
.07543 .31148 L
.0766 .3118 L
.07766 .3116 L
.07894 .31094 L
.08012 .31031 L
.08136 .31009 L
.08202 .31023 L
.08272 .31058 L
.08348 .31112 L
.0842 .31171 L
.0849 .31225 L
.08554 .31266 L
.08679 .31298 L
.08744 .31289 L
.08814 .31263 L
.08947 .3119 L
.09023 .31156 L
.09092 .3114 L
.09169 .31146 L
.0925 .31181 L
.09321 .31231 L
.09398 .31298 L
.09464 .31355 L
.09535 .31409 L
.09664 .3146 L
.09742 .31456 L
.09813 .31432 L
.09878 .31399 L
.09948 .31362 L
.10073 .31318 L
.10191 .31332 L
.1032 .31417 L
.10392 .31484 L
.10458 .31548 L
.10575 .31639 L
.10686 .31676 L
.10807 .31654 L
.10938 .31591 L
.11067 .31546 L
.11132 .31546 L
.11204 .3157 L
.1133 .31668 L
.11448 .3179 L
.11567 .31897 L
.1168 .31947 L
.11781 .31941 L
.11891 .31897 L
.1201 .31844 L
.12137 .31836 L
.12245 .31891 L
Mistroke
.12364 .32008 L
.1243 .32084 L
.12502 .32164 L
.12634 .32267 L
.12762 .32287 L
.12881 .32248 L
.12953 .32215 L
.13022 .32191 L
.13149 .32195 L
.13221 .32234 L
.13287 .32293 L
.13436 .32473 L
.13548 .32604 L
.13669 .32688 L
.13801 .32695 L
.13924 .32648 L
.1399 .32622 L
.14062 .32608 L
.14194 .32647 L
.14321 .32773 L
.14439 .32936 L
.14557 .33087 L
.14681 .33181 L
.14787 .33193 L
.14903 .33156 L
.15028 .33114 L
.15098 .33113 L
.15162 .33136 L
.15286 .33251 L
.15403 .33421 L
.15513 .33588 L
.15629 .33721 L
.15728 .33772 L
.15837 .33766 L
.15954 .33722 L
.1608 .337 L
.16199 .33757 L
.16307 .33888 L
.16434 .341 L
.16552 .34293 L
.16618 .34373 L
.16689 .34429 L
.16813 .34449 L
.16886 .34428 L
.16962 .34398 L
.17028 .3438 L
.17099 .34384 L
.17166 .34417 L
.17237 .34487 L
.17365 .34693 L
Mistroke
.17494 .34943 L
.17562 .35059 L
.17635 .35154 L
.17698 .35206 L
.17767 .3523 L
.1789 .35206 L
.18009 .35161 L
.18137 .35179 L
.18257 .35308 L
.18368 .35514 L
.18496 .35793 L
.18618 .36007 L
.18726 .36105 L
.18844 .3611 L
.18973 .36056 L
.19037 .36038 L
.19108 .36047 L
.19234 .36167 L
.19352 .36398 L
.1946 .36665 L
.19578 .36929 L
.1969 .37085 L
.19793 .37126 L
.19913 .37084 L
.2004 .37028 L
.20147 .37058 L
.20266 .37225 L
.22338 .39787 L
.24271 .42248 L
.24404 .43029 L
.24477 .43558 L
.24546 .44031 L
.2461 .44384 L
.2468 .44617 L
.24801 .44556 L
.24868 .44283 L
.2494 .43878 L
.25068 .4316 L
.25139 .42963 L
.25206 .43023 L
.2528 .43414 L
.25359 .44209 L
.25487 .46036 L
.25554 .47016 L
.25626 .47824 L
.25758 .47975 L
.2588 .45842 L
.26009 .40965 L
.2613 .34471 L
.26357 .21576 L
Mistroke
.26473 .16783 L
.26598 .14065 L
.26716 .13721 L
.26823 .14744 L
.26952 .16646 L
.27023 .17607 L
.27089 .18294 L
.27206 .18842 L
.27335 .18544 L
.27457 .17828 L
.27589 .17222 L
.27659 .17139 L
.27733 .17271 L
.27865 .17972 L
.27981 .18806 L
.28105 .19537 L
.28177 .19774 L
.28241 .19853 L
.28367 .19697 L
.28483 .19387 L
.28605 .1917 L
.28709 .19232 L
.28824 .19592 L
.28947 .20184 L
.29063 .20734 L
.29127 .20961 L
.29196 .21117 L
.29319 .21159 L
.29435 .2101 L
.29559 .20843 L
.29665 .20837 L
.29782 .21051 L
.2989 .21418 L
.30006 .21878 L
.30115 .2224 L
.30216 .2243 L
.30343 .22457 L
.30463 .22351 L
.30571 .22268 L
.30688 .22306 L
.30816 .22553 L
.3088 .22743 L
.30951 .22976 L
.31078 .2337 L
.31194 .23605 L
.3131 .23678 L
.3142 .23632 L
.31537 .23555 L
.31664 .23564 L
.31775 .23709 L
Mistroke
.31893 .23992 L
.31996 .24284 L
.32105 .24557 L
.32171 .24676 L
.32245 .24754 L
.32373 .24767 L
.32446 .24732 L
.32523 .24692 L
.32597 .24677 L
.32664 .24698 L
.32793 .24857 L
.32866 .25008 L
.32934 .25171 L
.33066 .25487 L
.3319 .25694 L
.33299 .25764 L
.33417 .25744 L
.33536 .25693 L
.33667 .25704 L
.33796 .25845 L
.33866 .25972 L
.33931 .26111 L
.34047 .26359 L
.34174 .26563 L
.34301 .26646 L
.34371 .26642 L
.34437 .2662 L
.34553 .26578 L
.34679 .26595 L
.34749 .26652 L
.34826 .26755 L
.34965 .27011 L
.35036 .27146 L
.35102 .27258 L
.35226 .27394 L
.35346 .27424 L
.35476 .27383 L
.35544 .2736 L
.35615 .27351 L
.35742 .2741 L
.3586 .27557 L
.3597 .27743 L
.3609 .27939 L
.3622 .28075 L
.36346 .28103 L
.36461 .28068 L
.36572 .28031 L
.3669 .28043 L
.36795 .28123 L
.36893 .28251 L
Mistroke
.37001 .28418 L
.37118 .2858 L
.37242 .28678 L
.37359 .28688 L
.37474 .28649 L
.37581 .28612 L
.37707 .28626 L
.37822 .28714 L
.37885 .2879 L
.37954 .28885 L
.38079 .29054 L
.38203 .29166 L
.38316 .29196 L
.38446 .2916 L
.3857 .29111 L
.38684 .29106 L
.38789 .29161 L
.38905 .2928 L
.39028 .29436 L
.39151 .29563 L
.3922 .29604 L
.39284 .2962 L
.39401 .29599 L
.39524 .29545 L
.39589 .29522 L
.39659 .29514 L
.39785 .29558 L
.39862 .29622 L
.39935 .29701 L
.40005 .29782 L
.40071 .29854 L
.40192 .29948 L
.40257 .2997 L
.40326 .2997 L
.40398 .29949 L
.40467 .29918 L
.40596 .29864 L
.40717 .2986 L
.40828 .29917 L
.40951 .30032 L
.41081 .30164 L
.41155 .30221 L
.41223 .30251 L
.41298 .30259 L
.41377 .30241 L
.41446 .30211 L
.4151 .30178 L
.41581 .30147 L
.41656 .30128 L
.41723 .30132 L
Mistroke
.41796 .30159 L
.41865 .30205 L
.41928 .30261 L
.42049 .30376 L
.42177 .30466 L
.42292 .30488 L
.42419 .30448 L
.42534 .30388 L
.42641 .30347 L
.42768 .30355 L
.42883 .30421 L
.43017 .30536 L
.43141 .30628 L
.43249 .30664 L
.43364 .30645 L
.43479 .30588 L
.43606 .30524 L
.43716 .30505 L
.43833 .30541 L
.43944 .30618 L
.44045 .30701 L
.44173 .30778 L
.44244 .30795 L
.44308 .30791 L
.44433 .30741 L
.44551 .30673 L
.44619 .30642 L
.4469 .30625 L
.44817 .30646 L
.44887 .30684 L
.44953 .30731 L
.45025 .30786 L
.45103 .30839 L
.45233 .30886 L
.45357 .30867 L
.45477 .30804 L
.45588 .30741 L
.45707 .30706 L
.45839 .30732 L
.45906 .30769 L
.45977 .30818 L
.46106 .30905 L
.46175 .30935 L
.46239 .30948 L
.4636 .30925 L
.4649 .30854 L
.46557 .30813 L
.4663 .30777 L
.46753 .30757 L
.46883 .308 L
Mistroke
.47004 .30878 L
.47116 .30948 L
.47185 .30974 L
.47259 .30983 L
.4733 .3097 L
.47395 .30943 L
.47526 .30864 L
.47649 .308 L
.4778 .30787 L
.4785 .30808 L
.47925 .30847 L
.47999 .30895 L
.48078 .30945 L
.48152 .30981 L
.48219 .30998 L
.48345 .30981 L
.48463 .30919 L
.4853 .30876 L
.48602 .30835 L
.4873 .30796 L
.48853 .30818 L
.48922 .30853 L
.48988 .30894 L
.49057 .30938 L
.49122 .30974 L
.49198 .31 L
.49267 .31004 L
.49383 .3097 L
.49506 .30897 L
.49612 .30834 L
.49727 .30799 L
.49798 .30803 L
.49862 .30823 L
.4999 .30895 L
.50104 .30965 L
.50228 .31004 L
.50355 .30984 L
.50475 .30919 L
.50582 .30852 L
.50699 .30804 L
.50827 .3081 L
.50896 .30839 L
.50962 .30877 L
.5108 .30952 L
.51204 .31003 L
.51313 .31001 L
.51433 .3095 L
.51543 .30881 L
.51642 .30827 L
.51761 .30804 L
Mistroke
.51887 .30839 L
.52004 .3091 L
.52114 .30979 L
.52234 .31018 L
.52365 .30998 L
.52431 .30965 L
.52503 .30922 L
.52631 .30848 L
.52759 .3082 L
.5288 .30853 L
.52988 .3092 L
.53107 .30998 L
.53235 .31045 L
.53308 .31044 L
.53377 .31024 L
.53449 .30987 L
.53516 .30947 L
.53593 .30901 L
.53665 .30869 L
.53785 .30858 L
.53916 .30911 L
.54045 .31001 L
.54115 .31048 L
.54182 .3108 L
.54305 .31097 L
.5437 .31081 L
.5444 .31048 L
.54507 .31009 L
.5458 .30966 L
.54649 .30934 L
.54713 .30918 L
.54837 .30934 L
.5497 .31014 L
.55092 .31105 L
.55204 .31166 L
.55274 .31179 L
.55348 .31172 L
.55422 .31144 L
.55504 .31099 L
.55574 .31059 L
.5565 .31024 L
.55721 .31009 L
.55786 .31013 L
.55916 .31074 L
.55989 .3113 L
.56057 .31186 L
.56181 .3127 L
.56313 .31298 L
.57283 .3146 L
.58328 .31676 L
Mistroke
.59344 .3195 L
.60276 .32277 L
.62104 .33 L
.6302 .33418 L
.63998 .34004 L
.65071 .34862 L
.66068 .35692 L
.68204 .38051 L
.7022 .40757 L
.71192 .4228 L
.72222 .44352 L
.72326 .44656 L
.7244 .44492 L
.72547 .43951 L
.72646 .43358 L
.72761 .4296 L
.72884 .43305 L
.72998 .44459 L
.73101 .45962 L
.73225 .4763 L
.73295 .48126 L
.73359 .48092 L
.73476 .46432 L
.73601 .42215 L
.73716 .36381 L
.73823 .3007 L
.7394 .23421 L
.74068 .17623 L
.74195 .14365 L
.74264 .13696 L
.74329 .13695 L
.74445 .14784 L
.7457 .16633 L
.7464 .17586 L
.74717 .18362 L
.74789 .18765 L
.74855 .18845 L
.74982 .18398 L
.75052 .17975 L
.75116 .17599 L
.75244 .17155 L
.75362 .17302 L
.75491 .18014 L
.75627 .18987 L
.75745 .19623 L
.75856 .19852 L
.75978 .19718 L
.76108 .19371 L
.76232 .19166 L
.76347 .19271 L
Mistroke
.76473 .19723 L
.76607 .20392 L
.76723 .20887 L
.76831 .21139 L
.76951 .21148 L
.77079 .2097 L
.77187 .20836 L
.77304 .20857 L
.77427 .21127 L
.77541 .21547 L
.77647 .2196 L
.77746 .22271 L
.77861 .22454 L
.77965 .22456 L
.7808 .22353 L
.78204 .22264 L
.78321 .22323 L
.78428 .22533 L
.78556 .22927 L
.78626 .23159 L
.78692 .23356 L
.7882 .23615 L
.78937 .23678 L
.79058 .23619 L
.79189 .23544 L
.79259 .2355 L
.79332 .23612 L
.79464 .23866 L
.79589 .2421 L
.79706 .24518 L
.79771 .24646 L
.79842 .24736 L
.79965 .24775 L
.8008 .24724 L
.80202 .24677 L
.80306 .24715 L
.80421 .24873 L
.80526 .25105 L
.8064 .25385 L
.80747 .25606 L
.80845 .25729 L
.8181 .26582 L
.83866 .28089 L
.84867 .28681 L
.85776 .29134 L
.85891 .29193 L
.85998 .29185 L
.86109 .29141 L
.86232 .29103 L
.86356 .29126 L
Mistroke
.86425 .29175 L
.86489 .29239 L
.86612 .29391 L
.86726 .29524 L
.86832 .29601 L
.86946 .29619 L
.87059 .29583 L
.87185 .29529 L
.87293 .29515 L
.8741 .29562 L
.8752 .29663 L
.87621 .29779 L
.87736 .29897 L
.87858 .29966 L
.87974 .29964 L
.88079 .29922 L
.88202 .29867 L
.88272 .29854 L
.88336 .2986 L
.88455 .29922 L
.8858 .30042 L
.887 .30164 L
.88828 .30247 L
.8895 .30255 L
.89061 .30213 L
.89191 .3015 L
.89264 .3013 L
.89332 .3013 L
.89457 .30185 L
.89527 .30242 L
.89591 .30302 L
.89703 .30405 L
.89823 .30476 L
.89955 .3048 L
.90078 .30428 L
.90144 .30392 L
.90216 .3036 L
.90347 .30345 L
.90475 .30401 L
.90593 .30498 L
.90695 .30585 L
.90806 .3065 L
.90927 .30661 L
.9104 .3062 L
.91161 .30553 L
.91288 .30508 L
.91397 .30517 L
.91515 .30582 L
.91656 .30694 L
.91725 .30744 L
Mistroke
.91789 .30777 L
.91908 .30794 L
.92037 .30749 L
.92104 .30711 L
.92177 .3067 L
.92308 .30625 L
.92379 .30628 L
.92444 .30649 L
.92521 .30694 L
.92594 .30747 L
.92715 .30835 L
.92843 .30885 L
.92964 .30871 L
.93074 .30817 L
.93204 .30742 L
.93277 .30714 L
.93344 .30705 L
.93467 .30736 L
.93597 .30819 L
.9372 .30902 L
.93789 .30934 L
.93853 .30947 L
.9397 .30928 L
.94095 .30862 L
.94199 .308 L
.9431 .3076 L
.94433 .30769 L
.94548 .30827 L
.94613 .30871 L
.94682 .30918 L
.94807 .30975 L
.94937 .30974 L
.95011 .30944 L
.95079 .30905 L
.95199 .30832 L
.95329 .30786 L
.95452 .30801 L
.95565 .3086 L
.95671 .3093 L
.95785 .30986 L
.95892 .30998 L
.9599 .3097 L
.96108 .30903 L
.96233 .30829 L
.96339 .30797 L
.96457 .30813 L
.96577 .30875 L
.96689 .30946 L
.9681 .30998 L
.96941 .30994 L
Mistroke
.97058 .3094 L
.97181 .30862 L
.97285 .30812 L
.974 .308 L
.97506 .30834 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00WooonfX4o`0007[ooo]Z1Ol0001noookJPGo
0000VooonfX009oooo]Z1?l0001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000N_oo
nfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX0
09kooo]Z1Ol0001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000N_oonfX5o`0007ko
oo]Z1Ol0002KoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z
002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001]
oookJP?o001o2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0005gooo]Z2_l007l6oook
JP?o001o2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0005gooo]Z2_l007l6oookJP?o
001o2_oonfX6o`0007gooo]Z1Ol0002KoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000
O_oonfX5o`0009_ooo]Z002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oo
nfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007gooo]Z1ol0002JoookJP00W_oonfX6o`00
06cooo]Z0ol007l:oookJPGo0000OOoonfX7o`0009[ooo]Z002NoookJPKo0000JOoonfX6o`00O`[o
oo]Z1Ol0001moookJPOo0000V_oonfX009kooo]Z1_l0001YoookJPKo001o2_oonfX5o`0007gooo]Z
1ol0002JoookJP00W_oonfX6o`0006_ooo]Z1?l007l:oookJPGo0000OOoonfX7o`0009[ooo]Z002N
oookJP[o0000J?oonfX3o`00O`[ooo]Z1Ol0001moookJPOo0000V_oonfX009kooo]Z2_l0001eoook
JPGo0000OOoonfX;o`0009Kooo]Z002NoookJP[o0000MOoonfX5o`0007gooo]Z2ol0002FoookJP00
W_oonfX:o`0007Gooo]Z1Ol0001moookJP_o0000U_oonfX009kooo]Z2ol0001doookJPGo0000OOoo
nfX<o`0009Gooo]Z002NoookJP_o0000M?oonfX5o`0007gooo]Z3?l0002EoookJP00W_oonfX;o`00
07Cooo]Z1Ol0001moookJPco0000UOoonfX009kooo]Z2ol0001doookJPGo0000OOoonfX<o`0009Go
oo]Z002NoookJPco0000LooonfX5o`0007gooo]Z3Ol0002DoookJP00W_oonfX<o`0007?ooo]Z1Ol0
001moookJPgo0000U?oonfX009kooo]Z3?l0001coookJPGo0000OOoonfX=o`0009Cooo]Z002Noook
JPoo0000L?oonfX5o`0007gooo]Z4?l0002AoookJP00WOoonfXAo`0006oooo]Z1Ol0001moookJQ7o
0000T?oonfX009gooo]Z2?l000000ooonf[o0000o`000006o`0006oooo]Z1Ol0001moookJPCo0000
00?ooo]Zo`000?l000002_l0002@oookJP00WOoonfX5o`0000Cooo]Z2?l0001_oookJPGo0000OOoo
nfX4o`0000Gooo]Z2?l0002@oookJP00WOoonfX4o`0000Gooo]Z2?l0001_oookJPGo0000OOoonfX4
o`0000Gooo]Z2?l0002@oookJP00WOoonfX4o`0000Gooo]Z2Ol0001^oookJPGo0000OOoonfX4o`00
00Kooo]Z1ol0002@oookJP00WOoonfX4o`0000Gooo]Z2Ol0001^oookJPGo0000OOoonfX4o`0000Ko
oo]Z2?l0002?oookJP00WOoonfX4o`0000Kooo]Z2?l0001^oookJPGo0000OOoonfX4o`0000Kooo]Z
2?l0002?oookJP00WOoonfX4o`0000[ooo]Z1Ol0001]oookJPGo0000OOoonfX4o`0000Wooo]Z1Ol0
002?oookJP00WOoonfX4o`0000[ooo]Z2?l0001ZoookJPGo0000OOoonfX4o`0000[ooo]Z1ol0002<
oookJP00WOoonfX4o`0000[ooo]Z2?l0001ZoookJPGo0000OOoonfX4o`0000[ooo]Z2?l0002;oook
JP00WOoonfX4o`0000_ooo]Z1ol0001ZoookJPGo0000OOoonfX4o`0000[ooo]Z2Ol0002:oookJP00
WOoonfX4o`0000_ooo]Z1ol0001ZoookJPGo0000OOoonfX4o`0000_ooo]Z2?l0002:oookJP00WOoo
nfX4o`0000_ooo]Z2?l0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2?l0002:oookJP00WOoonfX4
o`0000_ooo]Z2?l0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2?l0002:oookJP00WOoonfX4o`00
00kooo]Z1_l0001XoookJPGo0000OOoonfX4o`0000oooo]Z1Ol00029oookJP00WOoonfX4o`0000oo
oo]Z1Ol0001XoookJPGo0000OOoonfX4o`0000oooo]Z1Ol00029oookJP00WOoonfX4o`0000oooo]Z
2?l0001UoookJPGo0000OOoonfX4o`0000oooo]Z2?l00026oookJP00WOoonfX4o`00013ooo]Z1ol0
001UoookJPGo0000OOoonfX4o`00013ooo]Z1ol00026oookJP00WOoonfX4o`00013ooo]Z2?l00016
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000OOoonfX4o`00013ooo]Z2?l00025
oookJP00WOoonfX4o`00013ooo]Z2?l00015oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oook
JPGo0000OOoonfX4o`00013ooo]Z2?l00025oookJP00WOoonfX4o`00017ooo]Z2?l00014oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000AoookJPSo0000Q?oonfX009gooo]Z1?l0000Doook
JPGo0000=ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000OOoonfX4o`0001Cooo]Z1Ol00024oookJP00WOoonfX4o`0001Cooo]Z1Ol0000goookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007cooo]Z1?l0000DoookJPGo
0000Q?oonfX009gooo]Z1?l0000EoookJPSo0000?ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX5o`0007gooo]Z1?l0000EoookJPSo0000P?oonfX009gooo]Z1?l0000EoookJPSo0000?ooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001moookJPCo00005Ooo
nfX8o`00083ooo]Z002MoookJPCo00005OoonfX8o`0003oooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Wooo]Z1Ol0001moookJPCo00005OoonfX9o`0007oooo]Z002MoookJPCo00005_oonfX8o`00
03kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001moookJPCo00005OoonfX9o`00
07oooo]Z002MoookJPCo00005ooonfX7o`0003kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`ko
oo]Z1Ol0001moookJPCo00005_oonfX8o`0007oooo]Z002MoookJPCo00006OoonfX5o`0003oooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007gooo]Z1?l0000JoookJPGo
0000O_oonfX009gooo]Z1?l0000JoookJPSo0000>ooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000
OOoonfX4o`0001[ooo]Z2?l0001koookJP00WOoonfX4o`0001[ooo]Z2Ol0000koookJPGo001o2_oo
nfX7o`00O`Sooo]Z1Ol0001moookJPCo00006_oonfX9o`0007[ooo]Z002MoookJPCo00006_oonfX9
o`0005Wooo]Z1Ol0001moookJPCo00006ooonfX8o`0007[ooo]Z002MoookJPCo00006ooonfX9o`00
05Sooo]Z1Ol0001moookJPCo00006ooonfX8o`0007[ooo]Z002MoookJPCo00007?oonfX8o`0005So
oo]Z1Ol0001moookJPCo00007?oonfX8o`0007Wooo]Z002MoookJPCo00007ooonfX5o`0005Sooo]Z
1Ol0001moookJPCo00007ooonfX6o`0007Sooo]Z002MoookJPCo00008?oonfX7o`0005Gooo]Z1Ol0
001moookJPCo00007ooonfX6o`0007Sooo]Z002MoookJPCo00008?oonfX9o`0005?ooo]Z1Ol0001m
oookJPCo00008?oonfX6o`0007Oooo]Z002MoookJPCo00008?oonfX9o`0005?ooo]Z1Ol0001moook
JPCo00008OoonfX6o`0007Kooo]Z002MoookJPCo00008OoonfX9o`0005;ooo]Z1Ol0001moookJPCo
00008OoonfX7o`0007Gooo]Z002MoookJPCo00009?oonfX6o`0005;ooo]Z1Ol0001moookJPCo0000
8_oonfX7o`0007Cooo]Z002MoookJPCo00009OoonfX8o`0004oooo]Z1Ol0001moookJPCo00008ooo
nfX8o`0007;ooo]Z002MoookJPCo00009_oonfX8o`0004kooo]Z1Ol0001loookJPGo00009?oonfX8
o`00077ooo]Z002MoookJPCo00009_oonfX9o`0004gooo]Z1Ol0001loookJPGo00009OoonfX9o`00
06oooo]Z000RoookJP?o001oMOoonfX3o`00O`Co00000_oonfX3o`00O`?ooo]Z1Ol007lIoookJPWo
0000COoonfX5o`0007Cooo]Z1Ol007l3oookJPGo00000_oonfX5o`00Oaoooo]Z2Ol0001>oookJP?o
001o7OoonfX002;ooo]Z0ol007mdoookJPCo001o1?l00002oookJP?o001o0_oonfX7o`00Oacooo]Z
2Ol00019oookJPGo0000LooonfX7o`00O`;ooo]Z1?l00002oookJPOo001o8?oonfX9o`0004cooo]Z
0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Oagooo]Z2?l00019oookJPGo0000
LooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00Ob7ooo]Z2Ol0001;oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o
001oIooonfX:o`00O`;ooo]Z0ol007l2oookJPCo00001_oonfX3o`00O`?ooo]Z0ol007lLoookJPWo
0000B?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l000001?oonf[o
001oo`00Ool007l3oookJP?o001o8_oonfX9o`0004Wooo]Z0ol007lMoookJP004ooonfX:o`00O`Go
oo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1?l0000<oookJP?o001o7OoonfX;o`0004Go
oo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00001ooonfX3o`00Ob?o
oo]Z2Ol00018oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l00000
0ol0000<oookJP?o001o8?oonfX9o`0004Cooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oook
J_l0003o000000;o00001ooonfX3o`00ObGooo]Z2Ol00016oookJP?o001o7OoonfX002;ooo]Z0ol0
07mcoookJP?o001o00?ooo]Zo`000?l000000ol00007oookJP;o001o0_oonfX4o`00Ob7ooo]Z2Ol0
0013oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l0
07l2oookJPCo001o9_oonfX:o`0004Cooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l0
0ooonf[o0000o`000003o`0000Oooo]Z1ol007lSoookJPWo0000@_oonfX5o`0007;ooo]Z0ol007l3
oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJPOo001o:OoonfX9o`0004?ooo]Z0ol007lM
oookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z
00Gooo]Z1_l007lToookJPgo0000?_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`00
0?l000000_l00002oookJPKo001o:ooonfX:o`00047ooo]Z0ol007lMoookJP007ooonfX6o`00Og?o
oo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l/oookJP[o
0000?OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP;o
001o<OoonfX;o`0003_ooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z
0_l007l]oookJPgo0000>OoonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo
00000_oonfX2o`00Oc?ooo]Z3Ol0000goookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o
1?l00009oookJPOo001o:?oonfX=o`0003Sooo]Z1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z
1ol007l^oookJPgo0000>?oonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00002Ooo
nfX7o`00Ob_ooo]Z2ol0000goookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPOo001o<?oo
nfX;o`0003Wooo]Z0ol007lMoookJP00W?oonfX4o`0003cooo]Z3_l0000coookJPGo0000O?oonfX4
o`0003gooo]Z3Ol0001DoookJP00W?oonfX4o`0003gooo]Z4_l0000^oookJPGo0000O?oonfX4o`00
03kooo]Z4Ol0001?oookJP00W?oonfX4o`0004;ooo]Z3_l0000]oookJPGo0000O?oonfX4o`00047o
oo]Z3ol0001>oookJP00W?oonfX4o`0004;ooo]Z4ol0000XoookJPGo0000O?oonfX4o`0004;ooo]Z
4ol00019oookJP00W?oonfX4o`0004Kooo]Z5?l0000SoookJPGo0000O?oonfX4o`0004Oooo]Z4ol0
0014oookJP00W?oonfX4o`0004Sooo]Z6?l0000MoookJPGo0000O?oonfX4o`0004Sooo]Z6?l0000n
oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP00
3_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[o
o`000?oo00009Ol0000?oookJP007?oonfX4o`0000;ooo]Z1?l000000ooonf[o0000o`00000Vo`00
04gooo]Z1?l0001coookJPCo00000_oonfX9o`0000;ooo]Z1?l000000ooonf[o0000o`00000Uo`00
04kooo]Z1?l0001doookJPCo000000?ooo]Zo`000?l000000_l00002oookJP03o`000?oonf[ooo]Z
01cooo]Z000hoookJQco0000B?oonfX4o`0007gooo]Z1Ol0000HoookJQWo0000BooonfX4o`0009ko
oo]Z0012oookJQ?o0000AooonfX4o`0007gooo]Z1Ol0000QoookJQCo0000AooonfX4o`0009kooo]Z
0017oookJQ?o0000@_oonfX4o`0007gooo]Z1Ol0000VoookJQ;o0000A?oonfX4o`0009kooo]Z001<
oookJPko0000@_oonfX4o`0007gooo]Z1Ol0000[oookJQ3o0000@OoonfX4o`0009kooo]Z001=oook
JQ;o0000?OoonfX4o`0007gooo]Z1Ol0000^oookJPoo0000?ooonfX4o`0009kooo]Z001BoookJPko
0000??oonfX4o`0007gooo]Z1Ol0000boookJPko0000??oonfX4o`0009kooo]Z001CoookJPgo0000
??oonfX4o`0007gooo]Z1Ol0000eoookJPgo0000>_oonfX4o`0009kooo]Z001GoookJPgo0000>?oo
nfX4o`0007gooo]Z1Ol0000hoookJPco0000>?oonfX4o`0009kooo]Z001HoookJPgo0000=ooonfX4
o`0007gooo]Z1Ol0000joookJP_o0000=ooonfX4o`0009kooo]Z001LoookJP[o0000=_oonfX4o`00
07gooo]Z1Ol0000moookJP[o0000=OoonfX4o`0009kooo]Z001MoookJPco0000<ooonfX4o`0007go
oo]Z1Ol0000ooookJP[o0000<ooonfX4o`0009kooo]Z001QoookJPWo0000<_oonfX4o`0007gooo]Z
1Ol00011oookJPWo0000<_oonfX4o`0009kooo]Z001RoookJPWo0000<OoonfX4o`0007gooo]Z1Ol0
0012oookJP[o0000<?oonfX4o`0009kooo]Z001RoookJP[o0000<?oonfX4o`0007gooo]Z1Ol00014
oookJPWo0000;ooonfX4o`0009kooo]Z001SoookJPco0000;OoonfX4o`0007gooo]Z1Ol00016oook
JPWo0000;OoonfX4o`0009kooo]Z001WoookJPSo0000;OoonfX4o`0007gooo]Z1Ol00017oookJPWo
0000;?oonfX4o`0009kooo]Z001XoookJPSo0000;?oonfX4o`0007gooo]Z1Ol00019oookJPSo0000
:ooonfX4o`0009kooo]Z001XoookJPWo0000:ooonfX4o`0007gooo]Z1Ol0001:oookJPSo0000:_oo
nfX4o`0009kooo]Z001[oookJPWo0000:?oonfX4o`0007gooo]Z1Ol0001<oookJPOo0000:OoonfX4
o`0009kooo]Z001/oookJPWo00009ooonfX4o`0007gooo]Z1Ol0001=oookJPOo0000:?oonfX4o`00
09kooo]Z001]oookJPWo00009_oonfX4o`0007gooo]Z1Ol0001>oookJPOo00009ooonfX4o`0009ko
oo]Z001]oookJPWo00009_oonfX4o`0007gooo]Z1Ol0001?oookJPOo00009_oonfX4o`0009kooo]Z
001aoookJPGo00009_oonfX4o`0007gooo]Z1Ol0001@oookJPKo00009_oonfX4o`0009kooo]Z001b
oookJPSo00008_oonfX4o`0007gooo]Z1Ol0001AoookJPKo00009OoonfX4o`0009kooo]Z001boook
JPSo00008_oonfX4o`0007gooo]Z1Ol0001BoookJPKo00009?oonfX4o`0009kooo]Z001boookJPWo
00008OoonfX4o`0007gooo]Z1Ol0001BoookJPOo00008ooonfX4o`0009kooo]Z001coookJPSo0000
8OoonfX4o`0007gooo]Z1Ol0001CoookJPOo00008_oonfX4o`0009kooo]Z001foookJPGo00008Ooo
nfX4o`0007gooo]Z1Ol0001DoookJPOo00008OoonfX4o`0009kooo]Z001goookJPSo00007OoonfX4
o`0007gooo]Z1Ol0001EoookJPOo00008?oonfX4o`0009kooo]Z001goookJPWo00007?oonfX4o`00
07gooo]Z1Ol0001FoookJPOo00007ooonfX4o`0009kooo]Z001goookJPWo00007?oonfX4o`0007go
oo]Z1Ol0001GoookJPOo00007_oonfX4o`0009kooo]Z001hoookJPWo00006ooonfX4o`0007gooo]Z
1Ol0001HoookJPOo00007OoonfX4o`0009kooo]Z001ioookJPWo00006_oonfX4o`0007gooo]Z1Ol0
001IoookJPOo00007?oonfX4o`0009kooo]Z001loookJPOo00006?oonfX5o`0007gooo]Z1Ol0001J
oookJPOo00006ooonfX4o`0009kooo]Z001moookJPOo00005ooonfX5o`0005oooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001KoookJPOo00006_oonfX4o`0009kooo]Z001noookJPKo
00005ooonfX5o`0005kooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001LoookJPKo
00006_oonfX4o`0009kooo]Z001ooookJPKo00005_oonfX4o`0005oooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oook
JPGo0000GOoonfX6o`0001Wooo]Z1?l0002NoookJP00P?oonfX6o`0001Gooo]Z1?l0001NoookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0005kooo]Z1_l0000HoookJPCo
0000W_oonfX0083ooo]Z1ol0000DoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX6o`0005gooo]Z1ol0000GoookJPCo0000W_oonfX0087ooo]Z1_l0000DoookJPCo0000G_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0005oooo]Z1ol0000FoookJPCo0000W_oo
nfX008;ooo]Z1_l0000CoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`Sooo]Z1Ol0001PoookJPKo00005_oonfX4o`0009kooo]Z0023oookJPKo00004_oonfX4o`00
05kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001QoookJPKo00005?oonfX5o`00
09kooo]Z0023oookJPOo00004OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[o
oo]Z1Ol0001RoookJPKo00004ooonfX5o`0009kooo]Z0024oookJPOo00004?oonfX4o`0005kooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001RoookJPOo00004_oonfX5o`0009kooo]Z
0025oookJPKo00004?oonfX4o`0005oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o
3_oonfX5o`0006?ooo]Z1_l0000BoookJPCo0000WooonfX008Kooo]Z1_l0000?oookJPCo0000Gooo
nfX7o`00O`Wooo]Z1ol007l8oookJPGo0000I?oonfX6o`00017ooo]Z1?l0002OoookJP00QooonfX6
o`0000kooo]Z1?l0001PoookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001UoookJPKo00004?oonfX4
o`0009oooo]Z0027oookJPOo00003OoonfX4o`0007kooo]Z1Ol0001UoookJPOo00003ooonfX4o`00
09oooo]Z0028oookJPOo00003?oonfX4o`0007kooo]Z1Ol0001VoookJPOo00003_oonfX4o`0009oo
oo]Z0029oookJPKo00003?oonfX4o`0007kooo]Z1Ol0001WoookJPKo00003_oonfX4o`0009oooo]Z
002:oookJPKo00002ooonfX4o`0007kooo]Z1Ol0001XoookJPKo00003OoonfX4o`0009oooo]Z002;
oookJPKo00002_oonfX4o`0007kooo]Z1Ol0001YoookJPGo00003OoonfX4o`0009oooo]Z002;oook
JPOo00002OoonfX4o`0007kooo]Z1Ol0001YoookJPKo00003?oonfX4o`0009oooo]Z002<oookJPKo
00002OoonfX4o`0007kooo]Z1Ol0001ZoookJPKo00002ooonfX4o`0009oooo]Z002=oookJPKo0000
2?oonfX4o`0007kooo]Z1Ol0001ZoookJPKo00002ooonfX4o`0009oooo]Z002>oookJPKo00001ooo
nfX4o`0007kooo]Z1Ol0001[oookJPKo00002_oonfX4o`0009oooo]Z002>oookJPOo00001_oonfX4
o`0007kooo]Z1Ol0001/oookJPGo00002_oonfX4o`0009oooo]Z002?oookJPOo00001OoonfX4o`00
07kooo]Z1Ol0001/oookJPKo00002OoonfX4o`0009oooo]Z002@oookJPKo00001OoonfX4o`0007ko
oo]Z1Ol0001]oookJPGo00002OoonfX4o`0009oooo]Z002AoookJPGo00001OoonfX4o`0007kooo]Z
1Ol0001]oookJPKo00002?oonfX4o`0009oooo]Z002BoookJPSo000000?ooo]Zo`000?l000000_l0
001noookJPGo0000K_oonfX5o`0000?ooo]Z1?l000000ooonf[o0000o`000002o`0009oooo]Z002B
oookJPgo0000O_oonfX5o`0006kooo]Z1_l00002oookJPCo000000?ooo]Zo`000?l000000_l0002O
oookJP00T_oonfX=o`0007kooo]Z1Ol0001_oookJPGo00000_oonfX9o`0009oooo]Z002BoookJPgo
0000O_oonfX5o`0006oooo]Z1_l000000ooonf[o0000o`000007o`0009oooo]Z002BoookJPgo0000
O_oonfX5o`00073ooo]Z1Ol000000ooonf[o0000o`000007o`0009oooo]Z002BoookJPgo0000O_oo
nfX5o`00073ooo]Z3ol0002OoookJP00TooonfX<o`0007kooo]Z1Ol0001aoookJPko0000WooonfX0
09?ooo]Z2ol0001ooookJPGo0000LOoonfX>o`0009oooo]Z002CoookJP_o0000OooonfX5o`00077o
oo]Z3_l0002OoookJP00TooonfX;o`0007oooo]Z1Ol0001boookJPgo0000WooonfX009?ooo]Z2ol0
001ooookJPGo0000L_oonfX=o`0009oooo]Z002CoookJP_o0000OooonfX5o`0007?ooo]Z2ol0002P
oookJP00U?oonfX:o`0007oooo]Z1Ol0001coookJP_o0000X?oonfX009Oooo]Z1ol0001ooookJPGo
0000M?oonfX:o`000:3ooo]Z002GoookJPOo0000OooonfX5o`0007Sooo]Z1_l0002PoookJP00Uooo
nfX7o`0007oooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5
o`0007Sooo]Z1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`00
0:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z
1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol0
07l:oookJPKo0000MooonfX6o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001h
oookJPKo0000X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002Poook
JP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002IoookJPGo0000
L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Wooo]Z1Ol0001_oookJPKo001o2_oo
nfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0006oooo]Z1_l007l:oookJPGo0000NOoonfX5
o`000:3ooo]Z002IoookJPGo0000LOoonfX4o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wo
oo]Z1Ol0001boookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007oooo]Z
1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001ooookJPGo0000NOoonfX5o`000:3ooo]Z002J
oookJPCo0000OooonfX5o`0007Wooo]Z1Ol0002PoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo
0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol0
07l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8
oookJPKo0000oooonfXNoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooook
JQoooo]Z003ooookJP;ooo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Wooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>
oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoook
JP00oooonfX1oookJPCo001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z
2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z3_oonfX4o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oook
JPKo0000oooonfXNoookJP00oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4_oonfX3o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003o
oookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00
Oooooo]Z;?oonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z
1ol007oooookJRgooo]Z003ooookJPoooo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.04262 .30961 L
.06244 .31009 L
.06368 .30935 L
.06438 .309 L
.06503 .30882 L
.06622 .30893 L
.06747 .30963 L
.06882 .3106 L
.06958 .31102 L
.07029 .31123 L
.07153 .31108 L
.07222 .31076 L
.07286 .3104 L
.07409 .30973 L
.07523 .3095 L
.07649 .30989 L
.07719 .31034 L
.07783 .31084 L
.079 .31169 L
.08026 .31216 L
.08146 .312 L
.08255 .31145 L
.08383 .31077 L
.08454 .31057 L
.08519 .31056 L
.08646 .31108 L
.08766 .31202 L
.08834 .31258 L
.08905 .31308 L
.09034 .31349 L
.09106 .31341 L
.09173 .31315 L
.09246 .31277 L
.09326 .31234 L
.09398 .31207 L
.09465 .31198 L
.09535 .3121 L
.09611 .31248 L
.09681 .31302 L
.09747 .31361 L
.09871 .31466 L
.09942 .31507 L
.10018 .31525 L
.10082 .31521 L
.10153 .31497 L
.10229 .31459 L
.10311 .31418 L
.10388 .31392 L
.10458 .31388 L
Mistroke
.10586 .31442 L
.10707 .31549 L
.10776 .31617 L
.10849 .31682 L
.10979 .31749 L
.11093 .31744 L
.11217 .31691 L
.11281 .3166 L
.1135 .31635 L
.11474 .3164 L
.11594 .31715 L
.11724 .31849 L
.11839 .31963 L
.1196 .32033 L
.1207 .32035 L
.1219 .31989 L
.12292 .31944 L
.12403 .3193 L
.12535 .31992 L
.12607 .32061 L
.12674 .32137 L
.12802 .32284 L
.12922 .32374 L
.1299 .32393 L
.13064 .32387 L
.13192 .32337 L
.13265 .32308 L
.13343 .32293 L
.13409 .32302 L
.13481 .3234 L
.14492 .32811 L
.16441 .33931 L
.17534 .34811 L
.18531 .35662 L
.20598 .37924 L
.22512 .40269 L
.24369 .42611 L
.24482 .43396 L
.24588 .44142 L
.24699 .44643 L
.2482 .44634 L
.24942 .44066 L
.25073 .43281 L
.25195 .42999 L
.25306 .43509 L
.25438 .45091 L
.25507 .46155 L
.25581 .47218 L
.25645 .47905 L
.25716 .48195 L
Mistroke
.2584 .46973 L
.25965 .43106 L
.26035 .39845 L
.261 .36343 L
.26342 .2213 L
.26471 .16651 L
.26592 .14016 L
.26701 .13684 L
.26819 .14845 L
.26947 .16776 L
.27067 .18225 L
.27191 .18809 L
.27257 .18725 L
.27328 .18416 L
.27456 .17635 L
.27577 .17133 L
.27686 .1717 L
.27804 .17734 L
.27913 .18514 L
.2803 .19293 L
.28141 .19718 L
.28242 .19768 L
.28363 .19517 L
.28491 .19181 L
.28621 .191 L
.28696 .19241 L
.28765 .19485 L
.28914 .20223 L
.28988 .20576 L
.29055 .20836 L
.29182 .21073 L
.29249 .21067 L
.29319 .2099 L
.2943 .20815 L
.29549 .20717 L
.29679 .20871 L
.29801 .21262 L
.29939 .21814 L
.3007 .22215 L
.30187 .22355 L
.30315 .22297 L
.3044 .22174 L
.30572 .22165 L
.30641 .22251 L
.30716 .2242 L
.30849 .22838 L
.30974 .23237 L
.31044 .23403 L
.31108 .23501 L
.31233 .23546 L
Mistroke
.31351 .23475 L
.31464 .23413 L
.31584 .23462 L
.31687 .23634 L
.318 .23929 L
.31921 .24274 L
.32052 .24545 L
.32175 .2464 L
.32288 .24611 L
.32417 .24546 L
.32489 .24542 L
.32554 .24578 L
.32682 .24766 L
.32802 .25049 L
.32933 .25366 L
.32999 .25489 L
.33072 .2558 L
.3315 .25622 L
.33224 .25618 L
.33291 .25591 L
.33364 .25559 L
.33495 .25553 L
.3357 .25608 L
.33638 .25701 L
.33765 .25952 L
.33899 .26244 L
.34018 .26431 L
.34131 .26502 L
.34254 .26482 L
.34323 .26454 L
.34387 .26434 L
.34514 .26459 L
.34635 .26593 L
.34743 .26787 L
.3486 .27017 L
.34988 .27208 L
.35053 .2726 L
.35124 .27283 L
.35249 .27257 L
.35367 .27216 L
.35484 .27229 L
.35596 .27327 L
.35697 .27478 L
.35806 .27672 L
.35925 .27854 L
.36051 .27957 L
.3617 .27961 L
.36278 .27921 L
.36408 .27893 L
.36474 .2791 L
Mistroke
.36545 .27959 L
.36672 .28119 L
.36791 .28307 L
.36863 .28412 L
.36931 .2849 L
.37058 .28561 L
.37129 .28559 L
.37195 .28539 L
.37267 .2851 L
.37345 .28486 L
.37464 .28498 L
.37576 .28583 L
.37641 .28662 L
.37709 .28758 L
.37831 .28928 L
.37959 .29047 L
.38078 .29075 L
.38209 .29035 L
.38281 .29005 L
.38348 .28987 L
.38472 .29008 L
.38537 .29053 L
.38608 .29124 L
.38749 .29304 L
.38818 .29388 L
.38882 .2945 L
.39005 .29509 L
.3907 .29507 L
.39139 .29487 L
.39262 .29434 L
.39374 .2941 L
.39505 .29456 L
.39574 .29514 L
.39646 .29594 L
.3977 .29738 L
.39902 .29849 L
.39978 .29873 L
.40046 .29871 L
.40115 .29849 L
.40181 .2982 L
.40252 .29787 L
.40327 .29765 L
.40409 .29767 L
.40486 .29799 L
.4061 .29905 L
.40724 .30028 L
.40856 .3014 L
.40981 .30175 L
.41096 .30145 L
.41203 .30093 L
Mistroke
.4132 .30052 L
.41445 .30068 L
.41517 .3011 L
.41582 .30165 L
.41731 .30309 L
.41861 .30399 L
.41927 .30415 L
.41999 .3041 L
.42125 .30359 L
.42194 .30322 L
.42259 .30294 L
.42386 .30281 L
.42502 .30331 L
.42609 .30419 L
.42723 .3052 L
.42847 .30594 L
.42961 .30602 L
.43086 .30553 L
.43152 .30517 L
.43222 .30481 L
.43349 .30454 L
.43468 .30491 L
.436 .30588 L
.4367 .30647 L
.43744 .30701 L
.43809 .30734 L
.4388 .30749 L
.44005 .30723 L
.44136 .30653 L
.4426 .30596 L
.44372 .30589 L
.44493 .30642 L
.44608 .30727 L
.44716 .30805 L
.4484 .30852 L
.44952 .30838 L
.45075 .30776 L
.4514 .30738 L
.45208 .30703 L
.45332 .30679 L
.45445 .30712 L
.45551 .3078 L
.45665 .30862 L
.45772 .30914 L
.4587 .30922 L
.45985 .30884 L
.46109 .3081 L
.46227 .30753 L
.46335 .30742 L
.4646 .30787 L
Mistroke
.46578 .30865 L
.46684 .30932 L
.46801 .30968 L
.46926 .30944 L
.46996 .30908 L
.4706 .30869 L
.47184 .308 L
.47301 .30776 L
.47411 .30804 L
.47527 .30872 L
.47628 .30938 L
.47736 .30985 L
.47852 .30985 L
.4796 .3094 L
.48079 .30866 L
.48206 .30805 L
.48272 .30794 L
.48344 .30802 L
.48471 .30862 L
.4861 .3095 L
.48688 .30986 L
.4876 .31001 L
.48891 .30974 L
.48958 .30939 L
.4903 .30893 L
.49162 .3082 L
.49284 .30801 L
.49412 .30843 L
.49533 .30917 L
.49642 .30978 L
.4976 .31003 L
.49888 .30968 L
.49953 .30932 L
.50024 .30886 L
.5015 .30819 L
.50268 .30801 L
.50393 .30842 L
.50463 .30884 L
.50526 .30924 L
.50649 .30988 L
.50765 .31002 L
.50831 .30986 L
.50901 .30953 L
.51026 .30875 L
.51091 .30838 L
.5116 .30811 L
.51236 .30802 L
.51308 .30816 L
.51435 .30881 L
.51502 .30924 L
Mistroke
.51573 .30967 L
.51703 .31009 L
.51824 .30988 L
.5194 .30926 L
.52048 .30859 L
.52167 .30815 L
.52295 .30828 L
.52412 .3089 L
.5252 .30962 L
.52639 .31018 L
.52766 .3102 L
.5283 .30997 L
.529 .30959 L
.53026 .30882 L
.53149 .30838 L
.53262 .30848 L
.53368 .30902 L
.53467 .3097 L
.53576 .31035 L
.53693 .31064 L
.53815 .31034 L
.53931 .30969 L
.54044 .30906 L
.54148 .30879 L
.54273 .30907 L
.54339 .30944 L
.54408 .30993 L
.54535 .31081 L
.54653 .31123 L
.54759 .31112 L
.54872 .31059 L
.54996 .30988 L
.55111 .30951 L
.55243 .30976 L
.55312 .31016 L
.55386 .31071 L
.55451 .31122 L
.55521 .3117 L
.55647 .31217 L
.55768 .31198 L
.55879 .31142 L
.5601 .31074 L
.56135 .31056 L
.5625 .31099 L
.56356 .31177 L
.56469 .31271 L
.56591 .31338 L
.56705 .31345 L
.56809 .31307 L
.56908 .31253 L
Mistroke
.57015 .31207 L
.5713 .31203 L
.57237 .31253 L
.57365 .31361 L
.57482 .3146 L
.57603 .3152 L
.57735 .31511 L
.5786 .31453 L
.57975 .314 L
.58093 .31391 L
.58217 .3145 L
.58323 .31545 L
.58438 .31657 L
.58563 .31739 L
.58633 .31754 L
.58697 .31748 L
.58821 .31699 L
.58938 .31645 L
.59047 .3163 L
.59163 .31676 L
.59262 .31762 L
.59371 .31879 L
.59488 .31987 L
.59614 .3204 L
.59733 .32022 L
.59841 .31973 L
.59968 .3193 L
.60039 .31933 L
.60104 .31958 L
.60229 .32064 L
.60347 .32202 L
.60414 .32277 L
.60485 .3234 L
.60612 .32393 L
.60683 .32387 L
.60748 .32365 L
.6082 .32334 L
.60898 .32303 L
.61028 .32302 L
.61152 .32384 L
.61272 .32525 L
.61383 .32668 L
.61502 .3278 L
.61634 .32818 L
.61701 .32805 L
.61772 .32777 L
.61901 .32731 L
.62028 .32749 L
.62142 .32844 L
.62274 .33021 L
Mistroke
.62399 .33192 L
.62514 .33295 L
.62621 .33321 L
.62737 .33291 L
.62861 .33246 L
.62985 .33255 L
.63055 .33301 L
.63119 .33368 L
.6336 .33733 L
.63426 .33815 L
.63495 .33876 L
.63571 .33908 L
.63642 .33907 L
.63769 .33863 L
.63841 .3384 L
.63909 .33837 L
.64032 .33902 L
.64102 .33985 L
.64167 .34085 L
.64309 .34335 L
.64439 .34516 L
.64559 .34589 L
.64673 .34576 L
.64794 .34531 L
.64925 .34532 L
.65056 .3465 L
.65131 .34771 L
.65201 .34905 L
.6528 .35061 L
.65354 .35194 L
.65421 .35286 L
.65494 .3535 L
.65626 .35367 L
.65748 .3532 L
.6588 .35304 L
.65953 .35345 L
.6602 .35421 L
.68108 .37609 L
.70028 .39869 L
.71904 .42211 L
.72138 .43669 L
.72253 .44401 L
.7236 .44711 L
.72482 .44482 L
.72547 .44152 L
.72616 .43726 L
.72726 .43134 L
.72849 .43068 L
.72918 .4345 L
.72982 .44077 L
Mistroke
.73052 .4501 L
.73125 .46135 L
.73249 .47774 L
.73319 .48183 L
.73385 .48002 L
.73511 .45688 L
.73627 .41221 L
.7376 .33934 L
.73885 .26359 L
.74 .20205 L
.74124 .15647 L
.74241 .13751 L
.74348 .13848 L
.74473 .15357 L
.74539 .16374 L
.7461 .17384 L
.74739 .186 L
.74858 .18772 L
.74928 .18516 L
.74992 .1815 L
.75061 .17718 L
.75136 .17322 L
.75264 .17096 L
.75333 .17262 L
.75398 .1758 L
.75519 .18417 L
.7565 .19297 L
.75773 .19743 L
.75887 .19736 L
.75995 .1948 L
.76114 .19173 L
.76238 .19098 L
.76354 .1937 L
.76461 .19851 L
.76559 .20353 L
.76672 .20828 L
.76779 .21057 L
.76893 .21046 L
.77015 .20866 L
.77131 .20727 L
.77235 .20758 L
.77358 .21041 L
.77428 .21292 L
.77491 .2155 L
.77607 .21991 L
.77733 .22294 L
.77859 .22351 L
.77979 .22251 L
.78095 .22153 L
.78202 .22175 L
Mistroke
.78318 .22376 L
.78446 .22766 L
.78512 .22989 L
.78582 .23205 L
.78706 .23474 L
.78813 .2355 L
.78931 .23503 L
.79057 .23421 L
.79174 .23436 L
.79286 .23591 L
.79387 .23839 L
.79495 .2415 L
.79614 .24448 L
.79743 .2462 L
.79814 .24641 L
.79879 .24624 L
.80005 .24558 L
.80124 .24547 L
.80191 .24594 L
.80263 .24695 L
.8039 .24972 L
.80468 .25168 L
.80541 .25341 L
.80606 .25469 L
.80677 .25566 L
.80808 .25624 L
.80929 .25583 L
.81059 .25542 L
.81125 .25559 L
.81197 .25618 L
.81318 .25812 L
.81447 .26094 L
.81567 .26334 L
.8168 .2647 L
.81802 .26503 L
.81867 .26485 L
.81937 .26456 L
.82006 .26434 L
.82079 .26435 L
.8221 .26531 L
.82331 .26727 L
.82444 .26949 L
.82567 .27159 L
.82699 .27273 L
.83807 .27956 L
.8582 .29038 L
.86846 .29449 L
.87957 .29764 L
.88071 .29781 L
.88195 .2987 L
Mistroke
.88304 .29986 L
.8842 .30101 L
.88484 .30145 L
.88555 .30171 L
.8868 .30159 L
.88803 .30103 L
.88918 .30056 L
.88984 .30049 L
.89054 .30064 L
.8918 .30146 L
.89327 .30288 L
.89398 .3035 L
.89463 .30391 L
.89581 .30416 L
.89707 .30378 L
.89836 .30311 L
.89901 .30287 L
.89973 .30278 L
.90105 .30321 L
.90228 .30419 L
.90349 .30526 L
.90464 .30593 L
.90528 .30605 L
.90598 .30598 L
.9072 .30545 L
.90795 .30504 L
.90865 .30472 L
.90996 .30457 L
.91113 .30506 L
.91239 .30605 L
.91365 .30702 L
.91428 .30734 L
.91498 .30749 L
.91623 .30724 L
.9174 .30661 L
.91848 .30606 L
.91963 .30586 L
.92032 .30601 L
.92104 .30637 L
.92234 .30733 L
.92302 .30784 L
.92374 .30827 L
.92454 .30851 L
.92529 .30849 L
.92594 .30829 L
.92665 .30793 L
.92734 .30752 L
.92808 .30712 L
.92878 .30686 L
.92941 .30679 L
Mistroke
.93065 .30712 L
.93185 .30791 L
.93312 .30879 L
.93379 .3091 L
.93452 .30924 L
.93581 .30895 L
.93694 .30831 L
.93814 .30765 L
.93946 .30741 L
.94068 .30781 L
.94193 .30862 L
.94309 .30935 L
.94414 .30967 L
.94527 .30951 L
.94638 .30895 L
.94754 .30824 L
.94854 .30783 L
.94963 .30781 L
.9507 .30824 L
.95167 .30886 L
.95272 .30952 L
.95386 .3099 L
.95491 .3098 L
.95589 .30935 L
.95689 .30872 L
.9578 .30821 L
.95886 .30794 L
.95999 .30814 L
.96099 .30867 L
.96205 .30936 L
.96321 .30991 L
.96428 .30999 L
.96546 .30956 L
.96672 .30878 L
.96795 .30815 L
.96864 .308 L
.96928 .30804 L
.97045 .3085 L
.97169 .30928 L
.9728 .30985 L
.97383 .31003 L
.97497 .30973 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00WooonfX4o`0007[ooo]Z1Ol0001noookJPCo
0000W?oonfX009oooo]Z1?l0001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000N_oo
nfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX0
09kooo]Z1Ol0001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000N_oonfX5o`0007ko
oo]Z1Ol0002KoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z
002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1Ol0001]
oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX5o`0005gooo]Z2_l007l6oook
JP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00WOoonfX6o`0005gooo]Z2_l007l6oookJP?o
001o2_oonfX6o`0007gooo]Z1_l0002JoookJP00WOoonfX6o`0006gooo]Z0ol007l:oookJPGo0000
O_oonfX6o`0009[ooo]Z002MoookJPOo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oo
nfX009gooo]Z1ol0001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00WOoonfX7o`00
06cooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002MoookJPOo0000JOoonfX6o`00O`[o
oo]Z1Ol0001noookJPKo0000V_oonfX009gooo]Z1ol0001YoookJPKo001o2_oonfX5o`0007kooo]Z
1_l0002JoookJP00WOoonfX7o`0006_ooo]Z1?l007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002M
oookJP[o0000JOoonfX3o`00O`[ooo]Z1Ol0001noookJP[o0000U_oonfX009gooo]Z2ol0001eoook
JPGo0000O_oonfX:o`0009Kooo]Z002MoookJP_o0000MOoonfX5o`0007kooo]Z2_l0002FoookJP00
WOoonfX<o`0007Cooo]Z1Ol0001noookJP_o0000UOoonfX009gooo]Z3?l0001doookJPGo0000O_oo
nfX;o`0009Gooo]Z002MoookJPco0000M?oonfX5o`0007gooo]Z3?l0002EoookJP00WOoonfX<o`00
07Cooo]Z1Ol0001moookJPco0000UOoonfX009gooo]Z3?l0001doookJPGo0000OOoonfX<o`0009Go
oo]Z002MoookJPco0000M?oonfX5o`0007gooo]Z3?l0002EoookJP00WOoonfX<o`0007Cooo]Z1Ol0
001moookJPco0000UOoonfX009gooo]Z3?l0001doookJPGo0000OOoonfX=o`0009Cooo]Z002Moook
JQ3o0000L?oonfX5o`0007gooo]Z4?l0002AoookJP00WOoonfXAo`0006oooo]Z1Ol0001moookJPCo
000000?ooo]Zo`000?l000002Ol0002AoookJP00WOoonfX4o`0000Cooo]Z2Ol0001_oookJPGo0000
OOoonfX4o`0000Gooo]Z2?l0002@oookJP00WOoonfX4o`0000Gooo]Z2?l0001_oookJPGo0000OOoo
nfX4o`0000Gooo]Z2?l0002@oookJP00WOoonfX4o`0000Gooo]Z2?l0001_oookJPGo0000OOoonfX4
o`0000Gooo]Z2?l0002@oookJP00WOoonfX4o`0000Gooo]Z2Ol0001^oookJPGo0000OOoonfX4o`00
00Gooo]Z2?l0002@oookJP00WOoonfX4o`0000Kooo]Z2?l0001^oookJPGo0000OOoonfX4o`0000Ko
oo]Z2?l0002?oookJP00WOoonfX4o`0000Kooo]Z2?l0001^oookJPGo0000OOoonfX4o`0000Kooo]Z
2?l0002?oookJP00WOoonfX4o`0000[ooo]Z1?l0001^oookJPGo0000OOoonfX4o`0000Wooo]Z1Ol0
002?oookJP00WOoonfX4o`0000[ooo]Z1ol0001[oookJPGo0000OOoonfX4o`0000[ooo]Z2?l0002;
oookJP00WOoonfX4o`0000[ooo]Z2?l0001ZoookJPGo0000OOoonfX4o`0000[ooo]Z2?l0002;oook
JP00WOoonfX4o`0000[ooo]Z2?l0001ZoookJPGo0000OOoonfX4o`0000[ooo]Z2?l0002;oookJP00
WOoonfX4o`0000[ooo]Z2Ol0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2?l0002:oookJP00WOoo
nfX4o`0000[ooo]Z2Ol0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2?l0002:oookJP00WOoonfX4
o`0000_ooo]Z2?l0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2?l0002:oookJP00WOoonfX4o`00
00oooo]Z1?l0001YoookJPGo0000OOoonfX4o`0000oooo]Z1Ol00029oookJP00WOoonfX4o`0000oo
oo]Z1?l0001YoookJPGo0000OOoonfX4o`0000oooo]Z1Ol00029oookJP00WOoonfX4o`0000oooo]Z
2?l0001UoookJPGo0000OOoonfX4o`0000oooo]Z2?l00026oookJP00WOoonfX4o`0000oooo]Z2?l0
001UoookJPGo0000OOoonfX4o`00013ooo]Z1ol00026oookJP00WOoonfX4o`0000oooo]Z2?l00017
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000OOoonfX4o`00013ooo]Z1ol00026
oookJP00WOoonfX4o`00013ooo]Z2?l00015oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oook
JPGo0000OOoonfX4o`00013ooo]Z2?l00025oookJP00WOoonfX4o`00017ooo]Z1ol00015oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000AoookJPSo0000Q?oonfX009gooo]Z1?l0000Coook
JPKo0000=ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000OOoonfX4o`0001?ooo]Z1_l00024oookJP00WOoonfX4o`0001Cooo]Z2?l0000doookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007_ooo]Z1Ol0000DoookJPOo
0000P_oonfX009gooo]Z1?l0000DoookJPSo0000@?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX5o`0007cooo]Z1Ol0000EoookJPSo0000P?oonfX009gooo]Z1?l0000EoookJPSo0000?ooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001loookJPGo00005Ooo
nfX8o`00083ooo]Z002MoookJPCo00005OoonfX8o`0003oooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Wooo]Z1Ol0001loookJPCo00005_oonfX8o`00083ooo]Z002MoookJPCo00005_oonfX7o`00
03oooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001loookJPCo00005ooonfX8o`00
07oooo]Z002MoookJPCo00006OoonfX5o`0003kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`ko
oo]Z1Ol0001loookJPCo00006_oonfX5o`0007oooo]Z002MoookJPCo00006OoonfX5o`0003oooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007cooo]Z1?l0000JoookJPGo
0000OooonfX009gooo]Z1?l0000IoookJPSo0000??oonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000
O?oonfX4o`0001_ooo]Z2?l0001koookJP00WOoonfX4o`0001[ooo]Z2?l0000loookJPGo001o2_oo
nfX7o`00O`Sooo]Z1Ol0001loookJPCo00006ooonfX8o`0007_ooo]Z002MoookJPCo00006_oonfX9
o`0005Wooo]Z1Ol0001loookJPCo00006ooonfX9o`0007[ooo]Z002MoookJPCo00006ooonfX8o`00
05Wooo]Z1Ol0001loookJPCo00007?oonfX8o`0007[ooo]Z002MoookJPCo00007_oonfX6o`0005So
oo]Z1Ol0001loookJPCo00007ooonfX6o`0007Wooo]Z002MoookJPCo00007ooonfX8o`0005Gooo]Z
1Ol0001loookJPCo00008?oonfX8o`0007Kooo]Z002LoookJPGo00007ooonfX8o`0005Gooo]Z1Ol0
001loookJPCo00008?oonfX9o`0007Gooo]Z002LoookJPGo00008?oonfX8o`0005Cooo]Z1Ol0001l
oookJPCo00008OoonfX8o`0007Gooo]Z002LoookJPGo00008?oonfX8o`0005Cooo]Z1Ol0001loook
JPCo00008OoonfX8o`0007Gooo]Z002LoookJPCo00009?oonfX6o`0005?ooo]Z1Ol0001loookJPCo
00009OoonfX5o`0007Cooo]Z002LoookJPCo00009OoonfX8o`00053ooo]Z1Ol0001loookJPCo0000
9OoonfX9o`00073ooo]Z002LoookJPCo00009OoonfX9o`0004oooo]Z1Ol0001loookJPCo00009Ooo
nfX9o`00073ooo]Z002LoookJPCo00009_oonfX8o`0004oooo]Z1Ol0001loookJPCo00009_oonfX8
o`00073ooo]Z002LoookJPCo00009_oonfX9o`0004kooo]Z1Ol0001loookJPCo00009ooonfX8o`00
06oooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00000ooonfX3o`00O`?ooo]Z1Ol007lLoookJPSo
0000BooonfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX5o`00Ob;ooo]Z1ol0001=oookJP?o
001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o1?l00003oookJP?o001o0_oonfX7o`00Oa_ooo]Z
2Ol0001:oookJPGo0000LooonfX7o`00O`;ooo]Z1?l00002oookJPOo001o8OoonfX8o`0004cooo]Z
0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00Oacooo]Z2?l0001:oookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
Ob;ooo]Z2Ol0001:oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Cooo]Z0ol007l3oookJP?o
001o7?oonfX8o`0004Wooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o
000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ob7ooo]Z2_l00019oookJP?o001o7OoonfX001?o
oo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000002o`000003
o`00Oooonf[ooo]Z00[ooo]Z0ol007lOoookJPWo0000AOoonfX5o`0007;ooo]Z0ol007l3oookJP?o
001o00?ooo]Zo`000?l000000_l00007oookJP?o001o9?oonfX9o`0004Oooo]Z0ol007lMoookJP00
8_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00[ooo]Z
0ol007lOoookJP[o0000A?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l00000
0_l00007oookJP?o001o9OoonfX:o`0004Gooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol0
07l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l2oookJPCo001o8?oo
nfX9o`0004Cooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oo
nfX2o`00O`;ooo]Z1?l007lWoookJP[o0000@ooonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3
o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX7o`00Ob;ooo]Z3Ol0000o
oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1ol007lY
oookJP[o0000@_oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o0000
00;o000000?o001ooookJ_oonfX01OoonfX6o`00ObOooo]Z2Ol0000ooookJPGo0000L_oonfX3o`00
O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1_l007l/oookJP[o0000@?oonfX3o`00
Oagooo]Z000OoookJPKo001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oo
nfX01OoonfX2o`00Ob_ooo]Z2_l0000noookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o
0000o`000002o`0000;ooo]Z0_l007lboookJP[o0000>ooonfX6o`00Oagooo]Z000OoookJPKo001o
M?oonfX3o`00O`Co00002?oonfX2o`00Obcooo]Z3Ol0000joookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l00002oookJP;o001o=?oonfX;o`0003Sooo]Z1_l007lMoookJP00
8OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol007lZoookJP[o0000>OoonfX5o`0007?ooo]Z
1ol007l2oookJPCo00000ooonfX7o`00Oboooo]Z3Ol0000goookJPCo001o7OoonfX002;ooo]Z0ol0
07meoookJP;o001o1?l00009oookJPOo001o:ooonfX=o`0003Gooo]Z1Ol0001doookJPGo001o0ooo
nfX4o`0000?ooo]Z1ol007laoookJPko0000=OoonfX3o`00Oagooo]Z002LoookJPCo0000??oonfX=
o`0003Cooo]Z1Ol0001loookJPCo0000?OoonfX?o`0005;ooo]Z002LoookJPCo0000@?oonfX=o`00
033ooo]Z1Ol0001loookJPCo0000@?oonfX>o`00053ooo]Z002LoookJPCo0000@?oonfXBo`0002_o
oo]Z1Ol0001loookJPCo0000@ooonfX@o`0004_ooo]Z002LoookJPCo0000A?oonfX?o`0002[ooo]Z
1Ol0001loookJPCo0000A_oonfX=o`0004_ooo]Z002LoookJPCo0000A_oonfXCo`0002Cooo]Z1Ol0
001loookJPCo0000BOoonfX@o`0004Gooo]Z002LoookJPCo0000B_oonfXIo`0001[ooo]Z1Ol0001l
oookJPCo0000BooonfXHo`0003_ooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000MoookJP03o`000?oonf[ooo]Z
00cooo]Z9Ol0001;oookJPCo0000M_oonfX4o`0000;ooo]Z2Ol000000ooonf[o0000o`000002o`00
0003oookJ_l0003o000002Ko0000BooonfX4o`00077ooo]Z1?l000000ooonf[o0000o`000003o`00
0003oookJ_l0003o000000;o00007_oonfX003[ooo]Z6?l0001:oookJPCo0000OOoonfX5o`0001[o
oo]Z6?l0001:oookJPCo0000W_oonfX004?ooo]Z4ol00016oookJPCo0000OOoonfX5o`0002?ooo]Z
4ol00016oookJPCo0000W_oonfX004Sooo]Z3ol00015oookJPCo0000OOoonfX5o`0002Sooo]Z3ol0
0015oookJPCo0000W_oonfX004[ooo]Z4ol0000ooookJPCo0000OOoonfX5o`0002Wooo]Z4_l00011
oookJPCo0000W_oonfX004kooo]Z4_l0000loookJPCo0000OOoonfX5o`0002kooo]Z3_l00010oook
JPCo0000W_oonfX005?ooo]Z3ol0000joookJPCo0000OOoonfX5o`0003?ooo]Z3Ol0000loookJPCo
0000W_oonfX005?ooo]Z4Ol0000goookJPGo0000OOoonfX5o`0003Cooo]Z3Ol0000koookJPCo0000
W_oonfX005[ooo]Z2ol0000foookJPGo0000OOoonfX5o`0003Sooo]Z2_l0000joookJPCo0000W_oo
nfX005gooo]Z2_l0000doookJPGo0000OOoonfX5o`0003Wooo]Z3Ol0000foookJPCo0000W_oonfX0
05oooo]Z2_l0000boookJPCo0000O_oonfX5o`0003gooo]Z2Ol0000foookJPCo0000W_oonfX0067o
oo]Z2Ol0000aoookJPCo0000O_oonfX5o`0003kooo]Z2Ol0000eoookJPCo0000W_oonfX006;ooo]Z
2_l0000_oookJPCo0000O_oonfX5o`0003oooo]Z3?l0000aoookJPCo0000W_oonfX006Cooo]Z2Ol0
000^oookJPCo0000O_oonfX5o`0004;ooo]Z2_l0000`oookJPCo0000W_oonfX006Kooo]Z2?l0000]
oookJPCo0000O_oonfX5o`0004?ooo]Z2Ol0000`oookJPCo0000W_oonfX006Oooo]Z2?l0000/oook
JPCo0000O_oonfX5o`0004Cooo]Z2Ol0000_oookJPCo0000W_oonfX006Wooo]Z1ol0000[oookJPCo
0000O_oonfX5o`0004Oooo]Z2_l0000[oookJPCo0000W_oonfX006[ooo]Z1ol0000ZoookJPCo0000
O_oonfX5o`0004Sooo]Z2Ol0000[oookJPCo0000W_oonfX006_ooo]Z1ol0000YoookJPCo0000O_oo
nfX5o`0004Wooo]Z2?l0000[oookJPCo0000W_oonfX006cooo]Z1ol0000XoookJPCo0000O_oonfX5
o`0004Wooo]Z2Ol0000ZoookJPCo0000W_oonfX006gooo]Z1ol0000WoookJPCo0000O_oonfX5o`00
04gooo]Z2?l0000WoookJPCo0000W_oonfX006kooo]Z1ol0000VoookJPCo0000O_oonfX5o`0004go
oo]Z2Ol0000VoookJPCo0000W_oonfX006oooo]Z1ol0000UoookJPCo0000O_oonfX5o`0004kooo]Z
2Ol0000UoookJPCo0000W_oonfX0073ooo]Z1ol0000ToookJPCo0000O_oonfX5o`0004oooo]Z2Ol0
000ToookJPCo0000W_oonfX0077ooo]Z1ol0000SoookJPCo0000O_oonfX5o`0005;ooo]Z1ol0000S
oookJPCo0000W_oonfX007;ooo]Z1ol0000RoookJPCo0000O_oonfX5o`0005?ooo]Z1ol0000Roook
JPCo0000W_oonfX007?ooo]Z1ol0000QoookJPCo0000O_oonfX5o`0005Cooo]Z1ol0000QoookJPCo
0000W_oonfX007Cooo]Z1ol0000PoookJPCo0000O_oonfX5o`0005Gooo]Z1ol0000PoookJPCo0000
W_oonfX007Gooo]Z1ol0000OoookJPCo0000O_oonfX5o`0005Kooo]Z1ol0000OoookJPCo0000W_oo
nfX007Kooo]Z1ol0000NoookJPCo0000O_oonfX5o`0005Oooo]Z1ol0000NoookJPCo0000W_oonfX0
07Oooo]Z1ol0000MoookJPCo0000O_oonfX5o`0005Sooo]Z1ol0000MoookJPCo0000W_oonfX007So
oo]Z1ol0000LoookJPCo0000O_oonfX5o`0005Wooo]Z1ol0000LoookJPCo0000W_oonfX007Wooo]Z
1ol0000KoookJPCo0000O_oonfX5o`0005[ooo]Z1ol0000KoookJPCo0000W_oonfX007[ooo]Z1ol0
000JoookJPCo0000O_oonfX5o`0005_ooo]Z1_l0000JoookJPGo0000W_oonfX007_ooo]Z1ol0000I
oookJPCo0000O_oonfX5o`0005cooo]Z1_l0000IoookJPGo0000W_oonfX007cooo]Z1_l0000Ioook
JPCo0000H?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0005gooo]Z1_l0000Hoook
JPGo0000W_oonfX007gooo]Z1_l0000HoookJPCo0000GooonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o2OoonfX5o`0005gooo]Z1ol0000GoookJPCo0000WooonfX007kooo]Z1_l0000GoookJPCo0000
GooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00O`Wooo]Z1Ol0001NoookJPOo00005_oonfX4o`0009oooo]Z001noookJPOo
00005_oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo
0000GooonfX7o`0001Gooo]Z1?l0002OoookJP00OooonfX6o`0001Kooo]Z1?l0001NoookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000GooonfX7o`0001Cooo]Z1?l0002OoookJP00P?oo
nfX6o`0001Gooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000HOoo
nfX6o`0001Cooo]Z1?l0002OoookJP00POoonfX6o`0001Cooo]Z1?l0001NoookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0006;ooo]Z1_l0000CoookJPCo0000WooonfX0
087ooo]Z1ol0000CoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5o`00
06?ooo]Z1_l0000BoookJPCo0000WooonfX008;ooo]Z1ol0000BoookJPCo0000G_oonfX3o`00O`?o
oo]Z0ol007l7oookJPKo001o2_oonfX5o`0006?ooo]Z1ol0000AoookJPCo0000WooonfX008?ooo]Z
1_l0000BoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0006Cooo]Z
1ol0000@oookJPCo0000WooonfX008Cooo]Z1_l0000AoookJPCo0000GooonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000IOoonfX7o`0000oooo]Z1?l0002OoookJP00QOoo
nfX6o`00013ooo]Z1?l0001OoookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001VoookJPKo00003ooo
nfX4o`0009oooo]Z0025oookJPOo00003ooonfX4o`00063ooo]Z1Ol007l:oookJPOo001o2?oonfX5
o`0006Oooo]Z1_l0000>oookJPCo0000WooonfX008Kooo]Z1_l0000?oookJPCo0000O_oonfX5o`00
06Sooo]Z1_l0000=oookJPCo0000WooonfX008Oooo]Z1_l0000>oookJPCo0000O_oonfX5o`0006So
oo]Z1ol0000<oookJPCo0000WooonfX008Sooo]Z1_l0000=oookJPCo0000O_oonfX5o`0006Wooo]Z
1ol0000;oookJPCo0000WooonfX008Sooo]Z1ol0000<oookJPCo0000O_oonfX5o`0006[ooo]Z1ol0
000:oookJPCo0000WooonfX008Wooo]Z1ol0000;oookJPCo0000O_oonfX5o`0006_ooo]Z1_l0000:
oookJPCo0000WooonfX008[ooo]Z1ol0000:oookJPCo0000O_oonfX5o`0006cooo]Z1_l00009oook
JPCo0000WooonfX008_ooo]Z1_l0000:oookJPCo0000O_oonfX5o`0006gooo]Z1_l00008oookJPCo
0000WooonfX008cooo]Z1_l00009oookJPCo0000O_oonfX5o`0006gooo]Z1ol00007oookJPCo0000
WooonfX008gooo]Z1_l00008oookJPCo0000O_oonfX5o`0006kooo]Z1ol00006oookJPCo0000Wooo
nfX008gooo]Z1ol00007oookJPCo0000O_oonfX5o`0006oooo]Z1ol00005oookJPCo0000WooonfX0
08kooo]Z1ol00006oookJPCo0000O_oonfX5o`00073ooo]Z1_l00005oookJPCo0000WooonfX008oo
oo]Z1ol00005oookJPCo0000O_oonfX5o`00077ooo]Z1Ol00005oookJPCo0000WooonfX0093ooo]Z
1_l00005oookJPCo0000O_oonfX5o`0007;ooo]Z1?l00005oookJPCo0000WooonfX0097ooo]Z1Ol0
0005oookJPCo0000O_oonfX5o`0007;ooo]Z1?l00005oookJPCo0000WooonfX009;ooo]Z3Ol0001n
oookJPGo0000L_oonfX=o`0009oooo]Z002BoookJPgo0000O_oonfX5o`0007;ooo]Z3Ol0002Ooook
JP00T_oonfX=o`0007kooo]Z1Ol0001boookJPgo0000WooonfX009?ooo]Z3?l0001noookJPGo0000
LooonfX<o`0009oooo]Z002CoookJPco0000O_oonfX5o`0007?ooo]Z3?l0002OoookJP00TooonfX<
o`0007kooo]Z1Ol0001coookJPco0000WooonfX009?ooo]Z3?l0001noookJPGo0000LooonfX;o`00
0:3ooo]Z002CoookJPco0000O_oonfX5o`0007?ooo]Z2ol0002PoookJP00TooonfX<o`0007kooo]Z
1Ol0001coookJP_o0000X?oonfX009?ooo]Z3?l0001noookJPGo0000M?oonfX:o`000:3ooo]Z002C
oookJPco0000O_oonfX5o`0007Cooo]Z2_l0002PoookJP00U?oonfX;o`0007kooo]Z1Ol0001doook
JP[o0000X?oonfX009Sooo]Z1ol0001noookJPGo0000M?oonfX:o`000:3ooo]Z002HoookJPOo0000
O_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX6o`0007oooo]Z1Ol0001hoookJPKo0000X?oo
nfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX6o`00
07;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[o
oo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z
1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPKo0000MooonfX6o`000:3ooo]Z002H
oookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0001boook
JP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo
0000N?oonfX6o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000
X?oonfX009Wooo]Z1Ol0001_oookJPKo001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00VOoonfX5
o`0006oooo]Z1_l007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000LOoonfX4o`00
O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001boookJP?o001o2_oonfX5o`0007Wo
oo]Z1Ol0002PoookJP00VOoonfX4o`00083ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1?l0
0020oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPCo0000P?oonfX5o`0007Wooo]Z1Ol0002P
oookJP00VOoonfX4o`00083ooo]Z1Ol0001ioookJPCo0000XOoonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0
003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX0
0?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o
001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o
2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPKo001o2_oo
nfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX0
0?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[o
oo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJPgo
oo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1?l007l<
oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX6o`000?oooo]Z7_oonfX00?oo
oo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol007l9oookJPGo0000
oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3
o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgo
oo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooonfX>oookJPOo001ooooonfX]oookJP00oooo
nfX?oookJPGo001ooooonfX^oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001
\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30971 L
.02605 .31001 L
.02729 .30978 L
.02846 .30912 L
.02946 .3085 L
.03053 .30808 L
.0317 .30812 L
.03279 .30862 L
.03395 .30936 L
.0352 .30995 L
.03638 .30997 L
.03746 .30953 L
.03873 .30874 L
.03939 .30838 L
.04011 .30813 L
.04141 .3082 L
.04262 .30882 L
.04387 .30962 L
.04519 .31012 L
.04588 .3101 L
.04664 .30987 L
.04733 .30951 L
.04797 .3091 L
.04925 .30841 L
.05041 .30823 L
.05105 .30837 L
.05175 .3087 L
.05302 .30953 L
.05414 .31017 L
.05539 .31037 L
.05669 .30992 L
.05791 .30918 L
.05905 .30864 L
.06009 .30855 L
.06124 .30897 L
.06244 .30978 L
.0631 .31023 L
.0638 .31061 L
.06509 .31082 L
.06633 .31039 L
.06748 .30971 L
.06873 .30914 L
.06944 .30907 L
.0701 .30919 L
.0708 .30951 L
.07144 .30994 L
.07213 .31046 L
.07287 .31099 L
.0741 .31151 L
Mistroke
.07525 .31144 L
.07595 .31114 L
.07661 .31077 L
.07784 .31011 L
.07903 .30988 L
.08011 .31021 L
.08131 .31104 L
.08257 .31202 L
.08327 .3124 L
.08394 .31258 L
.08519 .3124 L
.08589 .31206 L
.08654 .3117 L
.08729 .31131 L
.088 .31108 L
.08917 .31116 L
.09046 .31193 L
.09171 .313 L
.09237 .3135 L
.09307 .31387 L
.0938 .31404 L
.09448 .31397 L
.09526 .31368 L
.09596 .31331 L
.09662 .31296 L
.09733 .31269 L
.09861 .3127 L
.09933 .31304 L
.10012 .31364 L
.10089 .31436 L
.10172 .3151 L
.10249 .31563 L
.1032 .31589 L
.10391 .31592 L
.10458 .31574 L
.10572 .3152 L
.10694 .31469 L
.1081 .31471 L
.10916 .31529 L
.11033 .31639 L
.11157 .31759 L
.11229 .31808 L
.11294 .31831 L
.11422 .31819 L
.11545 .31762 L
.1161 .31734 L
.11678 .31717 L
.11804 .31743 L
.11921 .31835 L
.12041 .31967 L
Mistroke
.12171 .32088 L
.12245 .32125 L
.12313 .32135 L
.12382 .32122 L
.12446 .32097 L
.1256 .32046 L
.12668 .32028 L
.12791 .32078 L
.12903 .32187 L
.1301 .32316 L
.13109 .32423 L
.13213 .32488 L
.13327 .32494 L
.13443 .32451 L
.13567 .32406 L
.13683 .32419 L
.13789 .32496 L
.14288 .32931 L
.15292 .33436 L
.15843 .3369 L
.16359 .33995 L
.1727 .34703 L
.18274 .35468 L
.2012 .3738 L
.22109 .3966 L
.24115 .42216 L
.24235 .42091 L
.24366 .42454 L
.24489 .43243 L
.24602 .44077 L
.24665 .44453 L
.24735 .44709 L
.24807 .44756 L
.24875 .44591 L
.24995 .43938 L
.25123 .43198 L
.25196 .43028 L
.25276 .43215 L
.25352 .43798 L
.25421 .44655 L
.25495 .4577 L
.25565 .46841 L
.25694 .48156 L
.25818 .47518 L
.25887 .46018 L
.25951 .43868 L
.26015 .41048 L
.26085 .37319 L
.26225 .28746 L
.26348 .21679 L
Mistroke
.26478 .16254 L
.26545 .14586 L
.2662 .13695 L
.26752 .1413 L
.26875 .15869 L
.26944 .16921 L
.27009 .17778 L
.27134 .18707 L
.27249 .1864 L
.27361 .18029 L
.2748 .17321 L
.27593 .17037 L
.27695 .17255 L
.27815 .17984 L
.27945 .18939 L
.28068 .19565 L
.28181 .19715 L
.30275 .2214 L
.32316 .24406 L
.34222 .26294 L
.35163 .27083 L
.36054 .27796 L
.36177 .27761 L
.36293 .27793 L
.36413 .27918 L
.36477 .28013 L
.36546 .28126 L
.36617 .28238 L
.36691 .28336 L
.36755 .28395 L
.36824 .28429 L
.36888 .28434 L
.36957 .28418 L
.37081 .2837 L
.37202 .28362 L
.37334 .28447 L
.37458 .28607 L
.37572 .28774 L
.37675 .28892 L
.37789 .28952 L
.37907 .2894 L
.38018 .28895 L
.38143 .2887 L
.38213 .28888 L
.38276 .28929 L
.384 .29064 L
.38516 .29219 L
.38582 .29297 L
.38652 .29358 L
.38777 .294 L
Mistroke
.38846 .29389 L
.38911 .29365 L
.38982 .29333 L
.39058 .29309 L
.39187 .29323 L
.39308 .29416 L
.39426 .29554 L
.39535 .29678 L
.39653 .29762 L
.39783 .29769 L
.39848 .29746 L
.39919 .29714 L
.40046 .29671 L
.40163 .29689 L
.40271 .29766 L
.4039 .29893 L
.40518 .30021 L
.40582 .30063 L
.40651 .30086 L
.40777 .30067 L
.409 .30009 L
.41013 .29971 L
.41119 .29982 L
.41219 .3004 L
.41327 .30143 L
.41444 .30257 L
.41566 .30331 L
.41682 .30336 L
.41786 .30296 L
.41899 .30239 L
.42021 .3021 L
.42132 .30241 L
.42254 .30333 L
.42383 .30451 L
.42495 .30525 L
.426 .30543 L
.42715 .30509 L
.42837 .30444 L
.42907 .30414 L
.42971 .304 L
.43042 .30406 L
.43116 .30436 L
.43242 .3053 L
.43314 .30593 L
.4338 .30643 L
.43503 .30697 L
.43635 .3068 L
.43757 .30616 L
.43874 .30559 L
.44006 .30548 L
Mistroke
.44126 .30603 L
.44192 .30652 L
.44264 .3071 L
.44394 .30794 L
.44517 .30814 L
.44646 .30769 L
.44767 .30699 L
.44878 .30654 L
.45008 .30662 L
.4508 .30696 L
.45148 .30742 L
.4527 .30832 L
.454 .30892 L
.45468 .30896 L
.45543 .30878 L
.45675 .30807 L
.45749 .30764 L
.45829 .3073 L
.45904 .3072 L
.45973 .30732 L
.46101 .308 L
.46222 .30885 L
.4633 .30939 L
.46447 .30946 L
.46575 .30893 L
.4664 .30854 L
.46711 .30812 L
.46836 .30767 L
.46954 .30782 L
.47072 .30845 L
.47184 .3092 L
.47284 .30969 L
.47394 .30979 L
.47512 .30936 L
.47639 .30858 L
.47758 .30801 L
.47866 .30792 L
.47996 .30842 L
.48062 .30884 L
.48133 .30931 L
.48261 .30989 L
.48379 .30989 L
.48451 .30961 L
.48519 .30923 L
.48647 .30844 L
.48718 .30813 L
.48784 .308 L
.48856 .30808 L
.48933 .30837 L
.49052 .30909 L
Mistroke
.49179 .3098 L
.493 .31 L
.4941 .30966 L
.49539 .30889 L
.49607 .30847 L
.4968 .30815 L
.4975 .30803 L
.49813 .30808 L
.49936 .30862 L
.50048 .30933 L
.50168 .3099 L
.503 .30994 L
.50423 .30938 L
.50489 .30896 L
.50561 .30852 L
.50692 .30804 L
.5082 .30823 L
.50938 .30887 L
.5104 .30951 L
.5115 .30997 L
.51271 .30994 L
.51384 .30942 L
.51505 .30866 L
.51632 .30812 L
.5174 .30815 L
.51859 .30868 L
.51927 .30912 L
.52 .30958 L
.52069 .30993 L
.52132 .31011 L
.52253 .30999 L
.5238 .30933 L
.52508 .30857 L
.5258 .3083 L
.52645 .30822 L
.52723 .30836 L
.52796 .30871 L
.52937 .30964 L
.53058 .31026 L
.53186 .31033 L
.53307 .30982 L
.53417 .30914 L
.53547 .30859 L
.5362 .30854 L
.53687 .3087 L
.5381 .3094 L
.53941 .3103 L
.54063 .3108 L
.54132 .31081 L
.54196 .31065 L
Mistroke
.54313 .31004 L
.54437 .30934 L
.54548 .30906 L
.54652 .30928 L
.54767 .30997 L
.5489 .31088 L
.55013 .31148 L
.55083 .31155 L
.55148 .31142 L
.5528 .31078 L
.55347 .31038 L
.5542 .31004 L
.55551 .30992 L
.55675 .31048 L
.55796 .31141 L
.55906 .3122 L
.56012 .31258 L
.56126 .31244 L
.56233 .31193 L
.56331 .31139 L
.56446 .31104 L
.5657 .31131 L
.56688 .31212 L
.56798 .31306 L
.56921 .31385 L
.57037 .31402 L
.57142 .31369 L
.57254 .3131 L
.57378 .31263 L
.57508 .3128 L
.57619 .31354 L
.5774 .31466 L
.57872 .31565 L
.57993 .31593 L
.58056 .31581 L
.58126 .31553 L
.582 .31515 L
.58267 .31483 L
.58391 .31463 L
.58459 .31482 L
.58524 .31521 L
.58639 .31626 L
.58765 .31749 L
.58888 .31824 L
.58999 .3183 L
.59127 .3178 L
.59248 .31727 L
.59361 .3172 L
.59464 .31768 L
.59578 .31875 L
Mistroke
.59697 .32006 L
.59828 .3211 L
.59946 .32134 L
.60012 .32119 L
.60084 .32089 L
.60213 .32035 L
.60335 .32037 L
.60464 .32124 L
.60574 .32249 L
.60695 .32391 L
.60764 .32452 L
.60837 .32489 L
.60967 .32488 L
.6104 .32461 L
.61107 .32431 L
.61181 .32407 L
.6126 .32406 L
.61329 .32433 L
.61403 .32492 L
.61474 .32571 L
.61538 .32656 L
.61668 .32821 L
.61791 .32917 L
.61908 .32931 L
.62035 .32886 L
.62151 .3285 L
.62258 .32866 L
.62386 .32975 L
.62501 .33135 L
.62567 .33232 L
.62636 .33323 L
.6276 .33428 L
.62867 .33445 L
.62985 .33408 L
.6311 .3337 L
.63227 .33396 L
.63338 .33503 L
.6344 .33653 L
.63548 .33829 L
.63667 .33979 L
.63795 .34042 L
.63865 .34036 L
.63931 .34014 L
.64049 .33974 L
.64175 .33995 L
.64242 .34051 L
.64316 .34147 L
.64463 .34405 L
.6453 .34519 L
.646 .34621 L
Mistroke
.64727 .34721 L
.65731 .35512 L
.67725 .37386 L
.69885 .39556 L
.70898 .40835 L
.71165 .41792 L
.71236 .42157 L
.71312 .42499 L
.71385 .42715 L
.71452 .42796 L
.71583 .42635 L
.71649 .4245 L
.71722 .42244 L
.7185 .42088 L
.71969 .42382 L
.72081 .43046 L
.72198 .43919 L
.72299 .44521 L
.72409 .44766 L
.72528 .44444 L
.72655 .43673 L
.72775 .43088 L
.72884 .43161 L
.73012 .44279 L
.73131 .46039 L
.73262 .47808 L
.73328 .48199 L
.734 .47961 L
.73522 .45577 L
.73652 .40133 L
.73775 .33019 L
.73888 .26072 L
.74017 .19256 L
.74138 .15126 L
.74247 .13654 L
.74365 .14073 L
.74494 .15862 L
.74564 .16945 L
.7463 .17805 L
.74746 .18684 L
.74873 .1862 L
.74992 .17952 L
.75104 .17298 L
.75205 .17038 L
.75315 .17259 L
.75434 .17982 L
.75561 .18913 L
.75669 .19499 L
.75788 .19719 L
.75919 .19502 L
Mistroke
.75984 .1931 L
.76056 .19122 L
.76184 .19016 L
.76303 .19289 L
.76452 .20002 L
.76525 .20377 L
.76593 .20667 L
.7672 .20968 L
.76787 .20986 L
.76857 .20922 L
.76977 .2073 L
.77088 .2062 L
.77211 .20734 L
.77342 .21142 L
.77481 .21706 L
.77613 .22114 L
.77732 .22247 L
.77861 .22176 L
.77985 .22052 L
.78117 .22063 L
.78186 .22166 L
.78261 .22352 L
.78394 .2279 L
.7852 .23177 L
.7859 .23325 L
.78654 .23403 L
.78778 .2341 L
.78896 .23327 L
.79009 .23285 L
.79129 .23381 L
.79232 .23595 L
.79345 .23916 L
.79466 .24248 L
.79597 .24467 L
.7972 .24504 L
.79833 .24449 L
.79962 .24405 L
.80034 .24434 L
.801 .24506 L
.80227 .2476 L
.80347 .25066 L
.80415 .25227 L
.80488 .25362 L
.80617 .25481 L
.80689 .25482 L
.80756 .25458 L
.80829 .25423 L
.80909 .25403 L
.80978 .2542 L
.81041 .25471 L
Mistroke
.81167 .25674 L
.81288 .25944 L
.81402 .26179 L
.81524 .26332 L
.81589 .26361 L
.81659 .26359 L
.81728 .26335 L
.81801 .26305 L
.81932 .26302 L
.82055 .26412 L
.82125 .26523 L
.82189 .26646 L
.82304 .26878 L
.82431 .2707 L
.82545 .27142 L
.82652 .27131 L
.82765 .27088 L
.82886 .2708 L
.83016 .27179 L
.8309 .27285 L
.83159 .27404 L
.83229 .27532 L
.83295 .27643 L
.83418 .2779 L
.83531 .27833 L
.83654 .27804 L
.83784 .27762 L
.83905 .27788 L
.84011 .2789 L
.84125 .28061 L
.84224 .2822 L
.84331 .28358 L
.84456 .28432 L
.84575 .28418 L
.84691 .28373 L
.84798 .28358 L
.8491 .28408 L
.85016 .28521 L
.85141 .28702 L
.85255 .28854 L
.85369 .28941 L
.85489 .2895 L
.8561 .28906 L
.85741 .28869 L
.85805 .28878 L
.85873 .28912 L
.85995 .29034 L
.86138 .29222 L
.86207 .29303 L
.86271 .29358 L
Mistroke
.86385 .294 L
.86509 .29374 L
.86575 .29345 L
.86644 .29317 L
.8677 .29311 L
.86879 .29371 L
.87 .29499 L
.8712 .29643 L
.8725 .29751 L
.87372 .29774 L
.87484 .29739 L
.876 .29687 L
.87705 .29669 L
.87827 .29714 L
.87957 .29835 L
.88079 .29968 L
.88192 .30059 L
.88323 .30086 L
.88392 .30069 L
.88466 .30036 L
.88589 .29981 L
.88659 .29968 L
.88725 .29977 L
.88791 .30007 L
.88864 .30062 L
.88996 .30193 L
.89124 .30302 L
.89243 .30342 L
.89316 .30332 L
.89385 .30306 L
.89513 .30241 L
.89585 .30216 L
.89651 .3021 L
.89724 .30228 L
.89801 .30272 L
.89923 .30379 L
.89987 .30438 L
.90055 .30492 L
.90181 .30543 L
.90296 .30525 L
.90402 .30473 L
.90514 .30418 L
.90636 .30401 L
.90749 .30444 L
.90868 .30536 L
.90998 .30643 L
.91119 .30696 L
.91232 .30687 L
.91301 .30658 L
.91367 .30622 L
Mistroke
.91489 .3056 L
.91621 .30548 L
.91696 .30574 L
.91765 .30617 L
.9187 .30699 L
.91969 .30771 L
.92084 .30814 L
.92189 .30802 L
.92304 .30747 L
.9243 .30677 L
.92547 .30648 L
.92655 .30673 L
.92779 .30751 L
.92895 .30836 L
.92999 .30887 L
.93112 .30892 L
.93235 .30842 L
.93365 .30765 L
.93476 .30724 L
.93598 .30734 L
.9372 .308 L
.93848 .3089 L
.93916 .30926 L
.9399 .30948 L
.9412 .3093 L
.94243 .30864 L
.94375 .30789 L
.945 .30766 L
.94615 .308 L
.94728 .3087 L
.94848 .30946 L
.94962 .30981 L
.95066 .30966 L
.95182 .30906 L
.95292 .30838 L
.95411 .30793 L
.9554 .30806 L
.9567 .30877 L
.95791 .30953 L
.9586 .30984 L
.95924 .30996 L
.95997 .30989 L
.96066 .30963 L
.96133 .30926 L
.96205 .3088 L
.96333 .30814 L
.96404 .308 L
.9647 .30806 L
.96544 .30833 L
.96622 .30878 L
Mistroke
.96754 .3096 L
.96876 .31 L
.97003 .30978 L
.9707 .30944 L
.97142 .30899 L
.97271 .30826 L
.97392 .30803 L
.97501 .30832 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00W_oonfX4o`0007_ooo]Z1Ol0001noookJPCo
0000W?oonfX009kooo]Z1?l0001koookJPGo0000O_oonfX4o`0009cooo]Z002NoookJPGo0000N_oo
nfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX0
09kooo]Z1Ol0001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000N_oonfX5o`0007ko
oo]Z1Ol0002KoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z
002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1_l0001/
oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0005cooo]Z2_l007l6oook
JP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0005cooo]Z2_l007l6oookJP?o
001o2_oonfX6o`0007gooo]Z1_l0002JoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000
O_oonfX6o`0009[ooo]Z002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oo
nfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`00
06cooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPKo0000JOoonfX6o`00O`[o
oo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1_l0001YoookJPKo001o2_oonfX5o`0007kooo]Z
1_l0002JoookJP00W_oonfX6o`0006_ooo]Z1?l007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002N
oookJP[o0000J?oonfX3o`00O`[ooo]Z1Ol0001noookJP[o0000U_oonfX009kooo]Z2_l0001eoook
JPGo0000O_oonfX:o`0009Kooo]Z002NoookJP[o0000MOoonfX5o`0007gooo]Z2ol0002FoookJP00
W_oonfX:o`0007Gooo]Z1Ol0001moookJP_o0000U_oonfX009kooo]Z2ol0001doookJPGo0000OOoo
nfX<o`0009Gooo]Z002NoookJP_o0000M?oonfX5o`0007gooo]Z3?l0002EoookJP00W_oonfX;o`00
07Cooo]Z1Ol0001moookJPco0000UOoonfX009kooo]Z2ol0001doookJPGo0000OOoonfX<o`0009Go
oo]Z002NoookJP_o0000M?oonfX5o`0007gooo]Z3Ol0002DoookJP00W_oonfX;o`0007Cooo]Z1Ol0
001moookJPgo0000U?oonfX009kooo]Z2ol0001doookJPGo0000OOoonfX=o`0009Cooo]Z002Moook
JPco0000M?oonfX5o`0007gooo]Z4?l0002AoookJP00WOoonfX<o`0007Cooo]Z1Ol0001moookJPSo
000000?ooo]Zo`000?l000001_l0002@oookJP00WOoonfX5o`0000?ooo]Z1Ol0001coookJPGo0000
OOoonfX4o`0000Gooo]Z2?l0002@oookJP00WOoonfX4o`0000Cooo]Z1_l0001boookJPGo0000OOoo
nfX4o`0000Gooo]Z2?l0002@oookJP00WOoonfX4o`0000Cooo]Z1_l0001boookJPGo0000OOoonfX4
o`0000Gooo]Z2?l0002@oookJP00WOoonfX4o`0000Gooo]Z1_l0001aoookJPGo0000OOoonfX4o`00
00Gooo]Z2?l0002@oookJP00WOoonfX4o`0000Gooo]Z1ol0001`oookJPGo0000OOoonfX4o`0000Ko
oo]Z1ol0002@oookJP00WOoonfX4o`0000Kooo]Z1ol0001_oookJPGo0000OOoonfX4o`0000Wooo]Z
1Ol0002?oookJP00WOoonfX4o`0000Oooo]Z1ol0001^oookJPGo0000OOoonfX4o`0000Wooo]Z2?l0
002<oookJP00WOoonfX4o`0000Sooo]Z1_l0001^oookJPGo0000OOoonfX4o`0000Wooo]Z2?l0002<
oookJP00WOoonfX4o`0000Wooo]Z1_l0001]oookJPGo0000OOoonfX4o`0000[ooo]Z1ol0002<oook
JP00WOoonfX4o`0000[ooo]Z1_l0001/oookJPGo0000OOoonfX4o`0000[ooo]Z2?l0002;oookJP00
WOoonfX4o`0000[ooo]Z1ol0001[oookJPGo0000OOoonfX4o`0000[ooo]Z2?l0002;oookJP00WOoo
nfX4o`0000_ooo]Z1_l0001[oookJPGo0000OOoonfX4o`0000_ooo]Z2?l0002:oookJP00WOoonfX4
o`0000cooo]Z1_l0001ZoookJPGo0000OOoonfX4o`0000kooo]Z1Ol0002:oookJP00WOoonfX4o`00
00gooo]Z1_l0001YoookJPGo0000OOoonfX4o`0000kooo]Z1Ol0002:oookJP00WOoonfX4o`0000go
oo]Z1ol0001XoookJPGo0000OOoonfX4o`0000oooo]Z1ol00027oookJP00WOoonfX4o`0000kooo]Z
1ol0001WoookJPGo0000OOoonfX4o`0000oooo]Z2?l00026oookJP00WOoonfX4o`0000oooo]Z1_l0
001WoookJPGo0000OOoonfX4o`0000oooo]Z2?l00026oookJP00WOoonfX4o`00013ooo]Z1_l00018
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000OOoonfX4o`00013ooo]Z1ol00026
oookJP00WOoonfX4o`00017ooo]Z1_l00016oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oook
JPGo0000O?oonfX5o`00013ooo]Z2?l00025oookJP00WOoonfX4o`00017ooo]Z1ol00015oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2OoonfX5o`0007cooo]Z1Ol0000CoookJPGo0000QOoonfX009gooo]Z1?l0000Boook
JPOo0000=ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000O?oonfX5o`0001?ooo]Z1_l00024oookJP00WOoonfX4o`0001?ooo]Z1ol0000foookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007_ooo]Z1?l0000EoookJPSo
0000POoonfX009gooo]Z1?l0000DoookJPOo0000@OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX5o`0007cooo]Z1?l0000EoookJPSo0000POoonfX009gooo]Z1?l0000EoookJPOo0000@?oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001loookJPCo00005_oo
nfX7o`00087ooo]Z002MoookJPCo00005_oonfX7o`0003oooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Wooo]Z1Ol0001loookJPCo00005_oonfX8o`00083ooo]Z002MoookJPCo00005ooonfX7o`00
03kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001loookJPCo00006OoonfX5o`00
083ooo]Z002MoookJPCo00006?oonfX7o`0003gooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`ko
oo]Z1Ol0001loookJPCo00006OoonfX6o`0007oooo]Z002MoookJPCo00006OoonfX7o`0003gooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007cooo]Z1?l0000JoookJPSo
0000O?oonfX009gooo]Z1?l0000JoookJPOo0000??oonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000
O?oonfX4o`0001[ooo]Z2?l0001loookJP00WOoonfX4o`0001_ooo]Z1ol0000loookJPGo001o2_oo
nfX7o`00O`Sooo]Z1Ol0001loookJPCo00006ooonfX8o`0007_ooo]Z002MoookJPCo00007?oonfX7
o`0005Wooo]Z1Ol0001loookJPCo00006ooonfX8o`0007_ooo]Z002MoookJPCo00007OoonfX7o`00
05Sooo]Z1Ol0001loookJPCo00007_oonfX6o`0007[ooo]Z002LoookJPGo00007_oonfX7o`0005Oo
oo]Z1Ol0001loookJPCo00007ooonfX8o`0007Oooo]Z002LoookJPGo00007ooonfX7o`0005Kooo]Z
1Ol0001loookJPCo00007ooonfX8o`0007Oooo]Z002LoookJPGo00008?oonfX7o`0005Gooo]Z1Ol0
001loookJPCo00008?oonfX8o`0007Kooo]Z002LoookJPCo00008_oonfX7o`0005Cooo]Z1Ol0001l
oookJPCo00008?oonfX9o`0007Gooo]Z002LoookJPCo00008ooonfX7o`0005?ooo]Z1Ol0001loook
JPCo00008OoonfX8o`0007Gooo]Z002LoookJPCo00009?oonfX8o`00057ooo]Z1Ol0001loookJPCo
00009?oonfX8o`0007;ooo]Z002LoookJPCo00009OoonfX8o`00053ooo]Z1Ol0001loookJPCo0000
9OoonfX8o`00077ooo]Z002LoookJPCo00009_oonfX9o`0004kooo]Z1Ol0001loookJPCo00009Ooo
nfX8o`00077ooo]Z002LoookJPCo00009ooonfX9o`0004gooo]Z1Ol0001loookJPCo00009_oonfX8
o`00073ooo]Z002LoookJPCo0000:OoonfX8o`0004cooo]Z1Ol0001loookJPCo0000:OoonfX8o`00
06gooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00000ooonfX3o`00O`?ooo]Z1Ol007lLoookJPSo
0000BooonfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX5o`00Ob7ooo]Z2Ol0001<oookJP?o
001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o1?l00003oookJP?o001o0_oonfX7o`00Oagooo]Z
1ol0001:oookJPGo0000LooonfX7o`00O`;ooo]Z1?l00002oookJPOo001o8OoonfX9o`0004_ooo]Z
0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00Oakooo]Z1ol00019oookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
Ob;ooo]Z2?l0001;oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Cooo]Z0ol007l3oookJP?o
001o7_oonfX9o`0004Kooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o
000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ob7ooo]Z3?l00017oookJP?o001o7OoonfX001?o
oo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000002o`000003
o`00Oooonf[ooo]Z00[ooo]Z0ol007lOoookJPWo0000AOoonfX5o`0007;ooo]Z0ol007l3oookJP?o
001o00?ooo]Zo`000?l000000_l00007oookJP?o001o9OoonfX8o`0004Oooo]Z0ol007lMoookJP00
8_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00[ooo]Z
0ol007lPoookJPSo0000AOoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l00000
0_l00007oookJP?o001o9OoonfX9o`0004Kooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol0
07l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l2oookJPCo001o8Ooo
nfX;o`00047ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oo
nfX2o`00O`;ooo]Z1?l007lVoookJPco0000@_oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3
o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX7o`00ObCooo]Z2Ol00011
oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1ol007lZ
oookJP[o0000@OoonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o0000
00;o000000?o001ooookJ_oonfX01OoonfX6o`00ObKooo]Z2_l0000ooookJPGo0000L_oonfX3o`00
O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1_l007l/oookJPWo0000@OoonfX3o`00
Oagooo]Z000OoookJPKo001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oo
nfX01OoonfX2o`00Ob[ooo]Z3Ol0000loookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o
0000o`000002o`0000;ooo]Z0_l007laoookJPco0000>_oonfX6o`00Oagooo]Z000OoookJPKo001o
M?oonfX3o`00O`Co00002?oonfX2o`00Obcooo]Z3?l0000koookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l00002oookJP;o001o<_oonfX<o`0003Wooo]Z1_l007lMoookJP00
8OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol007lYoookJPgo0000=ooonfX5o`0007?ooo]Z
1ol007l2oookJPCo00000ooonfX7o`00Oboooo]Z3Ol0000goookJPCo001o7OoonfX002;ooo]Z0ol0
07meoookJP;o001o1?l00009oookJPOo001o:_oonfX=o`0003Kooo]Z1Ol0001doookJPGo001o0ooo
nfX4o`0000?ooo]Z1ol007l`oookJPko0000=_oonfX3o`00Oagooo]Z002LoookJPCo0000?_oonfX>
o`00037ooo]Z1Ol0001loookJPCo0000?_oonfX=o`0005?ooo]Z002LoookJPCo0000?ooonfX=o`00
037ooo]Z1Ol0001loookJPCo0000?ooonfX>o`00057ooo]Z002LoookJPCo0000@?oonfXAo`0002co
oo]Z1Ol0001loookJPCo0000@?oonfXBo`0004cooo]Z002LoookJPCo0000A?oonfXBo`0002Oooo]Z
1Ol0001loookJPCo0000A?oonfXBo`0004Sooo]Z002LoookJPCo0000AOoonfXFo`0002;ooo]Z1Ol0
001loookJPCo0000AOoonfXFo`0004?ooo]Z002LoookJPCo0000BOoonfXHo`0001cooo]Z1Ol0001l
oookJPCo0000BOoonfXHo`0003gooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000LoookJPCo000000?ooo]Zo`00
0?l000000ol000000ooonf[o0000o`00000Xo`0004_ooo]Z1?l0001doookJPCo000000?ooo]Zo`00
0?l000004_l000000ooonf[o0000o`00000To`0004[ooo]Z1?l0001doookJPCo000000?ooo]Zo`00
0?l000000_l00002oookJP03o`000?oonf[ooo]Z01cooo]Z000koookJQSo0000BOoonfX4o`0007go
oo]Z1Ol0000KoookJQSo0000BOoonfX4o`0009kooo]Z0010oookJQOo0000AOoonfX4o`0007gooo]Z
1Ol0000QoookJQKo0000AOoonfX4o`0009kooo]Z0016oookJQ;o0000A?oonfX4o`0007gooo]Z1Ol0
000VoookJQ;o0000A?oonfX4o`0009kooo]Z001:oookJQ;o0000@?oonfX4o`0007gooo]Z1Ol0000[
oookJQ7o0000@?oonfX4o`0009kooo]Z001?oookJPko0000?ooonfX4o`0007gooo]Z1Ol0000`oook
JPgo0000?ooonfX4o`0009kooo]Z001@oookJPko0000?_oonfX4o`0007gooo]Z1Ol0000`oookJPko
0000?_oonfX4o`0009kooo]Z001EoookJP_o0000??oonfX4o`0007gooo]Z1Ol0000eoookJPgo0000
>_oonfX4o`0009kooo]Z001FoookJPco0000>OoonfX5o`0007gooo]Z1Ol0000foookJPgo0000>Ooo
nfX4o`0009kooo]Z001JoookJP[o0000=ooonfX5o`0007gooo]Z1Ol0000joookJPco0000=_oonfX4
o`0009kooo]Z001KoookJPco0000=?oonfX5o`0007gooo]Z1Ol0000koookJPco0000=OoonfX4o`00
09kooo]Z001MoookJPco0000<_oonfX4o`0007kooo]Z1Ol0000ooookJPWo0000=?oonfX4o`0009ko
oo]Z001OoookJP_o0000<OoonfX4o`0007kooo]Z1Ol0000ooookJPWo0000=?oonfX4o`0009kooo]Z
001QoookJP_o0000;ooonfX4o`0007kooo]Z1Ol00010oookJPco0000<?oonfX4o`0009kooo]Z001T
oookJPWo0000;_oonfX4o`0007kooo]Z1Ol00014oookJPWo0000;ooonfX4o`0009kooo]Z001Voook
JPSo0000;OoonfX4o`0007kooo]Z1Ol00014oookJPWo0000;ooonfX4o`0009kooo]Z001WoookJPSo
0000;?oonfX4o`0007kooo]Z1Ol00015oookJPWo0000;_oonfX4o`0009kooo]Z001YoookJPSo0000
:_oonfX4o`0007kooo]Z1Ol00019oookJPOo0000;?oonfX4o`0009kooo]Z001ZoookJPSo0000:Ooo
nfX4o`0007kooo]Z1Ol00019oookJPSo0000:ooonfX4o`0009kooo]Z001[oookJPSo0000:?oonfX4
o`0007kooo]Z1Ol0001:oookJPSo0000:_oonfX4o`0009kooo]Z001/oookJPSo00009ooonfX4o`00
07kooo]Z1Ol0001;oookJPSo0000:OoonfX4o`0009kooo]Z001^oookJPOo00009_oonfX4o`0007ko
oo]Z1Ol0001=oookJPSo00009ooonfX4o`0009kooo]Z001_oookJPOo00009OoonfX4o`0007kooo]Z
1Ol0001>oookJPSo00009_oonfX4o`0009kooo]Z001`oookJPOo00009?oonfX4o`0007kooo]Z1Ol0
001?oookJPSo00009OoonfX4o`0009kooo]Z001aoookJPOo00008ooonfX4o`0007kooo]Z1Ol0001@
oookJPSo00009?oonfX4o`0009kooo]Z001boookJPOo00008_oonfX4o`0007kooo]Z1Ol0001Boook
JPOo00008ooonfX4o`0009kooo]Z001coookJPOo00008OoonfX4o`0007kooo]Z1Ol0001CoookJPOo
00008_oonfX4o`0009kooo]Z001doookJPOo00008?oonfX4o`0007kooo]Z1Ol0001DoookJPOo0000
8OoonfX4o`0009kooo]Z001eoookJPOo00007ooonfX4o`0007kooo]Z1Ol0001EoookJPOo00007ooo
nfX5o`0009kooo]Z001foookJPOo00007_oonfX4o`0007kooo]Z1Ol0001FoookJPOo00007_oonfX5
o`0009kooo]Z001goookJPOo00007OoonfX4o`0007kooo]Z1Ol0001GoookJPOo00007OoonfX5o`00
09kooo]Z001hoookJPOo00007?oonfX4o`0007kooo]Z1Ol0001HoookJPOo00007?oonfX4o`0009oo
oo]Z001ioookJPKo00007?oonfX4o`0007kooo]Z1Ol0001IoookJPOo00006ooonfX4o`0009oooo]Z
001joookJPKo00006ooonfX4o`0007kooo]Z1Ol0001JoookJPOo00006_oonfX4o`0009oooo]Z001k
oookJPKo00006_oonfX4o`0007kooo]Z1Ol0001KoookJPOo00006OoonfX4o`0009oooo]Z001koook
JPOo00006OoonfX4o`00063ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001Loook
JPOo00006?oonfX4o`0009oooo]Z001loookJPOo00006?oonfX4o`0005oooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00O`Wooo]Z1Ol0001MoookJPOo00005ooonfX4o`0009oooo]Z001moookJPOo0000
5ooonfX4o`0005oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool0
07l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000G_oonfX7o`0001Kooo]Z1?l0002Ooook
JP00O_oonfX7o`0001Kooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o2?oonfX5o`0005oooo]Z1ol0000EoookJPCo0000WooonfX007oooo]Z1ol0000EoookJPCo0000
G_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0005oooo]Z1ol0000DoookJPCo0000
WooonfX0083ooo]Z1ol0000DoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oo
nfX5o`00067ooo]Z1ol0000CoookJPCo0000WooonfX0087ooo]Z1ol0000CoookJPCo0000G_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001RoookJPOo00004_oonfX4
o`0009oooo]Z0022oookJPOo00004_oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`Wooo]Z1Ol0001SoookJPOo00004OoonfX4o`0009oooo]Z0023oookJPOo00004OoonfX4o`0005ko
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001ToookJPOo00004?oonfX4o`0009oo
oo]Z0024oookJPKo00004OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z
1Ol0001UoookJPKo00004?oonfX4o`0009oooo]Z0025oookJPKo00004?oonfX4o`0005oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0006Kooo]Z1_l0000?oookJPCo0000
WooonfX008Kooo]Z1_l0000?oookJPCo0000GooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000Iooo
nfX6o`0000kooo]Z1?l0002OoookJP00Q_oonfX7o`0000kooo]Z1?l0001PoookJPGo001o2_oonfX7
o`00O`Sooo]Z1Ol0001WoookJPOo00003OoonfX4o`0009oooo]Z0027oookJPOo00003OoonfX4o`00
07kooo]Z1Ol0001XoookJPKo00003OoonfX4o`0009oooo]Z0028oookJPKo00003OoonfX4o`0007ko
oo]Z1Ol0001YoookJPKo00003?oonfX4o`0009oooo]Z0029oookJPKo00003?oonfX4o`0007kooo]Z
1Ol0001ZoookJPKo00002ooonfX4o`0009oooo]Z002:oookJPKo00002ooonfX4o`0007kooo]Z1Ol0
001ZoookJPKo00002ooonfX4o`0009oooo]Z002:oookJPOo00002_oonfX4o`0007kooo]Z1Ol0001[
oookJPKo00002_oonfX4o`0009oooo]Z002;oookJPKo00002_oonfX4o`0007kooo]Z1Ol0001/oook
JPGo00002_oonfX4o`0009oooo]Z002<oookJPKo00002OoonfX4o`0007kooo]Z1Ol0001/oookJPGo
00002_oonfX4o`0009oooo]Z002=oookJPKo00002?oonfX4o`0007kooo]Z1Ol0001]oookJPGo0000
2OoonfX4o`0009oooo]Z002=oookJPOo00001ooonfX4o`0007kooo]Z1Ol0001]oookJPGo00002Ooo
nfX4o`0009oooo]Z002>oookJPOo00001_oonfX4o`0007kooo]Z1Ol0001]oookJPSo00001_oonfX4
o`0009oooo]Z002?oookJPKo00001_oonfX4o`0007kooo]Z1Ol0001^oookJPSo00001OoonfX4o`00
09oooo]Z002@oookJPKo00001OoonfX4o`0007kooo]Z1Ol0001^oookJPSo00001OoonfX4o`0009oo
oo]Z002AoookJPGo00001OoonfX4o`0007kooo]Z1Ol0001^oookJPSo00001OoonfX4o`0009oooo]Z
002AoookJPGo00001OoonfX4o`0007kooo]Z1Ol0001^oookJPWo00001?oonfX4o`0009oooo]Z002B
oookJPgo0000O_oonfX5o`0006kooo]Z4Ol0002OoookJP00T_oonfX=o`0007kooo]Z1Ol0001_oook
JQ3o0000WooonfX009;ooo]Z3Ol0001noookJPGo0000LooonfX<o`0009oooo]Z002CoookJPco0000
O_oonfX5o`0007?ooo]Z2ol0002PoookJP00TooonfX<o`0007kooo]Z1Ol0001coookJP_o0000X?oo
nfX009?ooo]Z3?l0001noookJPGo0000LooonfX;o`000:3ooo]Z002CoookJPco0000O_oonfX5o`00
07?ooo]Z2ol0002PoookJP00TooonfX<o`0007kooo]Z1Ol0001coookJP_o0000X?oonfX009?ooo]Z
3?l0001noookJPGo0000LooonfX;o`000:3ooo]Z002CoookJPco0000O_oonfX5o`0007?ooo]Z2ol0
002PoookJP00U?oonfX;o`0007kooo]Z1Ol0001doookJP[o0000X?oonfX009Cooo]Z2ol0001noook
JPGo0000M?oonfX:o`000:3ooo]Z002DoookJP_o0000O_oonfX5o`0007Cooo]Z2_l0002PoookJP00
V?oonfX7o`0007kooo]Z1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0001ooookJPGo0000N?oo
nfX6o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX0
09Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX6o`0007;o
oo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z
1Ol0001hoookJPKo0000X?oonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX6o`0007Oooo]Z1_l0
002PoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002Ioook
JPGo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009Wooo]Z1Ol0001boookJP?o
001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000
N?oonfX6o`000:3ooo]Z002IoookJPGo0000KooonfX6o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oo
nfX009Wooo]Z1Ol0001_oookJPKo001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`00
077ooo]Z1?l007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[o
oo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001ooookJPGo0000NOoonfX5o`000:3ooo]Z
002IoookJPGo0000OooonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX4o`00083ooo]Z1Ol0001i
oookJPGo0000X?oonfX009Wooo]Z1?l00020oookJPGo0000NOoonfX4o`000:7ooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003ooookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol0
07l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003o
oookJQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2Ooo
nfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003o
oookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7o
oo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z
1ol007l8oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z
1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00oooonfX>
oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooook
JQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o
2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3
o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oook
JP00oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z
;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30833 L
.02605 .30805 L
.02729 .3083 L
.02846 .30897 L
.02946 .30959 L
.03053 .30997 L
.0317 .30985 L
.03279 .30931 L
.03395 .30858 L
.0352 .30809 L
.03638 .30819 L
.03746 .30873 L
.03873 .30954 L
.03944 .30988 L
.04011 .31004 L
.04132 .30984 L
.04262 .30913 L
.04327 .30872 L
.04396 .30837 L
.04519 .30815 L
.04588 .30831 L
.04652 .30861 L
.04797 .30956 L
.04925 .31014 L
.05041 .31012 L
.05105 .30988 L
.05175 .30949 L
.05302 .30873 L
.05414 .30836 L
.05539 .30857 L
.05669 .30935 L
.05791 .31014 L
.05905 .31052 L
.06009 .31038 L
.06124 .30981 L
.06244 .3091 L
.0631 .30884 L
.0638 .30874 L
.06509 .30912 L
.06633 .30996 L
.06748 .31072 L
.06873 .31107 L
.06944 .31097 L
.0701 .3107 L
.07078 .31032 L
.07152 .30988 L
.07222 .30955 L
.07287 .30939 L
.07405 .30956 L
Mistroke
.07531 .31034 L
.07639 .31116 L
.07754 .31178 L
.07825 .31189 L
.0789 .3118 L
.08018 .31121 L
.08143 .31053 L
.08257 .31029 L
.08384 .31071 L
.08455 .3112 L
.08521 .31175 L
.08639 .31263 L
.08768 .31305 L
.08835 .31298 L
.08909 .3127 L
.08981 .31231 L
.09059 .31189 L
.09131 .31163 L
.09198 .31157 L
.09328 .31205 L
.10458 .31551 L
.12515 .32217 L
.14426 .33039 L
.16272 .34129 L
.18242 .35643 L
.20237 .37512 L
.21287 .38535 L
.22397 .39691 L
.2339 .41004 L
.24481 .42996 L
.24599 .43879 L
.24727 .44643 L
.24848 .44786 L
.2496 .44349 L
.2509 .43517 L
.25155 .4319 L
.25228 .43064 L
.25354 .43691 L
.25473 .45226 L
.25586 .47001 L
.25706 .48181 L
.25807 .47779 L
.25919 .45239 L
.26039 .39972 L
.26168 .32322 L
.26288 .24851 L
.264 .18971 L
.26523 .14883 L
.26588 .13861 L
.26658 .13579 L
Mistroke
.26732 .14017 L
.26801 .14899 L
.26932 .16942 L
.27054 .18345 L
.27167 .18739 L
.27291 .1829 L
.27423 .17446 L
.27498 .17103 L
.27567 .16989 L
.27642 .17117 L
.27722 .17511 L
.27868 .18579 L
.2794 .19069 L
.28005 .19406 L
.28126 .19654 L
.28256 .19439 L
.28325 .19232 L
.2839 .19057 L
.28458 .18947 L
.28532 .18956 L
.28656 .193 L
.28726 .19631 L
.2879 .1997 L
.28913 .20561 L
.29028 .20864 L
.29153 .20863 L
.2922 .20767 L
.29291 .20645 L
.29365 .20548 L
.29435 .20528 L
.29567 .20743 L
.30547 .22216 L
.34395 .26492 L
.36384 .28068 L
.37399 .2872 L
.38489 .29286 L
.39513 .2967 L
.40448 .29992 L
.41336 .30265 L
.4228 .30478 L
.43268 .30636 L
.43379 .30585 L
.43482 .30529 L
.4359 .30498 L
.43708 .30522 L
.43828 .30602 L
.43956 .30705 L
.44075 .30767 L
.44184 .30768 L
.44256 .30742 L
Mistroke
.44322 .30707 L
.44393 .30665 L
.44472 .30629 L
.4454 .30615 L
.44604 .3062 L
.44672 .30644 L
.44745 .30689 L
.44812 .30741 L
.44886 .30796 L
.44956 .30838 L
.4502 .30861 L
.45142 .30854 L
.45272 .3079 L
.454 .3072 L
.45472 .30699 L
.45539 .30699 L
.4566 .30747 L
.45789 .30838 L
.45905 .30907 L
.46013 .30929 L
.46131 .30896 L
.46258 .30822 L
.4638 .30763 L
.46449 .30751 L
.46514 .30759 L
.46645 .30823 L
.46712 .30869 L
.46786 .30918 L
.4691 .30966 L
.47041 .30948 L
.47162 .30882 L
.47275 .30816 L
.47344 .3079 L
.47419 .30784 L
.4749 .30799 L
.47555 .3083 L
.47686 .30916 L
.47809 .30978 L
.47942 .30981 L
.48012 .30955 L
.48087 .30911 L
.48166 .30862 L
.48241 .30822 L
.48308 .30802 L
.48381 .30801 L
.48447 .30819 L
.48518 .30855 L
.48646 .30937 L
.48771 .30992 L
.48886 .30989 L
Mistroke
.49011 .3093 L
.49083 .30884 L
.49148 .30845 L
.49217 .30816 L
.49291 .30804 L
.4936 .30814 L
.49425 .30839 L
.49542 .3091 L
.49666 .30979 L
.49772 .30999 L
.49889 .30967 L
.50005 .30898 L
.5013 .30828 L
.50201 .30807 L
.50266 .30806 L
.50393 .30853 L
.50515 .30929 L
.50646 .30992 L
.50771 .30991 L
.50886 .30939 L
.51016 .30857 L
.51138 .30809 L
.51265 .30822 L
.51332 .30853 L
.51404 .30898 L
.51523 .30971 L
.51653 .31005 L
.51775 .30974 L
.51888 .30908 L
.51999 .30844 L
.52103 .30815 L
.52211 .30833 L
.5233 .30899 L
.52462 .30982 L
.52585 .3102 L
.52713 .30993 L
.52781 .30957 L
.52854 .30912 L
.52983 .30847 L
.53105 .3084 L
.53215 .30886 L
.53334 .30967 L
.53464 .31038 L
.53538 .31052 L
.53607 .31044 L
.5368 .31016 L
.53747 .30978 L
.53825 .30931 L
.53897 .30895 L
.54025 .30876 L
Mistroke
.54092 .30895 L
.54164 .30933 L
.54295 .31027 L
.54417 .31094 L
.54541 .31102 L
.54607 .3108 L
.54678 .31044 L
.54745 .31003 L
.54819 .30964 L
.54889 .30941 L
.54953 .30938 L
.55078 .30984 L
.55141 .31027 L
.55211 .31081 L
.55332 .31161 L
.55446 .31189 L
.55511 .31179 L
.55582 .31151 L
.55651 .31112 L
.55725 .3107 L
.55795 .31041 L
.55858 .3103 L
.55982 .31059 L
.56128 .31164 L
.56207 .31229 L
.56282 .31276 L
.56414 .31305 L
.56484 .31289 L
.56559 .31254 L
.56623 .31218 L
.56692 .31183 L
.56819 .31157 L
.56942 .31203 L
.57057 .31293 L
.57122 .31351 L
.57192 .31406 L
.57318 .3146 L
.57394 .31457 L
.57464 .31433 L
.57597 .31365 L
.57714 .31326 L
.57824 .31343 L
.57944 .31425 L
.58073 .31547 L
.58138 .31602 L
.58209 .31644 L
.58336 .31661 L
.58461 .31614 L
.58576 .31558 L
.58701 .31541 L
Mistroke
.58819 .31594 L
.58925 .31691 L
.59041 .3181 L
.59167 .319 L
.59237 .31917 L
.59301 .31912 L
.59425 .31863 L
.59542 .31814 L
.59652 .3181 L
.59768 .31875 L
.59867 .31975 L
.59976 .32098 L
.60094 .32198 L
.6022 .32229 L
.60338 .32194 L
.60447 .32146 L
.60574 .32131 L
.60639 .32156 L
.6071 .32209 L
.60836 .32352 L
.60954 .32494 L
.61021 .32555 L
.61092 .32594 L
.61219 .32596 L
.6129 .3257 L
.61356 .32542 L
.61428 .32518 L
.61505 .32517 L
.61635 .32591 L
.61708 .32672 L
.61776 .32762 L
.61897 .32923 L
.61966 .32992 L
.62031 .33034 L
.62143 .33048 L
.62263 .33007 L
.62391 .32969 L
.62509 .33 L
.62638 .3313 L
.62759 .33309 L
.6287 .33461 L
.62986 .33556 L
.63113 .33565 L
.6323 .33522 L
.63356 .33497 L
.63428 .3352 L
.63495 .33572 L
.64409 .34163 L
.66482 .36004 L
.68348 .37907 L
Mistroke
.69402 .39427 L
.70376 .40872 L
.71407 .42728 L
.71679 .42558 L
.71753 .42339 L
.71822 .42189 L
.71894 .42155 L
.71972 .4231 L
.72042 .42628 L
.72106 .43037 L
.72174 .43551 L
.72249 .44102 L
.72379 .4475 L
.72502 .44701 L
.72617 .44111 L
.72744 .43322 L
.72808 .43095 L
.72876 .43108 L
.73 .43969 L
.73107 .45453 L
.7322 .47205 L
.73344 .48227 L
.73459 .47279 L
.73536 .45315 L
.73608 .42478 L
.73742 .35129 L
.73882 .26331 L
.74011 .1934 L
.74129 .15186 L
.74253 .13589 L
.74378 .14324 L
.74449 .15335 L
.74515 .16387 L
.74642 .18076 L
.74706 .18555 L
.74776 .1874 L
.74901 .1834 L
.75018 .1759 L
.75088 .1721 L
.75155 .17013 L
.75281 .17191 L
.75351 .17572 L
.75416 .18037 L
.75487 .18578 L
.75564 .19101 L
.75694 .19612 L
.75816 .19582 L
.75935 .19261 L
.76044 .18988 L
.76163 .18971 L
Mistroke
.76293 .19378 L
.76359 .19703 L
.76429 .20078 L
.76556 .20648 L
.7668 .20895 L
.76795 .20835 L
.76921 .20626 L
.76985 .20547 L
.77055 .20528 L
.77172 .20706 L
.77299 .2115 L
.77408 .21603 L
.77528 .21987 L
.77644 .22139 L
.77753 .22096 L
.77867 .21972 L
.7799 .21923 L
.78104 .22063 L
.78212 .22359 L
.78317 .22723 L
.78414 .23026 L
.78529 .23255 L
.78653 .23302 L
.78767 .23226 L
.78876 .23163 L
.79003 .23227 L
.7912 .23458 L
.79257 .23854 L
.79386 .2419 L
.79511 .2436 L
.79582 .24378 L
.79647 .24357 L
.7977 .24288 L
.79884 .24285 L
.80007 .24426 L
.80072 .24561 L
.80142 .24735 L
.80211 .24915 L
.80284 .25091 L
.80415 .25303 L
.80528 .25351 L
.80652 .25306 L
.80717 .25278 L
.80786 .25268 L
.80911 .2535 L
.8103 .25556 L
.81156 .25843 L
.81263 .26061 L
.8138 .262 L
.81496 .26223 L
Mistroke
.81601 .26185 L
.81722 .26154 L
.81836 .26209 L
.81942 .26354 L
.8204 .26544 L
.82145 .26757 L
.8226 .26932 L
.82386 .27007 L
.82505 .26984 L
.82611 .26945 L
.82729 .26953 L
.82855 .27072 L
.82924 .27181 L
.8299 .273 L
.83107 .2751 L
.83232 .27659 L
.8334 .277 L
.83459 .27671 L
.83567 .27634 L
.83668 .2764 L
.83788 .27733 L
.83896 .2789 L
.84012 .28082 L
.8414 .28246 L
.84268 .28307 L
.84339 .28299 L
.84404 .28275 L
.84522 .28235 L
.84649 .28256 L
.8472 .2831 L
.84797 .28402 L
.84937 .28611 L
.85004 .28702 L
.85074 .28777 L
.85201 .28835 L
.86205 .29282 L
.87234 .29631 L
.87305 .29599 L
.8738 .29577 L
.87451 .29577 L
.87516 .296 L
.87589 .29653 L
.87658 .29722 L
.87734 .29808 L
.87814 .29895 L
.87877 .29949 L
.87947 .29987 L
.88069 .29992 L
.88138 .29967 L
.88213 .29931 L
Mistroke
.88283 .29901 L
.88347 .29887 L
.88465 .29909 L
.8859 .30005 L
.88699 .30118 L
.88817 .30221 L
.88889 .30256 L
.88955 .30265 L
.89086 .30226 L
.89212 .30164 L
.8933 .3014 L
.89446 .30178 L
.89569 .30278 L
.89695 .30396 L
.89767 .30446 L
.89833 .30473 L
.89902 .30478 L
.89975 .3046 L
.90046 .30427 L
.90111 .30392 L
.90242 .30344 L
.90365 .30362 L
.9048 .30438 L
.90606 .30548 L
.90725 .30627 L
.90835 .30646 L
.90962 .30604 L
.91027 .30568 L
.91098 .30531 L
.91221 .30498 L
.91337 .30527 L
.91454 .30608 L
.91565 .30698 L
.91665 .30757 L
.91774 .30773 L
.91892 .30734 L
.92018 .30663 L
.92136 .30617 L
.92244 .30625 L
.9319 .30706 L
.93452 .30868 L
.93585 .30926 L
.9366 .30926 L
.9373 .30906 L
.93863 .30831 L
.93989 .30766 L
.94103 .30753 L
.94226 .30799 L
.94328 .30867 L
.94423 .30928 L
Mistroke
.94522 .30965 L
.94631 .30958 L
.9474 .30907 L
.94857 .30835 L
.94965 .30789 L
.95065 .30787 L
.95175 .30831 L
.95276 .30896 L
.95388 .30962 L
.95507 .30989 L
.95633 .30954 L
.95751 .30883 L
.95858 .30823 L
.95973 .30799 L
.96075 .30823 L
.96171 .30876 L
.96285 .30949 L
.96389 .30992 L
.96498 .30991 L
.96601 .30947 L
.96712 .30878 L
.96829 .30818 L
.96932 .30805 L
.97025 .30831 L
.97119 .30883 L
.97207 .30939 L
.9731 .30988 L
.97405 .30998 L
.97509 .30967 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00WooonfX4o`0007[ooo]Z1Ol0001noookJPCo0000W?oonfX009oooo]Z1?l0001joookJPGo
0000O_oonfX4o`0009cooo]Z002NoookJPGo0000N_oonfX5o`0007kooo]Z1?l0002LoookJP00W_oo
nfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001joookJPGo0000O_oonfX5
o`0009_ooo]Z002NoookJPGo0000N_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0007[o
oo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001]oookJP?o001o2_oonfX5o`0007kooo]Z
1Ol0002KoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002N
oookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1Ol0001Moook
JP[o001o1_oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009kooo]Z1Ol0001MoookJP[o
001o1_oonfX3o`00O`[ooo]Z1_l0001moookJPKo0000V_oonfX009kooo]Z1Ol0001]oookJP?o001o
2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000O_oo
nfX6o`0009[ooo]Z002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX0
09kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX6o`0006Wo
oo]Z1_l007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPKo0000JOoonfX6o`00O`[ooo]Z
1Ol0001noookJPKo0000V_oonfX009kooo]Z1_l0001[oookJPCo001o2_oonfX5o`0007kooo]Z1_l0
002JoookJP00WOoonfX;o`0006Sooo]Z0ol007l:oookJPGo0000O_oonfX9o`0009Oooo]Z002Moook
JP_o0000MOoonfX5o`0007kooo]Z2_l0002FoookJP00WOoonfX;o`0007Gooo]Z1Ol0001moookJP_o
0000U_oonfX009gooo]Z2ol0001eoookJPGo0000OOoonfX;o`0009Kooo]Z002MoookJP_o0000MOoo
nfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX;o`0007Gooo]Z1Ol0001moookJPco0000UOoonfX0
09gooo]Z3?l0001doookJPGo0000OOoonfX<o`0009Gooo]Z002MoookJPco0000M?oonfX5o`0007go
oo]Z3?l0002EoookJP00WOoonfX<o`0007Cooo]Z1Ol0001moookJPco0000UOoonfX009gooo]Z3?l0
001doookJPGo0000OOoonfX<o`0009Gooo]Z002MoookJQ3o0000L?oonfX5o`0007gooo]Z4?l0002A
oookJP00WOoonfX@o`00073ooo]Z1Ol0001moookJQ3o0000TOoonfX009gooo]Z4?l0001`oookJPGo
0000OOoonfX@o`00097ooo]Z002MoookJPCo00001?oonfX8o`00073ooo]Z1Ol0001moookJPCo0000
1OoonfX7o`00097ooo]Z002MoookJPCo00001?oonfX9o`0006oooo]Z1Ol0001moookJPCo00001Ooo
nfX8o`00093ooo]Z002MoookJPCo00001?oonfX9o`0006oooo]Z1Ol0001moookJPCo00001OoonfX8
o`00093ooo]Z002MoookJPCo00001OoonfX8o`0006oooo]Z1Ol0001moookJPCo00001OoonfX8o`00
093ooo]Z002MoookJPCo00001OoonfX8o`0006oooo]Z1Ol0001moookJPCo00001OoonfX8o`00093o
oo]Z002MoookJPCo00002OoonfX5o`0006kooo]Z1Ol0001moookJPCo00002OoonfX5o`0008oooo]Z
002MoookJPCo00002OoonfX8o`0006_ooo]Z1Ol0001moookJPCo00002OoonfX8o`0008cooo]Z002M
oookJPCo00002OoonfX8o`0006_ooo]Z1Ol0001moookJPCo00002OoonfX8o`0008cooo]Z002Moook
JPCo00002_oonfX7o`0006_ooo]Z1Ol0001moookJPCo00002_oonfX7o`0008cooo]Z002MoookJPCo
00002_oonfX8o`0006[ooo]Z1Ol0001moookJPCo00002_oonfX8o`0008_ooo]Z002MoookJPCo0000
2_oonfX9o`0006Wooo]Z1Ol0001moookJPCo00002_oonfX8o`0008_ooo]Z002MoookJPCo00002_oo
nfX:o`0006Sooo]Z1Ol0001moookJPCo00002ooonfX8o`0008[ooo]Z002MoookJPCo00003_oonfX6
o`0006Sooo]Z1Ol0001moookJPCo00003_oonfX5o`0008[ooo]Z002MoookJPCo00003ooonfX6o`00
06Oooo]Z1Ol0001moookJPCo00003_oonfX8o`0008Oooo]Z002LoookJPGo00004?oonfX6o`0006Ko
oo]Z1Ol0001moookJPCo00003ooonfX7o`0008Oooo]Z002LoookJPGo00004?oonfX7o`0006Gooo]Z
1Ol0001moookJPCo00003ooonfX7o`0008Oooo]Z002LoookJPGo00004OoonfX6o`0006Gooo]Z1Ol0
001moookJPCo00003ooonfX8o`0008Kooo]Z002LoookJPCo00004ooonfX6o`0004Kooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001moookJPCo00003ooonfX8o`0008Kooo]Z002Loook
JPCo00005?oonfX6o`0004Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001moook
JPCo00004?oonfX7o`0008Kooo]Z002LoookJPCo00005?oonfX7o`0004?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9
oookJPGo0000O?oonfX5o`0001?ooo]Z1Ol00025oookJP00W?oonfX4o`0001Gooo]Z1ol0000eoook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001loook
JPGo00004ooonfX8o`0008;ooo]Z002LoookJPCo00005_oonfX7o`0003Cooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000NooonfX5o`0001?ooo]Z2?l00022oookJP00
W?oonfX4o`0001Oooo]Z1ol0000ooookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000
O?oonfX4o`0001Gooo]Z2?l00021oookJP00W?oonfX4o`0001Sooo]Z1ol0000noookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0007cooo]Z1?l0000EoookJPSo0000POoo
nfX009cooo]Z1?l0000IoookJPKo0000?_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5
o`0007cooo]Z1?l0000FoookJPSo0000P?oonfX009cooo]Z1?l0000JoookJPKo0000?OoonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0007cooo]Z1?l0000IoookJPGo0000P?oonfX009co
oo]Z1?l0000KoookJPKo0000??oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0007co
oo]Z1?l0000IoookJPSo0000OOoonfX009cooo]Z1?l0000KoookJPOo0000??oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000O?oonfX4o`0001[ooo]Z2?l0001loookJP00
W?oonfX4o`0001cooo]Z1ol0000koookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001loookJPCo0000
6_oonfX8o`0007cooo]Z002LoookJPCo00007OoonfX7o`0003_ooo]Z1Ol007l:oookJPOo001o2?oo
nfX5o`0007cooo]Z1?l0000JoookJPSo0000O?oonfX009cooo]Z1?l0000NoookJPOo0000F?oonfX5
o`0007cooo]Z1?l0000KoookJPSo0000NooonfX009cooo]Z1?l0000OoookJPKo0000F?oonfX5o`00
07cooo]Z1?l0000NoookJPSo0000N?oonfX009cooo]Z1?l0000PoookJPKo0000EooonfX5o`0007co
oo]Z1?l0000NoookJPWo0000MooonfX009cooo]Z1?l0000QoookJPKo0000E_oonfX5o`0007cooo]Z
1?l0000OoookJPSo0000MooonfX009cooo]Z1?l0000QoookJPOo0000EOoonfX5o`0007cooo]Z1?l0
000OoookJPSo0000MooonfX009cooo]Z1?l0000RoookJPOo0000E?oonfX5o`0007cooo]Z1?l0000P
oookJPSo0000M_oonfX009cooo]Z1?l0000SoookJPOo0000DooonfX5o`0007cooo]Z1?l0000Soook
JPSo0000LooonfX009cooo]Z1?l0000ToookJPOo0000D_oonfX5o`0007cooo]Z1?l0000SoookJPWo
0000L_oonfX009cooo]Z1?l0000UoookJPSo0000D?oonfX5o`0007cooo]Z1?l0000ToookJPWo0000
LOoonfX009cooo]Z1?l0000VoookJPSo0000CooonfX5o`0007cooo]Z1?l0000ToookJPWo0000LOoo
nfX009cooo]Z1?l0000WoookJPSo0000C_oonfX5o`0007cooo]Z1?l0000UoookJPSo0000LOoonfX0
09cooo]Z1?l0000XoookJPSo0000COoonfX5o`0007cooo]Z1?l0000YoookJPSo0000KOoonfX002;o
oo]Z0ol007meoookJP;o001o1?l00003oookJP?o001o0ooonfX5o`00Oacooo]Z2?l0001;oookJPGo
0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPGo001o8OoonfX8o`0004gooo]Z0ol007lMoookJP00
8_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol007l2oookJPOo001o7?oonfX8o`0004[ooo]Z
1Ol0001coookJPOo001o0_oonfX4o`0000;ooo]Z1ol007lPoookJPWo0000C?oonfX3o`00Oagooo]Z
000RoookJP?o001oM?oonfX3o`00O`Co00000ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o7OoonfX8o`0004Wooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo
001o0_oonfX4o`000003oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o8OoonfX;o`00
04Wooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`03
oookJ_l0003o000000;o000000?o001ooookJ_oonfX01?oonfX3o`00O`?ooo]Z0ol007lMoookJPSo
0000B?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l000001?oonf[o
001oo`00Ool007l3oookJP?o001o8ooonfX9o`0004Sooo]Z0ol007lMoookJP004ooonfX:o`00O`Go
oo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oo
nfX02_oonfX3o`00Oaoooo]Z1ol00017oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o
0000o`000002o`0000Oooo]Z0ol007lToookJPWo0000AooonfX3o`00Oagooo]Z000RoookJP?o001o
LooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX02_oonfX3o`00Ob3ooo]Z
2?l00015oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000Oooo]Z
0ol007lToookJPWo0000AooonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0
003o000000;o000000?o001ooookJ_oonfX01OoonfX2o`00O`;ooo]Z1?l007lQoookJPWo0000@ooo
nfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP;o001o0_oo
nfX4o`00ObKooo]Z3?l00012oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Z
o`000?l000000_l000000ol007oooo]ZoookJP05oookJPOo001o8ooonfX:o`00047ooo]Z1Ol0001b
oookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oonfX7o`00Ob[ooo]Z2Ol00012
oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol0
07oooo]ZoookJP05oookJPKo001o9OoonfX;o`0003oooo]Z1Ol0001boookJP?o001o0ooonfX3o`00
O`03oookJ_l0003o000000;o00000_oonfX6o`00Ob_ooo]Z2_l00011oookJP?o001o7OoonfX001oo
oo]Z1_l007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP05oookJP;o
001o:ooonfX;o`0003gooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o
00000_oonfX2o`00Oc3ooo]Z2ol0000loookJPKo001o7OoonfX001oooo]Z1_l007mdoookJP?o001o
1?l00008oookJP;o001o;OoonfX;o`0003_ooo]Z1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo
001o0_oonfX4o`0000;ooo]Z0_l007ldoookJP[o0000>OoonfX6o`00Oagooo]Z000QoookJPCo001o
M?oonfX3o`00O`Co00002OoonfX7o`00ObWooo]Z2ol0000ioookJPGo0000LooonfX7o`00O`;ooo]Z
1?l00003oookJPOo001o;_oonfX=o`0003Sooo]Z1?l007lMoookJP008_oonfX3o`00OgGooo]Z0_l0
07l4o`0000Wooo]Z1ol007l[oookJPco0000=_oonfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooo
nfX7o`00Oboooo]Z3ol0000foookJP?o001o7OoonfX009cooo]Z1?l0000moookJPco0000=?oonfX5
o`0007cooo]Z1?l0000loookJPoo0000DooonfX009cooo]Z1?l0000ooookJPgo0000<OoonfX5o`00
07cooo]Z1?l0000ooookJPco0000DooonfX009cooo]Z1?l00011oookJPgo0000;ooonfX5o`0007co
oo]Z1?l00012oookJPko0000C_oonfX009cooo]Z1?l00014oookJPgo0000;?oonfX5o`0007cooo]Z
1?l00015oookJQ3o0000BOoonfX009cooo]Z1?l00016oookJPoo0000:?oonfX5o`0007cooo]Z1?l0
0017oookJQ?o0000A?oonfX009cooo]Z1?l00019oookJQ[o00006_oonfX5o`0007cooo]Z1?l00018
oookJQ_o0000>ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go
00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooo
nfX000kooo]Zool0003oo`0002Go00003ooonfX001gooo]Z00?o0000oookJ_l000000ol000000ooo
nf[o0000o`000002o`000003oookJ_l0003o000002;o0000CooonfX4o`0007Kooo]Z1Ol000000ooo
nf[o0000o`000007o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000009?l0001=oook
JPCo0000L_oonfX9o`000003oookJ_l0003o000000;o00007_oonfX003Sooo]Z6Ol0001;oookJPCo
0000OOoonfX5o`0001Wooo]Z6ol00018oookJPCo0000W_oonfX004Cooo]Z4?l00018oookJPCo0000
OOoonfX5o`0002;ooo]Z4_l00018oookJPCo0000W_oonfX004Oooo]Z4?l00015oookJPCo0000OOoo
nfX5o`0002Oooo]Z4_l00013oookJPCo0000W_oonfX004[ooo]Z3ol00013oookJPCo0000OOoonfX5
o`0002cooo]Z3_l00012oookJPCo0000W_oonfX004kooo]Z3Ol00011oookJPCo0000OOoonfX5o`00
02gooo]Z4Ol0000noookJPCo0000W_oonfX0057ooo]Z3?l0000ooookJPCo0000OOoonfX5o`00037o
oo]Z3_l0000moookJPCo0000W_oonfX005Cooo]Z2ol0000moookJPCo0000OOoonfX5o`0003Kooo]Z
3Ol0000ioookJPCo0000W_oonfX005Kooo]Z2ol0000koookJPCo0000OOoonfX5o`0003Kooo]Z3Ol0
000ioookJPCo0000W_oonfX005Sooo]Z2ol0000ioookJPCo0000OOoonfX5o`0003[ooo]Z2_l0000h
oookJPCo0000W_oonfX005[ooo]Z2_l0000hoookJPCo0000OOoonfX5o`0003_ooo]Z3Ol0000doook
JPCo0000W_oonfX005cooo]Z2_l0000foookJPCo0000OOoonfX5o`0003cooo]Z3Ol0000coookJPCo
0000W_oonfX005kooo]Z2_l0000doookJPCo0000OOoonfX5o`00043ooo]Z2ol0000aoookJPCo0000
W_oonfX0063ooo]Z2Ol0000coookJPCo0000OOoonfX5o`00047ooo]Z2ol0000`oookJPCo0000W_oo
nfX0067ooo]Z2_l0000aoookJPCo0000OOoonfX5o`0004Cooo]Z2_l0000^oookJPCo0000W_oonfX0
06?ooo]Z2Ol0000`oookJPCo0000OOoonfX5o`0004Kooo]Z2Ol0000]oookJPCo0000W_oonfX006Go
oo]Z2?l0000_oookJPCo0000OOoonfX5o`0004Sooo]Z2?l0000/oookJPCo0000W_oonfX006Kooo]Z
2Ol0000]oookJPCo0000OOoonfX5o`0004Wooo]Z2?l0000[oookJPCo0000W_oonfX006Sooo]Z2?l0
000/oookJPCo0000OOoonfX5o`0004_ooo]Z1ol0000ZoookJPCo0000W_oonfX006Wooo]Z2Ol0000Z
oookJPCo0000OOoonfX5o`0004cooo]Z1ol0000YoookJPCo0000W_oonfX006[ooo]Z2Ol0000Yoook
JPCo0000OOoonfX5o`0004gooo]Z1ol0000XoookJPCo0000W_oonfX006cooo]Z2?l0000XoookJPCo
0000OOoonfX5o`0004kooo]Z1ol0000WoookJPCo0000W_oonfX006gooo]Z2Ol0000VoookJPCo0000
OOoonfX5o`0004oooo]Z1ol0000VoookJPCo0000W_oonfX006oooo]Z2?l0000UoookJPCo0000OOoo
nfX5o`00053ooo]Z1ol0000UoookJPCo0000W_oonfX0073ooo]Z2?l0000ToookJPCo0000OOoonfX5
o`00057ooo]Z1ol0000ToookJPCo0000W_oonfX0077ooo]Z2?l0000RoookJPGo0000OOoonfX5o`00
05;ooo]Z1ol0000SoookJPCo0000W_oonfX007?ooo]Z1ol0000QoookJPGo0000OOoonfX5o`0005?o
oo]Z1ol0000RoookJPCo0000W_oonfX007Cooo]Z1ol0000PoookJPGo0000OOoonfX5o`0005Cooo]Z
1ol0000QoookJPCo0000W_oonfX007Gooo]Z1ol0000OoookJPCo0000O_oonfX5o`0005Gooo]Z1ol0
000PoookJPCo0000W_oonfX007Kooo]Z1ol0000NoookJPCo0000O_oonfX5o`0005Kooo]Z1ol0000O
oookJPCo0000W_oonfX007Oooo]Z1ol0000MoookJPCo0000O_oonfX5o`0005Oooo]Z1ol0000Noook
JPCo0000W_oonfX007Sooo]Z1ol0000LoookJPCo0000O_oonfX5o`0005Sooo]Z1ol0000MoookJPCo
0000W_oonfX007Wooo]Z1ol0000KoookJPCo0000O_oonfX5o`0005Wooo]Z1ol0000LoookJPCo0000
W_oonfX007[ooo]Z1ol0000JoookJPCo0000O_oonfX5o`0005[ooo]Z1ol0000KoookJPCo0000W_oo
nfX007_ooo]Z1ol0000IoookJPCo0000O_oonfX5o`0005_ooo]Z1ol0000JoookJPCo0000W_oonfX0
07cooo]Z1ol0000HoookJPCo0000H?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`00
05cooo]Z1_l0000JoookJPCo0000W_oonfX007gooo]Z1ol0000GoookJPCo0000GooonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o2OoonfX5o`0005gooo]Z1_l0000IoookJPCo0000W_oonfX007kooo]Z
1ol0000FoookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001NoookJPKo00006?oonfX4o`00
09kooo]Z001ooookJPKo00005_oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l8oookJPGo0000G_oonfX7o`0001Oooo]Z1?l0002NoookJP00P?oonfX6o`0001Gooo]Z
1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000G_oonfX6o`0001Oooo]Z
1?l0002NoookJP00POoonfX6o`0001Cooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l8oookJPGo0000H?oonfX6o`0001Gooo]Z1Ol0002NoookJP00POoonfX7o`0001?ooo]Z1?l0001N
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`00067ooo]Z1_l0000D
oookJPGo0000W_oonfX008;ooo]Z1ol0000BoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o2OoonfX5o`00067ooo]Z1ol0000CoookJPGo0000W_oonfX008?ooo]Z1ol0000AoookJPCo
0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0006;ooo]Z1_l0000CoookJPCo
0000WooonfX008Cooo]Z1ol0000@oookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
3_oonfX5o`0006?ooo]Z1_l0000BoookJPCo0000WooonfX008Gooo]Z1_l0000@oookJPCo0000Gooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000I?oonfX6o`00017ooo]Z
1?l0002OoookJP00Q_oonfX6o`0000oooo]Z1?l0001OoookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0
001ToookJPKo00004OoonfX4o`0009oooo]Z0027oookJPKo00003_oonfX4o`00063ooo]Z1Ol007l:
oookJPOo001o2?oonfX5o`0006Gooo]Z1_l0000@oookJPCo0000WooonfX008Oooo]Z1ol0000=oook
JPCo0000O_oonfX5o`0006Kooo]Z1Ol0000@oookJPCo0000WooonfX008Sooo]Z1ol0000<oookJPCo
0000O_oonfX5o`0006Kooo]Z1_l0000?oookJPCo0000WooonfX008Wooo]Z1ol0000;oookJPCo0000
O_oonfX5o`0006Oooo]Z1_l0000>oookJPCo0000WooonfX008[ooo]Z1ol0000:oookJPCo0000O_oo
nfX5o`0006Oooo]Z1_l0000>oookJPCo0000WooonfX008_ooo]Z1_l0000:oookJPCo0000O_oonfX5
o`0006Sooo]Z1_l0000=oookJPCo0000WooonfX008cooo]Z1_l00009oookJPCo0000O_oonfX5o`00
06Wooo]Z1_l0000<oookJPCo0000WooonfX008gooo]Z1Ol00009oookJPCo0000O_oonfX5o`0006Wo
oo]Z1_l0000<oookJPCo0000WooonfX008gooo]Z1_l00008oookJPCo0000O_oonfX5o`0006[ooo]Z
1_l0000;oookJPCo0000WooonfX008kooo]Z1Ol00008oookJPCo0000O_oonfX5o`0006_ooo]Z1Ol0
000;oookJPCo0000WooonfX008kooo]Z1_l00007oookJPCo0000O_oonfX5o`0006_ooo]Z2ol00005
oookJPCo0000WooonfX008oooo]Z1_l00006oookJPCo0000O_oonfX5o`0006cooo]Z2_l00005oook
JPCo0000WooonfX008oooo]Z1_l00006oookJPCo0000O_oonfX5o`0006cooo]Z2_l00005oookJPCo
0000WooonfX0093ooo]Z1_l00004oookJPGo0000O_oonfX5o`0006gooo]Z2Ol00005oookJPCo0000
WooonfX0097ooo]Z1Ol00004oookJPGo0000O_oonfX5o`0006kooo]Z2?l00005oookJPCo0000Wooo
nfX0097ooo]Z3_l0001noookJPGo0000K_oonfXAo`0009oooo]Z002BoookJPco0000OooonfX5o`00
06oooo]Z4?l0002OoookJP00T_oonfX<o`0007oooo]Z1Ol0001boookJPgo0000WooonfX009?ooo]Z
2ol0001ooookJPGo0000LooonfX<o`0009oooo]Z002CoookJP_o0000OooonfX5o`0007?ooo]Z3?l0
002OoookJP00TooonfX;o`0007oooo]Z1Ol0001coookJPco0000WooonfX009?ooo]Z2ol0001ooook
JPGo0000LooonfX<o`0009oooo]Z002CoookJP_o0000OooonfX5o`0007?ooo]Z3?l0002OoookJP00
TooonfX;o`0007oooo]Z1Ol0001doookJP_o0000WooonfX009?ooo]Z2ol0001ooookJPGo0000M?oo
nfX;o`0009oooo]Z002DoookJP[o0000OooonfX5o`0007Cooo]Z2ol0002OoookJP00U?oonfX:o`00
07oooo]Z1Ol0001doookJP_o0000WooonfX009Gooo]Z2Ol0001ooookJPGo0000M?oonfX;o`0009oo
oo]Z002HoookJPKo0000OooonfX5o`0007Sooo]Z1ol0002OoookJP00V?oonfX6o`0007oooo]Z1Ol0
001hoookJPOo0000WooonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Sooo]Z1ol0002O
oookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX7o`0009oooo]Z002HoookJPKo
0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPOo0000WooonfX009Sooo]Z1_l0001boookJP?o001o
2_oonfX5o`0007Sooo]Z1ol0002OoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPKo0000Mooo
nfX7o`0009oooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPOo0000WooonfX0
09Wooo]Z1Ol0001boookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007;o
oo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z
1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001_oookJPKo001o2_oonfX5o`0007Wooo]Z1Ol0
002PoookJP00VOoonfX5o`0006oooo]Z1_l007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002Ioook
JPGo0000LOoonfX4o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001boookJP?o
001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007oooo]Z1Ol0001ioookJPGo0000
X?oonfX009Wooo]Z1Ol0001ooookJPGo0000N_oonfX4o`000:3ooo]Z002IoookJPCo0000P?oonfX5
o`0007[ooo]Z1?l0002PoookJP00VOoonfX4o`00083ooo]Z1Ol0001joookJPCo0000X?oonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooo
nfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6
o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo0000oooonfXOoook
JP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5
o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o
2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o
2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003o
oookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX6o`00
0?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z
0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/oookJP00oooonfX=
oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooook
JRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooonfX>oookJPOo001o
oooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[ooookJT;ooo]Z003ooook
J_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .3097 L
.02605 .30997 L
.02729 .30969 L
.02846 .309 L
.02946 .3084 L
.03053 .30807 L
.0317 .30826 L
.03279 .30885 L
.03395 .30958 L
.0352 .30999 L
.03638 .30978 L
.03746 .30918 L
.03873 .30843 L
.03944 .30817 L
.04011 .30811 L
.04132 .30849 L
.04262 .3093 L
.04327 .30969 L
.04396 .30998 L
.04519 .31002 L
.04588 .30977 L
.04652 .30941 L
.04726 .30894 L
.04797 .30855 L
.04925 .30824 L
.05041 .30855 L
.05166 .30934 L
.05236 .30979 L
.05302 .31012 L
.05414 .31029 L
.05539 .30987 L
.0566 .30914 L
.05791 .30856 L
.05907 .30861 L
.06028 .30924 L
.06132 .30997 L
.06244 .31057 L
.06315 .3107 L
.0638 .31063 L
.06509 .31004 L
.06632 .30932 L
.06748 .30899 L
.06873 .30928 L
.06939 .30968 L
.0701 .3102 L
.07084 .31073 L
.07155 .31112 L
.07287 .31131 L
.07404 .31088 L
Mistroke
.07528 .31017 L
.07645 .30973 L
.07751 .30984 L
.07876 .31056 L
.07942 .31108 L
.08012 .31161 L
.08139 .31222 L
.08257 .31215 L
.08327 .31185 L
.08394 .31148 L
.08519 .31087 L
.08589 .31074 L
.08654 .31082 L
.08725 .31114 L
.088 .31168 L
.08916 .31265 L
.09041 .31341 L
.09113 .31355 L
.09178 .31346 L
.09307 .31288 L
.09374 .31252 L
.09446 .31222 L
.09575 .31223 L
.09654 .31262 L
.09729 .31321 L
.09868 .31445 L
.0994 .31493 L
.10015 .3152 L
.1008 .31521 L
.10151 .31501 L
.10228 .31463 L
.10311 .31421 L
.10381 .31397 L
.10458 .31394 L
.10587 .31456 L
.10708 .31568 L
.1084 .31685 L
.10913 .31725 L
.10981 .31737 L
.11096 .3171 L
.11222 .31649 L
.11354 .31618 L
.11477 .31665 L
.12407 .31955 L
.13417 .32391 L
.14497 .33022 L
.16486 .34274 L
.17534 .34997 L
.18644 .35717 L
.19633 .36586 L
Mistroke
.20721 .37735 L
.22639 .4021 L
.23635 .41874 L
.23757 .4251 L
.23872 .42888 L
.23936 .42942 L
.24005 .42875 L
.24126 .4255 L
.24241 .42253 L
.24363 .42294 L
.24467 .42741 L
.24581 .43557 L
.24711 .44482 L
.24784 .44789 L
.24851 .44858 L
.2498 .4441 L
.25103 .43607 L
.25171 .43242 L
.25244 .43097 L
.25375 .43768 L
.25448 .44664 L
.25516 .45725 L
.25591 .46913 L
.25672 .47921 L
.25794 .48018 L
.25922 .4531 L
.26041 .40025 L
.26152 .33384 L
.26281 .25162 L
.26402 .18683 L
.26469 .16135 L
.26542 .14364 L
.26669 .13619 L
.26793 .14929 L
.26906 .16733 L
.27036 .18304 L
.27159 .18696 L
.27273 .1823 L
.27378 .17531 L
.27494 .16999 L
.27617 .17077 L
.27688 .17427 L
.27752 .17879 L
.27822 .18419 L
.27899 .18967 L
.28028 .19531 L
.28098 .19591 L
.28164 .19507 L
.28289 .1915 L
.28403 .18888 L
Mistroke
.28534 .1897 L
.28659 .19461 L
.2879 .2016 L
.28913 .20658 L
.29042 .20816 L
.2911 .20759 L
.29183 .20639 L
.29313 .2045 L
.29436 .20499 L
.29547 .20797 L
.29668 .2129 L
.29742 .21592 L
.29812 .21823 L
.29943 .22033 L
.30016 .22025 L
.30083 .21964 L
.30162 .21874 L
.30236 .21818 L
.30358 .21876 L
.30423 .22001 L
.30492 .22199 L
.30621 .22646 L
.3069 .22868 L
.30763 .23052 L
.30895 .2319 L
.31019 .23135 L
.31088 .2308 L
.31161 .23044 L
.31291 .23118 L
.31412 .23374 L
.31525 .23708 L
.31648 .24044 L
.3178 .24234 L
.31854 .24251 L
.31923 .24226 L
.31997 .24181 L
.32078 .24147 L
.32149 .24158 L
.32215 .24216 L
.32285 .24329 L
.3236 .245 L
.32501 .24869 L
.3257 .25026 L
.32635 .25133 L
.32755 .25218 L
.32886 .2518 L
.33013 .25135 L
.33084 .25153 L
.3315 .25212 L
.3327 .25421 L
Mistroke
.33398 .25717 L
.33512 .25947 L
.33618 .26068 L
.33735 .26087 L
.33861 .26037 L
.3393 .2602 L
.33994 .26029 L
.34065 .26078 L
.3414 .26177 L
.34265 .26419 L
.34337 .2657 L
.34404 .26694 L
.34527 .26843 L
.34591 .26871 L
.34659 .26869 L
.34773 .26827 L
.34898 .26808 L
.34963 .26836 L
.35031 .269 L
.35153 .27092 L
.35221 .27222 L
.35295 .27356 L
.35365 .2746 L
.35428 .27526 L
.3555 .27568 L
.35666 .27535 L
.35791 .275 L
.35862 .27512 L
.35928 .27555 L
.36862 .28163 L
.37943 .2886 L
.38472 .29122 L
.38584 .29092 L
.38704 .29125 L
.38836 .2925 L
.38958 .29406 L
.39076 .29526 L
.39187 .29573 L
.39286 .2956 L
.39395 .29514 L
.39511 .29478 L
.39634 .29507 L
.39739 .29594 L
.39854 .29726 L
.3998 .29853 L
.40095 .29906 L
.40158 .29905 L
.40228 .29884 L
.40354 .29826 L
.40471 .29801 L
Mistroke
.40596 .29847 L
.40714 .29954 L
.40822 .30068 L
.40951 .30166 L
.41016 .30184 L
.41087 .3018 L
.41213 .30128 L
.41331 .30076 L
.41402 .30066 L
.4147 .3008 L
.41597 .30163 L
.41735 .30297 L
.41811 .3036 L
.41882 .30398 L
.42 .30406 L
.4213 .30352 L
.42242 .30298 L
.4236 .30283 L
.42491 .30342 L
.42611 .30445 L
.42739 .30549 L
.42813 .30583 L
.4288 .30591 L
.43126 .30488 L
.4325 .30449 L
.4332 .30456 L
.43386 .30484 L
.43457 .30533 L
.43523 .30587 L
.43594 .30646 L
.43671 .30697 L
.4374 .30724 L
.43805 .30729 L
.43933 .30685 L
.44063 .30613 L
.44186 .30577 L
.44296 .30599 L
.44414 .30676 L
.44544 .30775 L
.4461 .30812 L
.44681 .30831 L
.44808 .30809 L
.44927 .30744 L
.45043 .30685 L
.45168 .30673 L
.45287 .30724 L
.45397 .30803 L
.45496 .30869 L
.45604 .30904 L
.45718 .30885 L
Mistroke
.45825 .30828 L
.45948 .30759 L
.46066 .30733 L
.46172 .30761 L
.46288 .30834 L
.46412 .30916 L
.46482 .30944 L
.46546 .30952 L
.46669 .30918 L
.46786 .30849 L
.46902 .30789 L
.47026 .30776 L
.47143 .30823 L
.4725 .30894 L
.47376 .30963 L
.47447 .30979 L
.47512 .30974 L
.47633 .30922 L
.47761 .30843 L
.47882 .30798 L
.48013 .30815 L
.48137 .30885 L
.48251 .30956 L
.48376 .30993 L
.48448 .30984 L
.48514 .30958 L
.48647 .30877 L
.48717 .30837 L
.48792 .3081 L
.48917 .30816 L
.49032 .30873 L
.49149 .30947 L
.49259 .30992 L
.49357 .30991 L
.49462 .30949 L
.49577 .30876 L
.49684 .30822 L
.49806 .30809 L
.49871 .30828 L
.4994 .30864 L
.50065 .30942 L
.50183 .30992 L
.50298 .30988 L
.50422 .30928 L
.50533 .30858 L
.50638 .30813 L
.50763 .30817 L
.50876 .30872 L
.5094 .30913 L
.51008 .30955 L
Mistroke
.51131 .30998 L
.51235 .30986 L
.51351 .30928 L
.51468 .30855 L
.5159 .30812 L
.51655 .30814 L
.51726 .30836 L
.5185 .30909 L
.5192 .30954 L
.51994 .30991 L
.52065 .31008 L
.52129 .31004 L
.52254 .30952 L
.52324 .30908 L
.52389 .30869 L
.52508 .30826 L
.52634 .30844 L
.54741 .31096 L
.55758 .31222 L
.56723 .31354 L
.57589 .31507 L
.58533 .31725 L
.6048 .32326 L
.60612 .32287 L
.60684 .32254 L
.60752 .32233 L
.60825 .32232 L
.60905 .32264 L
.60973 .3232 L
.61045 .32402 L
.61114 .3249 L
.61188 .32582 L
.61259 .32652 L
.61324 .32694 L
.61447 .32708 L
.61577 .3266 L
.61694 .32625 L
.61821 .32662 L
.6194 .32781 L
.62049 .32932 L
.62177 .33089 L
.62249 .33144 L
.62316 .33165 L
.62439 .33145 L
.6257 .33095 L
.62634 .33088 L
.62703 .33106 L
.62826 .33213 L
.62958 .33406 L
.63033 .3352 L
Mistroke
.63102 .33606 L
.63228 .3369 L
.63297 .33693 L
.63362 .33676 L
.63478 .33633 L
.63604 .33635 L
.63717 .33724 L
.63841 .33908 L
.63962 .34111 L
.64092 .34264 L
.64213 .34304 L
.64324 .34272 L
.64431 .34238 L
.64543 .34258 L
.64674 .34398 L
.64794 .3461 L
.64923 .34839 L
.64995 .34932 L
.65062 .34982 L
.65183 .34991 L
.65311 .34943 L
.65422 .34936 L
.65545 .35033 L
.66642 .3618 L
.6875 .38732 L
.70676 .41361 L
.7079 .41212 L
.70913 .41017 L
.7103 .41027 L
.71137 .41313 L
.71263 .41921 L
.71331 .42289 L
.71395 .42592 L
.71506 .42911 L
.71628 .42867 L
.71698 .42692 L
.71765 .42488 L
.71889 .4222 L
.71958 .42246 L
.72022 .42422 L
.72093 .42781 L
.72167 .43303 L
.72282 .44173 L
.72405 .44793 L
.72476 .44854 L
.7254 .447 L
.72667 .43973 L
.72777 .43298 L
.72895 .43142 L
.73006 .43892 L
Mistroke
.73107 .45273 L
.73226 .47155 L
.73355 .48246 L
.73477 .4708 L
.73589 .43517 L
.73849 .28375 L
.73977 .20824 L
.74095 .15929 L
.74202 .13817 L
.74317 .13787 L
.74431 .15227 L
.74558 .17222 L
.74674 .1844 L
.74799 .18657 L
.74918 .18063 L
.75026 .17355 L
.75143 .1695 L
.75271 .17229 L
.75336 .1762 L
.75405 .18137 L
.75529 .1904 L
.75647 .19531 L
.75774 .19525 L
.75894 .19193 L
.76005 .18912 L
.76105 .18883 L
.76215 .19173 L
.7633 .19737 L
.76437 .20298 L
.76565 .20736 L
.76637 .20815 L
.76704 .20789 L
.76827 .20596 L
.76957 .20436 L
.77086 .20559 L
.77207 .20952 L
.77314 .21407 L
.77433 .21828 L
.77563 .22034 L
.77634 .22025 L
.777 .21966 L
.77819 .21839 L
.77947 .2184 L
.78018 .21948 L
.78096 .22151 L
.78238 .22637 L
.78304 .22855 L
.78375 .23037 L
.78503 .23187 L
.80473 .25196 L
Mistroke
.82279 .26869 L
.84215 .28143 L
.86301 .29112 L
.87294 .29535 L
.88355 .29977 L
.88475 .301 L
.88602 .30178 L
.88668 .30185 L
.88741 .30169 L
.8887 .30109 L
.88991 .30068 L
.89121 .30094 L
.89244 .30189 L
.89356 .30299 L
.89472 .30385 L
.89579 .30411 L
.89697 .30379 L
.89822 .30314 L
.89942 .30281 L
.90055 .30307 L
.90156 .30378 L
.90265 .30477 L
.9038 .30562 L
.90504 .3059 L
.9062 .30555 L
.90727 .30497 L
.90851 .30451 L
.90921 .30452 L
.90986 .30474 L
.91106 .30556 L
.91232 .30661 L
.91353 .30723 L
.91483 .30716 L
.91605 .30656 L
.91717 .30597 L
.91848 .30579 L
.91923 .30603 L
.91992 .30645 L
.92117 .30742 L
.92183 .30788 L
.92252 .30821 L
.92376 .30826 L
.92491 .30777 L
.92607 .3071 L
.92715 .30672 L
.92812 .30679 L
.92916 .3073 L
.9303 .30814 L
.93135 .30879 L
.93257 .30904 L
Mistroke
.93388 .30861 L
.93505 .30791 L
.93628 .30739 L
.93738 .30741 L
.93842 .30789 L
.93956 .30868 L
.94077 .30937 L
.94194 .3095 L
.943 .30912 L
.94406 .30848 L
.94507 .30794 L
.94624 .30774 L
.94732 .30807 L
.94851 .30881 L
.94977 .30956 L
.95089 .3098 L
.9521 .30945 L
.95324 .30877 L
.95428 .30819 L
.9555 .30795 L
.95619 .3081 L
.95683 .3084 L
.95799 .30914 L
.95925 .3098 L
.9604 .3099 L
.96146 .30951 L
.96248 .30889 L
.96355 .30828 L
.96451 .30804 L
.96541 .30818 L
.9664 .30866 L
.96745 .30933 L
.96858 .30987 L
.9698 .3099 L
.97096 .3094 L
.97202 .30872 L
.97299 .30823 L
.97405 .30807 L
.97515 .3084 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00WooonfX4o`0007[ooo]Z1Ol0003ooookJQoooo]Z002OoookJPCo0000N_oonfX5o`0007ko
oo]Z1Ol0002KoookJP00WooonfX4o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0
001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000N_oonfX5o`0007kooo]Z1Ol0002K
oookJP00W_oonfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001joookJPGo
0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000
VooonfX009kooo]Z1Ol0001]oookJP?o001o2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5
o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z002MoookJPKo0000GOoonfX:o`00
O`Kooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z002MoookJPKo0000GOoonfX:o`00O`Ko
oo]Z0ol007l:oookJPKo0000OOoonfX5o`0009_ooo]Z002MoookJPKo0000KOoonfX3o`00O`[ooo]Z
1Ol0001noookJPGo0000VooonfX009gooo]Z1ol0001/oookJP?o001o2_oonfX5o`0007kooo]Z1Ol0
002KoookJP00WOoonfX7o`0006cooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z002Moook
JPOo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX009gooo]Z1ol0001YoookJPKo
001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00WOoonfX7o`0006Wooo]Z1_l007l:oookJPGo0000
O_oonfX6o`0009[ooo]Z002MoookJPOo0000JooonfX4o`00O`[ooo]Z1Ol0001noookJPWo0000Uooo
nfX009gooo]Z2ol0001XoookJP?o001o2_oonfX5o`0007kooo]Z2Ol0002GoookJP00WOoonfX;o`00
07Gooo]Z1Ol0001noookJP[o0000U_oonfX009gooo]Z2ol0001eoookJPGo0000O_oonfX:o`0009Ko
oo]Z002MoookJP_o0000MOoonfX5o`0007kooo]Z2_l0002FoookJP00WOoonfX;o`0007Gooo]Z1Ol0
001noookJP[o0000U_oonfX009gooo]Z2ol0001eoookJPGo0000O_oonfX;o`0009Gooo]Z002Moook
JPco0000M?oonfX5o`0007kooo]Z2ol0002EoookJP00WOoonfX<o`0007Cooo]Z1Ol0001noookJP_o
0000UOoonfX009gooo]Z3?l0001doookJPGo0000OOoonfX<o`0009Gooo]Z002MoookJPco0000M?oo
nfX5o`0007gooo]Z3?l0002EoookJP00WOoonfX@o`00073ooo]Z1Ol0001moookJPoo0000T_oonfX0
09gooo]Z4?l0001`oookJPGo0000OOoonfX@o`00097ooo]Z002MoookJQ3o0000L?oonfX5o`0007go
oo]Z4?l0002AoookJP00WOoonfX4o`0000Cooo]Z2?l0001`oookJPGo0000OOoonfX4o`0000Cooo]Z
2?l0002AoookJP00WOoonfX4o`0000Cooo]Z2?l0001`oookJPGo0000OOoonfX4o`0000Cooo]Z2Ol0
002@oookJP00WOoonfX4o`0000Gooo]Z1ol0001`oookJPGo0000OOoonfX4o`0000Cooo]Z2Ol0002@
oookJP00WOoonfX4o`0000Gooo]Z2?l0001_oookJPGo0000OOoonfX4o`0000Gooo]Z2?l0002@oook
JP00WOoonfX4o`0000Gooo]Z2?l0001_oookJPGo0000OOoonfX4o`0000Wooo]Z1?l0002@oookJP00
WOoonfX4o`0000Sooo]Z2?l0001/oookJPGo0000OOoonfX4o`0000Wooo]Z1ol0002=oookJP00WOoo
nfX4o`0000Wooo]Z2?l0001[oookJPGo0000OOoonfX4o`0000Wooo]Z2?l0002<oookJP00WOoonfX4
o`0000Wooo]Z2?l0001[oookJPGo0000OOoonfX4o`0000Wooo]Z2?l0002<oookJP00WOoonfX4o`00
00Wooo]Z2?l0001[oookJPGo0000OOoonfX4o`0000Wooo]Z2?l0002<oookJP00WOoonfX4o`0000[o
oo]Z2?l0001ZoookJPGo0000OOoonfX4o`0000Wooo]Z2?l0002<oookJP00WOoonfX4o`0000[ooo]Z
2?l0001ZoookJPGo0000OOoonfX4o`0000[ooo]Z2?l0002;oookJP00WOoonfX4o`0000gooo]Z1Ol0
001ZoookJPGo0000OOoonfX4o`0000gooo]Z1Ol0002;oookJP00WOoonfX4o`0000kooo]Z1?l0001Z
oookJPGo0000OOoonfX4o`0000gooo]Z1Ol0002;oookJP00WOoonfX4o`0000kooo]Z2?l0001Voook
JPGo0000OOoonfX4o`0000kooo]Z1ol00028oookJP00W?oonfX5o`0000kooo]Z2?l0001VoookJPGo
0000OOoonfX4o`0000kooo]Z2?l00027oookJP00W?oonfX5o`0000kooo]Z2?l0001VoookJPGo0000
OOoonfX4o`0000kooo]Z2?l00027oookJP00W?oonfX5o`0000oooo]Z1ol0001VoookJPGo0000OOoo
nfX4o`0000oooo]Z1ol00027oookJP00W?oonfX4o`00013ooo]Z2?l00017oookJPGo001o1?oonfX3
o`00O`?ooo]Z1Ol007l:oookJPGo0000OOoonfX4o`0000oooo]Z2?l00026oookJP00W?oonfX4o`00
01?ooo]Z1Ol00016oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000OOoonfX4o`00
01;ooo]Z1Ol00026oookJP00W?oonfX4o`0001?ooo]Z2?l00013oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5
o`0007gooo]Z1?l0000BoookJPKo0000QOoonfX009cooo]Z1?l0000DoookJPSo0000=OoonfX:o`00
O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000OOoonfX4o`00
01?ooo]Z1Ol00025oookJP00W?oonfX4o`0001Cooo]Z2?l0000eoookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o2?oonfX6o`0007cooo]Z1?l0000CoookJPKo0000Q?oonfX009cooo]Z
1?l0000EoookJPOo0000@OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX5o`0007gooo]Z
1?l0000DoookJPKo0000PooonfX009cooo]Z1?l0000EoookJPSo0000@?oonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001moookJPCo00005?oonfX7o`0008;ooo]Z002L
oookJPCo00006?oonfX5o`00043ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001m
oookJPCo00005OoonfX7o`00087ooo]Z002LoookJPCo00006?oonfX8o`0003gooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001moookJPCo00005_oonfX7o`00083ooo]Z002LoookJPCo
00006OoonfX8o`0003cooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol0001moookJPCo
00005ooonfX7o`0007oooo]Z002LoookJPCo00006OoonfX8o`0003gooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001o3_oonfX5o`0007gooo]Z1?l0000HoookJPOo0000O_oonfX009cooo]Z
1?l0000JoookJPOo0000?OoonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000O?oonfX5o`0001Wooo]Z
1ol0001moookJP00W?oonfX4o`0001[ooo]Z2?l0000moookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0
001loookJPGo00006_oonfX7o`0007cooo]Z002LoookJPCo00007OoonfX6o`0005[ooo]Z1Ol0001l
oookJPGo00006ooonfX7o`0007_ooo]Z002LoookJPCo00007OoonfX9o`0005Oooo]Z1Ol0001loook
JPCo00007OoonfX8o`0007Wooo]Z002LoookJPCo00007_oonfX8o`0005Oooo]Z1Ol0001loookJPCo
00007_oonfX8o`0007Sooo]Z002LoookJPCo00007ooonfX7o`0005Oooo]Z1Ol0001loookJPCo0000
7ooonfX8o`0007Oooo]Z002LoookJPCo00007ooonfX8o`0005Kooo]Z1Ol0001loookJPCo00008?oo
nfX8o`0007Kooo]Z002LoookJPCo00008_oonfX6o`0005Gooo]Z1Ol0001loookJPCo00008_oonfX7
o`0007Gooo]Z002LoookJPCo00008_oonfX9o`0005;ooo]Z1Ol0001loookJPCo00008ooonfX7o`00
07Cooo]Z002LoookJPCo00008ooonfX8o`0005;ooo]Z1Ol0001loookJPCo00009?oonfX7o`0007?o
oo]Z002LoookJPCo00009?oonfX8o`00057ooo]Z1Ol0001loookJPCo00009OoonfX7o`0007;ooo]Z
002LoookJPCo00009?oonfX8o`00057ooo]Z1Ol0001loookJPCo00009_oonfX7o`00077ooo]Z002L
oookJPCo00009ooonfX9o`0004gooo]Z1Ol0001loookJPCo00009ooonfX8o`0006oooo]Z002Loook
JPCo0000:?oonfX9o`0004cooo]Z1Ol0001loookJPCo0000:?oonfX8o`0006kooo]Z000RoookJP?o
001oMOoonfX2o`00O`Co00000ooonfX3o`00O`?ooo]Z1Ol007lJoookJPWo0000C?oonfX5o`0007Co
oo]Z1Ol007l3oookJPCo00000ooonfX5o`00Ob7ooo]Z2Ol0001<oookJP?o001o7OoonfX002;ooo]Z
0ol007mdoookJP?o001o1?l00003oookJP?o001o0_oonfX7o`00Oa[ooo]Z2Ol0001;oookJPGo0000
LooonfX7o`00O`;ooo]Z1?l00002oookJPOo001o8OoonfX9o`0004_ooo]Z0ol007lMoookJP008_oo
nfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00Oakooo]Z2Ol00017oookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`;o
oo]Z1?l000000ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Ob?ooo]Z2?l0001:oook
JP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o
0000o`000002o`000003o`00Oooonf[ooo]Z00Cooo]Z0ol007l3oookJP?o001o7OoonfX;o`0004Go
oo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o000000Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00Ob?ooo]Z2Ol00018oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o
001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00[o
oo]Z0ol007lMoookJPco0000A?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l0
00000_l00007oookJP?o001o9OoonfX8o`0004Oooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z
0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00[ooo]Z0ol007lNoookJPgo0000
@_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00007oookJP?o001o
9_oonfX9o`0004Gooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`00
0002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l2oookJPCo001o8ooonfX9o`00047ooo]Z1Ol0
001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oonfX2o`00O`;ooo]Z1?l0
07lWoookJP_o0000@_oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o
000000;o000000?o001ooookJ_oonfX01OoonfX7o`00ObKooo]Z2Ol0000ooookJPGo0000L_oonfX3
o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1ol007lZoookJP_o0000@?oonfX3
o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooook
J_oonfX01OoonfX6o`00ObSooo]Z2Ol0000noookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooo
nf[o0000o`000002o`0000;ooo]Z1_l007l/oookJPco0000?_oonfX3o`00Oagooo]Z000OoookJPKo
001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX2o`00Obko
oo]Z2_l0000koookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;o
oo]Z0_l007lboookJPgo0000>?oonfX6o`00Oagooo]Z000OoookJPKo001oM?oonfX3o`00O`Co0000
2?oonfX2o`00Oboooo]Z2ol0000ioookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`;o
oo]Z1?l00002oookJP;o001o=OoonfX<o`0003Kooo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z
0ol007l4o`0000Wooo]Z1ol007l[oookJPWo0000>OoonfX5o`0007?ooo]Z1ol007l2oookJPCo0000
0ooonfX7o`00Oc7ooo]Z3?l0000foookJPCo001o7OoonfX002;ooo]Z0ol007meoookJP;o001o1?l0
0009oookJPOo001o;?oonfX=o`0003Cooo]Z1Ol0001doookJPGo001o0ooonfX4o`0000?ooo]Z1ol0
07lcoookJP_o0000=_oonfX3o`00Oagooo]Z002LoookJPCo0000?ooonfX:o`0003Cooo]Z1Ol0001l
oookJPCo0000@?oonfX;o`0005?ooo]Z002LoookJPCo0000@?oonfX>o`0002oooo]Z1Ol0001loook
JPCo0000@_oonfX<o`00053ooo]Z002LoookJPCo0000@OoonfX>o`0002kooo]Z1Ol0001loookJPCo
0000A?oonfX;o`0004oooo]Z002LoookJPCo0000@_oonfXAo`0002[ooo]Z1Ol0001loookJPCo0000
AOoonfX?o`0004[ooo]Z002LoookJPCo0000A_oonfXBo`0002Gooo]Z1Ol0001loookJPCo0000B?oo
nfXAo`0004Gooo]Z002LoookJPCo0000AooonfXKo`0001_ooo]Z1Ol0001loookJPCo0000BooonfXG
o`0003cooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oo
oo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>
oookJ_oo0000ool0000Uo`0000oooo]Z000LoookJPCo000000?ooo]Zo`000?l000000_l000000ooo
nf[o0000o`00000Yo`0004_ooo]Z1?l0001doookJPCo000000?ooo]Zo`000?l000001ol000000ooo
nf[o0000o`000002o`000003oookJ_l0003o000000?o00001OoonfXNo`0004kooo]Z1?l0001eoook
JPCo000000?ooo]Zo`000?l000000_l000000ooonf[o0000oookJP0MoookJP00>_oonfXJo`0004So
oo]Z1?l0001moookJPGo00006OoonfXHo`0004_ooo]Z1?l0002NoookJP00A?oonfXCo`0004Gooo]Z
1?l0001moookJPGo00008ooonfXAo`0004Sooo]Z1?l0002NoookJP00B?oonfXBo`0004;ooo]Z1?l0
001moookJPGo0000:?oonfXBo`0004;ooo]Z1?l0002NoookJP00B_oonfXBo`00043ooo]Z1?l0001m
oookJPGo0000:ooonfX@o`00047ooo]Z1?l0002NoookJP00DOoonfX<o`0003oooo]Z1?l0001moook
JPGo0000;_oonfX@o`0003kooo]Z1?l0002NoookJP00E?oonfX;o`0003gooo]Z1?l0001moookJPGo
0000<OoonfX?o`0003cooo]Z1?l0002NoookJP00EooonfX9o`0003cooo]Z1?l0001moookJPGo0000
=?oonfX<o`0003cooo]Z1?l0002NoookJP00FOoonfX9o`0003[ooo]Z1?l0001moookJPGo0000=ooo
nfX=o`0003Sooo]Z1?l0002NoookJP00F_oonfX:o`0003Sooo]Z1?l0001moookJPGo0000>?oonfX=
o`0003Oooo]Z1?l0002NoookJP00G?oonfX9o`0003Oooo]Z1?l0001moookJPGo0000??oonfX:o`00
03Kooo]Z1?l0002NoookJP00GOoonfX:o`0003Gooo]Z1?l0001moookJPGo0000?OoonfX<o`0003?o
oo]Z1?l0002NoookJP00GooonfX:o`0003?ooo]Z1?l0001moookJPGo0000@OoonfX9o`0003;ooo]Z
1?l0002NoookJP00HOoonfX9o`0003;ooo]Z1?l0001moookJPGo0000@OoonfX:o`00037ooo]Z1?l0
002NoookJP00H_oonfX:o`00033ooo]Z1?l0001moookJPGo0000@_oonfX<o`0002kooo]Z1?l0002N
oookJP00I?oonfX9o`0002oooo]Z1?l0001moookJPGo0000A_oonfX9o`0002gooo]Z1?l0002Noook
JP00I_oonfX9o`0002gooo]Z1?l0001moookJPGo0000AooonfX8o`0002gooo]Z1?l0002NoookJP00
IooonfX9o`0002cooo]Z1?l0001moookJPGo0000AooonfX9o`0002cooo]Z1?l0002NoookJP00JOoo
nfX9o`0002[ooo]Z1?l0001moookJPGo0000BooonfX8o`0002Wooo]Z1?l0002NoookJP00J_oonfX9
o`0002Wooo]Z1?l0001moookJPGo0000BooonfX8o`0002Wooo]Z1?l0002NoookJP00K?oonfX9o`00
02Oooo]Z1?l0001moookJPGo0000C?oonfX8o`0002Sooo]Z1?l0002NoookJP00KOoonfX9o`0002Ko
oo]Z1?l0001moookJPGo0000C?oonfX9o`0002Oooo]Z1?l0002NoookJP00KooonfX8o`0002Gooo]Z
1?l0001moookJPGo0000CooonfX7o`0002Kooo]Z1?l0002NoookJP00L?oonfX8o`0002Cooo]Z1?l0
001moookJPGo0000D?oonfX7o`0002Gooo]Z1?l0002NoookJP00L_oonfX7o`0002?ooo]Z1?l0001m
oookJPGo0000DOoonfX7o`0002?ooo]Z1Ol0002NoookJP00LooonfX7o`0002;ooo]Z1?l0001moook
JPGo0000D_oonfX7o`0002;ooo]Z1Ol0002NoookJP00M?oonfX7o`00027ooo]Z1?l0001moookJPGo
0000DooonfX6o`0002;ooo]Z1Ol0002NoookJP00MOoonfX7o`00023ooo]Z1?l0001moookJPGo0000
E?oonfX6o`00027ooo]Z1?l0002OoookJP00M_oonfX7o`0001kooo]Z1Ol0001moookJPGo0000EOoo
nfX6o`00023ooo]Z1?l0002OoookJP00MooonfX7o`0001gooo]Z1Ol0001moookJPGo0000EOoonfX7
o`0001oooo]Z1?l0002OoookJP00N?oonfX7o`0001cooo]Z1Ol0001moookJPGo0000E_oonfX7o`00
01kooo]Z1?l0002OoookJP00NOoonfX7o`0001_ooo]Z1?l0001noookJPGo0000EooonfX7o`0001go
oo]Z1?l0002OoookJP00N_oonfX7o`0001[ooo]Z1?l0001noookJPGo0000F?oonfX7o`0001cooo]Z
1?l0002OoookJP00NooonfX7o`0001Wooo]Z1?l0001noookJPGo0000FOoonfX7o`0001_ooo]Z1?l0
002OoookJP00O?oonfX6o`0001Wooo]Z1?l0001noookJPGo0000F_oonfX7o`0001[ooo]Z1?l0002O
oookJP00OOoonfX6o`0001Sooo]Z1?l0001PoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oook
JPGo0000FooonfX7o`0001Wooo]Z1?l0002OoookJP00O_oonfX6o`0001Oooo]Z1?l0001OoookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000G?oonfX7o`0001Sooo]Z1?l0002OoookJP00
O_oonfX7o`0001Kooo]Z1?l0001OoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005gooo]Z1ol0000Goook
JPCo0000WooonfX007oooo]Z1ol0000EoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Sooo]Z1Ol0001NoookJPOo00005_oonfX4o`0009oooo]Z0020oookJPOo0000
5?oonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001NoookJPKo0000
5_oonfX4o`0009oooo]Z0021oookJPOo00004ooonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Sooo]Z1Ol0001PoookJPKo00005OoonfX4o`0009oooo]Z0022oookJPKo00004ooonfX4
o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000HOoonfX6
o`0001Cooo]Z1?l0002OoookJP00PooonfX6o`0001;ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l9oookJPGo0000HOoonfX6o`0001Cooo]Z1?l0002OoookJP00Q?oonfX6o`00017o
oo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000H_oonfX6o`0001?o
oo]Z1?l0002OoookJP00Q?oonfX7o`00013ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l>oookJPGo0000HooonfX6o`0001;ooo]Z1?l0002OoookJP00QOoonfX7o`0000oooo]Z1?l0
001OoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001SoookJPKo0000
4_oonfX4o`0009oooo]Z0026oookJPOo00003_oonfX4o`0005oooo]Z1ol007l9oookJPOo001o2?oo
nfX5o`0006Cooo]Z1_l0000AoookJPCo0000WooonfX008Oooo]Z1_l0000>oookJPCo0000H?oonfX5
o`00O`[ooo]Z1ol007l8oookJPGo0000IOoonfX6o`00013ooo]Z1?l0002OoookJP00R?oonfX6o`00
00gooo]Z1?l0001noookJPGo0000IOoonfX6o`00013ooo]Z1?l0002OoookJP00ROoonfX5o`0000go
oo]Z1?l0001noookJPGo0000I_oonfX6o`0000oooo]Z1?l0002OoookJP00ROoonfX6o`0000cooo]Z
1?l0001noookJPGo0000IooonfX6o`0000kooo]Z1?l0002OoookJP00R_oonfX6o`0000_ooo]Z1?l0
001noookJPGo0000IooonfX:o`0000[ooo]Z1?l0002OoookJP00R_oonfX6o`0000_ooo]Z1?l0001n
oookJPGo0000J?oonfX:o`0000Wooo]Z1?l0002OoookJP00RooonfX6o`0000[ooo]Z1?l0001noook
JPGo0000JOoonfX9o`0000Wooo]Z1?l0002OoookJP00S?oonfX5o`0000[ooo]Z1?l0001noookJPGo
0000JOoonfX9o`0000Wooo]Z1?l0002OoookJP00S?oonfX6o`0000Wooo]Z1?l0001noookJPGo0000
J_oonfX8o`0000Wooo]Z1?l0002OoookJP00SOoonfX5o`0000Wooo]Z1?l0001noookJPGo0000Jooo
nfX7o`0000Wooo]Z1?l0002OoookJP00SOoonfX5o`0000Wooo]Z1?l0001noookJPGo0000K_oonfX8
o`0000Gooo]Z1?l0002OoookJP00S_oonfX8o`0000Gooo]Z1?l0001noookJPGo0000K_oonfX8o`00
00Gooo]Z1?l0002OoookJP00S_oonfX8o`0000Gooo]Z1?l0001noookJPGo0000K_oonfX8o`0000Go
oo]Z1?l0002OoookJP00S_oonfX9o`0000Cooo]Z1?l0001noookJPGo0000K_oonfX9o`0000Cooo]Z
1?l0002OoookJP00SooonfX8o`0000Cooo]Z1?l0001noookJPGo0000KooonfX8o`0000Cooo]Z1?l0
002OoookJP00SooonfX@o`0007kooo]Z1Ol0001_oookJQ3o0000WooonfX008oooo]Z4?l0001noook
JPGo0000KooonfX@o`0009oooo]Z002?oookJQ3o0000O_oonfX5o`00073ooo]Z3ol0002OoookJP00
TooonfX<o`0007kooo]Z1Ol0001coookJPco0000WooonfX009?ooo]Z3?l0001noookJPGo0000Looo
nfX<o`0009oooo]Z002CoookJPco0000O_oonfX5o`0007?ooo]Z3?l0002OoookJP00TooonfX<o`00
07kooo]Z1Ol0001coookJPco0000WooonfX009?ooo]Z3?l0001noookJPGo0000M?oonfX;o`0009oo
oo]Z002CoookJPco0000O_oonfX5o`0007Cooo]Z2ol0002OoookJP00U?oonfX;o`0007kooo]Z1Ol0
001doookJP_o0000WooonfX009Cooo]Z2ol0001noookJPGo0000M?oonfX;o`0009oooo]Z002Doook
JP_o0000O_oonfX5o`0007Cooo]Z2ol0002OoookJP00U?oonfX;o`0007kooo]Z1Ol0001doookJP_o
0000WooonfX009Gooo]Z2_l0001noookJPGo0000MOoonfX:o`0009oooo]Z002HoookJPOo0000O_oo
nfX5o`0007Sooo]Z1ol0002OoookJP00V?oonfX7o`00077ooo]Z0ol007l:oookJPGo0000N?oonfX7
o`0009oooo]Z002HoookJPOo0000LOoonfX3o`00O`[ooo]Z1Ol0001hoookJPKo0000X?oonfX009So
oo]Z1ol0001aoookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002PoookJP00V?oonfX7o`00077ooo]Z
0ol007l:oookJPGo0000N?oonfX6o`000:3ooo]Z002HoookJPOo0000LOoonfX3o`00O`[ooo]Z1_l0
001goookJPKo0000X?oonfX009Sooo]Z1ol0001aoookJP?o001o2_oonfX5o`0007Sooo]Z1_l0002P
oookJP00VOoonfX6o`00077ooo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPKo
0000LOoonfX3o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001boookJP?o001o
2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0006oooo]Z1_l007l:oookJPGo0000NOoo
nfX5o`000:3ooo]Z002IoookJPGo0000KooonfX6o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX0
09Wooo]Z1Ol0001aoookJPCo001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007;o
oo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000OooonfX5o`0007Wooo]Z
1Ol0002PoookJP00VOoonfX5o`0007oooo]Z1Ol0001joookJPCo0000X?oonfX009[ooo]Z1?l0001o
oookJPGo0000N_oonfX4o`000:3ooo]Z003ooookJQkooo]Z1Ol0001joookJPCo0000X?oonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooo
nfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6
o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo0000oooonfXOoook
JP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5
o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o
2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o
2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003o
oookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX6o`00
0?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z
0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/oookJP00oooonfX=
oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooook
JRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooonfX>oookJPOo001o
oooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[ooookJT;ooo]Z003ooook
J_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30834 L
.02605 .30808 L
.02729 .30839 L
.02846 .30909 L
.02954 .30971 L
.03053 .30996 L
.03163 .30974 L
.03279 .30909 L
.03395 .30839 L
.0352 .3081 L
.03638 .30842 L
.03746 .30908 L
.03873 .3098 L
.03944 .30999 L
.04011 .30997 L
.04132 .30948 L
.04262 .30867 L
.04327 .30835 L
.04396 .30818 L
.04519 .30839 L
.04588 .30875 L
.04652 .30917 L
.04726 .30965 L
.04797 .30999 L
.04925 .3101 L
.05041 .30962 L
.05167 .30885 L
.05231 .30854 L
.05302 .30836 L
.05423 .30858 L
.05536 .30925 L
.05642 .30996 L
.05753 .3104 L
.05877 .31027 L
.0599 .30968 L
.06112 .30898 L
.06181 .30875 L
.06244 .30871 L
.0631 .30887 L
.0638 .30923 L
.06509 .31013 L
.06623 .31076 L
.06748 .31087 L
.06819 .31063 L
.06883 .31028 L
.06952 .30987 L
.07027 .30948 L
.07096 .30928 L
.0716 .30929 L
Mistroke
.07287 .30984 L
.07414 .31078 L
.07533 .31148 L
.07641 .31163 L
.07757 .31124 L
.07883 .31051 L
.07947 .31023 L
.08017 .31009 L
.08141 .31039 L
.08257 .3112 L
.08323 .31174 L
.08394 .31224 L
.08471 .3126 L
.08543 .31268 L
.08671 .31227 L
.08745 .31186 L
.08813 .3115 L
.08941 .31122 L
.09057 .31163 L
.09185 .31264 L
.09255 .31323 L
.0932 .31369 L
.09391 .314 L
.09456 .31407 L
.09526 .31392 L
.09602 .31358 L
.09668 .31322 L
.09738 .31289 L
.09864 .31275 L
.09934 .31301 L
.1001 .31354 L
.10147 .31479 L
.1023 .31544 L
.1031 .3158 L
.10381 .31586 L
.10458 .31566 L
.10579 .31506 L
.10691 .31465 L
.10813 .31483 L
.10942 .31579 L
.11047 .31684 L
.11159 .31777 L
.11282 .31812 L
.11396 .31782 L
.11461 .3175 L
.1153 .31719 L
.11606 .317 L
.11676 .31706 L
.11801 .31783 L
.11872 .31856 L
Mistroke
.11939 .3193 L
.12064 .32045 L
.12177 .32089 L
.12308 .32061 L
.12433 .32005 L
.12501 .31988 L
.12565 .31992 L
.12685 .32062 L
.12814 .32205 L
.12881 .32284 L
.12954 .32357 L
.13076 .32421 L
.13206 .32402 L
.13326 .32351 L
.13437 .32332 L
.13505 .32352 L
.13579 .32406 L
.13649 .32482 L
.13714 .32565 L
.13844 .32725 L
.13966 .3281 L
.14097 .32807 L
.14166 .3278 L
.14241 .3275 L
.14315 .32736 L
.14393 .32753 L
.1446 .32798 L
.14533 .32876 L
.14656 .33049 L
.14787 .33211 L
.14855 .33261 L
.1493 .33282 L
.15062 .33251 L
.15187 .33209 L
.15256 .33211 L
.1532 .3324 L
.15444 .33372 L
.15561 .33553 L
.15674 .33713 L
.15793 .33807 L
.15906 .33811 L
.16008 .33774 L
.16129 .33748 L
.16259 .33817 L
.16383 .33986 L
.16495 .34181 L
.16617 .34355 L
.16747 .34431 L
.1687 .34408 L
.16982 .34369 L
Mistroke
.17114 .34396 L
.17188 .3447 L
.17256 .34573 L
.1739 .34825 L
.17515 .3503 L
.17635 .35123 L
.17764 .3511 L
.17837 .35081 L
.17907 .35063 L
.18037 .35113 L
.18104 .35194 L
.18175 .35317 L
.18302 .35586 L
.1838 .35737 L
.18454 .35843 L
.1852 .35899 L
.18591 .35916 L
.18715 .35877 L
.18828 .35844 L
.18959 .35917 L
.19082 .3613 L
.19197 .36401 L
.19305 .36631 L
.19417 .36773 L
.19541 .3679 L
.19666 .36731 L
.19736 .36713 L
.198 .36731 L
.19917 .36876 L
.2004 .37166 L
.20166 .37497 L
.20236 .37645 L
.203 .37735 L
.20376 .3778 L
.20447 .37771 L
.20513 .37735 L
.20584 .37692 L
.20715 .37697 L
.20837 .37882 L
.20908 .38064 L
.20972 .38258 L
.21047 .38486 L
.21116 .3867 L
.21183 .38797 L
.21254 .38868 L
.21333 .3887 L
.21405 .38823 L
.21473 .38767 L
.21547 .38728 L
.21616 .38743 L
Mistroke
.2168 .38817 L
.2269 .40245 L
.23601 .41526 L
.23717 .42135 L
.23841 .42741 L
.23905 .42935 L
.23976 .43011 L
.24101 .4281 L
.24219 .42447 L
.24346 .42275 L
.24466 .42608 L
.24575 .43325 L
.24644 .43863 L
.24717 .44393 L
.24848 .44899 L
.2492 .44826 L
.24985 .44552 L
.25063 .44061 L
.25135 .43569 L
.25263 .4313 L
.2538 .4369 L
.25509 .45414 L
.2558 .46589 L
.25645 .4754 L
.25764 .48246 L
.25891 .46442 L
.26009 .41893 L
.26121 .3547 L
.2625 .26996 L
.26318 .22821 L
.2639 .19063 L
.26522 .14614 L
.26643 .1355 L
.26756 .14533 L
.26861 .16213 L
.26977 .17868 L
.271 .18657 L
.27166 .18611 L
.27237 .1829 L
.27365 .17429 L
.2749 .16916 L
.27606 .17095 L
.27728 .17872 L
.27843 .18754 L
.27968 .1941 L
.28039 .19531 L
.28103 .19488 L
.28233 .19137 L
.28301 .18936 L
.28374 .18807 L
Mistroke
.28443 .18815 L
.28507 .18947 L
.2863 .19486 L
.28746 .2011 L
.28868 .20596 L
.28972 .20735 L
.29086 .20627 L
.29209 .20412 L
.29341 .20366 L
.29465 .20642 L
.29578 .21096 L
.29685 .21537 L
.29798 .21854 L
.29922 .21935 L
.30037 .2183 L
.30144 .21722 L
.30244 .2173 L
.30353 .21923 L
.30471 .22302 L
.30595 .2273 L
.30711 .23002 L
.30776 .23067 L
.30845 .23072 L
.30967 .22987 L
.31084 .22926 L
.31208 .23021 L
.31313 .23256 L
.31429 .23606 L
.31499 .2381 L
.31565 .23967 L
.3169 .2412 L
.31759 .24126 L
.31824 .24097 L
.31899 .2405 L
.3197 .24022 L
.32099 .24089 L
.32215 .24306 L
.3234 .24635 L
.32405 .24803 L
.32476 .24949 L
.32546 .25044 L
.32609 .25085 L
.32733 .25064 L
.328 .2503 L
.32873 .25006 L
.33005 .25067 L
.33127 .25273 L
.33257 .25578 L
.33368 .25809 L
.3349 .25944 L
Mistroke
.33563 .25959 L
.33633 .25941 L
.33763 .25891 L
.33835 .25894 L
.33903 .25935 L
.33977 .26027 L
.34056 .2617 L
.34199 .26472 L
.34269 .26598 L
.34334 .26681 L
.34455 .26741 L
.34586 .26705 L
.34712 .26674 L
.34831 .26735 L
.34939 .26883 L
.35055 .27103 L
.35182 .27319 L
.35246 .2739 L
.35317 .27432 L
.35441 .27423 L
.35558 .2738 L
.35669 .27381 L
.35786 .27475 L
.35886 .27623 L
.35995 .27813 L
.36113 .27979 L
.3624 .28054 L
.36359 .28035 L
.36467 .27994 L
.36595 .28 L
.3666 .28042 L
.36732 .28121 L
.3686 .28314 L
.36976 .28483 L
.37047 .28553 L
.37114 .28589 L
.37185 .28596 L
.37262 .28575 L
.37329 .28548 L
.374 .28525 L
.37529 .28544 L
.37659 .28665 L
.37733 .28766 L
.378 .28863 L
.37924 .29009 L
.38055 .29067 L
.38173 .29041 L
.38283 .28997 L
.38403 .2899 L
.38532 .29074 L
Mistroke
.39551 .2958 L
.39616 .29658 L
.39685 .29731 L
.3976 .29788 L
.39828 .29814 L
.39953 .29797 L
.40023 .29766 L
.40088 .29736 L
.40219 .29716 L
.40293 .29743 L
.40359 .29791 L
.40515 .29955 L
.40583 .30023 L
.40659 .30078 L
.40784 .30103 L
.40853 .30084 L
.40917 .30055 L
.40986 .30021 L
.41052 .29998 L
.41128 .29992 L
.41197 .30013 L
.41323 .30108 L
.4144 .30225 L
.41568 .30321 L
.4164 .30341 L
.41704 .30336 L
.41821 .30288 L
.41944 .3023 L
.42008 .30217 L
.42079 .30225 L
.42203 .30297 L
.42321 .30405 L
.42446 .30502 L
.42553 .30532 L
.42671 .30502 L
.42802 .30434 L
.42924 .30397 L
.43056 .30431 L
.4313 .30483 L
.43198 .30541 L
.4332 .30638 L
.43389 .30671 L
.43453 .30682 L
.43571 .30652 L
.43696 .30584 L
.43817 .30538 L
.43948 .30558 L
.44071 .3064 L
.44185 .3073 L
.44288 .30784 L
Mistroke
.444 .3079 L
.44518 .30741 L
.44628 .30678 L
.44758 .30639 L
.44832 .30649 L
.44899 .3068 L
.45024 .30769 L
.45088 .30816 L
.45157 .30855 L
.45275 .30876 L
.45386 .30841 L
.45518 .30764 L
.45638 .30716 L
.45769 .30731 L
.4589 .30803 L
.45965 .30857 L
.46035 .309 L
.46166 .30933 L
.46295 .30893 L
.46368 .3085 L
.46435 .30809 L
.46501 .30778 L
.46574 .30761 L
.4665 .30769 L
.46722 .30798 L
.46847 .3088 L
.46915 .30924 L
.4698 .30954 L
.47106 .30963 L
.47219 .30915 L
.47346 .30838 L
.4741 .30807 L
.4748 .3079 L
.47556 .30796 L
.47627 .30823 L
.47692 .30862 L
.47762 .30908 L
.47889 .30975 L
.47961 .30986 L
.48028 .30977 L
.4815 .30918 L
.48279 .30839 L
.48395 .30804 L
.48503 .30822 L
.48622 .30887 L
.4875 .30965 L
.48867 .30994 L
.48975 .30969 L
.49095 .309 L
.49222 .30828 L
Mistroke
.49286 .3081 L
.49355 .30811 L
.49482 .30861 L
.49594 .30932 L
.49718 .30988 L
.49833 .30987 L
.49942 .30938 L
.50066 .30861 L
.50179 .30813 L
.50284 .30815 L
.50384 .30858 L
.50498 .30931 L
.50604 .30983 L
.50717 .30993 L
.5084 .30945 L
.50954 .30872 L
.51061 .30821 L
.51179 .30814 L
.51308 .30871 L
.51372 .30912 L
.51441 .30955 L
.51567 .30999 L
.51633 .30996 L
.51702 .30973 L
.51826 .309 L
.51939 .30838 L
.52062 .30818 L
.52194 .30868 L
.52268 .30915 L
.52336 .3096 L
.52467 .31012 L
.52592 .30996 L
.52708 .30933 L
.52813 .3087 L
.52934 .30836 L
.53048 .30861 L
.53154 .30925 L
.53252 .3099 L
.53359 .31037 L
.53472 .31034 L
.53587 .30982 L
.53709 .30909 L
.53825 .30871 L
.5393 .30887 L
.54054 .3096 L
.54119 .31007 L
.54188 .31052 L
.54315 .31091 L
.54433 .31065 L
.54547 .31001 L
Mistroke
.54671 .30939 L
.54801 .30934 L
.54922 .30995 L
.55034 .31078 L
.55139 .31143 L
.5526 .31163 L
.55371 .31126 L
.55493 .31056 L
.55623 .3101 L
.55734 .31027 L
.55856 .31104 L
.55987 .31207 L
.5606 .31249 L
.56127 .31267 L
.56257 .31243 L
.56381 .31176 L
.56497 .31128 L
.56601 .31129 L
.56722 .31195 L
.56835 .31291 L
.56941 .3137 L
.57038 .31405 L
.57144 .31392 L
.57256 .31339 L
.5737 .31285 L
.57492 .31277 L
.57606 .31336 L
.57711 .31428 L
.57834 .31534 L
.57903 .31572 L
.57967 .31586 L
.58085 .31562 L
.58209 .315 L
.5833 .31463 L
.58461 .31498 L
.58585 .31603 L
.587 .31717 L
.58814 .31796 L
.58918 .31811 L
.59037 .31772 L
.5915 .31718 L
.59273 .31702 L
.59403 .31768 L
.59514 .3188 L
.59636 .32008 L
.59767 .32085 L
.59841 .32087 L
.59908 .32069 L
.60031 .32013 L
.60162 .31988 L
Mistroke
.60273 .32036 L
.60395 .32159 L
.60508 .32293 L
.60611 .32386 L
.60733 .32423 L
.60864 .32386 L
.60979 .32339 L
.61101 .32342 L
.61207 .32414 L
.61321 .32549 L
.61419 .32676 L
.61526 .3278 L
.61651 .32819 L
.6177 .32786 L
.61885 .32743 L
.61991 .32744 L
.62116 .32834 L
.62235 .32991 L
.62343 .33141 L
.62458 .33252 L
.62583 .33281 L
.62698 .33244 L
.62769 .33218 L
.62835 .33207 L
.6296 .33255 L
.6307 .33382 L
.63187 .33563 L
.63288 .33706 L
.63396 .338 L
.63512 .33814 L
.6362 .33777 L
.63749 .33748 L
.63866 .33805 L
.63994 .33974 L
.6413 .34208 L
.64246 .34365 L
.64374 .34432 L
.64504 .34402 L
.64575 .34375 L
.6464 .34365 L
.64712 .34383 L
.6479 .34449 L
.64856 .3454 L
.64926 .34665 L
.64994 .34795 L
.65066 .34928 L
.65198 .35094 L
.65326 .35127 L
.65444 .35086 L
.65557 .35063 L
Mistroke
.6568 .35137 L
.65809 .35348 L
.6593 .35604 L
.66055 .35823 L
.66119 .35886 L
.66189 .35915 L
.66313 .35886 L
.66429 .35845 L
.66495 .35852 L
.66565 .35903 L
.6669 .36107 L
.66827 .36426 L
.66902 .3659 L
.66972 .36708 L
.671 .36797 L
.67217 .36765 L
.67326 .36717 L
.67444 .3675 L
.67575 .36955 L
.67641 .37116 L
.67713 .37312 L
.67841 .37619 L
.67961 .37768 L
.69816 .40096 L
.70854 .41286 L
.71841 .4244 L
.72269 .43914 L
.72393 .44704 L
.72509 .44888 L
.72614 .44502 L
.72726 .4375 L
.72853 .43149 L
.72917 .43186 L
.72988 .43587 L
.73112 .45155 L
.73228 .47036 L
.73345 .48223 L
.73452 .47647 L
.73576 .44219 L
.73693 .38319 L
.73914 .2418 L
.74038 .1777 L
.74152 .14394 L
.7428 .13602 L
.74344 .14127 L
.74414 .15113 L
.7454 .17142 L
.74659 .18419 L
.74723 .18663 L
.74793 .18585 L
Mistroke
.74916 .17894 L
.74985 .17424 L
.75058 .17047 L
.7519 .16972 L
.75312 .17606 L
.75426 .18486 L
.7555 .19272 L
.7562 .1949 L
.75684 .19529 L
.75798 .19306 L
.75919 .18938 L
.76033 .18794 L
.76137 .18981 L
.76259 .19535 L
.76391 .20236 L
.76515 .20661 L
.76629 .20722 L
.76737 .20569 L
.76838 .20399 L
.76948 .20356 L
.77066 .20584 L
.7719 .21063 L
.77307 .21548 L
.77412 .21845 L
.77527 .21939 L
.8161 .2605 L
.82588 .26937 L
.8364 .27854 L
.84633 .28525 L
.85542 .29008 L
.87385 .29792 L
.88311 .30093 L
.88548 .30049 L
.88677 .29996 L
.88797 .30005 L
.88928 .30094 L
.88997 .30163 L
.89071 .30237 L
.89203 .30328 L
.89323 .30336 L
.89453 .30281 L
.89522 .30246 L
.89595 .30221 L
.89659 .30218 L
.89729 .30237 L
.89853 .30324 L
.89977 .30439 L
.90047 .30491 L
.90111 .30522 L
.90229 .30525 L
Mistroke
.90353 .3047 L
.90465 .30415 L
.90584 .30399 L
.90697 .30445 L
.908 .30526 L
.9092 .30625 L
.91051 .3068 L
.91174 .30659 L
.91288 .30599 L
.91409 .30544 L
.91538 .30547 L
.91661 .30617 L
.91773 .30706 L
.91903 .30783 L
.91977 .30795 L
.92046 .30783 L
.92172 .3072 L
.92237 .30683 L
.92306 .30652 L
.92379 .30639 L
.92446 .30648 L
.92518 .3068 L
.92597 .30734 L
.92666 .30786 L
.9273 .3083 L
.92804 .30866 L
.92872 .30877 L
.92999 .30844 L
.93071 .30803 L
.93137 .30764 L
.93257 .30716 L
.93385 .3073 L
.93499 .30795 L
.93623 .30883 L
.93753 .30932 L
.93874 .30912 L
.93988 .30849 L
.94091 .3079 L
.9421 .3076 L
.94323 .30789 L
.94444 .30865 L
.94558 .30937 L
.94677 .30968 L
.94808 .30932 L
.9494 .30853 L
.95012 .30814 L
.95081 .30792 L
.95213 .30808 L
.95333 .30876 L
.95447 .30948 L
Mistroke
.95553 .30985 L
.95676 .30967 L
.95788 .30906 L
.95886 .30846 L
.9599 .30806 L
.96104 .30815 L
.96209 .30866 L
.96322 .30939 L
.96444 .3099 L
.96559 .30982 L
.96663 .30932 L
.96786 .30855 L
.96856 .30823 L
.9692 .30808 L
.97037 .30829 L
.97162 .30899 L
.97276 .30966 L
.97398 .30995 L
.97513 .30964 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00W_oonfX4o`0007_ooo]Z1Ol0001ooookJPCo0000VooonfX009kooo]Z1?l0001koookJPGo
0000OooonfX4o`0009_ooo]Z002NoookJPCo0000NooonfX5o`0007oooo]Z1?l0002KoookJP00W_oo
nfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001joookJPGo0000O_oonfX5
o`0009_ooo]Z002NoookJPGo0000N_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0007[o
oo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001]oookJP?o001o2_oonfX5o`0007kooo]Z
1Ol0002KoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z002N
oookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1_l0001Loook
JP[o001o1_oonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1_l0001LoookJP[o
001o1_oonfX3o`00O`[ooo]Z1_l0001moookJPGo0000VooonfX009kooo]Z1_l0001/oookJP?o001o
2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000O_oo
nfX5o`0009_ooo]Z002NoookJPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oonfX0
09kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007gooo]Z1ol0002JoookJP00W_oonfX6o`0006Wo
oo]Z1_l007l:oookJPGo0000OOoonfX7o`0009[ooo]Z002NoookJPKo0000JOoonfX6o`00O`[ooo]Z
1Ol0001moookJPOo0000V_oonfX009kooo]Z2Ol0001XoookJPCo001o2_oonfX5o`0007gooo]Z1ol0
002JoookJP00WOoonfX;o`0006Sooo]Z0ol007l:oookJPGo0000OOoonfX;o`0009Kooo]Z002Moook
JP_o0000MOoonfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX;o`0007Gooo]Z1Ol0001moookJP_o
0000U_oonfX009gooo]Z2ol0001eoookJPGo0000OOoonfX;o`0009Kooo]Z002MoookJP_o0000MOoo
nfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX;o`0007Gooo]Z1Ol0001moookJP_o0000U_oonfX0
09gooo]Z2ol0001eoookJPGo0000OOoonfX<o`0009Gooo]Z002MoookJPco0000M?oonfX5o`0007go
oo]Z3?l0002EoookJP00WOoonfX<o`0007Cooo]Z1Ol0001moookJPco0000UOoonfX009gooo]Z3ol0
001aoookJPGo0000OOoonfX?o`0009;ooo]Z002MoookJQ3o0000L?oonfX5o`0007gooo]Z4?l0002A
oookJP00WOoonfX@o`00073ooo]Z1Ol0001moookJQ3o0000TOoonfX009gooo]Z4?l0001`oookJPGo
0000OOoonfX@o`00097ooo]Z002MoookJPCo00001?oonfX8o`00073ooo]Z1Ol0001moookJPCo0000
1?oonfX8o`00097ooo]Z002MoookJPCo00001?oonfX8o`00073ooo]Z1Ol0001moookJPCo00001?oo
nfX8o`00097ooo]Z002MoookJPCo00001OoonfX7o`00073ooo]Z1Ol0001moookJPCo00001?oonfX8
o`00097ooo]Z002MoookJPCo00001OoonfX8o`0006oooo]Z1Ol0001moookJPCo00001OoonfX8o`00
093ooo]Z002MoookJPCo00002?oonfX5o`0006oooo]Z1Ol0001moookJPCo00002?oonfX5o`00093o
oo]Z002MoookJPCo00002?oonfX8o`0006cooo]Z1Ol0001moookJPCo00002?oonfX8o`0008gooo]Z
002MoookJPCo00002OoonfX8o`0006_ooo]Z1Ol0001moookJPCo00002OoonfX8o`0008cooo]Z002M
oookJPCo00002OoonfX8o`0006_ooo]Z1Ol0001moookJPCo00002OoonfX8o`0008cooo]Z002Moook
JPCo00002OoonfX8o`0006_ooo]Z1Ol0001moookJPCo00002OoonfX8o`0008cooo]Z002MoookJPCo
00002OoonfX8o`0006_ooo]Z1Ol0001moookJPCo00002_oonfX7o`0008cooo]Z002MoookJPCo0000
2_oonfX7o`0006_ooo]Z1Ol0001moookJPCo00002_oonfX7o`0008cooo]Z002MoookJPCo00003Ooo
nfX5o`0006[ooo]Z1Ol0001moookJPCo00003OoonfX5o`0008_ooo]Z002MoookJPCo00003OoonfX8
o`0006Oooo]Z1Ol0001moookJPCo00003OoonfX5o`0008_ooo]Z002MoookJPCo00003OoonfX9o`00
06Kooo]Z1Ol0001moookJPCo00003OoonfX6o`0008[ooo]Z002MoookJPCo00003_oonfX8o`0006Ko
oo]Z1Ol0001moookJPCo00003_oonfX5o`0008[ooo]Z002MoookJPCo00003_oonfX8o`0006Kooo]Z
1Ol0001moookJPCo00003_oonfX6o`0008Wooo]Z002MoookJPCo00003ooonfX7o`0006Kooo]Z1Ol0
001moookJPCo00003ooonfX6o`0008Sooo]Z002MoookJPCo00004_oonfX5o`0004Oooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001moookJPCo00003ooonfX7o`0008Oooo]Z002Moook
JPCo00004_oonfX5o`0004Kooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001moook
JPCo00004?oonfX7o`0008Kooo]Z002MoookJPCo00004_oonfX8o`0004?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9
oookJPGo0000OOoonfX4o`00017ooo]Z1ol00025oookJP00WOoonfX4o`0001?ooo]Z1ol0000foook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001moook
JPCo00004_oonfX7o`0008Cooo]Z002MoookJPCo00004ooonfX8o`0003Gooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000O?oonfX4o`0001?ooo]Z1ol00023oookJP00
WOoonfX4o`0001?ooo]Z2?l00011oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPGo0000
OOoonfX4o`0001Cooo]Z1ol00022oookJP00WOoonfX4o`0001Cooo]Z1ol00011oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0007gooo]Z1?l0000EoookJPOo0000POoo
nfX009gooo]Z1?l0000GoookJPGo0000@?oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2OoonfX5
o`0007gooo]Z1?l0000FoookJPOo0000P?oonfX009gooo]Z1?l0000GoookJPSo0000?OoonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0007gooo]Z1?l0000GoookJPOo0000OooonfX009go
oo]Z1?l0000GoookJPWo0000??oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`0007go
oo]Z1?l0000HoookJPOo0000O_oonfX009gooo]Z1?l0000HoookJPSo0000?OoonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Wooo]Z1ol0001moookJP00
WOoonfX4o`0001Wooo]Z1ol0000moookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0001moookJPCo0000
6_oonfX7o`0007cooo]Z002MoookJPCo00007?oonfX5o`0003gooo]Z1Ol007l:oookJPOo001o2?oo
nfX5o`0007gooo]Z1?l0000KoookJPOo0000NooonfX009cooo]Z1Ol0000LoookJPSo0000F?oonfX5
o`0007gooo]Z1?l0000LoookJPOo0000N_oonfX009cooo]Z1Ol0000LoookJPSo0000F?oonfX5o`00
07gooo]Z1?l0000MoookJPOo0000NOoonfX009cooo]Z1Ol0000MoookJPSo0000EooonfX5o`0007go
oo]Z1?l0000NoookJPOo0000N?oonfX009cooo]Z1?l0000NoookJPSo0000EooonfX5o`0007gooo]Z
1?l0000OoookJPOo0000MooonfX009cooo]Z1?l0000OoookJPSo0000E_oonfX5o`0007gooo]Z1?l0
000PoookJPOo0000M_oonfX009cooo]Z1?l0000RoookJPSo0000DooonfX5o`0007gooo]Z1?l0000Q
oookJPOo0000MOoonfX009cooo]Z1?l0000RoookJPWo0000D_oonfX5o`0007gooo]Z1?l0000Roook
JPSo0000LooonfX009cooo]Z1?l0000SoookJPSo0000D_oonfX5o`0007gooo]Z1?l0000SoookJPSo
0000L_oonfX009cooo]Z1?l0000ToookJPOo0000D_oonfX5o`0007gooo]Z1?l0000ToookJPSo0000
LOoonfX009cooo]Z1?l0000VoookJPWo0000C_oonfX5o`0007gooo]Z1?l0000UoookJPSo0000L?oo
nfX009cooo]Z1?l0000WoookJPSo0000C_oonfX5o`0007gooo]Z1?l0000WoookJPOo0000KooonfX0
09cooo]Z1?l0000WoookJPWo0000COoonfX5o`0007gooo]Z1?l0000XoookJPOo0000K_oonfX002;o
oo]Z0ol007meoookJP;o001o1?l00003oookJP?o001o0ooonfX5o`00Oa[ooo]Z2?l0001=oookJPGo
0000M?oonfX5o`00O`Cooo]Z1?l00002oookJPGo001o8_oonfX7o`0004gooo]Z0ol007lMoookJP00
8_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol007l2oookJPOo001o7?oonfX9o`0004Wooo]Z
1Ol0001coookJPOo001o0ooonfX4o`000003oookJ_l007oo001o00Go001o8_oonfX7o`0004cooo]Z
0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00Oagooo]Z2Ol00018oookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z1?l00004o`00O`04oookJ_l007oo001oo`00Ob?ooo]Z1ol0001;oook
JP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o
0000o`000002o`000003o`00Oooonf[ooo]Z00Cooo]Z0ol007l3oookJP?o001o7?oonfX9o`0004So
oo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l00003o`00O`?ooo]Z0ol007lSoookJPOo
0000B_oonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o
00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o001o7OoonfX;o`0004Gooo]Z
1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000?o00001_oonfX3o`00ObCooo]Z
2?l00018oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l0
00000ol007oooo]ZoookJP0:oookJP?o001o8OoonfX8o`0004Cooo]Z1Ol0001boookJP?o001o0ooo
nfX3o`00O`03oookJ_l0003o000000?o00001_oonfX3o`00ObGooo]Z2Ol00016oookJP?o001o7Ooo
nfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP05
oookJP;o001o0_oonfX4o`00Ob7ooo]Z2Ol00013oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l0
0ooonf[o0000o`000003o`000003oookJ_l007oo001o00;ooo]Z1?l007lVoookJP[o0000A?oonfX3
o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooook
J_oonfX01OoonfX7o`00Ob?ooo]Z2ol00010oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooo
nf[o0000o`000002o`0000;ooo]Z1ol007lXoookJP_o0000@_oonfX3o`00Oagooo]Z000RoookJP?o
001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX6o`00ObCo
oo]Z3Ol0000noookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;o
oo]Z1_l007l[oookJP_o0000@?oonfX3o`00Oagooo]Z000OoookJPKo001oLooonfX3o`00O`03oook
J_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX2o`00Obcooo]Z2Ol0000noookJPGo0000
L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l007laoookJP[o0000
??oonfX6o`00Oagooo]Z000OoookJPKo001oM?oonfX3o`00O`Co00002?oonfX2o`00Obcooo]Z3_l0
000ioookJPGo0000LooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l00002oookJP;o001o
<ooonfX:o`0003[ooo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol0
07lXoookJPko0000=ooonfX5o`0007?ooo]Z1ol007l2oookJPCo00000ooonfX7o`00Oboooo]Z2ol0
000ioookJPCo001o7OoonfX002;ooo]Z0ol007meoookJP;o001o1?l00009oookJPOo001o:ooonfX<
o`0003Kooo]Z1Ol0001doookJPGo001o0ooonfX4o`0000?ooo]Z1ol007laoookJP_o0000>?oonfX3
o`00Oagooo]Z002LoookJPCo0000??oonfX=o`0003Cooo]Z1Ol0001loookJPCo0000??oonfX=o`00
05Gooo]Z002LoookJPCo0000@OoonfX<o`00033ooo]Z1Ol0001loookJPCo0000?_oonfX=o`0005?o
oo]Z002LoookJPCo0000@ooonfX>o`0002cooo]Z1Ol0001loookJPCo0000@OoonfX@o`0004gooo]Z
002LoookJPCo0000A?oonfXBo`0002Oooo]Z1Ol0001loookJPCo0000@ooonfXCo`0004Sooo]Z002L
oookJPCo0000AOoonfXFo`0002;ooo]Z1Ol0001loookJPCo0000A_oonfXEo`0004?ooo]Z002Loook
JPCo0000B_oonfXFo`0001gooo]Z1Ol0001loookJPCo0000B?oonfXIo`0003gooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`00
00oooo]Z000MoookJP03o`000?oonf[o0000037o0000BooonfX4o`0007Oooo]Z1?l00002oookJSKo
0000BooonfX4o`0007Oooo]Z1?l000000ooonf[o0000o`000002o`0001kooo]Z000koookJQOo0000
B_oonfX4o`0007gooo]Z1Ol0000KoookJQSo0000BOoonfX4o`0009kooo]Z0011oookJQKo0000AOoo
nfX4o`0007gooo]Z1Ol0000QoookJQKo0000AOoonfX4o`0009kooo]Z0015oookJQ;o0000AOoonfX4
o`0007gooo]Z1Ol0000VoookJQ7o0000AOoonfX4o`0009kooo]Z001;oookJQ7o0000@?oonfX4o`00
07gooo]Z1Ol0000[oookJQ7o0000@?oonfX4o`0009kooo]Z001?oookJPgo0000@?oonfX4o`0007go
oo]Z1Ol0000_oookJPgo0000@?oonfX4o`0009kooo]Z001CoookJPgo0000??oonfX4o`0007gooo]Z
1Ol0000coookJPgo0000??oonfX4o`0009kooo]Z001DoookJPgo0000>ooonfX4o`0007gooo]Z1Ol0
000doookJPgo0000>ooonfX4o`0009kooo]Z001HoookJPWo0000>ooonfX4o`0007gooo]Z1Ol0000h
oookJP[o0000>_oonfX4o`0009kooo]Z001IoookJPgo0000=_oonfX4o`0007gooo]Z1Ol0000ioook
JPgo0000=_oonfX4o`0009kooo]Z001MoookJPWo0000=_oonfX4o`0007gooo]Z1Ol0000moookJPWo
0000=_oonfX4o`0009kooo]Z001MoookJPco0000<ooonfX4o`0007gooo]Z1Ol0000noookJPco0000
<_oonfX4o`0009kooo]Z001NoookJPco0000<_oonfX4o`0007gooo]Z1Ol0000ooookJP_o0000<_oo
nfX4o`0009kooo]Z001RoookJPWo0000<OoonfX4o`0007gooo]Z1Ol00012oookJPWo0000<OoonfX4
o`0009kooo]Z001SoookJPSo0000<OoonfX4o`0007gooo]Z1Ol00013oookJPWo0000<?oonfX4o`00
09kooo]Z001ToookJP_o0000;OoonfX4o`0007gooo]Z1Ol00014oookJP_o0000;OoonfX4o`0009ko
oo]Z001WoookJPWo0000;?oonfX4o`0007gooo]Z1Ol00017oookJPWo0000;?oonfX4o`0009kooo]Z
001WoookJPWo0000;?oonfX4o`0007gooo]Z1Ol00018oookJPSo0000;?oonfX4o`0009kooo]Z001X
oookJPWo0000:ooonfX4o`0007gooo]Z1Ol00018oookJPWo0000:_oonfX5o`0009kooo]Z001/oook
JPSo0000:?oonfX4o`0007gooo]Z1Ol0001<oookJPSo00009ooonfX5o`0009kooo]Z001/oookJPWo
00009ooonfX4o`0007gooo]Z1Ol0001<oookJPWo00009_oonfX5o`0009kooo]Z001]oookJPSo0000
9ooonfX4o`0007gooo]Z1Ol0001=oookJPSo00009_oonfX4o`0009oooo]Z001^oookJPSo00009_oo
nfX4o`0007gooo]Z1Ol0001=oookJPSo00009_oonfX4o`0009oooo]Z001aoookJPSo00008ooonfX4
o`0007gooo]Z1Ol0001AoookJPSo00008_oonfX4o`0009oooo]Z001aoookJPSo00008ooonfX4o`00
07gooo]Z1Ol0001AoookJPSo00008_oonfX4o`0009oooo]Z001boookJPOo00008ooonfX4o`0007go
oo]Z1Ol0001AoookJPSo00008_oonfX4o`0009oooo]Z001boookJPSo00008_oonfX4o`0007gooo]Z
1Ol0001BoookJPSo00008OoonfX4o`0009oooo]Z001eoookJPKo00008OoonfX4o`0007gooo]Z1Ol0
001EoookJPKo00008?oonfX4o`0009oooo]Z001eoookJPWo00007_oonfX4o`0007gooo]Z1Ol0001E
oookJPWo00007OoonfX4o`0009oooo]Z001foookJPSo00007_oonfX4o`0007gooo]Z1Ol0001Foook
JPSo00007OoonfX4o`0009oooo]Z001goookJPSo00007OoonfX4o`0007gooo]Z1Ol0001GoookJPSo
00007?oonfX4o`0009oooo]Z001goookJPSo00007OoonfX4o`0007gooo]Z1Ol0001HoookJPOo0000
7?oonfX4o`0009oooo]Z001joookJPGo00007OoonfX4o`0007gooo]Z1Ol0001JoookJPKo00006ooo
nfX4o`0009oooo]Z001koookJPOo00006_oonfX4o`0007gooo]Z1Ol0001KoookJPGo00006ooonfX4
o`0009oooo]Z001koookJPSo00006OoonfX4o`0007gooo]Z1Ol0001KoookJPGo00006ooonfX4o`00
09oooo]Z001koookJPSo00006OoonfX4o`0005oooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[o
oo]Z1Ol0001LoookJPGo00006_oonfX4o`0009oooo]Z001loookJPSo00006?oonfX4o`0005kooo]Z
1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001LoookJPKo00006OoonfX4o`0009oooo]Z
001ooookJPGo00006?oonfX4o`0005kooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000G?oonfX7o`0001So
oo]Z1?l0002OoookJP00OooonfX8o`0001Gooo]Z1?l0001MoookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o2?oonfX5o`0005gooo]Z1_l0000HoookJPCo0000WooonfX0083ooo]Z2?l0
000CoookJPGo0000GOoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0005gooo]Z1_l0
000GoookJPCo0000WooonfX0083ooo]Z2?l0000CoookJPGo0000GOoonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o2?oonfX5o`0005oooo]Z1_l0000FoookJPCo0000WooonfX0083ooo]Z2Ol0000Boook
JPGo0000GOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001Ooook
JPOo00005OoonfX4o`0009oooo]Z0021oookJPWo00004OoonfX4o`0005kooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`Wooo]Z1Ol0001PoookJPOo00005?oonfX4o`0009oooo]Z0024oookJPKo0000
4OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001QoookJPKo0000
5?oonfX4o`0009oooo]Z0025oookJPKo00004?oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`kooo]Z1Ol0001RoookJPKo00004ooonfX4o`0009oooo]Z0026oookJPGo00004?oonfX4
o`0005oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0006?ooo]Z1_l0
000BoookJPCo0000WooonfX008Kooo]Z1_l0000?oookJPCo0000GooonfX7o`00O`Wooo]Z1ol007l8
oookJPGo0000HooonfX7o`00017ooo]Z1?l0002OoookJP00QooonfX6o`0000kooo]Z1?l0001Poook
JPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001ToookJPOo00004?oonfX4o`0009oooo]Z0027oookJPKo
00003_oonfX4o`0007kooo]Z1Ol0001UoookJPOo00003ooonfX4o`0009oooo]Z0028oookJPKo0000
3OoonfX4o`0007kooo]Z1Ol0001VoookJPOo00003_oonfX4o`0009oooo]Z0029oookJPKo00003?oo
nfX4o`0007kooo]Z1Ol0001WoookJPOo00003OoonfX4o`0009oooo]Z0029oookJPOo00002ooonfX4
o`0007kooo]Z1Ol0001XoookJPOo00003?oonfX4o`0009oooo]Z002:oookJPKo00002ooonfX4o`00
07kooo]Z1Ol0001YoookJPOo00002ooonfX4o`0009oooo]Z002;oookJPKo00002_oonfX4o`0007ko
oo]Z1Ol0001ZoookJPKo00002ooonfX4o`0009oooo]Z002<oookJPKo00002OoonfX4o`0007kooo]Z
1Ol0001[oookJPKo00002_oonfX4o`0009oooo]Z002<oookJPKo00002OoonfX4o`0007kooo]Z1Ol0
001/oookJPKo00002OoonfX4o`0009oooo]Z002=oookJPKo00002?oonfX4o`0007kooo]Z1Ol0001/
oookJPOo00002?oonfX4o`0009oooo]Z002>oookJPGo00002?oonfX4o`0007kooo]Z1Ol0001]oook
JPKo00002?oonfX4o`0009oooo]Z002>oookJPSo00001OoonfX4o`0007kooo]Z1Ol0001^oookJPKo
00001ooonfX4o`0009oooo]Z002?oookJPSo00001?oonfX4o`0007kooo]Z1Ol0001_oookJPKo0000
1_oonfX4o`0009oooo]Z002?oookJPSo00001?oonfX4o`0007kooo]Z1Ol0001_oookJPKo00001_oo
nfX4o`0009oooo]Z002?oookJPSo00001?oonfX4o`0007kooo]Z1Ol0001`oookJPKo00001OoonfX4
o`0009oooo]Z002?oookJQ3o0000O_oonfX5o`00077ooo]Z1Ol000000ooonf[o0000o`000006o`00
09oooo]Z002?oookJQ3o0000O_oonfX5o`00077ooo]Z1Ol000000ooonf[o0000o`000006o`0009oo
oo]Z002@oookJPoo0000O_oonfX5o`0007;ooo]Z3Ol0002OoookJP00T?oonfX?o`0007kooo]Z1Ol0
001boookJPgo0000WooonfX009?ooo]Z3?l0001noookJPGo0000L_oonfX=o`0009oooo]Z002Coook
JPco0000O_oonfX5o`0007?ooo]Z3?l0002OoookJP00U?oonfX;o`0007kooo]Z1Ol0001coookJPco
0000WooonfX009Cooo]Z2ol0001noookJPGo0000LooonfX<o`0009oooo]Z002DoookJP_o0000O_oo
nfX5o`0007Cooo]Z2ol0002OoookJP00U?oonfX;o`0007kooo]Z1Ol0001doookJP_o0000WooonfX0
09Cooo]Z2_l0001ooookJPGo0000M?oonfX;o`0009oooo]Z002DoookJP[o0000OooonfX5o`0007Co
oo]Z2ol0002OoookJP00UOoonfX9o`0007oooo]Z1Ol0001doookJP_o0000WooonfX009Gooo]Z2Ol0
001ooookJPGo0000MOoonfX:o`0009oooo]Z002HoookJPKo0000OooonfX5o`0007Sooo]Z1ol0002O
oookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oonfX7o`0009oooo]Z002HoookJPKo
0000L_oonfX3o`00O`[ooo]Z1Ol0001hoookJPOo0000WooonfX009Sooo]Z1_l0001boookJP?o001o
2_oonfX5o`0007Sooo]Z1ol0002OoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000N?oo
nfX7o`0009oooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1_l0001goookJPKo0000X?oonfX0
09Wooo]Z1Ol0001boookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007;o
oo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z
1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001boookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0
002PoookJP00VOoonfX5o`0006oooo]Z1_l007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002Ioook
JPGo0000KooonfX6o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001aoookJPCo
001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000
NOoonfX5o`000:3ooo]Z002IoookJPGo0000OooonfX5o`0007[ooo]Z1?l0002PoookJP00VOoonfX5
o`0007oooo]Z1Ol0001joookJPCo0000X?oonfX009[ooo]Z1?l0001ooookJPGo0000N_oonfX4o`00
0:3ooo]Z002JoookJPCo0000OooonfX5o`0007[ooo]Z1?l0002PoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2
oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXNoook
JP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l007l:
oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoook
JP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00oooonfX1oookJPCo001o
2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooo
nfXOoookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4o`00
O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oookJPKo0000oooonfXNoookJP00
oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z1Ol0
003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oook
JP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z
3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z003o
oookJPoooo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.04262 .3097 L
.04376 .31003 L
.04498 .30977 L
.04561 .30942 L
.04631 .30898 L
.04754 .30836 L
.0487 .3083 L
.04995 .30886 L
.05102 .30958 L
.0522 .31015 L
.05294 .31023 L
.05363 .31008 L
.05429 .30977 L
.055 .30934 L
.05569 .30892 L
.05634 .30863 L
.05756 .30855 L
.05878 .3091 L
.05991 .30988 L
.06114 .3105 L
.06244 .31048 L
.06367 .30987 L
.06484 .3092 L
.06548 .30898 L
.06618 .30893 L
.06741 .3094 L
.06812 .30988 L
.06887 .31044 L
.06951 .31083 L
.07023 .3111 L
.07088 .31115 L
.07158 .31098 L
.07286 .3103 L
.07403 .30971 L
.07532 .30963 L
.07597 .30989 L
.07666 .31034 L
.07791 .3113 L
.07917 .31192 L
.08035 .31188 L
.08141 .31138 L
.08255 .31075 L
.08321 .31053 L
.08392 .31051 L
.0852 .31107 L
.08599 .31168 L
.08673 .31229 L
.08739 .31275 L
.08812 .31306 L
Mistroke
.0889 .31311 L
.0896 .31291 L
.09041 .3125 L
.09118 .31209 L
.09189 .31181 L
.09254 .31173 L
.09326 .31188 L
.09401 .31231 L
.09527 .31339 L
.09597 .31396 L
.09662 .31438 L
.0979 .3146 L
.09905 .31419 L
.10034 .31354 L
.10099 .31335 L
.1017 .31337 L
.10247 .31369 L
.1032 .31423 L
.10458 .31554 L
.10576 .31635 L
.10702 .31648 L
.10821 .31601 L
.10929 .3155 L
.11056 .3154 L
.11128 .31571 L
.11194 .31622 L
.11323 .31753 L
.11444 .31855 L
.1156 .3189 L
.11684 .31856 L
.1181 .31798 L
.11881 .31782 L
.11948 .3179 L
.12017 .31825 L
.12091 .31888 L
.12226 .32038 L
.12347 .32145 L
.12416 .32173 L
.1248 .32176 L
.12588 .32142 L
.12706 .32091 L
.1283 .32089 L
.12945 .32164 L
.1305 .32283 L
.13164 .32418 L
.13272 .32502 L
.13371 .32521 L
.13489 .32485 L
.13614 .32438 L
.13719 .32445 L
Mistroke
.13835 .3253 L
.14332 .32912 L
.14848 .33127 L
.14916 .33225 L
.14989 .33314 L
.15121 .33395 L
.152 .33392 L
.15273 .33367 L
.15345 .33339 L
.15412 .33325 L
.15535 .33368 L
.156 .33433 L
.1567 .33529 L
.15811 .33752 L
.1588 .33844 L
.15944 .33904 L
.16067 .33939 L
.16133 .33923 L
.16202 .33896 L
.16314 .33872 L
.16437 .33934 L
.16559 .34099 L
.16687 .34324 L
.16796 .3448 L
.16915 .34556 L
.17045 .34535 L
.17117 .34507 L
.17182 .34493 L
.1731 .34547 L
.17431 .34714 L
.17543 .34931 L
.17648 .35117 L
.17758 .35235 L
.17878 .35253 L
.18 .35208 L
.1813 .35202 L
.18252 .35319 L
.18363 .35526 L
.18486 .35791 L
.18602 .35977 L
.18667 .3603 L
.18736 .36045 L
.18857 .36005 L
.18973 .35973 L
.19096 .36048 L
.19201 .36227 L
.19315 .36498 L
.19385 .36662 L
.19451 .3679 L
.19575 .36917 L
Mistroke
.19644 .36922 L
.19708 .36898 L
.19783 .36859 L
.19853 .36839 L
.19968 .36899 L
.20096 .37134 L
.20219 .37464 L
.20284 .37633 L
.20353 .37777 L
.20479 .37901 L
.20597 .3787 L
.20716 .378 L
.20828 .37825 L
.20938 .38 L
.21056 .38333 L
.21163 .38661 L
.21263 .3889 L
.21381 .3899 L
.21511 .38921 L
.21637 .38837 L
.21708 .38857 L
.21773 .38941 L
.21888 .39244 L
.22014 .39693 L
.22132 .40049 L
.22242 .40193 L
.23139 .41544 L
.24107 .42962 L
.24175 .42767 L
.24247 .42534 L
.24377 .4233 L
.24448 .42457 L
.24513 .42741 L
.24589 .43251 L
.24662 .43822 L
.24788 .44693 L
.24905 .44941 L
.25034 .44438 L
.25098 .43993 L
.2517 .43514 L
.25299 .4318 L
.25418 .43954 L
.25484 .4483 L
.25555 .45998 L
.25685 .47897 L
.25806 .4807 L
.25935 .45232 L
.26057 .39468 L
.26167 .32465 L
.2628 .25005 L
Mistroke
.264 .18397 L
.26533 .14278 L
.26656 .13606 L
.26722 .14204 L
.26795 .15279 L
.26926 .17386 L
.27054 .18544 L
.27172 .18492 L
.27282 .17817 L
.27385 .17148 L
.27498 .16855 L
.2762 .17257 L
.27739 .18136 L
.27866 .19051 L
.27986 .1946 L
.28095 .19374 L
.28225 .18976 L
.28348 .1873 L
.28417 .1877 L
.28481 .18935 L
.28551 .19237 L
.28625 .19636 L
.28753 .20295 L
.28825 .20537 L
.2889 .20644 L
.28968 .20634 L
.29041 .20529 L
.29108 .20402 L
.29182 .2029 L
.29302 .20303 L
.2943 .20647 L
.29548 .21149 L
.29659 .21579 L
.29789 .2183 L
.29908 .21797 L
.3004 .21645 L
.30106 .21607 L
.30178 .21638 L
.30309 .21916 L
.30431 .22341 L
.30499 .22581 L
.30564 .22767 L
.30631 .229 L
.30705 .22964 L
.3083 .22917 L
.30945 .22827 L
.31008 .22814 L
.31077 .22857 L
.31203 .23102 L
.31324 .23467 L
Mistroke
.31437 .23789 L
.31568 .2399 L
.31687 .23994 L
.31799 .23925 L
.31902 .23903 L
.32016 .24007 L
.32136 .24268 L
.32264 .24615 L
.32385 .24867 L
.32452 .2494 L
.32525 .24964 L
.32652 .24916 L
.32773 .24879 L
.32902 .24972 L
.33012 .25179 L
.33134 .25471 L
.33203 .25623 L
.33276 .25744 L
.33406 .2583 L
.33478 .25818 L
.33546 .25789 L
.3362 .25762 L
.33699 .25767 L
.33768 .25814 L
.33842 .25915 L
.33912 .26048 L
.33977 .26188 L
.34107 .26449 L
.3423 .2659 L
.34346 .26606 L
.34474 .26559 L
.3459 .26553 L
.34697 .26637 L
.34825 .26847 L
.3494 .27071 L
.35005 .27177 L
.35074 .2726 L
.35199 .2731 L
.35309 .2728 L
.35429 .27245 L
.35555 .27294 L
.35672 .27443 L
.35773 .27619 L
.3588 .27795 L
.35998 .27911 L
.36106 .27929 L
.36234 .27886 L
.36307 .27865 L
.36375 .27869 L
.36497 .27954 L
Mistroke
.36628 .28142 L
.36755 .28339 L
.36876 .28456 L
.36985 .28477 L
.37103 .28438 L
.37176 .28413 L
.37244 .28406 L
.37371 .28469 L
.37443 .28548 L
.37508 .2864 L
.37585 .28753 L
.37657 .28847 L
.37776 .28943 L
.37907 .28947 L
.38034 .28896 L
.38105 .28878 L
.38171 .28882 L
.38288 .28955 L
.38399 .29086 L
.3853 .29256 L
.38651 .29354 L
.3877 .29365 L
.38896 .29316 L
.39022 .29282 L
.39094 .29295 L
.39161 .29334 L
.3928 .29458 L
.39393 .29594 L
.39494 .29687 L
.39604 .29723 L
.39723 .29694 L
.3985 .29639 L
.39958 .29629 L
.40077 .2969 L
.40206 .29823 L
.40277 .29901 L
.40343 .29963 L
.40422 .30009 L
.40494 .30021 L
.40561 .30009 L
.40633 .29978 L
.40703 .29945 L
.40767 .29921 L
.40835 .29914 L
.40908 .29933 L
.41031 .30024 L
.41161 .30158 L
.41289 .30251 L
.41361 .30269 L
.41428 .30261 L
Mistroke
.4155 .30207 L
.4168 .30155 L
.41796 .30165 L
.41905 .30234 L
.42023 .30345 L
.42153 .30445 L
.42276 .30469 L
.42391 .3043 L
.42522 .30363 L
.42641 .30342 L
.42752 .30385 L
.42857 .30468 L
.42967 .30563 L
.43088 .30626 L
.4321 .30617 L
.4334 .30553 L
.4346 .30499 L
.43572 .30498 L
.43704 .30571 L
.43824 .3067 L
.43891 .30716 L
.43964 .30748 L
.44096 .3074 L
.44164 .30709 L
.44238 .30667 L
.44303 .30633 L
.44371 .3061 L
.44501 .30623 L
.44621 .30697 L
.4475 .30794 L
.44822 .30832 L
.44888 .30846 L
.44965 .30837 L
.45039 .30806 L
.45106 .30767 L
.4518 .30725 L
.45301 .30688 L
.4543 .3072 L
.4555 .308 L
.45661 .30876 L
.45793 .30911 L
.45913 .30876 L
.4598 .30838 L
.46052 .30794 L
.46184 .30746 L
.46249 .30749 L
.46317 .30772 L
.46439 .3085 L
.46571 .30931 L
.46646 .30952 L
Mistroke
.46715 .30949 L
.46842 .30894 L
.46957 .30824 L
.47021 .30795 L
.4709 .30781 L
.47216 .3081 L
.47337 .30885 L
.47451 .30953 L
.4757 .30978 L
.47702 .30934 L
.47814 .30864 L
.47918 .30813 L
.48032 .30803 L
.48151 .30851 L
.4828 .30934 L
.48402 .30986 L
.48469 .30988 L
.48542 .30968 L
.4867 .30896 L
.48792 .30828 L
.48921 .30811 L
.49031 .30852 L
.49153 .30928 L
.49226 .30968 L
.49295 .3099 L
.49425 .30974 L
.49498 .30937 L
.49566 .30895 L
.49645 .30847 L
.49719 .30818 L
.49783 .3081 L
.49853 .30823 L
.49975 .30886 L
.50049 .30933 L
.50118 .3097 L
.50248 .30992 L
.50362 .30952 L
.50486 .30875 L
.50551 .30839 L
.50619 .30815 L
.50741 .30822 L
.50854 .30879 L
.5096 .30946 L
.51076 .30992 L
.51201 .30978 L
.51328 .30909 L
.51401 .30863 L
.51467 .30831 L
.51537 .30814 L
.51612 .30821 L
Mistroke
.51681 .30848 L
.51746 .30886 L
.51863 .3096 L
.51986 .31003 L
.5205 .30999 L
.52121 .30975 L
.52246 .30901 L
.52313 .30862 L
.52387 .30833 L
.52456 .30826 L
.5252 .30839 L
.52642 .30904 L
.52771 .30987 L
.52838 .31014 L
.52909 .31023 L
.53039 .30982 L
.5318 .30897 L
.53261 .30861 L
.53335 .3085 L
.5346 .30888 L
.5353 .30932 L
.53594 .30977 L
.53661 .3102 L
.53734 .3105 L
.53803 .31059 L
.53866 .31047 L
.53997 .3098 L
.54121 .30912 L
.54232 .30893 L
.54353 .30936 L
.5447 .31017 L
.54579 .31088 L
.54705 .31115 L
.5482 .31079 L
.54945 .31007 L
.55015 .30973 L
.5508 .30958 L
.55197 .3098 L
.55321 .31061 L
.55429 .31142 L
.55544 .31194 L
.55654 .31188 L
.55753 .31142 L
.5587 .31077 L
.55996 .31049 L
.56116 .31092 L
.56227 .31176 L
.56345 .31267 L
.56472 .31312 L
.56593 .31285 L
Mistroke
.56703 .31227 L
.56825 .31177 L
.56894 .31175 L
.56958 .31194 L
.57088 .31287 L
.57161 .31351 L
.57227 .31405 L
.57294 .31444 L
.57365 .31462 L
.57436 .31455 L
.57514 .31424 L
.57644 .31357 L
.57717 .31335 L
.57784 .31336 L
.57848 .31359 L
.57918 .31406 L
.58046 .31524 L
.58172 .31624 L
.5829 .31653 L
.60175 .32156 L
.61165 .3246 L
.61229 .32439 L
.61299 .32435 L
.61426 .32502 L
.61502 .32586 L
.61573 .32678 L
.61641 .32769 L
.61706 .32843 L
.61822 .32919 L
.6195 .32913 L
.62075 .32863 L
.62145 .32847 L
.6221 .32855 L
.6234 .32953 L
.62415 .3305 L
.62483 .33151 L
.62609 .33315 L
.6268 .33372 L
.62743 .33396 L
.62814 .33393 L
.6288 .33372 L
.62949 .33344 L
.63024 .33326 L
.63101 .33337 L
.63183 .33393 L
.63259 .33484 L
.63328 .33591 L
.63459 .33794 L
.63532 .33879 L
.636 .33926 L
Mistroke
.63725 .33931 L
.63788 .33909 L
.63857 .33883 L
.63981 .33883 L
.64051 .33928 L
.64115 .34002 L
.64232 .34194 L
.64356 .34404 L
.64482 .34536 L
.64597 .34555 L
.64661 .34536 L
.6473 .34509 L
.64855 .345 L
.64973 .34595 L
.65097 .34802 L
.65213 .35028 L
.6532 .35186 L
.65445 .35258 L
.65514 .35249 L
.65579 .35224 L
.65695 .35192 L
.65822 .35256 L
.65895 .35357 L
.65961 .35482 L
.66032 .35636 L
.66109 .35798 L
.6618 .35923 L
.66246 .36002 L
.66375 .36043 L
.66501 .35993 L
.66621 .35978 L
.66729 .36066 L
.66846 .36284 L
.66973 .36591 L
.67042 .3674 L
.67108 .36845 L
.67223 .36924 L
.6735 .36886 L
.67461 .3684 L
.67579 .3689 L
.67679 .37052 L
.67788 .37327 L
.67906 .37641 L
.68032 .3786 L
.68151 .379 L
.6826 .37841 L
.68389 .37795 L
.68454 .37831 L
.68525 .37935 L
.68652 .38261 L
Mistroke
.6877 .38627 L
.68842 .38812 L
.6891 .38931 L
.69037 .38984 L
.69108 .3894 L
.69174 .38883 L
.69247 .3884 L
.69323 .38854 L
.69442 .3905 L
.69569 .39462 L
.69679 .39852 L
.698 .40139 L
.69869 .40195 L
.69934 .4018 L
.70002 .40113 L
.70075 .40024 L
.70207 .3997 L
.70327 .40181 L
.71256 .41549 L
.71382 .42206 L
.71502 .42802 L
.71567 .43005 L
.71639 .43077 L
.71765 .42857 L
.71885 .42481 L
.72012 .42342 L
.72133 .42745 L
.72242 .43511 L
.72369 .44475 L
.72441 .44833 L
.72507 .44949 L
.72628 .44587 L
.72756 .43722 L
.72823 .43332 L
.72896 .4316 L
.73026 .43835 L
.73106 .44877 L
.73181 .46118 L
.73248 .47199 L
.73322 .4806 L
.73443 .47885 L
.73571 .44619 L
.73689 .38698 L
.738 .3152 L
.73922 .23564 L
.74051 .171 L
.74118 .14983 L
.74191 .13757 L
.7432 .13959 L
.74452 .15921 L
Mistroke
.74575 .1777 L
.74703 .18628 L
.74772 .18563 L
.74845 .18201 L
.74924 .1765 L
.74999 .17171 L
.75067 .16907 L
.75141 .16877 L
.75209 .17098 L
.75282 .17547 L
.75413 .18574 L
.75479 .19015 L
.75548 .19334 L
.75623 .19473 L
.75693 .19419 L
.75818 .1906 L
.7589 .18849 L
.75955 .18738 L
.76078 .18864 L
.76209 .19442 L
.76321 .20058 L
.76446 .20542 L
.76565 .20649 L
.76693 .20467 L
.76811 .20281 L
.76921 .20303 L
.77051 .20656 L
.7717 .21163 L
.77301 .21646 L
.77366 .21786 L
.77438 .21842 L
.77561 .21759 L
.77673 .21633 L
.77803 .21644 L
.77924 .21904 L
.78037 .22295 L
.78158 .22702 L
.78272 .22928 L
.78377 .22962 L
.78493 .22879 L
.78603 .22814 L
.78722 .22889 L
.78851 .23183 L
.78977 .23574 L
.79047 .23765 L
.79112 .23901 L
.79226 .24008 L
.79353 .23967 L
.79463 .23905 L
.79578 .23935 L
Mistroke
.79677 .24083 L
.79785 .24349 L
.79902 .24663 L
.80027 .24898 L
.80144 .24964 L
.80252 .24927 L
.80378 .24879 L
.80442 .24895 L
.80512 .24959 L
.80636 .25189 L
.80752 .25469 L
.80822 .25623 L
.80889 .25736 L
.81014 .25829 L
.81084 .25823 L
.81148 .25796 L
.8122 .25767 L
.81295 .25761 L
.81423 .25858 L
.81495 .25976 L
.81562 .26112 L
.81681 .26368 L
.81813 .26563 L
.81931 .26612 L
.82041 .26579 L
.82157 .26545 L
.82281 .26599 L
.82403 .26771 L
.82538 .27032 L
.82606 .2715 L
.82679 .27246 L
.82811 .27311 L
.82935 .27277 L
.83066 .27245 L
.83178 .27297 L
.833 .27457 L
.83443 .27707 L
.83513 .27813 L
.83577 .27883 L
.83652 .27925 L
.83733 .27928 L
.83801 .27906 L
.83874 .27878 L
.84005 .27872 L
.84128 .27968 L
.84198 .28064 L
.84262 .28167 L
.84338 .28287 L
.84407 .2838 L
.84531 .28471 L
Mistroke
.84664 .28462 L
.84786 .28415 L
.84901 .28414 L
.84967 .2845 L
.85036 .28517 L
.8516 .28689 L
.85225 .28782 L
.85294 .28867 L
.85369 .2893 L
.8544 .28955 L
.8642 .29356 L
.86951 .29521 L
.87441 .29649 L
.8855 .29944 L
.89589 .30294 L
.89714 .30408 L
.89784 .30451 L
.8985 .30469 L
.8997 .30448 L
.90098 .30383 L
.90224 .30342 L
.90342 .30368 L
.90448 .30443 L
.90563 .30545 L
.90672 .30614 L
.90792 .30627 L
.90916 .30577 L
.91033 .30515 L
.91142 .30491 L
.91241 .30518 L
.91356 .30597 L
.91465 .30686 L
.91582 .30747 L
.91706 .30743 L
.91813 .30693 L
.9193 .30629 L
.92055 .30606 L
.92126 .30625 L
.9219 .30661 L
.92319 .30758 L
.92435 .30829 L
.92555 .30843 L
.92684 .30791 L
.92804 .30722 L
.92915 .30688 L
.93044 .30718 L
.93113 .3076 L
.93185 .30813 L
.93306 .30889 L
.93375 .30909 L
Mistroke
.9344 .30908 L
.93505 .30888 L
.93576 .30851 L
.93706 .30776 L
.93832 .30745 L
.9395 .30779 L
.94021 .30824 L
.94089 .30871 L
.94215 .30941 L
.94286 .30953 L
.94351 .30945 L
.94422 .30916 L
.94498 .30871 L
.94598 .30812 L
.94707 .30781 L
.9481 .30799 L
.94906 .30851 L
.94999 .30913 L
.95086 .3096 L
.95177 .30978 L
.95277 .30955 L
.9538 .30898 L
.95487 .30834 L
.95579 .30802 L
.9568 .3081 L
.95788 .30862 L
.95904 .30937 L
.96013 .30984 L
.96113 .30984 L
.96207 .30946 L
.96306 .30885 L
.96391 .30836 L
.96485 .30809 L
.96585 .30822 L
.96693 .30878 L
.96794 .30942 L
.96888 .30984 L
.96982 .30991 L
.97084 .30956 L
.97174 .30901 L
.9727 .30844 L
.97356 .30814 L
.97436 .30813 L
.97524 .30845 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00W_oonfX4o`0007_ooo]Z1Ol0003ooookJQoooo]Z002NoookJPCo0000NooonfX5o`0007ko
oo]Z1?l0002LoookJP00W_oonfX4o`0007_ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0
001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000N_oonfX5o`0007kooo]Z1Ol0002K
oookJP00W_oonfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001joookJPGo
0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000
VooonfX009kooo]Z1Ol0001]oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX5
o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPGo0000GOoonfX:o`00
O`Kooo]Z0ol007l:oookJPGo0000O_oonfX6o`0009[ooo]Z002NoookJPGo0000GOoonfX:o`00O`Ko
oo]Z0ol007l:oookJPKo0000OOoonfX6o`0009[ooo]Z002NoookJPGo0000KOoonfX3o`00O`[ooo]Z
1Ol0001noookJPKo0000V_oonfX009kooo]Z1Ol0001]oookJP?o001o2_oonfX5o`0007kooo]Z1_l0
002JoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000OOoonfX7o`0009[ooo]Z002Noook
JPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001moookJPOo0000V_oonfX009gooo]Z1ol0001YoookJPKo
001o2_oonfX5o`0007gooo]Z1ol0002JoookJP00WOoonfX7o`0006Wooo]Z1_l007l:oookJPGo0000
OOoonfX7o`0009[ooo]Z002MoookJP[o0000J?oonfX4o`00O`[ooo]Z1Ol0001moookJP[o0000Uooo
nfX009gooo]Z2_l0001YoookJP?o001o2_oonfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX;o`00
07Gooo]Z1Ol0001moookJP_o0000U_oonfX009gooo]Z2ol0001eoookJPGo0000OOoonfX;o`0009Ko
oo]Z002MoookJP_o0000MOoonfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX;o`0007Gooo]Z1Ol0
001moookJP_o0000U_oonfX009gooo]Z2ol0001eoookJPGo0000OOoonfX;o`0009Kooo]Z002Moook
JP_o0000MOoonfX5o`0007gooo]Z3?l0002EoookJP00WOoonfX;o`0007Gooo]Z1Ol0001moookJPco
0000UOoonfX009gooo]Z2ol0001eoookJPGo0000OOoonfX<o`0009Gooo]Z002MoookJPoo0000LOoo
nfX5o`0007gooo]Z3ol0002BoookJP00WOoonfX?o`00077ooo]Z1Ol0001moookJPoo0000T_oonfX0
09gooo]Z3ol0001aoookJPGo0000OOoonfX?o`0009;ooo]Z002MoookJPCo00001?oonfX8o`00073o
oo]Z1Ol0001moookJQ3o0000TOoonfX009gooo]Z1?l00004oookJPSo0000L?oonfX5o`0007gooo]Z
1?l00004oookJPSo0000TOoonfX009gooo]Z1?l00004oookJPSo0000L?oonfX5o`0007gooo]Z1?l0
0004oookJPSo0000TOoonfX009gooo]Z1?l00004oookJPSo0000L?oonfX5o`0007gooo]Z1?l00004
oookJPWo0000T?oonfX009gooo]Z1?l00005oookJPOo0000L?oonfX5o`0007gooo]Z1?l00005oook
JPSo0000T?oonfX009gooo]Z1?l00008oookJPGo0000KooonfX5o`0007gooo]Z1?l00008oookJPOo
0000S_oonfX009gooo]Z1?l00008oookJPSo0000K?oonfX5o`0007gooo]Z1?l00009oookJPOo0000
SOoonfX009gooo]Z1?l00008oookJPWo0000JooonfX5o`0007gooo]Z1?l00009oookJPOo0000SOoo
nfX009gooo]Z1?l00009oookJPSo0000JooonfX5o`0007gooo]Z1?l00009oookJPSo0000S?oonfX0
09gooo]Z1?l00009oookJPSo0000JooonfX5o`0007gooo]Z1?l00009oookJPSo0000S?oonfX009go
oo]Z1?l00009oookJPSo0000JooonfX5o`0007gooo]Z1?l00009oookJPSo0000S?oonfX009gooo]Z
1?l0000=oookJPCo0000JooonfX5o`0007gooo]Z1?l0000=oookJPCo0000S?oonfX009gooo]Z1?l0
000=oookJPGo0000J_oonfX5o`0007gooo]Z1?l0000=oookJPGo0000RooonfX009gooo]Z1?l0000=
oookJPSo0000IooonfX5o`0007gooo]Z1?l0000=oookJPSo0000R?oonfX009cooo]Z1Ol0000=oook
JPSo0000IooonfX5o`0007gooo]Z1?l0000=oookJPSo0000R?oonfX009cooo]Z1Ol0000>oookJPOo
0000IooonfX5o`0007gooo]Z1?l0000>oookJPOo0000R?oonfX009cooo]Z1Ol0000>oookJPSo0000
I_oonfX5o`0007gooo]Z1?l0000>oookJPSo0000QooonfX009cooo]Z1?l0000?oookJPSo0000I_oo
nfX5o`0007gooo]Z1?l0000>oookJPSo0000QooonfX009cooo]Z1?l0000BoookJPGo0000B?oonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0007gooo]Z1?l0000AoookJPKo0000Q_oonfX0
09cooo]Z1?l0000CoookJPOo0000A?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`00
07gooo]Z1?l0000BoookJPOo0000Q?oonfX009cooo]Z1?l0000CoookJPOo0000A?oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001o
o`00O`Wooo]Z1Ol0001moookJPCo00004_oonfX8o`0008?ooo]Z002LoookJPCo00004ooonfX8o`00
03Kooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`00
07gooo]Z1?l0000CoookJPOo0000PooonfX009cooo]Z1?l0000DoookJPOo0000=_oonfX:o`00O`;o
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001loookJPCo00004ooonfX7o`0008?o
oo]Z002LoookJPCo00005?oonfX8o`00047ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z
1Ol0001moookJPCo00004ooonfX8o`0008;ooo]Z002LoookJPCo00005ooonfX5o`00047ooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000OOoonfX4o`0001Kooo]Z1Ol0
0022oookJP00W?oonfX4o`0001Oooo]Z2?l0000noookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9
oookJPGo0000OOoonfX4o`0001Kooo]Z2?l0001ooookJP00W?oonfX4o`0001Sooo]Z2?l0000moook
JP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000OOoonfX4o`0001Oooo]Z2?l0001noook
JP00W?oonfX4o`0001Sooo]Z2?l0000moookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo
0000OOoonfX4o`0001Oooo]Z2?l0001noookJP00W?oonfX4o`0001Sooo]Z2?l0000noookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001moookJPCo00006?oonfX7o`0007ko
oo]Z002LoookJPCo00006OoonfX8o`0003gooo]Z1ol007l9oookJPOo001o2?oonfX5o`0007gooo]Z
1?l0000HoookJPSo0000OOoonfX009cooo]Z1?l0000LoookJPSo0000>ooonfX5o`00O`[ooo]Z1ol0
07l8oookJPGo0000OOoonfX4o`0001_ooo]Z2?l0001joookJP00W?oonfX4o`0001cooo]Z2?l0001I
oookJPGo0000OOoonfX4o`0001_ooo]Z2?l0001joookJP00W?oonfX4o`0001gooo]Z2?l0001Hoook
JPGo0000OOoonfX4o`0001cooo]Z2?l0001ioookJP00W?oonfX4o`0001kooo]Z1ol0001HoookJPGo
0000OOoonfX4o`0001gooo]Z1ol0001ioookJP00W?oonfX4o`0001kooo]Z2?l0001GoookJPGo0000
OOoonfX4o`0001gooo]Z2?l0001hoookJP00W?oonfX4o`00027ooo]Z2?l0001DoookJPGo0000OOoo
nfX4o`00023ooo]Z2?l0001eoookJP00W?oonfX4o`00027ooo]Z2?l0001DoookJPGo0000OOoonfX4
o`00023ooo]Z2Ol0001doookJP00W?oonfX4o`0002;ooo]Z2?l0001CoookJPGo0000OOoonfX4o`00
027ooo]Z2?l0001doookJP00W?oonfX4o`0002;ooo]Z2?l0001CoookJPGo0000OOoonfX4o`00027o
oo]Z2Ol0001coookJP00W?oonfX4o`0002?ooo]Z2_l0001@oookJPGo0000OOoonfX4o`0002;ooo]Z
2_l0001aoookJP00W?oonfX4o`0002Kooo]Z2?l0001?oookJPGo0000OOoonfX4o`0002Gooo]Z2?l0
001`oookJP00W?oonfX4o`0002Kooo]Z2Ol0001>oookJPGo0000OOoonfX4o`0002Kooo]Z2?l0001_
oookJP00W?oonfX4o`0002Oooo]Z2?l0001>oookJPGo0000OOoonfX4o`0002Kooo]Z2?l0001_oook
JP008_oonfX3o`00OgGooo]Z0_l007l4o`0000?ooo]Z0ol007l3oookJPGo001o6_oonfX;o`0004[o
oo]Z1Ol0001doookJPGo001o1?oonfX4o`0000;ooo]Z1Ol007lOoookJPco0000BooonfX3o`00Oago
oo]Z000RoookJP?o001oM?oonfX3o`00O`Co00000ooonfX3o`00O`;ooo]Z1ol007lLoookJPSo0000
B_oonfX5o`0007?ooo]Z1ol007l3oookJPCo000000?ooo]Zo`00Ool007l01Ol007lRoookJPSo0000
BooonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`Co00000ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o7?oonfX9o`0004Wooo]Z1Ol0001coookJP?o001o
00Cooo]Zo`00Ool007oo001o0_oonfX5o`0000Co001o00Cooo]Zo`00Ool007oo001o8_oonfX8o`00
04_ooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`03
oookJ_l0003o000000;o000000?o001ooookJ_oonfX01?oonfX3o`00O`?ooo]Z0ol007lLoookJPSo
0000BOoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000ol00003o`00O`?o
oo]Z0ol007lRoookJPWo0000BOoonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z
2_l007l2oookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o001o
7OoonfX;o`0004Gooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000?o0000
1_oonfX3o`00Ob?ooo]Z2ol00016oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?o
oo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o001o8?oonfX9o`0004Cooo]Z1Ol0
001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00001ooonfX3o`00ObGooo]Z2_l0
0015oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l00000
0ol007oooo]ZoookJP05oookJP;o001o0_oonfX4o`00Ob3ooo]Z2Ol00014oookJPGo0000L_oonfX3
o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l007l2oookJPCo001o9_oonfX9
o`0004Gooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`00
0003o`00Oooonf[ooo]Z00Gooo]Z1ol007lRoookJPco0000@?oonfX5o`0007;ooo]Z0ol007l3oook
JP?o001o00?ooo]Zo`000?l000000_l00002oookJPOo001o:?oonfX<o`00047ooo]Z0ol007lMoook
JP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Go
oo]Z1_l007lWoookJPWo0000?ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l0
00000_l00002oookJPKo001o;?oonfX:o`00043ooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z
0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l[oookJPgo0000
>ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP;o001o
<OoonfX;o`0003_ooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z0_l0
07l/oookJPco0000>ooonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo0000
0_oonfX2o`00Oc;ooo]Z3?l0000ioookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o1?l0
0009oookJPOo001o:OoonfX=o`0003Oooo]Z1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z1ol0
07l`oookJPWo0000>_oonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00002OoonfX7
o`00Ob[ooo]Z3Ol0000foookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPOo001o<?oonfX<
o`0003Sooo]Z0ol007lMoookJP00W?oonfX4o`0003kooo]Z3Ol0000boookJPGo0000O?oonfX4o`00
03gooo]Z3ol0001BoookJP00W?oonfX4o`0003oooo]Z3Ol0000aoookJPGo0000O?oonfX4o`0003oo
oo]Z4?l0001?oookJP00W?oonfX4o`0003oooo]Z4Ol0000]oookJPGo0000O?oonfX4o`00043ooo]Z
4_l0001<oookJP00W?oonfX4o`0004Cooo]Z4Ol0000XoookJPGo0000O?oonfX4o`0004?ooo]Z4_l0
0019oookJP00W?oonfX4o`0004Gooo]Z5Ol0000SoookJPGo0000O?oonfX4o`0004Wooo]Z4Ol00014
oookJP00W?oonfX4o`0004Sooo]Z6_l0000KoookJPGo0000O?oonfX4o`0004cooo]Z5ol0000koook
JP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oo
nf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`00
0?oo00009Ol0000?oookJP007OoonfX00ol0003ooo]ZoookJP06oookJRWo0000COoonfX4o`0007Wo
oo]Z2Ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000002Ko0000C_oonfX4o`0007[o
oo]Z1?l000000ooonf[o0000oookJP0MoookJP00>OoonfXKo`0004Sooo]Z1?l0001moookJPGo0000
6OoonfXHo`0004_ooo]Z1?l0002NoookJP00@_oonfXFo`0004Cooo]Z1?l0001moookJPGo00008_oo
nfXBo`0004Sooo]Z1?l0002NoookJP00AooonfXAo`0004Cooo]Z1?l0001moookJPGo00009ooonfXB
o`0004?ooo]Z1?l0002NoookJP00BooonfXAo`00043ooo]Z1?l0001moookJPGo0000:ooonfXAo`00
043ooo]Z1?l0002NoookJP00D?oonfX>o`0003kooo]Z1?l0001moookJPGo0000;_oonfX?o`0003oo
oo]Z1?l0002NoookJP00DOoonfX>o`0003gooo]Z1?l0001moookJPGo0000<OoonfX=o`0003kooo]Z
1?l0002NoookJP00EOoonfX<o`0003_ooo]Z1?l0001moookJPGo0000=_oonfX<o`0003[ooo]Z1?l0
002NoookJP00E_oonfX<o`0003[ooo]Z1?l0001moookJPGo0000>OoonfX:o`0003Wooo]Z1?l0002N
oookJP00FooonfX;o`0003Kooo]Z1?l0001moookJPGo0000>_oonfX<o`0003Kooo]Z1?l0002Noook
JP00G?oonfX;o`0003Gooo]Z1?l0001moookJPGo0000>_oonfX=o`0003Gooo]Z1?l0002NoookJP00
G_oonfX:o`0003Cooo]Z1?l0001moookJPGo0000?_oonfX9o`0003Gooo]Z1?l0002NoookJP00Gooo
nfX<o`00037ooo]Z1?l0001moookJPGo0000?ooonfX<o`00037ooo]Z1?l0002NoookJP00H?oonfX<
o`00033ooo]Z1?l0001moookJPGo0000@?oonfX;o`00037ooo]Z1?l0002NoookJP00I?oonfX8o`00
033ooo]Z1?l0001moookJPGo0000@ooonfX9o`00033ooo]Z1?l0002NoookJP00I?oonfX;o`0002go
oo]Z1?l0001moookJPGo0000A?oonfX9o`0002oooo]Z1?l0002NoookJP00J?oonfX8o`0002cooo]Z
1?l0001moookJPGo0000AooonfX9o`0002cooo]Z1?l0002NoookJP00J?oonfX8o`0002cooo]Z1?l0
001moookJPGo0000B?oonfX9o`0002_ooo]Z1?l0002NoookJP00J?oonfX9o`0002_ooo]Z1?l0001m
oookJPGo0000BOoonfX8o`0002_ooo]Z1?l0002NoookJP00J_oonfX:o`0002Sooo]Z1?l0001moook
JPGo0000BOoonfX;o`0002Oooo]Z1Ol0002NoookJP00K?oonfX9o`0002Oooo]Z1?l0001moookJPGo
0000COoonfX8o`0002Kooo]Z1Ol0002NoookJP00KOoonfX9o`0002Kooo]Z1?l0001moookJPGo0000
COoonfX9o`0002Gooo]Z1Ol0002NoookJP00K_oonfX8o`0002Kooo]Z1?l0001moookJPGo0000C_oo
nfX8o`0002Gooo]Z1?l0002OoookJP00K_oonfX8o`0002Kooo]Z1?l0001moookJPGo0000CooonfX8
o`0002Cooo]Z1?l0002OoookJP00L_oonfX8o`00027ooo]Z1Ol0001moookJPGo0000D_oonfX8o`00
027ooo]Z1?l0002OoookJP00L_oonfX8o`00027ooo]Z1Ol0001moookJPGo0000D_oonfX8o`00027o
oo]Z1?l0002OoookJP00L_oonfX9o`00023ooo]Z1Ol0001moookJPGo0000D_oonfX8o`00027ooo]Z
1?l0002OoookJP00LooonfX8o`00023ooo]Z1?l0001noookJPGo0000DooonfX8o`00023ooo]Z1?l0
002OoookJP00M_oonfX8o`0001gooo]Z1?l0001noookJPGo0000E_oonfX8o`0001gooo]Z1?l0002O
oookJP00MooonfX7o`0001gooo]Z1?l0001noookJPGo0000E_oonfX9o`0001cooo]Z1?l0002Ooook
JP00MooonfX8o`0001cooo]Z1?l0001noookJPGo0000EooonfX8o`0001cooo]Z1?l0002OoookJP00
MooonfX8o`0001cooo]Z1?l0001noookJPGo0000EooonfX8o`0001cooo]Z1?l0002OoookJP00N?oo
nfX8o`0001_ooo]Z1?l0001noookJPGo0000F?oonfX7o`0001cooo]Z1?l0002OoookJP00NooonfX7
o`0001Wooo]Z1?l0001noookJPGo0000FooonfX8o`0001Sooo]Z1?l0002OoookJP00NooonfX9o`00
01Oooo]Z1?l0001noookJPGo0000FooonfX8o`0001Sooo]Z1?l0002OoookJP00O?oonfX8o`0001Oo
oo]Z1?l0001PoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000FooonfX8o`0001So
oo]Z1?l0002OoookJP00O?oonfX8o`0001Oooo]Z1?l0001OoookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007l9oookJPGo0000G?oonfX8o`0001Oooo]Z1?l0002OoookJP00OOoonfX7o`0001Oooo]Z1?l0
001OoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005gooo]Z1ol0000GoookJPCo0000WooonfX0083ooo]Z
1Ol0000FoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z
1Ol0001OoookJPKo00005_oonfX4o`0009oooo]Z0020oookJPSo00004ooonfX4o`0005kooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001OoookJPSo00004ooonfX4o`0009oooo]Z0020
oookJPSo00004ooonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001P
oookJPSo00004ooonfX4o`0009oooo]Z0021oookJPSo00004_oonfX4o`0005kooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000HOoonfX7o`0001?ooo]Z1?l0002Ooook
JP00POoonfX8o`0001;ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo
0000HOoonfX8o`0001;ooo]Z1?l0002OoookJP00P_oonfX7o`0001;ooo]Z1?l0001NoookJP?o001o
0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000HOoonfX8o`0001;ooo]Z1?l0002OoookJP00QOoo
nfX4o`0001;ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000I?oo
nfX6o`00017ooo]Z1?l0002OoookJP00QOoonfX4o`0001;ooo]Z1?l0001OoookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001UoookJPSo00003_oonfX4o`0009oooo]Z0025
oookJPKo00004?oonfX4o`0005oooo]Z1ol007l9oookJPOo001o2?oonfX5o`0006Gooo]Z2?l0000>
oookJPCo0000WooonfX008Gooo]Z1_l0000@oookJPCo0000H?oonfX5o`00O`[ooo]Z1ol007l8oook
JPGo0000I_oonfX7o`0000kooo]Z1?l0002OoookJP00QOoonfX7o`0000oooo]Z1?l0001noookJPGo
0000I_oonfX8o`0000gooo]Z1?l0002OoookJP00Q_oonfX6o`0000oooo]Z1?l0001noookJPGo0000
I_oonfX9o`0000cooo]Z1?l0002OoookJP00QooonfX6o`0000kooo]Z1?l0001noookJPGo0000JOoo
nfX6o`0000cooo]Z1?l0002OoookJP00R?oonfX5o`0000kooo]Z1?l0001noookJPGo0000J_oonfX6
o`0000_ooo]Z1?l0002OoookJP00R?oonfX6o`0000gooo]Z1?l0001noookJPGo0000JooonfX5o`00
00_ooo]Z1?l0002OoookJP00ROoonfX5o`0000gooo]Z1?l0001noookJPGo0000JooonfX6o`0000[o
oo]Z1?l0002OoookJP00ROoonfX6o`0000cooo]Z1?l0001noookJPGo0000K?oonfX6o`0000Wooo]Z
1?l0002OoookJP00R_oonfX5o`0000cooo]Z1?l0001noookJPGo0000K?oonfX6o`0000Wooo]Z1?l0
002OoookJP00R_oonfX6o`0000_ooo]Z1?l0001noookJPGo0000KOoonfX6o`0000Sooo]Z1?l0002O
oookJP00RooonfX6o`0000[ooo]Z1?l0001noookJPGo0000K_oonfX5o`0000Sooo]Z1?l0002Ooook
JP00RooonfX;o`0000Gooo]Z1?l0001noookJPGo0000K_oonfX8o`0000Gooo]Z1?l0002OoookJP00
S?oonfX;o`0000Cooo]Z1?l0001noookJPGo0000KooonfX7o`0000Gooo]Z1?l0002OoookJP00SOoo
nfX:o`0000Cooo]Z1?l0001noookJPGo0000KooonfX8o`0000Cooo]Z1?l0002OoookJP00S_oonfX9
o`0000Cooo]Z1?l0001noookJPGo0000KooonfX8o`0000Cooo]Z1?l0002OoookJP00SooonfX8o`00
00Cooo]Z1?l0001noookJPGo0000KooonfX@o`0009oooo]Z002@oookJPoo0000O_oonfX5o`00073o
oo]Z3ol0002OoookJP00TOoonfX>o`0007kooo]Z1Ol0001`oookJPoo0000WooonfX009?ooo]Z3?l0
001noookJPGo0000L?oonfX?o`0009oooo]Z002CoookJPco0000O_oonfX5o`0007Cooo]Z2ol0002O
oookJP00TooonfX<o`0007kooo]Z1Ol0001doookJP_o0000WooonfX009Cooo]Z2ol0001noookJPGo
0000M?oonfX;o`0009oooo]Z002DoookJP_o0000O_oonfX5o`0007Cooo]Z2ol0002OoookJP00U?oo
nfX;o`0007kooo]Z1Ol0001doookJP_o0000WooonfX009Cooo]Z2ol0001noookJPGo0000M?oonfX;
o`0009oooo]Z002DoookJP_o0000O_oonfX5o`0007Cooo]Z2ol0002OoookJP00U?oonfX;o`0007ko
oo]Z1Ol0001doookJP_o0000WooonfX009Cooo]Z2ol0001noookJPGo0000M?oonfX;o`0009oooo]Z
002EoookJP[o0000O_oonfX5o`0007Gooo]Z2_l0002OoookJP00V?oonfX7o`0007kooo]Z1Ol0001h
oookJPOo0000WooonfX009Sooo]Z1ol0001aoookJP?o001o2_oonfX5o`0007Sooo]Z1ol0002Ooook
JP00V?oonfX7o`00077ooo]Z0ol007l:oookJPGo0000N?oonfX7o`0009oooo]Z002IoookJPKo0000
LOoonfX3o`00O`[ooo]Z1Ol0001ioookJPKo0000WooonfX009Wooo]Z1_l0001aoookJP?o001o2_oo
nfX5o`0007Wooo]Z1_l0002OoookJP00VOoonfX6o`00077ooo]Z0ol007l:oookJPKo0000N?oonfX6
o`0009oooo]Z002IoookJPKo0000LOoonfX3o`00O`[ooo]Z1Ol0001ioookJPKo0000WooonfX009Wo
oo]Z1_l0001aoookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX6o`00077ooo]Z
0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z1Ol0
001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001_oookJPKo001o2_oonfX5o`0007Wooo]Z1Ol0002P
oookJP00VOoonfX5o`0006oooo]Z1_l007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo
0000LOoonfX4o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001boookJP?o001o
2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007oooo]Z1Ol0001ioookJPGo0000X?oo
nfX009Wooo]Z1Ol0001ooookJPGo0000NOoonfX5o`000:3ooo]Z002JoookJPCo0000OooonfX5o`00
07Wooo]Z1?l0002QoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2
oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXNoook
JP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l9oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l007l:
oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoook
JP00o_oonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00oooonfX1oookJPCo001o
2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooo
nfXOoookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4o`00
O`cooo]Z1Ol0003ooookJQoooo]Z003ooookJPoooo]Z1Ol007l:oookJPKo0000oooonfXNoookJP00
oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z1Ol0
003ooookJQoooo]Z003ooookJQ?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oook
JP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z
3OoonfX4o`00O`;ooo]Z0ol007oooookJRcooo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z003o
oookJPoooo]Z1Ol007oooookJRkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30834 L
.02605 .30812 L
.02729 .30848 L
.02846 .3092 L
.02954 .30977 L
.03053 .30992 L
.03163 .30958 L
.03279 .30887 L
.03395 .30826 L
.0352 .30818 L
.03638 .3087 L
.03746 .30939 L
.03873 .30993 L
.03944 .30994 L
.04011 .30975 L
.04132 .30905 L
.04262 .30835 L
.04327 .3082 L
.04396 .30826 L
.04519 .30883 L
.04588 .30929 L
.04663 .30974 L
.04733 .31002 L
.04797 .31009 L
.04921 .30971 L
.05038 .309 L
.05164 .30842 L
.05236 .30837 L
.05302 .30854 L
.05415 .30918 L
.05537 .30998 L
.05653 .31034 L
.05759 .31015 L
.05871 .30953 L
.0599 .30888 L
.06111 .30869 L
.0618 .30889 L
.06244 .30924 L
.06372 .31014 L
.06437 .31051 L
.06508 .31075 L
.06585 .31074 L
.06657 .31049 L
.06723 .31013 L
.06793 .30971 L
.0686 .30937 L
.06932 .30918 L
.07064 .30947 L
.07193 .31034 L
Mistroke
.07312 .31114 L
.07439 .31142 L
.07558 .31103 L
.07666 .31042 L
.07782 .30995 L
.07908 .31009 L
.07972 .31045 L
.08042 .31097 L
.08157 .31185 L
.08282 .31234 L
.08358 .31228 L
.08428 .31201 L
.08495 .31164 L
.08566 .31125 L
.0869 .31092 L
.0876 .31105 L
.08826 .31139 L
.08897 .31193 L
.08972 .31257 L
.09037 .31307 L
.09106 .31344 L
.09181 .3136 L
.0925 .31349 L
.09333 .31313 L
.09408 .31272 L
.09474 .31242 L
.09543 .31226 L
.09667 .31259 L
.09737 .31308 L
.09801 .31365 L
.09877 .31433 L
.09948 .31485 L
.10077 .3152 L
.10194 .31484 L
.10321 .3142 L
.10392 .31399 L
.10458 .314 L
.10573 .31457 L
.10694 .31569 L
.10801 .31666 L
.10916 .31719 L
.11041 .31701 L
.11157 .31645 L
.11229 .31617 L
.11296 .31609 L
.11422 .31659 L
.12446 .32084 L
.14288 .32926 L
.18131 .35343 L
.19156 .36113 L
Mistroke
.20116 .37068 L
.21118 .38344 L
.2222 .40177 L
.23259 .41589 L
.24246 .42712 L
.24352 .42424 L
.24467 .42471 L
.24575 .42988 L
.24675 .43752 L
.24792 .44615 L
.24915 .4499 L
.25018 .44692 L
.25132 .43929 L
.25257 .43239 L
.25328 .43236 L
.25392 .43581 L
.25516 .45161 L
.25634 .47129 L
.25749 .48274 L
.25857 .47502 L
.25974 .43874 L
.26099 .37046 L
.26223 .28704 L
.26337 .21415 L
.26457 .16001 L
.26588 .13577 L
.26702 .14057 L
.26805 .15629 L
.26918 .17437 L
.27037 .18512 L
.27167 .18399 L
.27286 .176 L
.27415 .16892 L
.27488 .16823 L
.27557 .17018 L
.27681 .17845 L
.27793 .18733 L
.27924 .19357 L
.28048 .19345 L
.28163 .18996 L
.28268 .18712 L
.28388 .18726 L
.28502 .19139 L
.28608 .19722 L
.28707 .20225 L
.2881 .20531 L
.28923 .2055 L
.29038 .20354 L
.29162 .20182 L
.29276 .20274 L
Mistroke
.29381 .20603 L
.29503 .21134 L
.29567 .21393 L
.29635 .21602 L
.2976 .21749 L
.29876 .2166 L
.29996 .21526 L
.30128 .21568 L
.30252 .21873 L
.30367 .22291 L
.30481 .22657 L
.30585 .22835 L
.30704 .2284 L
.30817 .22746 L
.3094 .2271 L
.3107 .22886 L
.31181 .23198 L
.31303 .23575 L
.31434 .23841 L
.31507 .23891 L
.31575 .23882 L
.31705 .23802 L
.31829 .23798 L
.31933 .2393 L
.32049 .24209 L
.32162 .24519 L
.32284 .24763 L
.32397 .24841 L
.32501 .24811 L
.326 .24762 L
.32705 .24773 L
.32819 .24911 L
.32941 .25183 L
.33046 .25437 L
.3316 .25636 L
.3323 .25693 L
.33294 .25704 L
.33421 .25658 L
.33536 .25634 L
.33658 .25723 L
.34673 .26734 L
.35637 .27566 L
.37446 .28734 L
.38454 .29262 L
.38576 .29252 L
.38707 .29198 L
.38831 .29188 L
.38945 .29256 L
.39157 .29506 L
.39277 .29608 L
Mistroke
.3939 .29627 L
.39503 .29589 L
.39625 .29541 L
.39755 .29556 L
.39874 .29651 L
.4 .29795 L
.40067 .29863 L
.40138 .29914 L
.40269 .29933 L
.40389 .29886 L
.40518 .29837 L
.4059 .29838 L
.40656 .29864 L
.40779 .29967 L
.40907 .30101 L
.40976 .30156 L
.41049 .30189 L
.4118 .30177 L
.41261 .3014 L
.41337 .30103 L
.41405 .30084 L
.41479 .30087 L
.41602 .30155 L
.41715 .30262 L
.41845 .30372 L
.41969 .30407 L
.42083 .30373 L
.42188 .30319 L
.42304 .30284 L
.42427 .30315 L
.43469 .30598 L
.4359 .30685 L
.43703 .30711 L
.43821 .30675 L
.4395 .30604 L
.44081 .30568 L
.44154 .30582 L
.44221 .30616 L
.4435 .30715 L
.44469 .30792 L
.44537 .30811 L
.4461 .30807 L
.44682 .30779 L
.44762 .30734 L
.44831 .30696 L
.44905 .30667 L
.44975 .30661 L
.45039 .30676 L
.45184 .30766 L
.45255 .30819 L
Mistroke
.4532 .30858 L
.45442 .30886 L
.45506 .30872 L
.45574 .3084 L
.45684 .30775 L
.45802 .30729 L
.45931 .30746 L
.46051 .3082 L
.46117 .30866 L
.46188 .30909 L
.46317 .30935 L
.46443 .3089 L
.46559 .3082 L
.46668 .30774 L
.4677 .30776 L
.46882 .30828 L
.47003 .3091 L
.47122 .30963 L
.47248 .30952 L
.47356 .30896 L
.47473 .30826 L
.47541 .30801 L
.47613 .30795 L
.47746 .30844 L
.47874 .30928 L
.47993 .30979 L
.48121 .30968 L
.48194 .30932 L
.48262 .3089 L
.48333 .30847 L
.484 .30818 L
.48477 .30807 L
.48547 .30821 L
.48667 .30885 L
.48795 .30962 L
.48916 .30991 L
.49025 .30961 L
.49154 .30883 L
.49222 .30844 L
.49294 .30817 L
.49425 .30826 L
.49546 .3089 L
.49669 .30964 L
.49738 .30987 L
.49802 .30991 L
.49919 .30951 L
.50044 .30874 L
.50155 .30821 L
.50259 .30815 L
.50374 .30862 L
Mistroke
.50497 .3094 L
.50627 .3099 L
.50701 .30988 L
.50769 .30964 L
.50894 .30889 L
.50958 .30851 L
.51028 .30822 L
.51159 .30823 L
.51283 .30886 L
.51403 .30961 L
.51514 .30996 L
.51621 .30978 L
.51736 .30915 L
.51852 .30847 L
.51979 .3082 L
.52111 .30866 L
.52235 .30947 L
.52357 .31003 L
.5247 .31 L
.52574 .30952 L
.52672 .30891 L
.5278 .30843 L
.52896 .30845 L
.53011 .30903 L
.53132 .30984 L
.53236 .31029 L
.53349 .31025 L
.53472 .30965 L
.53602 .3089 L
.5367 .3087 L
.53745 .30871 L
.53877 .30933 L
.54001 .3102 L
.54071 .31058 L
.54134 .31076 L
.54258 .31057 L
.54375 .30993 L
.54487 .30934 L
.54607 .3092 L
.5472 .30967 L
.54822 .31041 L
.54942 .31119 L
.55072 .31141 L
.55195 .31094 L
.55308 .31029 L
.5543 .30991 L
.5556 .31025 L
.55682 .31114 L
.55794 .31196 L
.55925 .31235 L
Mistroke
.56 .31221 L
.56068 .3119 L
.56132 .31154 L
.56202 .31118 L
.56327 .31093 L
.56457 .31147 L
.56575 .31243 L
.56644 .31299 L
.56709 .31337 L
.56776 .31358 L
.56849 .31354 L
.56921 .31329 L
.56989 .31293 L
.57117 .31234 L
.57188 .31226 L
.57254 .31243 L
.57326 .31285 L
.57403 .31349 L
.57524 .31456 L
.57656 .31518 L
.57781 .31498 L
.57897 .3144 L
.58011 .31399 L
.58115 .31412 L
.58235 .31494 L
.58348 .31603 L
.58472 .31698 L
.58602 .31718 L
.58714 .31677 L
.58836 .31621 L
.58967 .31619 L
.59041 .31659 L
.59108 .31717 L
.59232 .31847 L
.59362 .31949 L
.59474 .31967 L
.59597 .31924 L
.59709 .31876 L
.59814 .31871 L
.59937 .31944 L
.6005 .32066 L
.60182 .32205 L
.60304 .32266 L
.6041 .32252 L
.60522 .32203 L
.60647 .32174 L
.6076 .32219 L
.60868 .32326 L
.60984 .32471 L
.61093 .32579 L
Mistroke
.61194 .3262 L
.6218 .33017 L
.62306 .32968 L
.62369 .32958 L
.62439 .32973 L
.62515 .33027 L
.62586 .3311 L
.62722 .3331 L
.62851 .33463 L
.62969 .33513 L
.63099 .3348 L
.63171 .33453 L
.63236 .33442 L
.63355 .33491 L
.63483 .33649 L
.63602 .33844 L
.63712 .33991 L
.63841 .3406 L
.63909 .34053 L
.6398 .34027 L
.64101 .33995 L
.64169 .34009 L
.64233 .34055 L
.65143 .34732 L
.66973 .36409 L
.68939 .38937 L
.70914 .41538 L
.71039 .41305 L
.71103 .41232 L
.71172 .41248 L
.71247 .41407 L
.71317 .41686 L
.71451 .42413 L
.71579 .42993 L
.71695 .43135 L
.71759 .43037 L
.71829 .42833 L
.71956 .42451 L
.72026 .42385 L
.72103 .42523 L
.72184 .42918 L
.72259 .43468 L
.7233 .44045 L
.72405 .44582 L
.72469 .44887 L
.72539 .44989 L
.72671 .44498 L
.72793 .43639 L
.72862 .43281 L
.72925 .43197 L
Mistroke
.72998 .43485 L
.73066 .44161 L
.73186 .46022 L
.73317 .47951 L
.73383 .48294 L
.73454 .4784 L
.73582 .44345 L
.73709 .37584 L
.7383 .29473 L
.73938 .22484 L
.74057 .1668 L
.74186 .13727 L
.74257 .13549 L
.74323 .14084 L
.74442 .15936 L
.7457 .17852 L
.74638 .18425 L
.74712 .18611 L
.7479 .18379 L
.74862 .17919 L
.74991 .17063 L
.75063 .1683 L
.75129 .16859 L
.75248 .17451 L
.75375 .18451 L
.75482 .19145 L
.75601 .19419 L
.75728 .19176 L
.758 .18937 L
.75865 .18754 L
.75992 .18699 L
.76113 .191 L
.76224 .19704 L
.76328 .20234 L
.76448 .20557 L
.76557 .20532 L
.76678 .20313 L
.76809 .20177 L
.7693 .20361 L
.77042 .20779 L
.77168 .21326 L
.77288 .21673 L
.77396 .21747 L
.77512 .21638 L
.77639 .21513 L
.77703 .21522 L
.77774 .21614 L
.77899 .21971 L
.78016 .22399 L
.78128 .22721 L
Mistroke
.78245 .22858 L
.78345 .22825 L
.78454 .22732 L
.78572 .22717 L
.78698 .22909 L
.78817 .23254 L
.78926 .23586 L
.79055 .23844 L
.7912 .2389 L
.79191 .23883 L
.79318 .23806 L
.79436 .23791 L
.79507 .23857 L
.79575 .23976 L
.79703 .24305 L
.79774 .24501 L
.79841 .24658 L
.79919 .24783 L
.79989 .24835 L
.80109 .24817 L
.80238 .24758 L
.80359 .248 L
.80469 .24972 L
.8061 .25307 L
.80679 .25468 L
.80743 .25586 L
.80863 .25698 L
.80992 .2568 L
.81101 .25636 L
.81221 .25664 L
.81347 .25835 L
.81464 .26085 L
.81589 .26336 L
.81707 .26467 L
.81773 .26484 L
.81844 .2647 L
.81969 .26423 L
.82089 .26443 L
.82198 .26563 L
.82323 .26796 L
.82441 .27019 L
.82551 .27151 L
.82652 .27184 L
.82763 .27154 L
.8288 .2712 L
.83008 .27175 L
.83126 .27333 L
.83252 .27559 L
.83319 .27667 L
.83389 .27752 L
Mistroke
.83516 .27809 L
.83634 .27778 L
.83744 .27744 L
.83865 .27777 L
.83934 .27842 L
.84005 .27942 L
.84134 .28151 L
.84201 .28246 L
.84272 .2832 L
.84351 .28358 L
.84424 .28357 L
.84491 .28335 L
.84565 .28306 L
.84634 .28291 L
.84698 .283 L
.84819 .28391 L
.84948 .2857 L
.85069 .28739 L
.852 .28838 L
.85325 .28832 L
.8544 .28786 L
.85555 .28772 L
.85658 .28824 L
.85778 .28959 L
.85891 .29112 L
.86014 .29235 L
.86144 .29265 L
.86256 .29227 L
.86378 .29185 L
.86509 .29213 L
.86583 .29274 L
.8665 .2935 L
.86773 .29502 L
.86904 .29612 L
.87015 .29626 L
.87138 .29581 L
.8725 .2954 L
.87355 .29548 L
.87478 .29636 L
.87591 .29762 L
.87714 .29886 L
.87845 .29937 L
.87951 .29912 L
.88065 .2986 L
.88189 .29835 L
.88303 .29882 L
.88409 .29979 L
.88509 .30084 L
.88618 .3017 L
.88735 .30194 L
Mistroke
.88799 .30177 L
.88869 .30145 L
.88997 .30089 L
.89121 .30094 L
.89236 .30168 L
.89349 .30276 L
.89471 .30375 L
.89586 .30407 L
.89691 .30378 L
.89805 .3032 L
.89926 .30284 L
.9005 .30317 L
.9012 .30368 L
.90186 .30426 L
.90254 .30488 L
.90319 .30536 L
.9044 .30577 L
.9057 .30543 L
.90644 .30503 L
.90712 .30469 L
.90817 .30444 L
.90931 .30477 L
.91038 .30555 L
.91136 .30637 L
.91251 .30702 L
.91376 .30701 L
.91494 .30645 L
.91604 .30588 L
.91727 .3057 L
.91844 .30619 L
.91948 .30699 L
.92061 .30779 L
.92185 .30813 L
.92315 .30772 L
.92427 .30708 L
.92549 .30662 L
.9268 .30685 L
.928 .30764 L
.92869 .30815 L
.92933 .30855 L
.93 .30881 L
.93073 .30885 L
.93198 .30838 L
.93312 .3077 L
.93438 .30727 L
.9357 .30756 L
.93681 .30828 L
.938 .30905 L
.93912 .30936 L
.94014 .30914 L
Mistroke
.94136 .30845 L
.9425 .30785 L
.94369 .30772 L
.945 .30828 L
.9463 .30915 L
.94703 .30951 L
.94769 .30967 L
.94896 .3094 L
.95017 .30869 L
.95084 .3083 L
.95156 .30802 L
.95284 .30807 L
.95363 .30844 L
.95438 .30892 L
.95504 .30934 L
.95576 .30969 L
.957 .30979 L
.95831 .30922 L
.95953 .30846 L
.96065 .30808 L
.96196 .30833 L
.96269 .30873 L
.96337 .30918 L
.96459 .3098 L
.96528 .30991 L
.96592 .30981 L
.96713 .30921 L
.96844 .30842 L
.96968 .30811 L
.97081 .30841 L
.97206 .30917 L
.97278 .30959 L
.97343 .30984 L
.97412 .30992 L
.97486 .30975 L
.97555 .30942 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00W_oonfX4o`0007_ooo]Z1Ol0001noookJPCo0000W?oonfX009kooo]Z1?l0001koookJPGo
0000O_oonfX4o`0009cooo]Z002NoookJPGo0000N_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oo
nfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001joookJPGo0000O_oonfX5
o`0009_ooo]Z002NoookJPGo0000N_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0007[o
oo]Z1Ol0001noookJPGo0000VooonfX009gooo]Z1_l0001]oookJP?o001o2_oonfX5o`0007kooo]Z
1Ol0002KoookJP00WOoonfX6o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z002M
oookJPKo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000VooonfX009gooo]Z1_l0001Moook
JP[o001o1_oonfX3o`00O`[ooo]Z1Ol0001moookJPKo0000VooonfX009gooo]Z1_l0001MoookJP[o
001o1_oonfX3o`00O`[ooo]Z1_l0001loookJPKo0000VooonfX009gooo]Z1_l0001]oookJP?o001o
2_oonfX5o`0007gooo]Z1_l0002KoookJP00WOoonfX6o`0006gooo]Z0ol007l:oookJPGo0000OOoo
nfX6o`0009_ooo]Z002MoookJPKo0000KOoonfX3o`00O`[ooo]Z1Ol0001moookJPKo0000VooonfX0
09gooo]Z1_l0001]oookJP?o001o2_oonfX5o`0007gooo]Z1_l0002KoookJP00WOoonfX6o`0006[o
oo]Z1_l007l:oookJPGo0000OOoonfX6o`0009_ooo]Z002MoookJPOo0000JOoonfX6o`00O`[ooo]Z
1Ol0001moookJPKo0000VooonfX009gooo]Z2_l0001XoookJPCo001o2_oonfX5o`0007gooo]Z2_l0
002GoookJP00WOoonfX:o`0006Wooo]Z0ol007l:oookJPGo0000OOoonfX:o`0009Oooo]Z002Moook
JP[o0000M_oonfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX:o`0007Kooo]Z1Ol0001moookJP_o
0000U_oonfX009gooo]Z2ol0001eoookJPGo0000OOoonfX;o`0009Kooo]Z002MoookJP_o0000MOoo
nfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX;o`0007Gooo]Z1Ol0001moookJP_o0000U_oonfX0
09gooo]Z2ol0001eoookJPGo0000OOoonfX<o`0009Gooo]Z002MoookJPco0000M?oonfX5o`0007go
oo]Z3?l0002EoookJP00WOoonfX<o`0007Cooo]Z1Ol0001moookJPco0000UOoonfX009gooo]Z3ol0
001aoookJPGo0000OOoonfX?o`0009;ooo]Z002MoookJPoo0000LOoonfX5o`0007gooo]Z3ol0002B
oookJP00WOoonfX?o`00077ooo]Z1Ol0001moookJQ3o0000TOoonfX009gooo]Z1?l00004oookJPOo
0000LOoonfX5o`0007gooo]Z1?l00004oookJPSo0000TOoonfX009gooo]Z1?l00004oookJPSo0000
L?oonfX5o`0007gooo]Z1?l00004oookJPSo0000TOoonfX009gooo]Z1?l00004oookJPSo0000L?oo
nfX5o`0007gooo]Z1?l00004oookJPSo0000TOoonfX009gooo]Z1?l00004oookJPSo0000L?oonfX5
o`0007gooo]Z1?l00004oookJPSo0000TOoonfX009gooo]Z1?l00008oookJPGo0000KooonfX5o`00
07gooo]Z1?l00005oookJPSo0000T?oonfX009gooo]Z1?l00008oookJPSo0000K?oonfX5o`0007go
oo]Z1?l00008oookJPOo0000S_oonfX009gooo]Z1?l00008oookJPSo0000K?oonfX5o`0007gooo]Z
1?l00008oookJPSo0000SOoonfX009gooo]Z1?l00009oookJPOo0000K?oonfX5o`0007gooo]Z1?l0
0009oookJPOo0000SOoonfX009gooo]Z1?l00009oookJPOo0000K?oonfX5o`0007gooo]Z1?l00009
oookJPSo0000S?oonfX009gooo]Z1?l00009oookJPSo0000JooonfX5o`0007gooo]Z1?l00009oook
JPSo0000S?oonfX009gooo]Z1?l00009oookJPSo0000JooonfX5o`0007gooo]Z1?l00009oookJPSo
0000S?oonfX009gooo]Z1?l0000<oookJPGo0000JooonfX5o`0007gooo]Z1?l0000=oookJPCo0000
S?oonfX009gooo]Z1?l0000=oookJPOo0000J?oonfX5o`0007gooo]Z1?l0000=oookJPOo0000ROoo
nfX009gooo]Z1?l0000=oookJPOo0000J?oonfX5o`0007gooo]Z1?l0000=oookJPSo0000R?oonfX0
09gooo]Z1?l0000=oookJPSo0000IooonfX5o`0007gooo]Z1?l0000=oookJPSo0000R?oonfX009go
oo]Z1?l0000=oookJPSo0000IooonfX5o`0007gooo]Z1?l0000=oookJPSo0000R?oonfX009gooo]Z
1?l0000>oookJPSo0000I_oonfX5o`0007gooo]Z1?l0000>oookJPOo0000R?oonfX009gooo]Z1?l0
000AoookJPGo0000I_oonfX5o`0007gooo]Z1?l0000AoookJPGo0000QooonfX009gooo]Z1?l0000A
oookJPGo0000B?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0007gooo]Z1?l0000A
oookJPGo0000QooonfX009gooo]Z1?l0000BoookJPOo0000A?oonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o2OoonfX5o`0007gooo]Z1?l0000AoookJPSo0000Q?oonfX009gooo]Z1?l0000BoookJPOo
0000A?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001moookJPCo00004_oonfX8o`0008?ooo]Z002Moook
JPCo00004_oonfX8o`0003Kooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o2?oonfX5o`0007gooo]Z1?l0000BoookJPSo0000PooonfX009gooo]Z1?l0000CoookJPOo
0000=_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001loookJPCo
00004_oonfX8o`0008?ooo]Z002MoookJPCo00005OoonfX6o`00047ooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Sooo]Z1Ol0001moookJPCo00005_oonfX5o`0008;ooo]Z002MoookJPCo00005_oo
nfX5o`00047ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000OOoo
nfX4o`0001Kooo]Z2?l0001ooookJP00WOoonfX4o`0001Kooo]Z2?l0000noookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l9oookJPGo0000OOoonfX4o`0001Kooo]Z2?l0001ooookJP00WOoonfX4o`00
01Oooo]Z1ol0000noookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000OOoonfX4o`00
01Oooo]Z1ol0001ooookJP00WOoonfX4o`0001Oooo]Z2?l0000moookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Oooo]Z2?l0001noookJP00WOoonfX4o`0001Oooo]Z
2?l0000noookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001moookJPCo
00005ooonfX8o`0007kooo]Z002MoookJPCo00006_oonfX5o`0003kooo]Z1ol007l9oookJPOo001o
2?oonfX5o`0007gooo]Z1?l0000JoookJPKo0000OOoonfX009gooo]Z1?l0000KoookJPOo0000??oo
nfX5o`00O`[ooo]Z1ol007l8oookJPGo0000OOoonfX4o`0001_ooo]Z2?l0001joookJP00WOoonfX4
o`0001_ooo]Z2?l0001IoookJPGo0000OOoonfX4o`0001_ooo]Z2?l0001joookJP00W?oonfX5o`00
01_ooo]Z2Ol0001HoookJPGo0000OOoonfX4o`0001cooo]Z1ol0001joookJP00W?oonfX5o`0001co
oo]Z2?l0001HoookJPGo0000OOoonfX4o`0001cooo]Z2?l0001ioookJP00W?oonfX5o`0001oooo]Z
2?l0001EoookJPGo0000OOoonfX4o`0001oooo]Z2?l0001foookJP00W?oonfX4o`00027ooo]Z2?l0
001DoookJPGo0000OOoonfX4o`0001oooo]Z2?l0001foookJP00W?oonfX4o`00027ooo]Z2Ol0001C
oookJPGo0000OOoonfX4o`00023ooo]Z2?l0001eoookJP00W?oonfX4o`0002;ooo]Z2Ol0001Boook
JPGo0000O?oonfX5o`00023ooo]Z2Ol0001doookJP00W?oonfX4o`0002;ooo]Z2_l0001AoookJPGo
0000O?oonfX5o`00027ooo]Z2?l0001doookJP00W?oonfX4o`0002Kooo]Z1ol0001@oookJPGo0000
O?oonfX5o`0002Cooo]Z2?l0001aoookJP00W?oonfX4o`0002Oooo]Z1ol0001?oookJPGo0000O?oo
nfX4o`0002Kooo]Z1ol0001aoookJP00W?oonfX4o`0002Sooo]Z1ol0001>oookJPGo0000O?oonfX4
o`0002Kooo]Z2?l0001`oookJP00W?oonfX4o`0002Wooo]Z1ol0001=oookJPGo0000O?oonfX4o`00
02Oooo]Z2?l0001_oookJP008_oonfX3o`00OgGooo]Z0_l007l4o`0000?ooo]Z0ol007l3oookJPGo
001o7?oonfX7o`0004cooo]Z1Ol0001doookJPGo001o0ooonfX4o`0000?ooo]Z1Ol007lQoookJPWo
0000C?oonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`Co00000ooonfX3o`00O`;ooo]Z
1ol007lLoookJPOo0000BooonfX5o`0007?ooo]Z1ol007l2oookJPCo00000_oonfX7o`00Ob7ooo]Z
2Ol0001;oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o1?l00003oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lMoookJPSo0000BOoonfX5o`0007?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l2oookJPCo000000?ooo]Zo`00Ool007l00_l007l01?oonf[o
001oo`00Ool007lRoookJPSo0000BooonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOo
oo]Z2_l007l2oookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP04oookJP?o
001o0ooonfX3o`00Oagooo]Z2Ol00017oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o
0000o`000002o`000004oookJ_l007oo001oo`00O`?ooo]Z0ol007lQoookJPco0000AooonfX3o`00
Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o00?ooo]Zo`000?l0
00000_l000000ol007oooo]ZoookJP0:oookJP?o001o7_oonfX9o`0004Kooo]Z1Ol0001boookJP?o
001o0ooonfX3o`00O`03oookJ_l0003o000000;o00001ooonfX3o`00ObGooo]Z2?l00017oookJP?o
001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]Z
oookJP0:oookJP?o001o7ooonfX:o`0004Cooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oook
J_l0003o000000;o00001ooonfX3o`00ObGooo]Z2Ol00016oookJP?o001o7OoonfX002;ooo]Z0ol0
07mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP05oookJP;o001o0_oo
nfX4o`00Ob7ooo]Z2_l00012oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`00
0002o`0000;ooo]Z0_l007l2oookJPCo001o9_oonfX<o`0004;ooo]Z0ol007lMoookJP008_oonfX3
o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z1ol007lT
oookJPWo0000@OoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002
oookJPOo001o:_oonfX9o`0004;ooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooo
nf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z1_l007lVoookJP[o0000?ooonfX5o`00
07;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJPKo001o;?oonfX<o`00
03kooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003
o`00Oooonf[ooo]Z00Gooo]Z0_l007l/oookJP[o0000?OoonfX5o`0007;ooo]Z0ol007l3oookJP?o
001o00?ooo]Zo`000?l000000_l00002oookJP;o001o<?oonfX<o`0003_ooo]Z1_l007lMoookJP00
7ooonfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z0_l007l^oookJPWo0000??oonfX5o`0007?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l2oookJPCo00000_oonfX2o`00OcCooo]Z2_l0000ioookJPKo
001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o1?l00009oookJPOo001o:OoonfX<o`0003Sooo]Z
1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z1ol007l_oookJPco0000>?oonfX4o`00Oagooo]Z
000RoookJP?o001oMOoonfX2o`00O`Co00002OoonfX7o`00Ob_ooo]Z2ol0000goookJPGo0000M?oo
nfX5o`00O`?ooo]Z1?l00003oookJPOo001o<?oonfX<o`0003Sooo]Z0ol007lMoookJP00W?oonfX4
o`0003gooo]Z3Ol0000coookJPGo0000O?oonfX4o`0003gooo]Z3Ol0001DoookJP00W?oonfX4o`00
03kooo]Z4?l0000_oookJPGo0000O?oonfX4o`0003kooo]Z4?l0001@oookJP00W?oonfX4o`0004;o
oo]Z3Ol0000^oookJPGo0000O?oonfX4o`0004;ooo]Z3Ol0001?oookJP00W?oonfX4o`0004?ooo]Z
4?l0000ZoookJPGo0000O?oonfX4o`0004?ooo]Z4Ol0001:oookJP00W?oonfX4o`0004Oooo]Z5?l0
000RoookJPGo0000O?oonfX4o`0004Oooo]Z4_l00015oookJP00W?oonfX4o`0004Sooo]Z6_l0000K
oookJPGo0000O?oonfX4o`0004Oooo]Z6ol0000loookJP003_oonf[oo`000?oo00009Ol0000?oook
JP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oo
nf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP007OoonfX00ol0
003ooo]Zo`000007o`000003oookJ_l0003o000002Oo0000BooonfX4o`0007Oooo]Z1?l000000ooo
nf[o0000o`000006o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000_l000000ooo
nf[o0000o`00000Qo`0004cooo]Z1?l0001goookJPCo000000?ooo]Zo`000?l000000_l0000Noook
JP00>_oonfXJo`0004Sooo]Z1?l0001moookJPGo00006_oonfXJo`0004Sooo]Z1?l0002NoookJP00
@?oonfXFo`0004Kooo]Z1?l0001moookJPGo00008?oonfXEo`0004Oooo]Z1?l0002NoookJP00B?oo
nfX@o`0004Cooo]Z1?l0001moookJPGo0000:?oonfXAo`0004?ooo]Z1?l0002NoookJP00C_oonfX<
o`0004;ooo]Z1?l0001moookJPGo0000;OoonfX=o`0004;ooo]Z1?l0002NoookJP00DOoonfX;o`00
043ooo]Z1?l0001moookJPGo0000;_oonfX?o`0003oooo]Z1?l0002NoookJP00DooonfX;o`0003ko
oo]Z1?l0001moookJPGo0000<_oonfX>o`0003cooo]Z1?l0002NoookJP00EOoonfX;o`0003_ooo]Z
1Ol0001moookJPGo0000=_oonfX<o`0003[ooo]Z1?l0002NoookJP00EooonfX:o`0003[ooo]Z1Ol0
001moookJPGo0000=ooonfX<o`0003Wooo]Z1?l0002NoookJP00FOoonfX:o`0003Sooo]Z1Ol0001m
oookJPGo0000>_oonfX:o`0003Sooo]Z1?l0002NoookJP00FooonfX:o`0003Kooo]Z1?l0001noook
JPGo0000?OoonfX:o`0003Gooo]Z1?l0002NoookJP00GOoonfX9o`0003Gooo]Z1?l0001noookJPGo
0000?ooonfX9o`0003?ooo]Z1Ol0002NoookJP00G_oonfX:o`0003?ooo]Z1?l0001noookJPGo0000
@?oonfX9o`0003;ooo]Z1Ol0002NoookJP00H?oonfX:o`00037ooo]Z1?l0001noookJPGo0000@Ooo
nfX<o`0002kooo]Z1Ol0002NoookJP00H_oonfX9o`00033ooo]Z1?l0001noookJPGo0000A?oonfX:
o`0002gooo]Z1?l0002OoookJP00HooonfX:o`0002kooo]Z1?l0001noookJPGo0000AOoonfX:o`00
02cooo]Z1?l0002OoookJP00IOoonfX9o`0002gooo]Z1?l0001noookJPGo0000AOoonfX;o`0002_o
oo]Z1?l0002OoookJP00IooonfX9o`0002_ooo]Z1?l0001noookJPGo0000B_oonfX8o`0002Wooo]Z
1?l0002OoookJP00J?oonfX:o`0002Wooo]Z1?l0001noookJPGo0000BooonfX8o`0002Sooo]Z1?l0
002OoookJP00J_oonfX9o`0002Sooo]Z1?l0001noookJPGo0000C?oonfX8o`0002Oooo]Z1?l0002O
oookJP00JooonfX:o`0002Kooo]Z1?l0001noookJPGo0000COoonfX8o`0002Kooo]Z1?l0002Ooook
JP00KOoonfX9o`0002Gooo]Z1?l0001noookJPGo0000CooonfX7o`0002Gooo]Z1?l0002OoookJP00
KooonfX9o`0002?ooo]Z1?l0001noookJPGo0000D?oonfX7o`0002Cooo]Z1?l0002OoookJP00L?oo
nfX9o`0002;ooo]Z1?l0001noookJPGo0000DOoonfX7o`0002?ooo]Z1?l0002OoookJP00L_oonfX8
o`00027ooo]Z1?l0001noookJPGo0000D_oonfX7o`0002;ooo]Z1?l0002OoookJP00LooonfX8o`00
023ooo]Z1?l0001noookJPGo0000DooonfX7o`00027ooo]Z1?l0002OoookJP00MOoonfX7o`0001oo
oo]Z1?l0001noookJPGo0000E?oonfX7o`00023ooo]Z1?l0002OoookJP00M_oonfX7o`0001kooo]Z
1?l0001noookJPGo0000EOoonfX6o`00023ooo]Z1?l0002OoookJP00MooonfX7o`0001gooo]Z1?l0
001noookJPGo0000E_oonfX6o`0001oooo]Z1?l0002OoookJP00N?oonfX7o`0001cooo]Z1?l0001n
oookJPGo0000EooonfX6o`0001kooo]Z1?l0002OoookJP00NOoonfX6o`0001cooo]Z1?l0001noook
JPGo0000EooonfX7o`0001gooo]Z1?l0002OoookJP00N_oonfX6o`0001_ooo]Z1?l0001noookJPGo
0000F?oonfX7o`0001cooo]Z1?l0002OoookJP00NooonfX6o`0001[ooo]Z1?l0001noookJPGo0000
FOoonfX6o`0001cooo]Z1?l0002OoookJP00NooonfX7o`0001Wooo]Z1?l0001noookJPGo0000F_oo
nfX6o`0001_ooo]Z1?l0002OoookJP00O?oonfX6o`0001Wooo]Z1?l0001noookJPGo0000FooonfX6
o`0001[ooo]Z1?l0002OoookJP00OOoonfX6o`0001Sooo]Z1?l0001PoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPGo0000FooonfX7o`0001Wooo]Z1?l0002OoookJP00O_oonfX6o`0001Oo
oo]Z1?l0001OoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000G?oonfX6o`0001Wo
oo]Z1?l0002OoookJP00O_oonfX6o`0001Oooo]Z1?l0001OoookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`00
05gooo]Z1_l0000HoookJPCo0000WooonfX007oooo]Z1_l0000FoookJPCo0000G_oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001NoookJPKo00005ooonfX4o`0009oo
oo]Z0020oookJPKo00005OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z
1_l0001MoookJPOo00005_oonfX4o`0009oooo]Z0020oookJPKo00005OoonfX4o`0005kooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001OoookJPOo00005OoonfX4o`0009oooo]Z0021
oookJPKo00005?oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8
oookJPGo0000H?oonfX6o`0001Gooo]Z1?l0002OoookJP00P_oonfX5o`0001Cooo]Z1?l0001Noook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000HOoonfX6o`0001Cooo]Z1?l0002Ooook
JP00P_oonfX6o`0001?ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo
0000H_oonfX6o`0001?ooo]Z1?l0002OoookJP00PooonfX6o`0001;ooo]Z1?l0001NoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000H_oonfX7o`0001;ooo]Z1?l0002OoookJP00Pooo
nfX6o`0001;ooo]Z1?l0001OoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z
1Ol0001SoookJPKo00004_oonfX4o`0009oooo]Z0024oookJPKo00004OoonfX4o`0005oooo]Z1ol0
07l9oookJPOo001o2?oonfX5o`0006Cooo]Z1_l0000AoookJPCo0000WooonfX008Gooo]Z1Ol0000A
oookJPCo0000H?oonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000IOoonfX6o`00013ooo]Z1?l0002O
oookJP00QOoonfX6o`00013ooo]Z1?l0001noookJPGo0000IOoonfX6o`00013ooo]Z1?l0002Ooook
JP00Q_oonfX6o`0000oooo]Z1?l0001noookJPGo0000I_oonfX6o`0000oooo]Z1?l0002OoookJP00
Q_oonfX7o`0000kooo]Z1?l0001noookJPGo0000IooonfX6o`0000kooo]Z1?l0002OoookJP00Qooo
nfX6o`0000kooo]Z1?l0001noookJPGo0000IooonfX7o`0000gooo]Z1?l0002OoookJP00R?oonfX6
o`0000gooo]Z1?l0001noookJPGo0000J?oonfX:o`0000Wooo]Z1?l0002OoookJP00ROoonfX6o`00
00cooo]Z1?l0001noookJPGo0000JOoonfX9o`0000Wooo]Z1?l0002OoookJP00ROoonfX7o`0000_o
oo]Z1?l0001noookJPGo0000J_oonfX9o`0000Sooo]Z1?l0002OoookJP00R_oonfX6o`0000_ooo]Z
1?l0001noookJPGo0000J_oonfX9o`0000Sooo]Z1?l0002OoookJP00RooonfX6o`0000[ooo]Z1?l0
001noookJPGo0000JooonfX8o`0000Sooo]Z1?l0002OoookJP00S?oonfX6o`0000Wooo]Z1?l0001n
oookJPGo0000K?oonfX7o`0000Sooo]Z1?l0002OoookJP00S?oonfX:o`0000Gooo]Z1?l0001noook
JPGo0000KooonfX7o`0000Gooo]Z1?l0002OoookJP00SOoonfX:o`0000Cooo]Z1?l0001noookJPGo
0000KooonfX8o`0000Cooo]Z1?l0002OoookJP00S_oonfX9o`0000Cooo]Z1?l0001noookJPGo0000
KooonfX8o`0000Cooo]Z1?l0002OoookJP00SooonfX8o`0000Cooo]Z1?l0001noookJPGo0000Kooo
nfX8o`0000Cooo]Z1?l0002OoookJP00T?oonfX7o`0000Cooo]Z1?l0001noookJPGo0000KooonfX8
o`0000Cooo]Z1?l0002OoookJP00TOoonfX>o`0007kooo]Z1Ol0001_oookJQ3o0000WooonfX009?o
oo]Z3?l0001noookJPGo0000L?oonfX?o`0009oooo]Z002CoookJPco0000O_oonfX5o`00073ooo]Z
3ol0002OoookJP00TooonfX<o`0007kooo]Z1Ol0001doookJP_o0000WooonfX009?ooo]Z3?l0001n
oookJPGo0000M?oonfX;o`0009oooo]Z002DoookJP_o0000O_oonfX5o`0007Cooo]Z2ol0002Ooook
JP00U?oonfX;o`0007kooo]Z1Ol0001doookJP_o0000WooonfX009Cooo]Z2ol0001noookJPGo0000
M?oonfX;o`0009oooo]Z002DoookJP_o0000O_oonfX5o`0007Cooo]Z2ol0002OoookJP00U?oonfX;
o`0007kooo]Z1Ol0001doookJP_o0000WooonfX009Cooo]Z2ol0001noookJPGo0000M?oonfX;o`00
09oooo]Z002DoookJP_o0000O_oonfX5o`0007Cooo]Z2ol0002OoookJP00UOoonfX:o`0007kooo]Z
1Ol0001eoookJP[o0000WooonfX009Sooo]Z1ol0001noookJPGo0000N?oonfX7o`0009oooo]Z002H
oookJPOo0000LOoonfX3o`00O`[ooo]Z1Ol0001ioookJPKo0000WooonfX009Sooo]Z1ol0001aoook
JP?o001o2_oonfX5o`0007Wooo]Z1_l0002OoookJP00V?oonfX7o`00077ooo]Z0ol007l:oookJPGo
0000NOoonfX6o`0009oooo]Z002HoookJPKo0000L_oonfX3o`00O`[ooo]Z1Ol0001ioookJPKo0000
WooonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX6o`0007Sooo]Z1_l0002OoookJP00VOoonfX5
o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00
O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001boookJP?o001o2_oonfX5o`0007Wo
oo]Z1Ol0002PoookJP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z
002IoookJPGo0000KooonfX6o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001_
oookJPKo001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`00077ooo]Z1?l007l:oook
JPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z1Ol0001ioookJPGo
0000X?oonfX009Wooo]Z1Ol0001ooookJPGo0000NOoonfX5o`000:3ooo]Z002JoookJPCo0000Oooo
nfX5o`0007Wooo]Z1Ol0002PoookJP00V_oonfX4o`0007oooo]Z1Ol0001ioookJPGo0000X?oonfX0
09[ooo]Z1?l0001ooookJPGo0000N_oonfX4o`000:3ooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJP;o
oo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z
0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooo
nfXOoookJP00oooonfX2oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z
003ooookJPgooo]Z1?l007l=oookJPGo0000oooonfXOoookJP00oooonfX>oookJPCo001o3?oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7o
oo]Z1?l007l9oookJPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oo
oookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oookJPCo
001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3_oonfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooo
nfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30969 L
.02605 .3099 L
.02729 .30951 L
.02846 .30879 L
.02954 .30825 L
.03053 .30815 L
.03163 .30855 L
.03279 .30928 L
.03395 .30984 L
.0352 .30982 L
.03638 .30923 L
.03746 .30856 L
.03873 .30817 L
.03944 .30826 L
.04011 .30854 L
.04141 .30937 L
.04262 .30993 L
.04386 .30987 L
.04452 .30958 L
.04521 .30916 L
.04637 .3085 L
.04765 .30829 L
.04879 .30872 L
.05001 .30952 L
.05116 .31009 L
.05221 .31012 L
.05352 .30952 L
.05473 .3088 L
.05536 .30856 L
.05606 .3085 L
.05679 .30867 L
.05747 .30903 L
.05863 .30983 L
.05986 .31042 L
.06051 .31048 L
.06121 .31032 L
.06244 .30966 L
.06311 .30927 L
.06381 .30897 L
.06458 .30887 L
.06529 .30904 L
.06657 .30982 L
.0673 .31035 L
.06797 .31074 L
.06923 .31098 L
.06991 .3108 L
.07057 .31047 L
.07184 .30974 L
.073 .30945 L
Mistroke
.0737 .30958 L
.07435 .3099 L
.07505 .31039 L
.0758 .31097 L
.07645 .3114 L
.07715 .31168 L
.07839 .3116 L
.07909 .31128 L
.07984 .31085 L
.08055 .31048 L
.0812 .3103 L
.08195 .31033 L
.08278 .31068 L
.08355 .31124 L
.08427 .31183 L
.08544 .31258 L
.08669 .31271 L
.08787 .31222 L
.08896 .31164 L
.09016 .31139 L
.09148 .31193 L
.09214 .31245 L
.09285 .31307 L
.09413 .31393 L
.09483 .3141 L
.09548 .31402 L
.09619 .31374 L
.09695 .31334 L
.09821 .31284 L
.09893 .31286 L
.09961 .31313 L
.10085 .31412 L
.10202 .31517 L
.10323 .31577 L
.10388 .31578 L
.10458 .31557 L
.10524 .31525 L
.10593 .3149 L
.10717 .31463 L
.10832 .31508 L
.10958 .31622 L
.11028 .31692 L
.11094 .31746 L
.1117 .31785 L
.11239 .31792 L
.11365 .31751 L
.11435 .31716 L
.11501 .31691 L
.1162 .31697 L
.11751 .31792 L
Mistroke
.11822 .31868 L
.11889 .3194 L
.12016 .32035 L
.12125 .32047 L
.12245 .32002 L
.12372 .31954 L
.12491 .31974 L
.12607 .32071 L
.12733 .32218 L
.12852 .32327 L
.12962 .32358 L
.13061 .32333 L
.13169 .32286 L
.13283 .32271 L
.13389 .32325 L
.14346 .32821 L
.18238 .35484 L
.18732 .35976 L
.18852 .36198 L
.18982 .36294 L
.19056 .36284 L
.19124 .36254 L
.19189 .36228 L
.19257 .36227 L
.19326 .36269 L
.19399 .3637 L
.19469 .36512 L
.19532 .36666 L
.19606 .36852 L
.19686 .37022 L
.19762 .37127 L
.19832 .37167 L
.19965 .37129 L
.20038 .37092 L
.20107 .37084 L
.20171 .37119 L
.20241 .37214 L
.20364 .37504 L
.20481 .3783 L
.20606 .38077 L
.20723 .38136 L
.2083 .3808 L
.20957 .38024 L
.21028 .3806 L
.21094 .38156 L
.21214 .38472 L
.21342 .38875 L
.21465 .39147 L
.21597 .39197 L
.21722 .39096 L
Mistroke
.21836 .39049 L
.21905 .39104 L
.21969 .39228 L
.22039 .39434 L
.22114 .39705 L
.22239 .40144 L
.2231 .4031 L
.22377 .40383 L
.22498 .40329 L
.22628 .40172 L
.22754 .40188 L
.22868 .40473 L
.22981 .40953 L
.23102 .4145 L
.23204 .41683 L
.23317 .41661 L
.23446 .41423 L
.23567 .413 L
.23698 .41562 L
.23771 .41898 L
.23838 .42273 L
.23959 .42907 L
.2409 .43203 L
.24214 .42995 L
.24329 .42613 L
.24434 .42438 L
.24547 .42703 L
.24653 .43396 L
.24751 .44192 L
.24859 .44872 L
.24977 .44978 L
.25101 .44334 L
.25216 .43522 L
.25339 .43253 L
.25455 .44112 L
.25559 .4571 L
.25672 .47557 L
.25795 .48262 L
.25925 .4592 L
.26036 .40946 L
.26159 .33113 L
.2628 .2481 L
.26408 .17699 L
.26482 .15107 L
.26549 .13831 L
.2668 .13893 L
.26802 .15749 L
.26867 .16843 L
.26935 .17793 L
.2706 .18579 L
Mistroke
.27174 .18224 L
.27285 .17433 L
.27404 .16826 L
.27515 .16905 L
.27617 .17509 L
.27737 .18476 L
.27867 .19231 L
.27989 .19334 L
.28103 .19024 L
.28222 .18666 L
.28351 .18668 L
.28473 .1914 L
.28585 .19769 L
.28708 .2033 L
.28778 .2048 L
.28844 .20499 L
.28975 .20299 L
.29049 .20163 L
.29116 .20099 L
.29184 .20129 L
.29255 .20279 L
.29327 .20534 L
.29406 .20881 L
.29474 .2118 L
.29548 .21443 L
.2968 .21657 L
.29746 .21637 L
.29817 .21558 L
.29947 .2142 L
.30074 .21499 L
.30192 .21819 L
.30308 .2225 L
.30416 .22586 L
.3053 .22749 L
.30654 .22712 L
.30779 .22609 L
.30849 .22601 L
.30913 .22654 L
.31036 .2292 L
.31152 .23286 L
.31261 .23594 L
.31377 .23763 L
.31476 .23769 L
.31585 .237 L
.31702 .2367 L
.31828 .23809 L
.31946 .24099 L
.32055 .24401 L
.32182 .24654 L
.32252 .24713 L
Mistroke
.32317 .24719 L
.32442 .2466 L
.3256 .24639 L
.32627 .24684 L
.32697 .24786 L
.32824 .25073 L
.32895 .25251 L
.32962 .25398 L
.3304 .25518 L
.3311 .25572 L
.33229 .25562 L
.33358 .2551 L
.33478 .25548 L
.33589 .25704 L
.34114 .26332 L
.34231 .26294 L
.3434 .26332 L
.34453 .26481 L
.34577 .26726 L
.34703 .2695 L
.34774 .27026 L
.34838 .27057 L
.34961 .27039 L
.35077 .26999 L
.35186 .27023 L
.35303 .27152 L
.35402 .27324 L
.35511 .27518 L
.35628 .27655 L
.35754 .27685 L
.35872 .27644 L
.35981 .27624 L
.36108 .27696 L
.36179 .27787 L
.36243 .2789 L
.3637 .28096 L
.36487 .28218 L
.36553 .28243 L
.36623 .28238 L
.36693 .28214 L
.36771 .28185 L
.36837 .28177 L
.36909 .28197 L
.37038 .28323 L
.37563 .28697 L
.38041 .28991 L
.38969 .29458 L
.39095 .29531 L
.39214 .29517 L
.3928 .29488 L
Mistroke
.39352 .29459 L
.39478 .29453 L
.39597 .29532 L
.39725 .29676 L
.39845 .29799 L
.39954 .2985 L
.40081 .29827 L
.40153 .29793 L
.40218 .29766 L
.4034 .2976 L
.40468 .2984 L
.40535 .29909 L
.40607 .29988 L
.40738 .30096 L
.40817 .30119 L
.40893 .30108 L
.4096 .30081 L
.41034 .30044 L
.41153 .30011 L
.41285 .30056 L
.41351 .3011 L
.41423 .30181 L
.41552 .30297 L
.41674 .30341 L
.41802 .30306 L
.41922 .30247 L
.42032 .30223 L
.42155 .30269 L
.4222 .3032 L
.42288 .30384 L
.42404 .3048 L
.42531 .30521 L
.42644 .30491 L
.42765 .30427 L
.4288 .30394 L
.42985 .30418 L
.43106 .30505 L
.43221 .30602 L
.43353 .30663 L
.43472 .30645 L
.43541 .3061 L
.43605 .30575 L
.43675 .30543 L
.43748 .30528 L
.4387 .30562 L
.43939 .30609 L
.44004 .30662 L
.44126 .30748 L
.44242 .30776 L
.44346 .30746 L
Mistroke
.44459 .30683 L
.44581 .30633 L
.44712 .30652 L
.44823 .30723 L
.44946 .30813 L
.45062 .30857 L
.45168 .30842 L
.45284 .3078 L
.45407 .30717 L
.45514 .30707 L
.45614 .30745 L
.45723 .30821 L
.4584 .30894 L
.45964 .30915 L
.46034 .30894 L
.46099 .3086 L
.46173 .30815 L
.46243 .30778 L
.46374 .30757 L
.46487 .30801 L
.46611 .30885 L
.46743 .30949 L
.46866 .30941 L
.46936 .30908 L
.47011 .30862 L
.47078 .30823 L
.47148 .30795 L
.47212 .30787 L
.47282 .308 L
.47404 .30867 L
.47478 .30916 L
.47547 .30954 L
.47628 .30976 L
.47701 .30969 L
.47769 .30942 L
.47833 .30905 L
.47908 .30857 L
.47977 .30823 L
.48093 .30806 L
.48217 .30853 L
.48333 .30927 L
.48442 .30979 L
.48569 .30976 L
.48688 .30916 L
.48754 .30873 L
.48825 .30835 L
.48955 .30813 L
.49022 .30832 L
.49092 .30869 L
.49219 .30948 L
Mistroke
.49332 .30989 L
.49457 .30967 L
.49582 .30895 L
.49714 .30825 L
.49783 .30813 L
.49859 .30825 L
.49928 .30857 L
.49993 .30897 L
.50124 .30972 L
.50245 .30988 L
.50308 .3097 L
.50377 .30935 L
.5045 .30888 L
.50516 .30849 L
.50641 .30813 L
.50709 .30823 L
.50774 .30851 L
.5089 .30923 L
.51013 .30983 L
.51123 .30986 L
.51245 .30931 L
.51357 .30861 L
.51459 .3082 L
.5158 .30831 L
.51709 .30903 L
.51832 .30976 L
.51943 .30999 L
.52072 .30957 L
.52143 .30914 L
.52209 .30873 L
.52328 .30829 L
.52456 .30851 L
.53016 .30924 L
.53081 .30886 L
.5315 .30858 L
.53274 .30859 L
.53404 .30929 L
.53473 .30976 L
.53547 .31021 L
.53678 .31047 L
.53802 .31003 L
.53915 .30935 L
.54035 .30889 L
.54157 .30908 L
.54269 .30977 L
.54399 .31066 L
.54521 .31099 L
.54626 .31073 L
.54739 .3101 L
.54863 .30952 L
Mistroke
.54977 .30954 L
.55042 .30983 L
.5511 .31029 L
.55233 .31121 L
.55302 .31158 L
.55366 .31173 L
.55436 .31167 L
.55511 .31137 L
.55576 .311 L
.55647 .31061 L
.55775 .31027 L
.559 .3107 L
.56015 .31158 L
.56136 .31245 L
.56265 .31275 L
.56387 .31233 L
.56499 .31171 L
.56624 .31138 L
.56694 .31152 L
.5676 .31188 L
.56901 .31305 L
.5697 .31359 L
.57034 .31394 L
.57166 .31403 L
.57235 .31376 L
.57308 .31337 L
.57427 .31287 L
.57558 .31302 L
.5763 .31348 L
.57697 .31406 L
.57769 .31473 L
.57847 .31536 L
.57919 .31572 L
.57986 .3158 L
.58117 .31538 L
.58246 .31477 L
.58311 .31463 L
.58382 .31473 L
.58508 .31555 L
.58626 .31671 L
.58697 .31735 L
.58764 .31776 L
.58891 .31787 L
.58962 .31761 L
.59027 .31729 L
.59099 .31698 L
.59175 .31685 L
.59293 .31726 L
.59419 .31844 L
.59529 .3196 L
Mistroke
.59648 .3204 L
.59717 .3205 L
.59781 .32037 L
.59849 .32009 L
.59921 .31976 L
.60052 .31954 L
.60171 .32017 L
.62032 .32915 L
.64113 .34165 L
.65027 .3477 L
.66032 .35452 L
.66998 .36336 L
.67901 .37296 L
.6988 .40203 L
.70921 .41679 L
.7191 .42737 L
.72016 .42461 L
.72131 .42565 L
.7224 .43152 L
.7234 .43949 L
.72456 .44773 L
.7258 .45011 L
.72683 .44584 L
.72797 .43769 L
.72922 .43222 L
.72993 .43387 L
.73057 .43912 L
.73181 .45763 L
.73299 .4766 L
.73415 .48259 L
.73522 .46597 L
.73639 .41831 L
.73764 .34088 L
.73884 .25765 L
.74015 .18218 L
.74139 .14252 L
.74255 .13557 L
.74369 .14853 L
.74472 .16623 L
.74592 .18175 L
.74704 .18576 L
.74827 .17999 L
.74957 .17092 L
.75068 .16773 L
.7519 .17187 L
.75331 .18282 L
.75401 .18801 L
.75465 .19153 L
.75585 .19359 L
.75716 .19044 L
Mistroke
.7583 .1869 L
.75937 .18616 L
.76049 .18931 L
.76172 .19592 L
.76287 .20183 L
.76408 .20491 L
.76471 .20494 L
.7654 .20404 L
.76662 .20172 L
.76778 .20105 L
.76883 .20305 L
.77005 .20788 L
.7712 .21284 L
.77226 .21584 L
.77324 .21657 L
.77432 .21564 L
.77546 .21432 L
.77666 .21458 L
.77798 .21777 L
.77914 .22204 L
.78038 .22592 L
.78161 .22754 L
.78272 .22713 L
.78377 .22621 L
.78488 .22611 L
.78619 .22822 L
.78739 .23183 L
.78807 .23398 L
.7888 .23592 L
.7901 .23771 L
.79133 .23749 L
.79245 .23678 L
.79377 .23707 L
.79502 .2393 L
.79616 .24242 L
.79723 .24519 L
.79835 .2469 L
.79958 .24713 L
.80064 .24659 L
.80161 .24635 L
.80267 .24709 L
.80379 .24916 L
.80492 .25198 L
.80599 .25431 L
.80723 .25569 L
.80835 .25568 L
.80959 .25515 L
.81028 .25511 L
.81093 .25544 L
.81209 .25707 L
Mistroke
.81333 .25975 L
.81454 .26219 L
.81586 .26351 L
.81711 .26341 L
.81827 .26298 L
.81931 .26313 L
.82045 .26437 L
.82165 .26662 L
.82278 .26881 L
.82402 .27032 L
.82532 .27054 L
.82644 .27013 L
.82766 .27004 L
.82898 .27117 L
.82972 .27235 L
.83039 .27358 L
.83169 .27575 L
.83293 .27679 L
.84171 .28243 L
.85125 .2872 L
.8707 .29447 L
.88102 .29854 L
.88233 .29995 L
.88306 .30062 L
.88374 .30104 L
.88455 .30119 L
.88528 .30103 L
.88597 .30072 L
.88671 .30036 L
.88736 .30015 L
.88808 .30013 L
.88883 .30042 L
.88953 .30094 L
.89077 .30216 L
.89142 .30276 L
.89212 .30321 L
.89283 .3034 L
.89349 .30334 L
.8948 .30276 L
.89596 .30228 L
.89724 .30241 L
.89795 .30284 L
.8986 .30339 L
.8993 .30405 L
.90007 .30469 L
.90137 .30521 L
.90207 .30513 L
.90273 .30486 L
.90399 .3042 L
.90519 .30394 L
Mistroke
.90626 .3043 L
.90742 .3052 L
.90869 .30622 L
.90933 .30654 L
.91003 .30665 L
.91128 .30628 L
.91244 .30564 L
.91361 .30528 L
.9149 .30562 L
.91611 .30652 L
.91723 .30736 L
.91835 .30775 L
.91936 .30759 L
.92052 .30698 L
.92161 .30643 L
.92282 .30635 L
.92408 .30698 L
.92518 .30781 L
.92635 .30847 L
.92762 .3085 L
.9288 .30794 L
.92952 .30751 L
.9302 .30719 L
.93147 .30709 L
.93262 .30763 L
.93385 .30851 L
.93501 .30909 L
.93608 .3091 L
.93726 .30856 L
.93855 .30781 L
.9392 .30759 L
.9399 .30757 L
.94115 .30807 L
.94248 .30897 L
.94323 .30937 L
.94392 .30954 L
.94519 .30927 L
.94583 .30891 L
.94654 .30847 L
.94776 .30792 L
.94906 .30802 L
.9503 .30872 L
.95142 .30943 L
.95256 .30976 L
.95378 .30947 L
.95481 .30886 L
.95595 .30823 L
.95718 .30807 L
.9585 .30861 L
.95964 .30935 L
Mistroke
.96089 .30985 L
.96207 .30969 L
.96316 .30909 L
.96442 .30836 L
.96556 .30812 L
.96663 .30842 L
.96764 .30903 L
.9687 .30965 L
.96986 .3099 L
.97061 .30973 L
.97132 .30938 L
.97216 .30885 L
.97293 .30841 L
.97374 .30815 L
.9745 .30818 L
.97531 .30848 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000O_oonfX4o`0009cooo]Z003ooookJQkooo]Z1Ol0001noookJPCo
0000W?oonfX009kooo]Z1Ol0001joookJPGo0000O_oonfX4o`0009cooo]Z002NoookJPGo0000N_oo
nfX5o`0007kooo]Z1?l0002LoookJP00W_oonfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX0
09kooo]Z1Ol0001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000N_oonfX5o`0007ko
oo]Z1Ol0002KoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z
002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001]
oookJP?o001o2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0005gooo]Z2_l007l6oook
JP?o001o2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0005gooo]Z2_l007l6oookJP?o
001o2_oonfX6o`0007gooo]Z1Ol0002KoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000
O_oonfX5o`0009_ooo]Z002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPKo0000V_oo
nfX009kooo]Z1Ol0001]oookJP?o001o2_oonfX5o`0007kooo]Z1_l0002JoookJP00W_oonfX5o`00
06gooo]Z0ol007l:oookJPGo0000OOoonfX7o`0009[ooo]Z002MoookJPOo0000JOoonfX6o`00O`[o
oo]Z1Ol0001moookJPOo0000V_oonfX009gooo]Z1ol0001YoookJPKo001o2_oonfX5o`0007gooo]Z
2_l0002GoookJP00WOoonfX:o`0006Sooo]Z1?l007l:oookJPGo0000OOoonfX:o`0009Oooo]Z002M
oookJP[o0000JOoonfX3o`00O`[ooo]Z1Ol0001moookJP_o0000U_oonfX009gooo]Z2ol0001eoook
JPGo0000OOoonfX;o`0009Kooo]Z002MoookJP_o0000MOoonfX5o`0007gooo]Z2ol0002FoookJP00
WOoonfX;o`0007Gooo]Z1Ol0001moookJP_o0000U_oonfX009gooo]Z2ol0001eoookJPGo0000OOoo
nfX;o`0009Kooo]Z002MoookJP_o0000MOoonfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX;o`00
07Gooo]Z1Ol0001moookJP_o0000U_oonfX009gooo]Z2ol0001eoookJPGo0000OOoonfX;o`0009Ko
oo]Z002MoookJP_o0000MOoonfX5o`0007gooo]Z3ol0002BoookJP00WOoonfX?o`00077ooo]Z1Ol0
001moookJPoo0000T_oonfX009gooo]Z3ol0001aoookJPGo0000OOoonfX?o`0009;ooo]Z002Moook
JPoo0000LOoonfX5o`0007gooo]Z3ol0002BoookJP00WOoonfX4o`0000?ooo]Z2?l0001aoookJPGo
0000OOoonfX4o`0000Cooo]Z1ol0002BoookJP00WOoonfX4o`0000?ooo]Z2?l0001aoookJPGo0000
OOoonfX4o`0000Cooo]Z2?l0002AoookJP00WOoonfX4o`0000Cooo]Z2?l0001`oookJPGo0000OOoo
nfX4o`0000Cooo]Z2?l0002AoookJP00WOoonfX4o`0000Cooo]Z2?l0001`oookJPGo0000OOoonfX4
o`0000Gooo]Z1ol0002AoookJP00WOoonfX4o`0000Oooo]Z2?l0001]oookJPGo0000OOoonfX4o`00
00Sooo]Z1?l0002AoookJP00WOoonfX4o`0000Sooo]Z2?l0001/oookJPGo0000OOoonfX4o`0000So
oo]Z1ol0002>oookJP00WOoonfX4o`0000Sooo]Z2?l0001/oookJPGo0000OOoonfX4o`0000Sooo]Z
2?l0002=oookJP00WOoonfX4o`0000Sooo]Z2?l0001/oookJPGo0000OOoonfX4o`0000Sooo]Z2?l0
002=oookJP00WOoonfX4o`0000Wooo]Z1ol0001/oookJPGo0000OOoonfX4o`0000Sooo]Z2?l0002=
oookJP00WOoonfX4o`0000Wooo]Z1ol0001/oookJPGo0000OOoonfX4o`0000Sooo]Z2?l0002=oook
JP00WOoonfX4o`0000Wooo]Z2?l0001[oookJPGo0000OOoonfX4o`0000Wooo]Z2?l0002<oookJP00
W?oonfX5o`0000cooo]Z1Ol0001[oookJPGo0000OOoonfX4o`0000cooo]Z1Ol0002<oookJP00W?oo
nfX5o`0000cooo]Z2?l0001XoookJPGo0000OOoonfX4o`0000cooo]Z2?l00029oookJP00W?oonfX5
o`0000gooo]Z1ol0001XoookJPGo0000OOoonfX4o`0000gooo]Z1ol00029oookJP00W?oonfX4o`00
00kooo]Z2?l0001WoookJPGo0000OOoonfX4o`0000gooo]Z2?l00028oookJP00W?oonfX4o`0000ko
oo]Z2?l0001WoookJPGo0000O?oonfX5o`0000gooo]Z2?l00028oookJP00W?oonfX4o`0000oooo]Z
1ol0001WoookJPGo0000O?oonfX5o`0000kooo]Z1ol00028oookJP00W?oonfX4o`0001;ooo]Z1?l0
001WoookJPGo0000O?oonfX5o`00017ooo]Z1?l00028oookJP00W?oonfX4o`0001;ooo]Z2?l00015
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000O?oonfX4o`0001;ooo]Z1ol00025
oookJP00W?oonfX4o`0001;ooo]Z2?l00014oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oook
JPGo0000O?oonfX4o`0001;ooo]Z2?l00024oookJP00W?oonfX4o`0001;ooo]Z2?l00014oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2OoonfX5o`0007cooo]Z1?l0000BoookJPSo0000Q?oonfX009cooo]Z1?l0000Coook
JPOo0000=ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPGo0000O?oonfX4o`0001?ooo]Z2?l00023oookJP00W?oonfX4o`0001?ooo]Z2?l0000foookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007_ooo]Z1?l0000DoookJPOo
0000PooonfX009cooo]Z1?l0000FoookJPGo0000@_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2?oonfX5o`0007cooo]Z1?l0000FoookJPKo0000P_oonfX009cooo]Z1?l0000FoookJPSo0000?ooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001loookJPCo00005ooo
nfX7o`00083ooo]Z002LoookJPCo00005ooonfX8o`0003kooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Wooo]Z1Ol0001loookJPCo00005ooonfX8o`0007oooo]Z002LoookJPCo00005ooonfX8o`00
03kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001loookJPCo00006?oonfX7o`00
07oooo]Z002LoookJPCo00006?oonfX7o`0003kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`ko
oo]Z1Ol0001loookJPCo00006?oonfX8o`0007kooo]Z002LoookJPCo00006ooonfX5o`0003kooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007cooo]Z1?l0000KoookJPGo
0000O_oonfX009cooo]Z1?l0000KoookJPSo0000>ooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000
O?oonfX4o`0001_ooo]Z2?l0001koookJP00W?oonfX4o`0001_ooo]Z2?l0000loookJPGo001o2_oo
nfX7o`00O`Sooo]Z1Ol0001loookJPCo00007?oonfX7o`0007_ooo]Z002LoookJPCo00007?oonfX8
o`0005Wooo]Z1Ol0001loookJPCo00007?oonfX8o`0007[ooo]Z002LoookJPCo00007?oonfX8o`00
05Wooo]Z1Ol0001loookJPCo00007OoonfX7o`0007[ooo]Z002LoookJPCo00007OoonfX8o`0005So
oo]Z1Ol0001loookJPCo00007ooonfX6o`0007Wooo]Z002LoookJPCo00008?oonfX7o`0005Kooo]Z
1Ol0001loookJPCo00008?oonfX8o`0007Kooo]Z002LoookJPCo00008?oonfX8o`0005Gooo]Z1Ol0
001loookJPCo00008?oonfX8o`0007Kooo]Z002LoookJPCo00008OoonfX8o`0005Cooo]Z1Ol0001l
oookJPCo00008OoonfX8o`0007Gooo]Z002LoookJPCo00008OoonfX9o`0005?ooo]Z1Ol0001loook
JPCo00008_oonfX7o`0007Gooo]Z002LoookJPCo00009?oonfX8o`00057ooo]Z1Ol0001loookJPCo
00009?oonfX8o`0007;ooo]Z002LoookJPCo00009OoonfX8o`00053ooo]Z1Ol0001loookJPCo0000
9OoonfX8o`00077ooo]Z002LoookJPCo00009_oonfX7o`00053ooo]Z1Ol0001loookJPCo00009Ooo
nfX8o`00077ooo]Z002LoookJPCo00009ooonfX6o`00053ooo]Z1Ol0001loookJPCo00009OoonfX9
o`00073ooo]Z002LoookJPCo0000:OoonfX8o`0004cooo]Z1Ol0001loookJPCo0000:OoonfX8o`00
06gooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00000ooonfX3o`00O`?ooo]Z1Ol007lKoookJPSo
0000C?oonfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX5o`00Ob7ooo]Z2Ol0001<oookJP?o
001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o1?l00003oookJP?o001o0_oonfX7o`00Oa[ooo]Z
2Ol0001;oookJPGo0000LooonfX7o`00O`;ooo]Z1?l00002oookJPOo001o8OoonfX8o`0004cooo]Z
0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2ol00018oookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
Ob;ooo]Z2?l0001;oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Cooo]Z0ol007l3oookJP?o
001o7OoonfX9o`0004Oooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o
000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ob?ooo]Z1ol0001:oookJP?o001o7OoonfX001?o
oo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000002o`000003
o`00Oooonf[ooo]Z00[ooo]Z0ol007lNoookJPSo0000AooonfX5o`0007;ooo]Z0ol007l3oookJP?o
001o00?ooo]Zo`000?l000000_l00007oookJP?o001o9?oonfX8o`0004Sooo]Z0ol007lMoookJP00
8_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00[ooo]Z
0ol007lNoookJPco0000@ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l00000
0_l00007oookJP?o001o9OoonfX8o`0004Oooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol0
07l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l2oookJPCo001o8?oo
nfX<o`00047ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oo
nfX2o`00O`;ooo]Z1?l007lUoookJP[o0000AOoonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3
o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX7o`00Ob?ooo]Z2ol00010
oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1ol007lX
oookJP_o0000@_oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o0000
00;o000000?o001ooookJ_oonfX01OoonfX6o`00ObGooo]Z2ol0000ooookJPGo0000L_oonfX3o`00
O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1_l007l[oookJP_o0000@?oonfX3o`00
Oagooo]Z000OoookJPKo001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oo
nfX01OoonfX2o`00Ob[ooo]Z2ol0000noookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o
0000o`000002o`0000;ooo]Z0_l007l`oookJPgo0000>_oonfX6o`00Oagooo]Z000OoookJPKo001o
M?oonfX3o`00O`Co00002?oonfX2o`00Oboooo]Z2?l0000loookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l00002oookJP;o001o<_oonfX>o`0003Oooo]Z1_l007lMoookJP00
8OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol007lZoookJP[o0000>OoonfX5o`0007?ooo]Z
1ol007l2oookJPCo00000ooonfX7o`00Oboooo]Z3_l0000foookJPCo001o7OoonfX002;ooo]Z0ol0
07meoookJP;o001o1?l00009oookJPOo001o:ooonfX=o`0003Gooo]Z1Ol0001doookJPGo001o0ooo
nfX4o`0000?ooo]Z1ol007laoookJPko0000=OoonfX3o`00Oagooo]Z002LoookJPCo0000??oonfX=
o`0003Cooo]Z1Ol0001loookJPCo0000?_oonfX>o`0005;ooo]Z002LoookJPCo0000?_oonfX?o`00
033ooo]Z1Ol0001loookJPCo0000@OoonfX<o`00057ooo]Z002LoookJPCo0000@OoonfXAo`0002_o
oo]Z1Ol0001loookJPCo0000A?oonfX>o`0004cooo]Z002LoookJPCo0000@_oonfXDo`0002Oooo]Z
1Ol0001loookJPCo0000A_oonfX@o`0004Sooo]Z002LoookJPCo0000A_oonfXEo`0002;ooo]Z1Ol0
001loookJPCo0000BOoonfXBo`0004?ooo]Z002LoookJPCo0000B_oonfXFo`0001gooo]Z1Ol0001l
oookJPCo0000B_oonfXFo`0003kooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000LoookJPCo00001OoonfX4o`00
0003oookJ_l0003o000002Go0000BooonfX4o`0007Wooo]Z2Ol00006oookJPCo00001?oonfXSo`00
04_ooo]Z1?l0001joookJPCo000000?ooo]Zo`000?oonfX07OoonfX003cooo]Z5_l0001:oookJPCo
0000OOoonfX5o`0001Sooo]Z6_l0001:oookJPCo0000W_oonfX0047ooo]Z5Ol00016oookJPCo0000
OOoonfX5o`00027ooo]Z5_l00015oookJPCo0000W_oonfX004Kooo]Z5?l00012oookJPCo0000OOoo
nfX5o`0002Kooo]Z4ol00013oookJPCo0000W_oonfX004[ooo]Z4_l00010oookJPCo0000OOoonfX5
o`0002[ooo]Z4Ol00011oookJPCo0000W_oonfX004kooo]Z4Ol0000moookJPCo0000OOoonfX5o`00
02oooo]Z3_l0000ooookJPCo0000W_oonfX005?ooo]Z3_l0000koookJPCo0000OOoonfX5o`0003Co
oo]Z2ol0000moookJPCo0000W_oonfX005Cooo]Z3_l0000joookJPCo0000OOoonfX5o`0003Kooo]Z
2ol0000koookJPCo0000W_oonfX005Wooo]Z2ol0000hoookJPCo0000OOoonfX5o`0003Sooo]Z2_l0
000joookJPCo0000W_oonfX005cooo]Z2Ol0000goookJPCo0000OOoonfX5o`0003[ooo]Z2_l0000h
oookJPCo0000W_oonfX005kooo]Z2?l0000foookJPCo0000OOoonfX5o`0003cooo]Z2_l0000foook
JPCo0000W_oonfX005oooo]Z2Ol0000doookJPCo0000OOoonfX5o`0003kooo]Z2Ol0000eoookJPCo
0000W_oonfX0067ooo]Z2?l0000coookJPCo0000OOoonfX5o`0003oooo]Z2_l0000coookJPCo0000
W_oonfX006;ooo]Z2Ol0000aoookJPCo0000OOoonfX5o`00047ooo]Z2Ol0000boookJPCo0000W_oo
nfX006?ooo]Z2Ol0000`oookJPCo0000OOoonfX5o`0004?ooo]Z2Ol0000`oookJPCo0000W_oonfX0
06Gooo]Z2?l0000_oookJPCo0000OOoonfX5o`0004Cooo]Z2_l0000^oookJPCo0000W_oonfX006Ko
oo]Z2Ol0000]oookJPCo0000OOoonfX5o`0004Kooo]Z2Ol0000]oookJPCo0000W_oonfX006Sooo]Z
2?l0000/oookJPCo0000OOoonfX5o`0004Oooo]Z2_l0000[oookJPCo0000W_oonfX006Wooo]Z2Ol0
000ZoookJPCo0000OOoonfX5o`0004Wooo]Z2Ol0000ZoookJPCo0000W_oonfX006[ooo]Z2Ol0000Y
oookJPCo0000OOoonfX5o`0004_ooo]Z2Ol0000XoookJPCo0000W_oonfX006cooo]Z2?l0000Xoook
JPCo0000OOoonfX5o`0004cooo]Z2Ol0000WoookJPCo0000W_oonfX006gooo]Z2?l0000WoookJPCo
0000OOoonfX5o`0004kooo]Z2Ol0000UoookJPCo0000W_oonfX006oooo]Z1ol0000VoookJPCo0000
OOoonfX5o`0004oooo]Z2Ol0000ToookJPCo0000W_oonfX0073ooo]Z1ol0000UoookJPCo0000OOoo
nfX5o`00057ooo]Z2?l0000SoookJPCo0000W_oonfX0077ooo]Z1ol0000ToookJPCo0000OOoonfX5
o`0005;ooo]Z2?l0000RoookJPCo0000W_oonfX007;ooo]Z2Ol0000QoookJPCo0000OOoonfX5o`00
05Cooo]Z1ol0000QoookJPCo0000W_oonfX007?ooo]Z2Ol0000PoookJPCo0000OOoonfX5o`0005Go
oo]Z1_l0000QoookJPCo0000W_oonfX007Cooo]Z2?l0000PoookJPCo0000OOoonfX5o`0005Kooo]Z
1_l0000PoookJPCo0000W_oonfX007Cooo]Z2?l0000PoookJPCo0000OOoonfX5o`0005Oooo]Z1_l0
000OoookJPCo0000W_oonfX007Oooo]Z1_l0000OoookJPCo0000OOoonfX5o`0005Oooo]Z1ol0000N
oookJPCo0000W_oonfX007Sooo]Z2?l0000KoookJPGo0000OOoonfX5o`0005Sooo]Z1ol0000Moook
JPCo0000W_oonfX007Sooo]Z2?l0000KoookJPGo0000OOoonfX5o`0005Wooo]Z1ol0000LoookJPCo
0000W_oonfX007Wooo]Z1ol0000KoookJPGo0000OOoonfX5o`0005[ooo]Z1_l0000LoookJPCo0000
W_oonfX007Wooo]Z1ol0000KoookJPCo0000O_oonfX5o`0005_ooo]Z1_l0000KoookJPCo0000W_oo
nfX007cooo]Z1Ol0000JoookJPCo0000O_oonfX5o`0005cooo]Z1_l0000JoookJPCo0000W_oonfX0
07cooo]Z2?l0000GoookJPCo0000H?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`00
05cooo]Z1ol0000HoookJPGo0000W_oonfX007cooo]Z2?l0000GoookJPCo0000GooonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o2OoonfX5o`0005gooo]Z1_l0000HoookJPGo0000W_oonfX007gooo]Z
2?l0000FoookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001NoookJPKo00005ooonfX5o`00
09kooo]Z001noookJPOo00005_oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l8oookJPGo0000GooonfX6o`0001Kooo]Z1?l0002OoookJP00P?oonfX6o`0001Gooo]Z
1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000G_oonfX7o`0001Gooo]Z
1?l0002OoookJP00POoonfX8o`0001;ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l8oookJPGo0000H?oonfX6o`0001Gooo]Z1?l0002OoookJP00POoonfX8o`0001;ooo]Z1?l0001N
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`00067ooo]Z1_l0000D
oookJPCo0000WooonfX008;ooo]Z1ol0000BoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o2OoonfX5o`0006;ooo]Z1_l0000CoookJPCo0000WooonfX008;ooo]Z1ol0000BoookJPCo
0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0006;ooo]Z1_l0000CoookJPCo
0000WooonfX008;ooo]Z2?l0000AoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
3_oonfX5o`0006?ooo]Z1_l0000BoookJPCo0000WooonfX008Gooo]Z1Ol0000AoookJPCo0000Gooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000I?oonfX6o`00017ooo]Z
1?l0002OoookJP00QOoonfX8o`0000kooo]Z1?l0001OoookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0
001ToookJPOo00004?oonfX4o`0009oooo]Z0026oookJPOo00003_oonfX4o`00063ooo]Z1Ol007l:
oookJPOo001o2?oonfX5o`0006Gooo]Z1_l0000@oookJPCo0000WooonfX008Kooo]Z2?l0000=oook
JPCo0000O_oonfX5o`0006Kooo]Z1_l0000?oookJPCo0000WooonfX008Oooo]Z1ol0000=oookJPCo
0000O_oonfX5o`0006Oooo]Z1_l0000>oookJPCo0000WooonfX008Oooo]Z2?l0000<oookJPCo0000
O_oonfX5o`0006Oooo]Z1_l0000>oookJPCo0000WooonfX008[ooo]Z1Ol0000<oookJPCo0000O_oo
nfX5o`0006Sooo]Z1_l0000=oookJPCo0000WooonfX008[ooo]Z2?l00009oookJPCo0000O_oonfX5
o`0006Wooo]Z1Ol0000=oookJPCo0000WooonfX008_ooo]Z1ol00009oookJPCo0000O_oonfX5o`00
06Wooo]Z1_l0000<oookJPCo0000WooonfX008_ooo]Z1ol00009oookJPCo0000O_oonfX5o`0006[o
oo]Z1_l0000;oookJPCo0000WooonfX008_ooo]Z1ol00009oookJPCo0000O_oonfX5o`0006[ooo]Z
1ol0000:oookJPCo0000WooonfX008_ooo]Z2?l00008oookJPCo0000O_oonfX5o`0006_ooo]Z1ol0
0009oookJPCo0000WooonfX008cooo]Z1ol00008oookJPCo0000O_oonfX5o`0006cooo]Z1ol00008
oookJPCo0000WooonfX008kooo]Z1Ol00008oookJPCo0000O_oonfX5o`0006gooo]Z1ol00007oook
JPCo0000WooonfX008oooo]Z1ol00005oookJPCo0000O_oonfX5o`0006kooo]Z2Ol00004oookJPCo
0000WooonfX008oooo]Z2?l00004oookJPCo0000O_oonfX5o`0006oooo]Z2?l00004oookJPCo0000
WooonfX008oooo]Z2?l00004oookJPCo0000O_oonfX5o`00073ooo]Z2?l00003oookJPCo0000Wooo
nfX008oooo]Z2?l00004oookJPCo0000O_oonfX5o`00077ooo]Z1ol00003oookJPCo0000WooonfX0
093ooo]Z3ol0001noookJPGo0000L_oonfX=o`0009oooo]Z002@oookJPoo0000O_oonfX5o`0007Co
oo]Z2ol0002OoookJP00T?oonfX?o`0007kooo]Z1Ol0001doookJP_o0000WooonfX0097ooo]Z3_l0
001noookJPGo0000M?oonfX;o`0009oooo]Z002DoookJP_o0000O_oonfX5o`0007Cooo]Z2ol0002O
oookJP00U?oonfX;o`0007kooo]Z1Ol0001doookJP_o0000WooonfX009Cooo]Z2ol0001noookJPGo
0000M?oonfX;o`0009oooo]Z002DoookJP_o0000O_oonfX5o`0007Cooo]Z2ol0002OoookJP00U?oo
nfX;o`0007kooo]Z1Ol0001doookJP_o0000WooonfX009Cooo]Z2ol0001noookJPGo0000M?oonfX:
o`000:3ooo]Z002DoookJP_o0000O_oonfX5o`0007Gooo]Z2Ol0002PoookJP00UOoonfX:o`0007ko
oo]Z1Ol0001eoookJPWo0000X?oonfX009Gooo]Z2_l0001noookJPGo0000MOoonfX9o`000:3ooo]Z
002IoookJPKo0000O_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX6o`00077ooo]Z0ol007l:
oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPKo0000LOoonfX3o`00O`[ooo]Z1Ol0001ioook
JPGo0000X?oonfX009Wooo]Z1_l0001aoookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00
VOoonfX6o`00077ooo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPKo0000LOoo
nfX3o`00O`[ooo]Z1_l0001hoookJPGo0000X?oonfX009Wooo]Z1_l0001aoookJP?o001o2_oonfX5
o`0007Wooo]Z1Ol0002PoookJP00VOoonfX6o`00077ooo]Z0ol007l:oookJPGo0000NOoonfX5o`00
0:3ooo]Z002IoookJPKo0000LOoonfX3o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z
1_l0001aoookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX6o`0006kooo]Z1_l0
07l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000KooonfX6o`00O`[ooo]Z1Ol0001i
oookJPGo0000X?oonfX009Wooo]Z1Ol0001aoookJPCo001o2_oonfX5o`0007Wooo]Z1Ol0002Poook
JP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000
OooonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007oooo]Z1Ol0001ioookJPGo0000X?oo
nfX009[ooo]Z1?l0001ooookJPGo0000N_oonfX4o`000:3ooo]Z002JoookJPCo0000OooonfX5o`00
07[ooo]Z1?l0002PoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`?o
oo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3
o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXNoookJP00oooonfX2oookJP?o001o3_oonfX3o`00
O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`So
oo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00o_oonfX6
o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oook
JPGo0000oooonfXOoookJP00oooonfX1oookJPCo001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoo
oo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPCo001o3Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooook
JPoooo]Z1Ol007l:oookJPKo0000oooonfXNoookJP00oooonfXAoookJPCo001o2OoonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol0
07oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oook
JP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRco
oo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z003ooookJPoooo]Z1Ol007oooookJRkooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.03279 .30868 L
.03405 .30818 L
.03477 .3082 L
.03543 .30843 L
.03665 .30917 L
.03793 .30983 L
.03908 .30987 L
.04016 .30939 L
.04144 .3086 L
.04262 .30822 L
.04384 .3085 L
.04501 .30921 L
.04624 .30989 L
.04693 .31004 L
.04758 .30997 L
.04827 .30969 L
.04892 .30931 L
.05014 .3086 L
.05146 .30839 L
.0522 .30863 L
.05288 .30902 L
.05395 .30974 L
.0551 .31023 L
.05636 .31009 L
.05753 .30945 L
.05885 .30876 L
.0601 .30872 L
.06122 .30928 L
.06244 .31013 L
.0637 .31064 L
.0644 .31061 L
.06505 .31038 L
.06624 .3097 L
.06749 .30914 L
.06815 .30911 L
.06887 .30932 L
.07015 .31015 L
.07093 .31071 L
.07167 .3111 L
.07234 .31124 L
.07306 .31115 L
.07376 .31085 L
.07441 .31047 L
.07519 .31004 L
.07591 .30979 L
.07665 .30979 L
.07736 .31004 L
.07811 .31052 L
.07892 .31116 L
Mistroke
.07962 .31166 L
.08028 .31197 L
.08104 .31207 L
.08173 .31191 L
.08298 .31126 L
.08363 .31092 L
.08433 .3107 L
.0856 .31089 L
.08678 .31171 L
.08807 .31273 L
.08879 .31309 L
.08947 .31318 L
.09017 .31304 L
.09092 .3127 L
.09163 .3123 L
.0923 .312 L
.09353 .31194 L
.09418 .31222 L
.09488 .31273 L
.09616 .31385 L
.09735 .31454 L
.09859 .31451 L
.09925 .31423 L
.09995 .31386 L
.1012 .31341 L
.10237 .31367 L
.10343 .31447 L
.10458 .31556 L
.10582 .31634 L
.10695 .31636 L
.10825 .31578 L
.10949 .31532 L
.11063 .31553 L
.11168 .31632 L
.11283 .3175 L
.11407 .31845 L
.11531 .31861 L
.11647 .31816 L
.11714 .31784 L
.11785 .31764 L
.11912 .31793 L
.11976 .31842 L
.12045 .31913 L
.12169 .32047 L
.12244 .32105 L
.12316 .32131 L
.1238 .32129 L
.12449 .32106 L
.1258 .32049 L
.12703 .32048 L
Mistroke
.12773 .32088 L
.12837 .32148 L
.12912 .32236 L
.12981 .32319 L
.13048 .32387 L
.13119 .32434 L
.13198 .32449 L
.1327 .32435 L
.1334 .32406 L
.13413 .32376 L
.13545 .32377 L
.13664 .3247 L
.13795 .32636 L
.13862 .32718 L
.13935 .32784 L
.14065 .32819 L
.14177 .32783 L
.14298 .32744 L
.14367 .32751 L
.14431 .32786 L
.14555 .32925 L
.14678 .33099 L
.14747 .33179 L
.14812 .33228 L
.14876 .33248 L
.14944 .33242 L
.15018 .33216 L
.15084 .3319 L
.15205 .33187 L
.15336 .33296 L
.1546 .33479 L
.15573 .33641 L
.15637 .33703 L
.15706 .33736 L
.1583 .33722 L
.15905 .33692 L
.15977 .33675 L
.16041 .33684 L
.16111 .33729 L
.16187 .33818 L
.16255 .33925 L
.16328 .34051 L
.16407 .34174 L
.1648 .34255 L
.16548 .34292 L
.16613 .34297 L
.16681 .34278 L
.16806 .34237 L
.16921 .34269 L
.17053 .34435 L
Mistroke
.17178 .34666 L
.17293 .34846 L
.174 .34923 L
.17517 .3491 L
.17641 .34867 L
.17765 .34905 L
.17835 .34986 L
.17899 .35095 L
.18025 .35351 L
.18142 .35547 L
.18207 .35609 L
.18277 .35632 L
.18354 .35616 L
.18424 .35587 L
.18491 .35568 L
.18563 .3558 L
.18693 .35727 L
.20647 .38096 L
.21682 .39299 L
.2175 .39246 L
.21815 .39186 L
.21881 .39149 L
.21955 .39174 L
.22029 .39293 L
.22109 .39521 L
.22252 .40051 L
.22323 .40279 L
.22389 .40421 L
.22458 .40481 L
.22534 .40452 L
.22659 .40296 L
.22729 .40237 L
.22792 .40251 L
.22859 .40356 L
.22929 .40569 L
.23056 .41116 L
.23121 .414 L
.23192 .41638 L
.23269 .41772 L
.23341 .41768 L
.23408 .41674 L
.2348 .41527 L
.23612 .41371 L
.23741 .41625 L
.2386 .42222 L
.23987 .42921 L
.24107 .43255 L
.24215 .4315 L
.24331 .42768 L
.24459 .42491 L
Mistroke
.24523 .4256 L
.24593 .42841 L
.24717 .43749 L
.24834 .44653 L
.24952 .45069 L
.25081 .4464 L
.25203 .43752 L
.25315 .43253 L
.25416 .43605 L
.25528 .45012 L
.25638 .4692 L
.25754 .48264 L
.25882 .47252 L
.25999 .43081 L
.26125 .35516 L
.26263 .2583 L
.26382 .18708 L
.2651 .14328 L
.2663 .13555 L
.2674 .14834 L
.26851 .16769 L
.26971 .18251 L
.27103 .18466 L
.27226 .17698 L
.27292 .17216 L
.27364 .16843 L
.27495 .16875 L
.27622 .17707 L
.2774 .18659 L
.27849 .1922 L
.27952 .19289 L
.28065 .18983 L
.28186 .18607 L
.28307 .18594 L
.28434 .19082 L
.28551 .1975 L
.28661 .20252 L
.28791 .20429 L
.2891 .20258 L
.29037 .20038 L
.29109 .20029 L
.29175 .20131 L
.29286 .20513 L
.29408 .2106 L
.29535 .21476 L
.29654 .21565 L
.30742 .22493 L
.32596 .24694 L
.33576 .25842 L
.33701 .26099 L
Mistroke
.33765 .26184 L
.33834 .2623 L
.33909 .26232 L
.3398 .26207 L
.34048 .2618 L
.34114 .26172 L
.34241 .26259 L
.34358 .26457 L
.34485 .26715 L
.34549 .26822 L
.3462 .26902 L
.34694 .26937 L
.34763 .26931 L
.34827 .26908 L
.34895 .26883 L
.34972 .26879 L
.35052 .26921 L
.3512 .27 L
.35195 .27122 L
.35326 .27364 L
.35399 .27473 L
.35465 .27538 L
.35594 .27563 L
.35716 .2752 L
.3584 .27513 L
.3597 .27625 L
.36082 .27801 L
.36205 .28 L
.36336 .28118 L
.36411 .28128 L
.36478 .28111 L
.36609 .28066 L
.36734 .28094 L
.36861 .28232 L
.36976 .2841 L
.37039 .28501 L
.37108 .28575 L
.37233 .28625 L
.3735 .28593 L
.37474 .28555 L
.3758 .28581 L
.37695 .28694 L
.3783 .28884 L
.37957 .29023 L
.38028 .29056 L
.38104 .29057 L
.38173 .29034 L
.38238 .29007 L
.38354 .28984 L
.38483 .29049 L
Mistroke
.38548 .29118 L
.38617 .29208 L
.38743 .29361 L
.38811 .29414 L
.38876 .29437 L
.38996 .29417 L
.39065 .29387 L
.39137 .29361 L
.39266 .29372 L
.39378 .2946 L
.395 .29605 L
.3963 .29731 L
.39752 .29764 L
.39821 .29747 L
.39895 .29714 L
.39961 .29686 L
.4003 .29671 L
.40162 .29715 L
.40284 .29832 L
.40415 .2997 L
.40488 .30021 L
.40555 .30041 L
.4063 .30032 L
.4071 .3 L
.40784 .29964 L
.40855 .29941 L
.4098 .29961 L
.41095 .3005 L
.41159 .30117 L
.41228 .30185 L
.41351 .30264 L
.41457 .30266 L
.41573 .30216 L
.41697 .30165 L
.41814 .30175 L
.41878 .30212 L
.41949 .30271 L
.42078 .30391 L
.42203 .30459 L
.42319 .30448 L
.42391 .30416 L
.42457 .3038 L
.42583 .30341 L
.42653 .30351 L
.42717 .30383 L
.42788 .30438 L
.42863 .30505 L
.42985 .30594 L
.43054 .30615 L
.43118 .30612 L
Mistroke
.43235 .30564 L
.4336 .305 L
.43471 .30487 L
.43575 .30531 L
.43689 .30621 L
.43812 .3071 L
.43936 .30735 L
.44006 .30717 L
.44071 .30684 L
.44202 .30614 L
.44276 .30597 L
.44343 .30604 L
.44463 .30668 L
.44593 .30768 L
.44716 .30825 L
.44829 .30813 L
.44935 .30759 L
.45048 .30698 L
.45156 .3068 L
.45254 .30712 L
.45371 .30792 L
.45496 .30872 L
.45614 .30892 L
.4572 .30855 L
.45832 .30789 L
.45952 .30741 L
.46082 .3076 L
.46204 .30837 L
.4632 .30912 L
.46443 .30938 L
.46548 .30905 L
.46663 .30837 L
.46794 .3078 L
.46916 .30793 L
.46979 .30825 L
.47049 .30871 L
.47122 .3092 L
.4719 .30953 L
.47314 .30961 L
.47382 .30936 L
.47447 .30899 L
.47563 .3083 L
.47688 .308 L
.47809 .30838 L
.47919 .30908 L
.48029 .30967 L
.48133 .3098 L
.48255 .30933 L
.48367 .30863 L
.4849 .30813 L
Mistroke
.4862 .30832 L
.48748 .30907 L
.48869 .30973 L
.48936 .30987 L
.49009 .30979 L
.49136 .30915 L
.49257 .30842 L
.49386 .30815 L
.49496 .30851 L
.49618 .30927 L
.49687 .30965 L
.4976 .30987 L
.4989 .30965 L
.49962 .30926 L
.5003 .30883 L
.50104 .30841 L
.50183 .30817 L
.50251 .30819 L
.50326 .30845 L
.50396 .30885 L
.50461 .30927 L
.50584 .30983 L
.50713 .30974 L
.50826 .30913 L
.50945 .30842 L
.51076 .30817 L
.51197 .30862 L
.51322 .30941 L
.51438 .30989 L
.51543 .30982 L
.51657 .30925 L
.51726 .30881 L
.51791 .30846 L
.51859 .30825 L
.51933 .30825 L
.52055 .30879 L
.52186 .30963 L
.52317 .31004 L
.5244 .30972 L
.5255 .30906 L
.5267 .30846 L
.52784 .30843 L
.5289 .30891 L
.53016 .30976 L
.53132 .31024 L
.53247 .31012 L
.53368 .30947 L
.5349 .30881 L
.53558 .30865 L
.53622 .30871 L
Mistroke
.53845 .31001 L
.53957 .31057 L
.5408 .31055 L
.54185 .31005 L
.54298 .30939 L
.54405 .3091 L
.54502 .3093 L
.54619 .31004 L
.54744 .3109 L
.54809 .31117 L
.54881 .31123 L
.55008 .31078 L
.55078 .31037 L
.55153 .30997 L
.55224 .30977 L
.5529 .3098 L
.5542 .31045 L
.55485 .31095 L
.55556 .3115 L
.55687 .31206 L
.55805 .31186 L
.55871 .31153 L
.55942 .31112 L
.56071 .31067 L
.56193 .31096 L
.56321 .31191 L
.56441 .31282 L
.56551 .31318 L
.56664 .31293 L
.56771 .31236 L
.56885 .31191 L
.57008 .31207 L
.57116 .3128 L
.5723 .31381 L
.57338 .31449 L
.57436 .31461 L
.58411 .31595 L
.58533 .3154 L
.58663 .31544 L
.58787 .31632 L
.58899 .31747 L
.59025 .31845 L
.59145 .31862 L
.59274 .31812 L
.59346 .31779 L
.59414 .31763 L
.59525 .31789 L
.59647 .31894 L
.59775 .32035 L
.59893 .3212 L
Mistroke
.59997 .32129 L
.60107 .32088 L
.60217 .32045 L
.60337 .32054 L
.60404 .32098 L
.60477 .32172 L
.60542 .32249 L
.6061 .3233 L
.60739 .32434 L
.60859 .32444 L
.60925 .32421 L
.60996 .32389 L
.61124 .32366 L
.61202 .32397 L
.61276 .32463 L
.61343 .32543 L
.61416 .32639 L
.61484 .32721 L
.61548 .3278 L
.61668 .3282 L
.61797 .32782 L
.61864 .32756 L
.61936 .32743 L
.62059 .32793 L
.62188 .32945 L
.623 .33103 L
.62419 .33221 L
.6255 .33245 L
.62671 .33201 L
.62802 .33181 L
.62876 .33216 L
.62945 .33284 L
.63079 .33479 L
.63205 .33656 L
.63319 .33735 L
.63443 .33724 L
.63556 .33682 L
.63676 .33691 L
.63789 .33795 L
.63892 .33957 L
.64011 .34154 L
.64141 .34282 L
.64263 .3429 L
.64375 .34249 L
.64496 .34245 L
.64626 .34363 L
.64748 .34575 L
.6486 .34774 L
.64991 .34912 L
.65065 .34927 L
Mistroke
.65134 .34911 L
.65259 .34867 L
.65323 .34871 L
.65393 .34912 L
.65461 .34995 L
.65532 .3512 L
.6566 .35382 L
.65726 .35499 L
.65797 .35587 L
.65875 .35629 L
.65947 .35625 L
.66015 .35599 L
.66088 .35572 L
.66157 .35571 L
.6622 .35606 L
.66341 .3578 L
.66468 .36063 L
.66589 .36302 L
.66721 .36415 L
.66845 .36386 L
.66961 .36344 L
.67075 .36399 L
.67179 .3657 L
.67299 .36863 L
.67411 .37124 L
.67535 .37275 L
.67665 .37263 L
.67777 .37206 L
.67898 .37237 L
.68028 .37464 L
.68149 .37801 L
.68223 .38 L
.68293 .38145 L
.68424 .38249 L
.6853 .38202 L
.68646 .38136 L
.68767 .38204 L
.6888 .38454 L
.68987 .38793 L
.69086 .39089 L
.69189 .39277 L
.69302 .39298 L
.69418 .392 L
.69541 .39153 L
.69656 .39312 L
.69761 .39636 L
.69883 .40093 L
.69952 .40304 L
.70015 .40431 L
.70132 .40468 L
Mistroke
.70255 .40324 L
.70377 .40234 L
.70509 .40438 L
.70634 .40928 L
.7075 .41436 L
.70853 .4173 L
.70968 .4176 L
.71088 .4155 L
.71201 .41378 L
.71325 .41508 L
.71455 .42086 L
.71568 .42731 L
.71689 .432 L
.71819 .43185 L
.7194 .42804 L
.72014 .42577 L
.72084 .4249 L
.72215 .42859 L
.72321 .43619 L
.72437 .44551 L
.72559 .45061 L
.72672 .44802 L
.72778 .44074 L
.72875 .43428 L
.72987 .43324 L
.73094 .44225 L
.73208 .46071 L
.7333 .47942 L
.73446 .48109 L
.7355 .45895 L
.73673 .40089 L
.73742 .35628 L
.73806 .3114 L
.73922 .23199 L
.74048 .16685 L
.74174 .13691 L
.74293 .13912 L
.7441 .15718 L
.74518 .17478 L
.74634 .18487 L
.74762 .18279 L
.74826 .1784 L
.74896 .1732 L
.75021 .16749 L
.75132 .16954 L
.75252 .178 L
.7537 .18735 L
.75495 .19281 L
.75613 .19205 L
.75721 .18852 L
Mistroke
.75828 .18569 L
.7593 .18603 L
.7605 .19064 L
.76181 .1981 L
.76247 .20129 L
.76318 .20353 L
.76446 .20401 L
.76556 .20201 L
.76674 .20025 L
.76802 .2015 L
.76922 .20586 L
.77 .20941 L
.77073 .21243 L
.77139 .21442 L
.7721 .21554 L
.77279 .21563 L
.77352 .21494 L
.77483 .21337 L
.7761 .21382 L
.77728 .21684 L
.77858 .22169 L
.7793 .22405 L
.77997 .22563 L
.78121 .22654 L
.78187 .22616 L
.78258 .2255 L
.78384 .22496 L
.78499 .22635 L
.78626 .22991 L
.78699 .23228 L
.78765 .23422 L
.78835 .23573 L
.7891 .23657 L
.78979 .23666 L
.79045 .23634 L
.79165 .23559 L
.79292 .2361 L
.79401 .23816 L
.79521 .24149 L
.79649 .24466 L
.79721 .24567 L
.79787 .24603 L
.79915 .24562 L
.80036 .24516 L
.80142 .24577 L
.8026 .2479 L
.80374 .25078 L
.80498 .25342 L
.80613 .25453 L
.80718 .25443 L
Mistroke
.80819 .25398 L
.80925 .25397 L
.81041 .25518 L
.81164 .25771 L
.81271 .26009 L
.81387 .26187 L
.81458 .26232 L
.81523 .26233 L
.81652 .26185 L
.81769 .26182 L
.81893 .26304 L
.82907 .27297 L
.83871 .28057 L
.84808 .2862 L
.85679 .29061 L
.86608 .2942 L
.86729 .29369 L
.86861 .29362 L
.86985 .29447 L
.87099 .2958 L
.87168 .2966 L
.87232 .29719 L
.87299 .29756 L
.87373 .29764 L
.87493 .29724 L
.87621 .29674 L
.87689 .29673 L
.87761 .29702 L
.8789 .29818 L
.87963 .29899 L
.88041 .29977 L
.88115 .30025 L
.88183 .30041 L
.88306 .30011 L
.88435 .29951 L
.88504 .29938 L
.88569 .29948 L
.88639 .29986 L
.88714 .30051 L
.88843 .30182 L
.88916 .30239 L
.88983 .30268 L
.89106 .30257 L
.89236 .30194 L
.89353 .3016 L
.89462 .30189 L
.89581 .30284 L
.8971 .30402 L
.89779 .30445 L
.89844 .30462 L
Mistroke
.89965 .30438 L
.90095 .30371 L
.90169 .30345 L
.90236 .30343 L
.9035 .30392 L
.90474 .30497 L
.90603 .30593 L
.90724 .30615 L
.90793 .30594 L
.90868 .30556 L
.90934 .3052 L
.91004 .30493 L
.91136 .305 L
.91258 .30579 L
.91389 .30684 L
.91462 .30724 L
.9153 .30737 L
.91609 .30723 L
.91684 .30687 L
.91759 .30644 L
.91829 .30611 L
.91956 .30602 L
.9207 .30659 L
.92135 .30709 L
.92204 .30762 L
.92327 .30823 L
.92433 .30818 L
.9255 .30761 L
.92674 .30695 L
.9279 .30682 L
.92855 .30703 L
.92926 .30745 L
.93055 .30839 L
.93181 .30892 L
.93297 .30875 L
.93422 .30806 L
.93494 .30766 L
.9356 .30743 L
.93629 .30739 L
.93704 .30762 L
.9377 .308 L
.9384 .30849 L
.93962 .30922 L
.94031 .30938 L
.94095 .30933 L
.94212 .3088 L
.94336 .30807 L
.94446 .30777 L
.9455 .308 L
.94664 .30868 L
Mistroke
.94786 .30943 L
.94916 .30964 L
.94989 .30942 L
.95057 .30904 L
.95127 .30861 L
.95192 .30825 L
.95314 .308 L
.95427 .30837 L
.95548 .30915 L
.95678 .30976 L
.95797 .30969 L
.95903 .30916 L
.96016 .30846 L
.96123 .30812 L
.9622 .30825 L
.96334 .30886 L
.96458 .30961 L
.96575 .30987 L
.96684 .30956 L
.96796 .30888 L
.96918 .30826 L
.97032 .30819 L
.97137 .30864 L
.97247 .30933 L
.97367 .30985 L
.9749 .30973 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00W_oonfX4o`0007_ooo]Z1Ol0003ooookJQoooo]Z002NoookJPCo0000NooonfX5o`0007ko
oo]Z1?l0002LoookJP00W_oonfX4o`0007_ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1?l0
001koookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000N_oonfX5o`0007kooo]Z1Ol0002K
oookJP00W_oonfX5o`0007[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001joookJPGo
0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000
VooonfX009kooo]Z1Ol0001]oookJP?o001o2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5
o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000GOoonfX:o`00
O`Kooo]Z0ol007l:oookJPGo0000OOoonfX6o`0009_ooo]Z002NoookJPGo0000GOoonfX:o`00O`Ko
oo]Z0ol007l:oookJPKo0000O?oonfX6o`0009_ooo]Z002NoookJPGo0000KOoonfX3o`00O`[ooo]Z
1Ol0001moookJPKo0000VooonfX009kooo]Z1_l0001/oookJP?o001o2_oonfX5o`0007gooo]Z1_l0
002KoookJP00W_oonfX6o`0006cooo]Z0ol007l:oookJPGo0000OOoonfX6o`0009_ooo]Z002Noook
JPKo0000K?oonfX3o`00O`[ooo]Z1Ol0001moookJPKo0000VooonfX009kooo]Z1_l0001YoookJPKo
001o2_oonfX5o`0007gooo]Z1_l0002KoookJP00WOoonfX7o`0006Wooo]Z1_l007l:oookJPGo0000
OOoonfX:o`0009Oooo]Z002MoookJP[o0000J?oonfX4o`00O`[ooo]Z1Ol0001moookJP[o0000Uooo
nfX009gooo]Z2_l0001YoookJP?o001o2_oonfX5o`0007gooo]Z2_l0002GoookJP00WOoonfX:o`00
07Kooo]Z1Ol0001moookJP[o0000UooonfX009gooo]Z2ol0001eoookJPGo0000OOoonfX;o`0009Ko
oo]Z002MoookJP_o0000MOoonfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX;o`0007Gooo]Z1Ol0
001moookJP_o0000U_oonfX009gooo]Z2ol0001eoookJPGo0000OOoonfX;o`0009Kooo]Z002Moook
JP_o0000MOoonfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX;o`0007Gooo]Z1Ol0001moookJP_o
0000U_oonfX009gooo]Z3_l0001boookJPGo0000OOoonfX?o`0009;ooo]Z002MoookJPko0000L_oo
nfX5o`0007gooo]Z3ol0002BoookJP00WOoonfX?o`00077ooo]Z1Ol0001moookJPoo0000T_oonfX0
09gooo]Z3ol0001aoookJPGo0000OOoonfX?o`0009;ooo]Z002MoookJPCo00000ooonfX8o`00077o
oo]Z1Ol0001moookJPCo00000ooonfX8o`0009;ooo]Z002MoookJPCo00000ooonfX8o`00077ooo]Z
1Ol0001moookJPCo00000ooonfX8o`0009;ooo]Z002MoookJPCo00001?oonfX8o`00073ooo]Z1Ol0
001moookJPCo00001?oonfX8o`00097ooo]Z002MoookJPCo00001?oonfX8o`00073ooo]Z1Ol0001m
oookJPCo00001?oonfX8o`00097ooo]Z002MoookJPCo00001ooonfX8o`0006gooo]Z1Ol0001moook
JPCo00001ooonfX8o`0008kooo]Z002MoookJPCo00002?oonfX7o`0006gooo]Z1Ol0001moookJPCo
00002?oonfX7o`0008kooo]Z002MoookJPCo00002?oonfX7o`0006gooo]Z1Ol0001moookJPCo0000
2?oonfX7o`0008kooo]Z002MoookJPCo00002?oonfX8o`0006cooo]Z1Ol0001moookJPCo00002?oo
nfX8o`0008gooo]Z002MoookJPCo00002?oonfX8o`0006cooo]Z1Ol0001moookJPCo00002?oonfX8
o`0008gooo]Z002MoookJPCo00002OoonfX7o`0006cooo]Z1Ol0001moookJPCo00002OoonfX7o`00
08gooo]Z002MoookJPCo00003?oonfX4o`0006cooo]Z1Ol0001moookJPCo00003?oonfX4o`0008go
oo]Z002MoookJPCo00003?oonfX4o`0006cooo]Z1Ol0001moookJPCo00003?oonfX8o`0008Wooo]Z
002MoookJPCo00003?oonfX7o`0006Wooo]Z1Ol0001moookJPCo00003?oonfX8o`0008Wooo]Z002M
oookJPCo00003?oonfX8o`0006Sooo]Z1Ol0001moookJPCo00003?oonfX8o`0008Wooo]Z002Moook
JPCo00003?oonfX9o`0006Oooo]Z1Ol0001moookJPCo00003OoonfX7o`0008Wooo]Z002MoookJPCo
00003OoonfX9o`0006Kooo]Z1Ol0001moookJPCo00003OoonfX8o`0008Sooo]Z002MoookJPCo0000
4?oonfX7o`0006Gooo]Z1Ol0001moookJPCo00004?oonfX5o`0008Sooo]Z002LoookJPGo00004Ooo
nfX7o`0006Cooo]Z1Ol0001moookJPCo00004?oonfX8o`0008Gooo]Z002LoookJPGo00004_oonfX6
o`0004Kooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001moookJPCo00004OoonfX7
o`0008Gooo]Z002LoookJPGo00004ooonfX6o`0004Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`Wooo]Z1Ol0001moookJPCo00004OoonfX7o`0008Gooo]Z002LoookJPCo00005OoonfX6o`0004?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oo
nf[o001oo`00Ool007l9oookJPGo0000OOoonfX4o`00017ooo]Z2?l00024oookJP00W?oonfX4o`00
01Gooo]Z1ol0000eoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Sooo]Z1Ol0001moookJPCo00004_oonfX8o`0008?ooo]Z002LoookJPCo00005_oonfX7o`0003Co
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000O?oonfX4o`0001Co
oo]Z1_l00023oookJP00W?oonfX4o`0001Oooo]Z1ol0000ooookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l8oookJPGo0000OOoonfX4o`0001Gooo]Z1ol00021oookJP00W?oonfX4o`0001Sooo]Z1_l0
000ooookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0007gooo]Z1?l0
000FoookJPOo0000P?oonfX009cooo]Z1?l0000IoookJPKo0000?_oonfX3o`00O`?ooo]Z0ol007l7
oookJPOo001o2OoonfX5o`0007gooo]Z1?l0000FoookJPOo0000P?oonfX009cooo]Z1?l0000Joook
JPKo0000?OoonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0007gooo]Z1?l0000Foook
JPSo0000OooonfX009cooo]Z1?l0000JoookJPOo0000??oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o3_oonfX5o`0007gooo]Z1?l0000GoookJPOo0000OooonfX009cooo]Z1?l0000KoookJPOo0000
??oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Wo
oo]Z2?l0001loookJP00W?oonfX4o`0001cooo]Z1ol0000koookJPOo001o2OoonfX7o`00O`Sooo]Z
1Ol0001moookJPCo00006_oonfX7o`0007cooo]Z002LoookJPCo00007OoonfX6o`0003cooo]Z1Ol0
07l:oookJPOo001o2?oonfX5o`0007gooo]Z1?l0000JoookJPSo0000NooonfX009cooo]Z1?l0000N
oookJPKo0000FOoonfX5o`0007gooo]Z1?l0000KoookJPSo0000N_oonfX009cooo]Z1?l0000Ooook
JPKo0000F?oonfX5o`0007gooo]Z1?l0000KoookJPSo0000N_oonfX009cooo]Z1?l0000OoookJPOo
0000EooonfX5o`0007gooo]Z1?l0000NoookJPSo0000MooonfX009cooo]Z1?l0000PoookJPKo0000
EooonfX5o`0007gooo]Z1?l0000OoookJPOo0000MooonfX009cooo]Z1?l0000QoookJPKo0000E_oo
nfX5o`0007gooo]Z1?l0000OoookJPSo0000M_oonfX009cooo]Z1?l0000RoookJPKo0000EOoonfX5
o`0007gooo]Z1?l0000OoookJPSo0000M_oonfX009cooo]Z1?l0000RoookJPWo0000D_oonfX5o`00
07gooo]Z1?l0000PoookJP[o0000LooonfX009cooo]Z1?l0000SoookJPWo0000DOoonfX5o`0007go
oo]Z1?l0000SoookJPSo0000L_oonfX009cooo]Z1?l0000ToookJPSo0000DOoonfX5o`0007gooo]Z
1?l0000SoookJPWo0000LOoonfX009cooo]Z1?l0000UoookJPSo0000D?oonfX5o`0007gooo]Z1?l0
000SoookJP[o0000L?oonfX009cooo]Z1?l0000UoookJP_o0000COoonfX5o`0007gooo]Z1?l0000T
oookJP[o0000KooonfX009cooo]Z1?l0000XoookJPSo0000COoonfX5o`0007gooo]Z1?l0000Xoook
JPOo0000K_oonfX002;ooo]Z0ol007meoookJP;o001o1?l00003oookJP?o001o0ooonfX5o`00Oa_o
oo]Z2?l0001<oookJPGo0000M?oonfX5o`00O`?ooo]Z1Ol00002oookJPGo001o8_oonfX8o`0004co
oo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol007l2oookJPOo001o
6_oonfX9o`0004_ooo]Z1Ol0001coookJPOo001o0_oonfX5o`000003oookJ_l007oo001o00Go001o
8_oonfX8o`0004_ooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2ol00018oookJPGo0000
LooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1Ol00004o`00O`04oookJ_l007oo001oo`00
Ob?ooo]Z2?l0001:oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;o
oo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Cooo]Z0ol007l3oookJP?o
001o7OoonfX9o`0004Oooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o
000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ob?ooo]Z2?l00019oookJP?o001o7OoonfX001?o
oo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000002o`000003
o`00Oooonf[ooo]Z00[ooo]Z0ol007lMoookJPWo0000AooonfX5o`0007;ooo]Z0ol007l3oookJP?o
001o00?ooo]Zo`000?l000000_l00007oookJP?o001o9OoonfX7o`0004Sooo]Z0ol007lMoookJP00
8_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00[ooo]Z
0ol007lNoookJP_o0000A?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l00000
0_l00007oookJP?o001o9_oonfX8o`0004Kooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol0
07l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l2oookJPCo001o8_oo
nfX8o`0004?ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00000_oo
nfX2o`00O`;ooo]Z1?l007lWoookJPWo0000A?oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3
o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX7o`00Ob?ooo]Z3?l0000o
oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1ol007lY
oookJPWo0000@ooonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0003o0000
00;o000000?o001ooookJ_oonfX01OoonfX6o`00ObGooo]Z2ol0000ooookJPGo0000L_oonfX3o`00
O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1_l007l[oookJP[o0000@OoonfX3o`00
Oagooo]Z000OoookJPKo001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oo
nfX01OoonfX2o`00Obcooo]Z2Ol0000noookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o
0000o`000002o`0000;ooo]Z0_l007laoookJP[o0000??oonfX6o`00Oagooo]Z000OoookJPKo001o
M?oonfX3o`00O`Co00002?oonfX2o`00Obcooo]Z3Ol0000joookJPGo0000LooonfX3o`00O`04oook
J_l007oo001oo`00O`;ooo]Z1?l00002oookJP;o001o<ooonfX:o`0003[ooo]Z1_l007lMoookJP00
8OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol007lXoookJP_o0000>_oonfX5o`0007?ooo]Z
1ol007l2oookJPCo00000ooonfX7o`00Obkooo]Z3?l0000ioookJPCo001o7OoonfX002;ooo]Z0ol0
07meoookJP;o001o1?l00009oookJPOo001o:ooonfX<o`0003Kooo]Z1Ol0001doookJPGo001o0ooo
nfX4o`0000?ooo]Z1ol007l`oookJPgo0000=ooonfX3o`00Oagooo]Z002LoookJPCo0000??oonfX?
o`0003;ooo]Z1Ol0001loookJPCo0000??oonfX?o`0005?ooo]Z002LoookJPCo0000?ooonfX=o`00
037ooo]Z1Ol0001loookJPCo0000?_oonfX>o`0005;ooo]Z002LoookJPCo0000@?oonfXAo`0002co
oo]Z1Ol0001loookJPCo0000@OoonfX@o`0004gooo]Z002LoookJPCo0000A?oonfXAo`0002Sooo]Z
1Ol0001loookJPCo0000A?oonfXAo`0004Wooo]Z002LoookJPCo0000AOoonfXEo`0002?ooo]Z1Ol0
001loookJPCo0000AOoonfXEo`0004Cooo]Z002LoookJPCo0000BOoonfXIo`0001_ooo]Z1Ol0001l
oookJPCo0000BOoonfXIo`0003cooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo
0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0
000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000MoookJP03o`000?oonf[ooo]Z
00Oooo]Z:?l0001=oookJPCo0000OOoonfX5o`0000?ooo]Z1?l000000ooonf[o0000o`00000Uo`00
04gooo]Z1?l0001ooookJP03o`000?oonf[ooo]Z01cooo]Z000joookJQWo0000BOoonfX4o`0007go
oo]Z1Ol0000JoookJQWo0000BOoonfX4o`0009kooo]Z0012oookJQGo0000AOoonfX4o`0007gooo]Z
1Ol0000RoookJQGo0000AOoonfX4o`0009kooo]Z0017oookJQ7o0000A?oonfX4o`0007gooo]Z1Ol0
000WoookJQ7o0000A?oonfX4o`0009kooo]Z001;oookJQ3o0000@OoonfX4o`0007gooo]Z1Ol0000[
oookJQ7o0000@?oonfX4o`0009kooo]Z001?oookJPko0000?ooonfX4o`0007gooo]Z1Ol0000`oook
JPgo0000?ooonfX4o`0009kooo]Z001@oookJQ3o0000??oonfX4o`0007gooo]Z1Ol0000aoookJPoo
0000??oonfX4o`0009kooo]Z001DoookJPgo0000>ooonfX4o`0007gooo]Z1Ol0000eoookJPco0000
>ooonfX4o`0009kooo]Z001HoookJPco0000>?oonfX4o`0007gooo]Z1Ol0000hoookJPco0000>?oo
nfX4o`0009kooo]Z001IoookJPco0000=ooonfX4o`0007gooo]Z1Ol0000ioookJPco0000=ooonfX4
o`0009kooo]Z001MoookJPWo0000=_oonfX4o`0007gooo]Z1Ol0000moookJPWo0000=_oonfX4o`00
09kooo]Z001NoookJP_o0000<ooonfX4o`0007gooo]Z1Ol0000noookJP_o0000<ooonfX4o`0009ko
oo]Z001NoookJPco0000<_oonfX4o`0007gooo]Z1Ol0000noookJPco0000<_oonfX4o`0009kooo]Z
001RoookJPWo0000<OoonfX4o`0007gooo]Z1Ol00012oookJPSo0000<_oonfX4o`0009kooo]Z001R
oookJPco0000;_oonfX4o`0007gooo]Z1Ol00013oookJP_o0000;_oonfX4o`0009kooo]Z001Voook
JPSo0000;_oonfX4o`0007gooo]Z1Ol00016oookJPSo0000;_oonfX4o`0009kooo]Z001WoookJPSo
0000;OoonfX4o`0007gooo]Z1Ol00016oookJPWo0000;OoonfX4o`0009kooo]Z001WoookJPWo0000
;?oonfX4o`0007gooo]Z1Ol00017oookJPWo0000;?oonfX4o`0009kooo]Z001ZoookJPWo0000:Ooo
nfX4o`0007gooo]Z1Ol0001:oookJPWo0000:OoonfX4o`0009kooo]Z001[oookJPSo0000:OoonfX4
o`0007gooo]Z1Ol0001;oookJPSo0000:OoonfX4o`0009kooo]Z001/oookJPSo0000:?oonfX4o`00
07gooo]Z1Ol0001<oookJPSo0000:?oonfX4o`0009kooo]Z001/oookJP_o00009OoonfX4o`0007go
oo]Z1Ol0001<oookJP_o00009OoonfX4o`0009kooo]Z001_oookJPSo00009OoonfX4o`0007gooo]Z
1Ol0001?oookJPWo00009?oonfX4o`0009kooo]Z001`oookJPOo00009OoonfX4o`0007gooo]Z1Ol0
001@oookJPSo00009?oonfX4o`0009kooo]Z001`oookJPSo00009?oonfX4o`0007gooo]Z1Ol0001@
oookJPSo00009?oonfX4o`0009kooo]Z001aoookJPSo00008ooonfX4o`0007gooo]Z1Ol0001Aoook
JPSo00008ooonfX4o`0009kooo]Z001coookJPOo00008_oonfX4o`0007gooo]Z1Ol0001DoookJPSo
00008?oonfX4o`0009kooo]Z001doookJPOo00008OoonfX4o`0007gooo]Z1Ol0001DoookJPSo0000
8?oonfX4o`0009kooo]Z001eoookJPOo00008?oonfX4o`0007gooo]Z1Ol0001EoookJPSo00007ooo
nfX4o`0009kooo]Z001foookJPOo00007ooonfX4o`0007gooo]Z1Ol0001FoookJPOo00007ooonfX4
o`0009kooo]Z001goookJPKo00007ooonfX4o`0007gooo]Z1Ol0001HoookJPSo00007?oonfX4o`00
09kooo]Z001hoookJPKo00007_oonfX4o`0007gooo]Z1Ol0001IoookJPOo00007?oonfX4o`0009ko
oo]Z001ioookJPKo00007OoonfX4o`0007gooo]Z1Ol0001IoookJPSo00006ooonfX4o`0009kooo]Z
001ioookJPOo00007?oonfX4o`0007gooo]Z1Ol0001IoookJPSo00006ooonfX4o`0009kooo]Z001j
oookJPOo00006ooonfX4o`0007gooo]Z1Ol0001JoookJPSo00006_oonfX4o`0009kooo]Z001koook
JPOo00006_oonfX4o`0005oooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001Moook
JPOo00005ooonfX5o`0009kooo]Z001loookJPKo00006_oonfX4o`0005kooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00O`Wooo]Z1Ol0001MoookJPSo00005_oonfX5o`0009kooo]Z001moookJPKo0000
6OoonfX4o`0005kooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool0
07l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000G_oonfX7o`0001Kooo]Z1Ol0002Noook
JP00O_oonfX6o`0001Sooo]Z1?l0001MoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o2?oonfX5o`0005kooo]Z1ol0000FoookJPCo0000WooonfX007kooo]Z1ol0000GoookJPCo0000
GOoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0005kooo]Z1ol0000EoookJPCo0000
WooonfX007oooo]Z1ol0000FoookJPCo0000GOoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oo
nfX5o`00067ooo]Z1Ol0000EoookJPCo0000WooonfX0083ooo]Z2Ol0000CoookJPCo0000GOoonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0001QoookJPSo00004_oonfX4
o`0009oooo]Z0021oookJPSo00004_oonfX5o`0005gooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`Wooo]Z1Ol0001RoookJPSo00004OoonfX4o`0009oooo]Z0022oookJPSo00004OoonfX5o`0005go
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001RoookJPSo00004OoonfX4o`0009oo
oo]Z0023oookJPOo00004OoonfX5o`0005gooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z
1Ol0001SoookJPOo00004OoonfX4o`0009oooo]Z0024oookJPOo00004?oonfX4o`0005oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0006Cooo]Z1ol0000@oookJPCo0000
WooonfX008Kooo]Z1Ol0000@oookJPCo0000GooonfX7o`00O`Wooo]Z1ol007l8oookJPGo0000I_oo
nfX5o`00013ooo]Z1?l0002OoookJP00Q_oonfX8o`0000gooo]Z1?l0001PoookJPGo001o2_oonfX7
o`00O`Sooo]Z1Ol0001VoookJPOo00003_oonfX4o`0009oooo]Z0027oookJPOo00003OoonfX4o`00
07kooo]Z1Ol0001WoookJPOo00003OoonfX4o`0009oooo]Z0027oookJPOo00003OoonfX4o`0007ko
oo]Z1Ol0001WoookJPOo00003OoonfX4o`0009oooo]Z0027oookJPSo00003?oonfX4o`0007kooo]Z
1Ol0001WoookJPSo00003?oonfX4o`0009oooo]Z0027oookJPSo00003?oonfX4o`0007kooo]Z1Ol0
001WoookJPSo00003?oonfX4o`0009oooo]Z002:oookJPGo00003?oonfX4o`0007kooo]Z1Ol0001Z
oookJPGo00003?oonfX4o`0009oooo]Z002;oookJPOo00002OoonfX4o`0007kooo]Z1Ol0001[oook
JPOo00002OoonfX4o`0009oooo]Z002;oookJPSo00002?oonfX4o`0007kooo]Z1Ol0001[oookJPSo
00002?oonfX4o`0009oooo]Z002;oookJPSo00002?oonfX4o`0007kooo]Z1Ol0001[oookJPSo0000
2?oonfX4o`0009oooo]Z002;oookJPSo00002?oonfX4o`0007kooo]Z1Ol0001[oookJPSo00002?oo
nfX4o`0009oooo]Z002<oookJPOo00002?oonfX4o`0007kooo]Z1Ol0001[oookJPSo00002?oonfX4
o`0009oooo]Z002<oookJPOo00002?oonfX4o`0007kooo]Z1Ol0001/oookJPOo00002?oonfX4o`00
09oooo]Z002?oookJPSo00001?oonfX4o`0007kooo]Z1Ol0001_oookJPSo00001?oonfX4o`0009oo
oo]Z002?oookJPSo00001?oonfX4o`0007kooo]Z1Ol0001_oookJPSo00001?oonfX4o`0009oooo]Z
002?oookJPSo00001?oonfX4o`0007kooo]Z1Ol0001_oookJPSo00001?oonfX4o`0009oooo]Z002?
oookJPSo00001?oonfX4o`0007kooo]Z1Ol0001`oookJPOo00001?oonfX4o`0009oooo]Z002@oook
JPoo0000O_oonfX5o`00073ooo]Z1ol000000ooonf[o0000o`000005o`0009oooo]Z002@oookJPoo
0000O_oonfX5o`00073ooo]Z3ol0002OoookJP00T?oonfX?o`0007kooo]Z1Ol0001aoookJPko0000
WooonfX0097ooo]Z3_l0001noookJPGo0000LOoonfX>o`0009oooo]Z002DoookJP_o0000O_oonfX5
o`0007Cooo]Z2ol0002OoookJP00U?oonfX;o`0007kooo]Z1Ol0001doookJP_o0000WooonfX009Co
oo]Z2ol0001noookJPGo0000M?oonfX;o`0009oooo]Z002DoookJP_o0000O_oonfX5o`0007Cooo]Z
2ol0002OoookJP00U?oonfX;o`0007kooo]Z1Ol0001eoookJP[o0000WooonfX009Gooo]Z2_l0001n
oookJPGo0000MOoonfX:o`0009oooo]Z002EoookJP[o0000O_oonfX5o`0007Gooo]Z2_l0002Ooook
JP00UOoonfX:o`0007kooo]Z1Ol0001eoookJP[o0000WooonfX009Gooo]Z2_l0001noookJPGo0000
MOoonfX:o`0009oooo]Z002EoookJP[o0000O_oonfX5o`0007Gooo]Z2_l0002OoookJP00V?oonfX6
o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX6o`0009oooo]Z002HoookJPKo0000L_oonfX3o`00
O`[ooo]Z1Ol0001ioookJPKo0000WooonfX009Sooo]Z1_l0001boookJP?o001o2_oonfX5o`0007Wo
oo]Z1_l0002OoookJP00V?oonfX6o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX6o`0009oooo]Z
002IoookJPGo0000L_oonfX3o`00O`[ooo]Z1_l0001hoookJPKo0000WooonfX009Wooo]Z1Ol0001b
oookJP?o001o2_oonfX5o`0007Wooo]Z1_l0002OoookJP00VOoonfX5o`0007;ooo]Z0ol007l:oook
JPGo0000NOoonfX6o`0009oooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z1Ol0001ioookJPKo
0000WooonfX009Wooo]Z1Ol0001boookJP?o001o2_oonfX5o`0007Wooo]Z1_l0002OoookJP00VOoo
nfX5o`0006oooo]Z1_l007l:oookJPGo0000NOoonfX6o`0009oooo]Z002IoookJPGo0000KooonfX6
o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001aoookJPCo001o2_oonfX5o`00
07Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3o
oo]Z002JoookJPCo0000OooonfX5o`0007Wooo]Z1Ol0002PoookJP00V_oonfX4o`0007oooo]Z1Ol0
001ioookJPGo0000X?oonfX009[ooo]Z1?l0001ooookJPGo0000N_oonfX4o`000:3ooo]Z002Joook
JPCo0000OooonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00
O`kooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX2o`00O`;o
oo]Z1?l007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooo
nfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oook
JP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo
0000oooonfXOoookJP00oooonfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo
0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3Ooo
nfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1?l007l<oookJPGo0000oooonfXO
oookJP00oooonfX?oookJPGo001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wo
oo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00oooo
nfXCoookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX0
0?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o
001ooooonfX/oookJP00oooonfX>oookJPOo001ooooonfX]oookJP00oooonfX?oookJPGo001ooooo
nfX^oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.03279 .30946 L
.03405 .30988 L
.03477 .3098 L
.03543 .30952 L
.03662 .30879 L
.03793 .30822 L
.03911 .30835 L
.04021 .30896 L
.04147 .30972 L
.04262 .30995 L
.04384 .30953 L
.04501 .30881 L
.04624 .30831 L
.04693 .30832 L
.04758 .30854 L
.04827 .30894 L
.04892 .30938 L
.05014 .31001 L
.05146 .31 L
.0522 .30966 L
.05288 .30924 L
.05403 .30863 L
.0551 .30851 L
.05627 .30899 L
.05753 .30984 L
.05885 .31038 L
.0601 .31016 L
.06122 .30952 L
.06244 .30891 L
.0637 .30893 L
.0644 .30927 L
.06505 .30971 L
.06624 .31051 L
.06749 .31085 L
.06815 .31072 L
.06887 .31039 L
.07015 .30965 L
.07093 .30938 L
.07167 .30939 L
.07234 .30963 L
.07306 .31009 L
.07377 .31063 L
.07453 .31115 L
.07525 .31146 L
.07591 .31151 L
.07664 .31133 L
.07734 .31097 L
.07811 .31053 L
.07892 .31018 L
Mistroke
.07963 .31009 L
.08027 .31024 L
.08151 .31103 L
.08222 .3116 L
.08288 .31206 L
.08357 .31237 L
.08433 .31242 L
.08559 .31194 L
.08629 .31155 L
.08694 .31124 L
.0882 .31115 L
.08935 .31176 L
.09061 .31281 L
.09124 .31327 L
.09194 .31358 L
.0927 .31362 L
.09341 .31341 L
.09406 .31308 L
.09476 .31271 L
.09596 .31238 L
.09726 .31285 L
.09792 .31338 L
.09862 .31402 L
.09989 .31496 L
.10115 .31514 L
.10235 .31466 L
.10342 .31415 L
.10458 .31406 L
.10582 .31476 L
.10695 .31584 L
.10825 .31686 L
.10949 .31705 L
.11063 .31661 L
.11168 .31613 L
.11284 .31607 L
.11407 .31683 L
.12449 .32161 L
.13462 .32537 L
.13994 .32713 L
.14067 .32805 L
.14135 .32873 L
.14213 .32915 L
.14285 .32918 L
.14414 .32872 L
.14488 .32849 L
.14555 .3285 L
.14667 .32919 L
.1479 .33078 L
.1492 .33257 L
.15039 .33348 L
Mistroke
.15171 .3334 L
.15244 .33311 L
.15313 .3329 L
.15435 .33318 L
.15505 .33382 L
.15569 .33468 L
.15691 .3366 L
.15806 .33802 L
.15908 .33852 L
.1602 .33831 L
.16141 .33791 L
.1627 .3383 L
.16379 .33962 L
.165 .34168 L
.16622 .34345 L
.16738 .34414 L
.16843 .34397 L
.16956 .34357 L
.17079 .34385 L
.1721 .34551 L
.17323 .34764 L
.17445 .34961 L
.17558 .35043 L
.17661 .35032 L
.1776 .34994 L
.17864 .34996 L
.17979 .35104 L
.18085 .35299 L
.182 .35537 L
.18327 .35715 L
.18455 .35748 L
.18525 .35722 L
.1859 .35696 L
.18707 .35707 L
.18832 .35864 L
.1938 .36489 L
.19498 .36466 L
.19624 .36589 L
.19697 .36737 L
.19762 .36901 L
.1989 .37214 L
.2001 .37382 L
.2014 .37385 L
.20262 .37321 L
.20374 .37344 L
.20491 .37533 L
.206 .37829 L
.20729 .38177 L
.20847 .38345 L
.20971 .38332 L
Mistroke
.21088 .38253 L
.21212 .38281 L
.21281 .38393 L
.21346 .38556 L
.21453 .38902 L
.21568 .3924 L
.21677 .394 L
.21777 .39389 L
.21888 .39287 L
.21994 .39249 L
.22108 .39405 L
.22233 .39811 L
.22357 .40271 L
.22488 .40552 L
.22557 .40568 L
.22632 .40502 L
.22764 .40338 L
.22889 .40384 L
.22959 .40558 L
.23023 .40799 L
.23148 .41369 L
.23265 .41766 L
.23376 .41853 L
.23495 .41669 L
.23613 .41459 L
.23745 .41565 L
.23858 .42043 L
.23979 .42747 L
.24094 .43232 L
.242 .43301 L
.24331 .42938 L
.24456 .42572 L
.24524 .42558 L
.24599 .42776 L
.24729 .43672 L
.24853 .44669 L
.24985 .45105 L
.25097 .44692 L
.25221 .43774 L
.25349 .43277 L
.25421 .43559 L
.25486 .44236 L
.25614 .46343 L
.25735 .48102 L
.25802 .48312 L
.25874 .47531 L
.26004 .43022 L
.26083 .38435 L
.26157 .33297 L
.26297 .23458 L
Mistroke
.26413 .17126 L
.26538 .13788 L
.26656 .13792 L
.26763 .15393 L
.26889 .17499 L
.26961 .18247 L
.27026 .18521 L
.27147 .18118 L
.27275 .17166 L
.27397 .16698 L
.27528 .17139 L
.27652 .18134 L
.27766 .18948 L
.27892 .19262 L
.27964 .19151 L
.2803 .18936 L
.28099 .18692 L
.28164 .18527 L
.28239 .18491 L
.28308 .18632 L
.30156 .22024 L
.3028 .22417 L
.30399 .22557 L
.30464 .22538 L
.30535 .22476 L
.30659 .22392 L
.30778 .22491 L
.30904 .22822 L
.31012 .23179 L
.3113 .23469 L
.3125 .23562 L
.31363 .23504 L
.31429 .2346 L
.31497 .23445 L
.31621 .23565 L
.31685 .23706 L
.31754 .23896 L
.31878 .24243 L
.31954 .24396 L
.32026 .24474 L
.3209 .24489 L
.3216 .24464 L
.32275 .24406 L
.32382 .2443 L
.325 .24608 L
.32626 .24922 L
.32759 .25218 L
.32884 .25337 L
.32997 .25316 L
.3312 .25268 L
Mistroke
.33237 .25319 L
.33343 .25485 L
.33457 .25743 L
.3358 .25994 L
.33694 .26107 L
.338 .26105 L
.339 .26063 L
.34006 .26059 L
.34128 .26177 L
.34197 .26299 L
.34261 .26431 L
.34376 .26658 L
.34502 .26801 L
.34616 .26811 L
.34722 .2677 L
.34834 .26763 L
.34955 .26866 L
.35971 .27791 L
.36927 .28472 L
.37041 .28516 L
.37164 .28482 L
.3728 .28448 L
.37387 .28479 L
.37483 .28574 L
.3759 .28724 L
.37702 .28872 L
.37804 .28947 L
.37922 .28947 L
.38049 .28898 L
.38167 .28888 L
.38279 .28959 L
.38406 .29117 L
.38476 .29209 L
.38541 .2928 L
.38669 .29343 L
.38785 .29318 L
.38887 .29275 L
.38995 .29265 L
.39113 .29334 L
.39222 .29457 L
.39331 .29586 L
.39449 .29668 L
.39577 .29663 L
.39697 .2961 L
.39765 .2959 L
.39836 .29592 L
.39964 .29671 L
.40035 .29747 L
.40102 .29823 L
.4018 .29901 L
Mistroke
.40254 .29948 L
.40317 .29962 L
.40387 .29952 L
.40508 .29898 L
.40576 .29872 L
.40649 .29865 L
.40781 .29928 L
.40901 .30047 L
.41029 .30164 L
.4115 .30203 L
.41261 .30171 L
.41376 .30115 L
.41502 .30099 L
.41573 .30126 L
.41638 .30175 L
.41768 .30299 L
.41891 .30387 L
.41961 .30403 L
.42027 .30393 L
.42096 .30364 L
.42159 .3033 L
.42229 .30299 L
.42302 .30286 L
.42424 .30326 L
.42537 .30419 L
.42662 .30523 L
.42732 .30557 L
.42795 .30565 L
.42864 .3055 L
.42937 .30516 L
.43069 .30451 L
.43142 .30439 L
.43211 .30453 L
.43286 .30496 L
.43367 .30561 L
.43436 .3062 L
.43511 .3067 L
.43583 .30693 L
.43649 .3069 L
.43774 .30636 L
.43837 .30601 L
.43907 .3057 L
.43973 .3056 L
.44043 .30573 L
.44169 .30651 L
.44239 .30707 L
.44305 .30755 L
.44382 .30788 L
.44452 .30793 L
.44579 .30746 L
Mistroke
.44651 .30704 L
.44717 .3067 L
.44837 .30654 L
.44965 .30712 L
.45078 .30796 L
.452 .30861 L
.45315 .30859 L
.45421 .30809 L
.45547 .30738 L
.45666 .3072 L
.45789 .30771 L
.45854 .30816 L
.45923 .30865 L
.46047 .30918 L
.46117 .30917 L
.46183 .30894 L
.46256 .30853 L
.46326 .30811 L
.46457 .30764 L
.46571 .30787 L
.46694 .30865 L
.46826 .30941 L
.46949 .30949 L
.47019 .30923 L
.47095 .30878 L
.47161 .30837 L
.47232 .30805 L
.47295 .30793 L
.47365 .30802 L
.47487 .30865 L
.47561 .30914 L
.47631 .30953 L
.47711 .30974 L
.47784 .30967 L
.47853 .30938 L
.47916 .309 L
.47991 .30854 L
.4806 .30821 L
.48176 .30812 L
.483 .30868 L
.48417 .30943 L
.48526 .30982 L
.48651 .30961 L
.48718 .30925 L
.48788 .3088 L
.4892 .3082 L
.49038 .30828 L
.49103 .30858 L
.49172 .30901 L
.49295 .3097 L
Mistroke
.49363 .30986 L
.49427 .30981 L
.49497 .30955 L
.49573 .3091 L
.49637 .30869 L
.49708 .30833 L
.49836 .30821 L
.4996 .30876 L
.50076 .30948 L
.50193 .30987 L
.50317 .30959 L
.50423 .30896 L
.50539 .30832 L
.50664 .30821 L
.50734 .30846 L
.50798 .30883 L
.50923 .30959 L
.51038 .30989 L
.51147 .3096 L
.51261 .30892 L
.51376 .30832 L
.51503 .30827 L
.51612 .30878 L
.5173 .30953 L
.51841 .30994 L
.51942 .30981 L
.52068 .30913 L
.52187 .30847 L
.52253 .3083 L
.52324 .30835 L
.52447 .30895 L
.5252 .30943 L
.52597 .30987 L
.52662 .31008 L
.52733 .31008 L
.528 .30986 L
.52871 .30947 L
.52999 .30872 L
.53128 .30851 L
.53201 .30874 L
.53268 .30913 L
.5339 .30995 L
.53459 .31028 L
.53524 .3104 L
.53635 .31013 L
.53756 .30943 L
.53884 .30886 L
.54002 .30898 L
.54997 .31064 L
.55124 .3114 L
Mistroke
.55189 .31152 L
.55259 .31141 L
.55336 .31107 L
.55407 .31066 L
.55473 .31032 L
.55543 .31011 L
.55609 .31013 L
.55681 .31041 L
.55812 .31138 L
.5594 .31224 L
.56058 .31241 L
.56177 .31195 L
.56289 .31134 L
.56412 .3111 L
.56544 .31168 L
.56675 .31277 L
.56741 .31325 L
.56813 .31358 L
.56941 .31349 L
.5706 .31289 L
.57178 .31241 L
.5729 .31254 L
.5739 .3132 L
.57499 .31418 L
.57618 .315 L
.57744 .31512 L
.57851 .31467 L
.57969 .31412 L
.58091 .31409 L
.5816 .31444 L
.58223 .31496 L
.5835 .31619 L
.58465 .31695 L
.58578 .31703 L
.58685 .31659 L
.58797 .31609 L
.58919 .31612 L
.59042 .31698 L
.59112 .3177 L
.59177 .31838 L
.59309 .3193 L
.59383 .31939 L
.5945 .31923 L
.59571 .31868 L
.59702 .31843 L
.59825 .31907 L
.5994 .32028 L
.60045 .32141 L
.60159 .3221 L
.60266 .32206 L
Mistroke
.60365 .32165 L
.60474 .32128 L
.60594 .32155 L
.60718 .32272 L
.60834 .32414 L
.60958 .32521 L
.61075 .32538 L
.6118 .325 L
.61294 .32462 L
.61418 .32492 L
.61549 .32627 L
.61672 .32789 L
.61785 .32894 L
.61906 .32918 L
.62038 .3287 L
.62154 .32847 L
.62278 .32911 L
.624 .33065 L
.62515 .33228 L
.62618 .33328 L
.62729 .33355 L
.62852 .33315 L
.62922 .33292 L
.62986 .3329 L
.63117 .33375 L
.63191 .33472 L
.63258 .33578 L
.63377 .33753 L
.63507 .33849 L
.6363 .33835 L
.63743 .33794 L
.63848 .33804 L
.63962 .33908 L
.64068 .3408 L
.64166 .34246 L
.6428 .34381 L
.64405 .34413 L
.64523 .34373 L
.64632 .34356 L
.64755 .34441 L
.64871 .34628 L
.64977 .34828 L
.65088 .34988 L
.6521 .35047 L
.65322 .35016 L
.65443 .34986 L
.65511 .3501 L
.65575 .35073 L
.69464 .39328 L
.71444 .41874 L
Mistroke
.7157 .42587 L
.71639 .42956 L
.71703 .43204 L
.71773 .4332 L
.71849 .43252 L
.71914 .43069 L
.71983 .42822 L
.72048 .42623 L
.72119 .42541 L
.72248 .42932 L
.72373 .43885 L
.72488 .4477 L
.7261 .45101 L
.7268 .44899 L
.72745 .445 L
.72875 .43545 L
.72949 .43281 L
.73016 .43412 L
.7309 .44044 L
.73159 .45037 L
.73241 .46483 L
.73315 .4767 L
.73386 .48299 L
.73452 .48118 L
.73523 .46867 L
.73599 .44164 L
.73728 .36706 L
.73849 .28075 L
.73917 .23403 L
.73981 .19579 L
.74055 .1623 L
.74123 .1433 L
.7419 .13523 L
.74261 .13663 L
.74388 .15494 L
.74456 .16692 L
.74527 .17734 L
.74605 .184 L
.74676 .18515 L
.74792 .1793 L
.74919 .1701 L
.75038 .16703 L
.75147 .17138 L
.75276 .18169 L
.75343 .18692 L
.75415 .19085 L
.75546 .1923 L
.75667 .18871 L
.75786 .18522 L
.75898 .18554 L
Mistroke
.76021 .19057 L
.76152 .19814 L
.76271 .20277 L
.76383 .20348 L
.76483 .20182 L
.76593 .19978 L
.76711 .19991 L
.76842 .20391 L
.76969 .20969 L
.77036 .21229 L
.77106 .21411 L
.77234 .21467 L
.77351 .21323 L
.77461 .21231 L
.77581 .21362 L
.77712 .21783 L
.77835 .22239 L
.77963 .22523 L
.78031 .22558 L
.78104 .22522 L
.78183 .22447 L
.78258 .22396 L
.78326 .22405 L
.78399 .22496 L
.78468 .22656 L
.78541 .22881 L
.78672 .23297 L
.78742 .23456 L
.78806 .23539 L
.78876 .23561 L
.7895 .23527 L
.79075 .23449 L
.79146 .23455 L
.79213 .2352 L
.79336 .23791 L
.79449 .24116 L
.79579 .24405 L
.79703 .2449 L
.81633 .26062 L
.82615 .26928 L
.83153 .27408 L
.83281 .27394 L
.83346 .27428 L
.83417 .27505 L
.83542 .27708 L
.83658 .27896 L
.83767 .27998 L
.83865 .28012 L
.83979 .27973 L
.84087 .27951 L
Mistroke
.84202 .28008 L
.84309 .28142 L
.84433 .28338 L
.84549 .28474 L
.84659 .28516 L
.84776 .28484 L
.84907 .28447 L
.85027 .28494 L
.85151 .28639 L
.85216 .28735 L
.85286 .28831 L
.85414 .28943 L
.85532 .2895 L
.85659 .28901 L
.85722 .28884 L
.85792 .2889 L
.85915 .28978 L
.8603 .29124 L
.861 .29215 L
.86167 .29285 L
.8629 .29343 L
.8636 .29334 L
.86424 .2931 L
.86494 .2928 L
.86569 .29262 L
.86685 .29296 L
.86794 .294 L
.86912 .29545 L
.87042 .29658 L
.8717 .29671 L
.87239 .29645 L
.87304 .29616 L
.8742 .29587 L
.87544 .29637 L
.89365 .30279 L
.8949 .30378 L
.8956 .30401 L
.89623 .30399 L
.89747 .30347 L
.89865 .30294 L
.89985 .30297 L
.90116 .30382 L
.90247 .30499 L
.90322 .30546 L
.90392 .30565 L
.90463 .30557 L
.90538 .30525 L
.90614 .30484 L
.90693 .30449 L
.90762 .30439 L
Mistroke
.90838 .30457 L
.90907 .30497 L
.90971 .30549 L
.91035 .30603 L
.91104 .30655 L
.91229 .30695 L
.91304 .3068 L
.91373 .30647 L
.91504 .30578 L
.9162 .30562 L
.91745 .30618 L
.91863 .30711 L
.9197 .30778 L
.92096 .30789 L
.92167 .30762 L
.92233 .30725 L
.92354 .30664 L
.92483 .3066 L
.92553 .30692 L
.92618 .30736 L
.92687 .30789 L
.92764 .30839 L
.92892 .30868 L
.92962 .30849 L
.93028 .30816 L
.9315 .30746 L
.93266 .30718 L
.9333 .30731 L
.93399 .30765 L
.93521 .30851 L
.93643 .30914 L
.93754 .30912 L
.93877 .30852 L
.94006 .30781 L
.94119 .30766 L
.94224 .30805 L
.94339 .30882 L
.94462 .30946 L
.94532 .30955 L
.94596 .30941 L
.94667 .30907 L
.94742 .30861 L
.94867 .308 L
.94939 .30793 L
.95006 .30809 L
.9512 .30874 L
.95242 .30949 L
.95312 .30972 L
.95376 .30972 L
.955 .30922 L
Mistroke
.95567 .3088 L
.9564 .30838 L
.95772 .30809 L
.95837 .30825 L
.95906 .3086 L
.96029 .30939 L
.96149 .30983 L
.9626 .30965 L
.96382 .30896 L
.96513 .30826 L
.96586 .30815 L
.96654 .30827 L
.96727 .30861 L
.96806 .30911 L
.96938 .30978 L
.97013 .30986 L
.97083 .3097 L
.97213 .30896 L
.97332 .30831 L
.97398 .30817 L
.9747 .30824 L
.97601 .3089 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000O_oonfX4o`0009cooo]Z002NoookJPCo0000NooonfX5o`0007ko
oo]Z1?l0002LoookJP00W_oonfX4o`0007_ooo]Z1Ol0001noookJPCo0000W?oonfX009kooo]Z1?l0
001koookJPGo0000O_oonfX4o`0009cooo]Z002NoookJPCo0000NooonfX5o`0007kooo]Z1?l0002L
oookJP00W_oonfX4o`0007_ooo]Z1Ol0001noookJPCo0000W?oonfX009kooo]Z1Ol0001joookJPGo
0000O_oonfX4o`0009cooo]Z002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000
VooonfX009kooo]Z1Ol0001]oookJP?o001o2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5
o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo0000GOoonfX:o`00
O`Kooo]Z0ol007l:oookJPGo0000OOoonfX6o`0009_ooo]Z002MoookJPKo0000GOoonfX:o`00O`Ko
oo]Z0ol007l:oookJPKo0000O?oonfX6o`0009_ooo]Z002MoookJPKo0000KOoonfX3o`00O`[ooo]Z
1Ol0001moookJPKo0000VooonfX009gooo]Z1_l0001]oookJP?o001o2_oonfX5o`0007gooo]Z1_l0
002KoookJP00WOoonfX6o`0006gooo]Z0ol007l:oookJPGo0000OOoonfX6o`0009_ooo]Z002Moook
JPKo0000KOoonfX3o`00O`[ooo]Z1Ol0001moookJPOo0000V_oonfX009gooo]Z1ol0001YoookJPKo
001o2_oonfX5o`0007gooo]Z1ol0002JoookJP00WOoonfX:o`0006Kooo]Z1_l007l:oookJPGo0000
OOoonfX:o`0009Oooo]Z002MoookJP[o0000J?oonfX4o`00O`[ooo]Z1Ol0001moookJP[o0000Uooo
nfX009gooo]Z2_l0001YoookJP?o001o2_oonfX5o`0007gooo]Z2_l0002GoookJP00WOoonfX:o`00
07Kooo]Z1Ol0001moookJP[o0000UooonfX009gooo]Z2_l0001foookJPGo0000OOoonfX:o`0009Oo
oo]Z002MoookJP[o0000M_oonfX5o`0007gooo]Z2_l0002GoookJP00WOoonfX;o`0007Gooo]Z1Ol0
001moookJP_o0000U_oonfX009gooo]Z2ol0001eoookJPGo0000OOoonfX;o`0009Kooo]Z002Moook
JP_o0000MOoonfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX;o`0007Gooo]Z1Ol0001moookJP_o
0000U_oonfX009gooo]Z3_l0001boookJPGo0000OOoonfX>o`0009?ooo]Z002MoookJPko0000L_oo
nfX5o`0007gooo]Z3_l0002CoookJP00WOoonfX>o`0007;ooo]Z1Ol0001moookJPoo0000T_oonfX0
09gooo]Z3ol0001aoookJPGo0000OOoonfX?o`0009;ooo]Z002MoookJPCo00001?oonfX7o`00077o
oo]Z1Ol0001moookJPCo00000ooonfX8o`0009;ooo]Z002MoookJPCo00001?oonfX8o`00073ooo]Z
1Ol0001moookJPCo00000ooonfX8o`0009;ooo]Z002MoookJPCo00001?oonfX9o`0006oooo]Z1Ol0
001moookJPCo00001?oonfX8o`00097ooo]Z002MoookJPCo00001?oonfX9o`0006oooo]Z1Ol0001m
oookJPCo00001?oonfX8o`00097ooo]Z002MoookJPCo00002?oonfX6o`0006kooo]Z1Ol0001moook
JPCo00001ooonfX8o`0008kooo]Z002MoookJPCo00002OoonfX5o`0006kooo]Z1Ol0001moookJPCo
00002?oonfX7o`0008kooo]Z002MoookJPCo00002OoonfX6o`0006gooo]Z1Ol0001moookJPCo0000
2?oonfX7o`0008kooo]Z002MoookJPCo00002_oonfX5o`0006gooo]Z1Ol0001moookJPCo00002?oo
nfX7o`0008kooo]Z002MoookJPCo00002_oonfX6o`0006cooo]Z1Ol0001moookJPCo00002?oonfX8
o`0008gooo]Z002MoookJPCo00002ooonfX5o`0006cooo]Z1Ol0001moookJPCo00002OoonfX7o`00
08gooo]Z002MoookJPCo00002ooonfX6o`0006_ooo]Z1Ol0001moookJPCo00002ooonfX5o`0008go
oo]Z002MoookJPCo00003?oonfX6o`0006[ooo]Z1Ol0001moookJPCo00003?oonfX7o`0008[ooo]Z
002MoookJPCo00003?oonfX6o`0006[ooo]Z1Ol0001moookJPCo00003?oonfX7o`0008[ooo]Z002M
oookJPCo00003OoonfX6o`0006Wooo]Z1Ol0001moookJPCo00003?oonfX8o`0008Wooo]Z002Moook
JPCo00003_oonfX5o`0006Wooo]Z1Ol0001moookJPCo00003OoonfX7o`0008Wooo]Z002MoookJPCo
00003_oonfX6o`0006Sooo]Z1Ol0001moookJPCo00003OoonfX7o`0008Wooo]Z002MoookJPCo0000
3ooonfX5o`0006Sooo]Z1Ol0001moookJPCo00004?oonfX5o`0008Sooo]Z002MoookJPCo00003ooo
nfX9o`0006Cooo]Z1Ol0001moookJPCo00004?oonfX8o`0008Gooo]Z002MoookJPCo00004?oonfX8
o`0004Kooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0001moookJPCo00004?oonfX8
o`0008Gooo]Z002MoookJPCo00004?oonfX9o`0004Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`Wooo]Z1Ol0001moookJPCo00004OoonfX7o`0008Gooo]Z002MoookJPCo00004OoonfX8o`0004Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oo
nf[o001oo`00Ool007l9oookJPGo0000OOoonfX4o`00017ooo]Z2?l00024oookJP00WOoonfX4o`00
01;ooo]Z1ol0000goookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Sooo]Z1Ol0001moookJPCo00004_oonfX7o`0008Cooo]Z002MoookJPCo00005OoonfX4o`0003Oo
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000O?oonfX4o`0001Co
oo]Z1Ol00024oookJP00WOoonfX4o`0001Gooo]Z1ol00010oookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l8oookJPGo0000OOoonfX4o`0001Gooo]Z1ol00021oookJP00WOoonfX4o`0001Gooo]Z2?l0
000ooookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`0007gooo]Z1?l0
000EoookJPSo0000P?oonfX009gooo]Z1?l0000EoookJPSo0000?ooonfX3o`00O`?ooo]Z0ol007l7
oookJPOo001o2OoonfX5o`0007gooo]Z1?l0000EoookJPSo0000P?oonfX009gooo]Z1?l0000Foook
JPOo0000?ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0007gooo]Z1?l0000Foook
JPSo0000OooonfX009gooo]Z1?l0000IoookJPGo0000?_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o3_oonfX5o`0007gooo]Z1?l0000IoookJPGo0000OooonfX009gooo]Z1?l0000IoookJPSo0000
??oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Wo
oo]Z1ol0001moookJP00WOoonfX4o`0001Wooo]Z2?l0000loookJPOo001o2OoonfX7o`00O`Sooo]Z
1Ol0001moookJPCo00006_oonfX7o`0007cooo]Z002MoookJPCo00006_oonfX7o`0003gooo]Z1Ol0
07l:oookJPOo001o2?oonfX5o`0007gooo]Z1?l0000JoookJPSo0000NooonfX009gooo]Z1?l0000J
oookJPSo0000F_oonfX5o`0007gooo]Z1?l0000JoookJPWo0000N_oonfX009gooo]Z1?l0000Moook
JPSo0000EooonfX5o`0007gooo]Z1?l0000MoookJPOo0000NOoonfX009gooo]Z1?l0000MoookJPSo
0000EooonfX5o`0007gooo]Z1?l0000NoookJPOo0000N?oonfX009gooo]Z1?l0000NoookJPSo0000
E_oonfX5o`0007gooo]Z1?l0000OoookJPOo0000MooonfX009gooo]Z1?l0000OoookJPOo0000E_oo
nfX5o`0007gooo]Z1?l0000PoookJPOo0000M_oonfX009gooo]Z1?l0000OoookJPSo0000EOoonfX5
o`0007cooo]Z1Ol0000QoookJPOo0000MOoonfX009gooo]Z1?l0000RoookJPSo0000D_oonfX5o`00
07cooo]Z1Ol0000RoookJPSo0000LooonfX009gooo]Z1?l0000RoookJPSo0000D_oonfX5o`0007co
oo]Z1Ol0000SoookJPSo0000L_oonfX009gooo]Z1?l0000SoookJPSo0000DOoonfX5o`0007cooo]Z
1?l0000UoookJPWo0000L?oonfX009gooo]Z1?l0000ToookJPOo0000DOoonfX5o`0007cooo]Z1?l0
000VoookJPWo0000KooonfX009gooo]Z1?l0000VoookJPWo0000COoonfX5o`0007cooo]Z1?l0000X
oookJPSo0000K_oonfX009gooo]Z1?l0000WoookJPWo0000C?oonfX5o`0007cooo]Z1?l0000Yoook
JPSo0000KOoonfX002;ooo]Z0ol007meoookJP?o001o1?l00002oookJP?o001o0ooonfX5o`00Oa[o
oo]Z2_l0001;oookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPGo001o8ooonfX7o`0004co
oo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z1?l007l4o`0000;ooo]Z0ol007l2oookJPOo001o
6_oonfX:o`0004[ooo]Z1Ol0001coookJPOo001o0_oonfX4o`0000;ooo]Z1ol007lSoookJPSo0000
B_oonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`03oookJ_l0003o000000;o00000_oo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o7_oonfX7o`0004Wooo]Z
1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`000003oookJ_l007oo001o00;o
001o00Cooo]Zo`00Ool007oo001o9?oonfX7o`0004[ooo]Z0ol007lMoookJP004ooonfX:o`00O`Go
oo]Z0ol007mWoookJP[o001o0_oonfX3o`00O`;ooo]Z1?l00006oookJP?o001o0ooonfX3o`00Oako
oo]Z2?l00017oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`000004
oookJ_l007oo001oo`00O`?ooo]Z0ol007lToookJPOo0000BOoonfX3o`00Oagooo]Z000CoookJP[o
001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o0_oonfX4o`0000cooo]Z0ol007lOoookJPSo
0000A_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00007oookJP?o
001o9OoonfX9o`0004Kooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l2oookJPCo0000
3?oonfX3o`00Ob3ooo]Z2?l00015oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000
o`000002o`0000Oooo]Z0ol007lVoookJPWo0000AOoonfX3o`00Oagooo]Z000RoookJP?o001oLooo
nfX3o`00O`;ooo]Z1?l00007oookJP;o001o0_oonfX4o`00Ob7ooo]Z2?l00014oookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l007l2oookJPCo001o9ooo
nfX9o`0004Cooo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000003
o`0000Oooo]Z1ol007lToookJP[o0000@?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Z
o`000?l000000_l00002oookJPOo001o:?oonfX<o`00047ooo]Z0ol007lMoookJP008_oonfX3o`00
Og?ooo]Z0ol007l00ooonf[o0000o`000003o`0000Oooo]Z1_l007lVoookJP[o0000?ooonfX5o`00
07;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJPKo001o;OoonfX9o`00
043ooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l00ooonf[o0000o`000003o`0000Oo
oo]Z0_l007l[oookJPco0000??oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l0
00000_l00002oookJP;o001o<_oonfX;o`0003[ooo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z
0ol007l4o`0000Sooo]Z0_l007l/oookJPco0000>ooonfX5o`0007?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l2oookJPCo00000_oonfX2o`00Oc;ooo]Z3?l0000ioookJPKo001o7OoonfX0027ooo]Z
1?l007mdoookJP?o001o1?l00009oookJPOo001o:_oonfX;o`0003Sooo]Z1Ol0001coookJPOo001o
0_oonfX4o`0000?ooo]Z1ol007l_oookJPgo0000=ooonfX4o`00Oagooo]Z000RoookJP?o001oMOoo
nfX2o`00O`Co00002OoonfX7o`00Ob[ooo]Z3Ol0000foookJPGo0000M?oonfX5o`00O`?ooo]Z1?l0
0003oookJPOo001o<?oonfX<o`0003Sooo]Z0ol007lMoookJP00W?oonfX4o`0003gooo]Z3_l0000b
oookJPGo0000O?oonfX4o`0003kooo]Z3Ol0001CoookJP00W?oonfX4o`0003oooo]Z3ol0000_oook
JPGo0000O?oonfX4o`0003oooo]Z3ol0001@oookJP00W?oonfX4o`00043ooo]Z4?l0000]oookJPGo
0000O?oonfX4o`00043ooo]Z4?l0001>oookJP00W?oonfX4o`0004?ooo]Z4Ol0000YoookJPGo0000
O?oonfX4o`0004?ooo]Z4?l0001;oookJP00W?oonfX4o`0004Oooo]Z4_l0000ToookJPGo0000O?oo
nfX4o`0004Sooo]Z4?l00016oookJP00W?oonfX4o`0004Sooo]Z6Ol0000LoookJPGo0000O?oonfX4
o`0004_ooo]Z5_l0000moookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo
00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0
000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP007OoonfX00ol0003ooo]ZoookJP05oook
JRco0000BooonfX4o`0007gooo]Z1Ol000000ooonf[o0000o`00000@o`0000;ooo]Z6ol0001<oook
JPCo0000OooonfX00ol0003ooo]ZoookJP0LoookJP00>ooonfXHo`0004Wooo]Z1?l0001moookJPGo
00006ooonfXIo`0004Sooo]Z1?l0002NoookJP00@?oonfXDo`0004Sooo]Z1?l0001moookJPGo0000
8?oonfXEo`0004Oooo]Z1?l0002NoookJP00B?oonfX?o`0004Gooo]Z1?l0001moookJPGo0000:?oo
nfXAo`0004?ooo]Z1?l0002NoookJP00C_oonfX<o`0004;ooo]Z1?l0001moookJPGo0000;?oonfX@
o`00043ooo]Z1?l0002NoookJP00D?oonfX=o`0003oooo]Z1?l0001moookJPGo0000;OoonfXAo`00
03kooo]Z1?l0002NoookJP00DOoonfX=o`0003kooo]Z1?l0001moookJPGo0000<OoonfX=o`0003ko
oo]Z1?l0002NoookJP00E?oonfX>o`0003[ooo]Z1?l0001moookJPGo0000=_oonfX<o`0003[ooo]Z
1?l0002NoookJP00EooonfX;o`0003[ooo]Z1?l0001moookJPGo0000=_oonfX<o`0003[ooo]Z1?l0
002NoookJP00F_oonfX<o`0003Kooo]Z1?l0001moookJPGo0000>_oonfX<o`0003Kooo]Z1?l0002N
oookJP00FooonfX;o`0003Kooo]Z1?l0001moookJPGo0000>ooonfX;o`0003Kooo]Z1?l0002Noook
JP00G_oonfX9o`0003Gooo]Z1?l0001moookJPGo0000?_oonfX9o`0003Gooo]Z1?l0002NoookJP00
GooonfX;o`0003;ooo]Z1?l0001moookJPGo0000?ooonfX<o`00037ooo]Z1?l0002NoookJP00H_oo
nfX9o`00037ooo]Z1?l0001moookJPGo0000@_oonfX9o`00037ooo]Z1?l0002NoookJP00HooonfX8
o`00037ooo]Z1?l0001moookJPGo0000@ooonfX9o`00033ooo]Z1?l0002NoookJP00I?oonfX;o`00
02gooo]Z1?l0001moookJPGo0000A?oonfX;o`0002gooo]Z1?l0002NoookJP00IooonfX8o`0002go
oo]Z1?l0001moookJPGo0000AooonfX9o`0002cooo]Z1?l0002NoookJP00IooonfX9o`0002cooo]Z
1?l0001moookJPGo0000B?oonfX8o`0002cooo]Z1?l0002NoookJP00J?oonfX;o`0002Wooo]Z1?l0
001moookJPGo0000B?oonfX;o`0002Wooo]Z1?l0002NoookJP00JooonfX8o`0002Wooo]Z1?l0001m
oookJPGo0000C?oonfX7o`0002Wooo]Z1?l0002NoookJP00K?oonfX8o`0002Sooo]Z1?l0001moook
JPGo0000C?oonfX7o`0002Wooo]Z1?l0002NoookJP00KOoonfX8o`0002Oooo]Z1?l0001moookJPGo
0000COoonfX7o`0002Sooo]Z1?l0002NoookJP00KooonfX8o`0002Gooo]Z1?l0001moookJPGo0000
CooonfX6o`0002Oooo]Z1?l0002NoookJP00L?oonfX8o`0002Cooo]Z1?l0001moookJPGo0000Cooo
nfX7o`0002Kooo]Z1?l0002NoookJP00LOoonfX8o`0002;ooo]Z1Ol0001moookJPGo0000D?oonfX7
o`0002Gooo]Z1?l0002NoookJP00LOoonfX9o`00027ooo]Z1Ol0001moookJPGo0000DOoonfX7o`00
02Cooo]Z1?l0002NoookJP00M?oonfX8o`0001oooo]Z1Ol0001moookJPGo0000D_oonfX7o`0002?o
oo]Z1?l0002NoookJP00MOoonfX7o`0001oooo]Z1?l0001noookJPGo0000DooonfX7o`0002;ooo]Z
1?l0002NoookJP00M_oonfX7o`0001kooo]Z1?l0001noookJPGo0000E?oonfX7o`00027ooo]Z1?l0
002NoookJP00MooonfX6o`0001kooo]Z1?l0001noookJPGo0000EOoonfX7o`00023ooo]Z1?l0002N
oookJP00N?oonfX6o`0001gooo]Z1?l0001noookJPGo0000E_oonfX7o`0001oooo]Z1?l0002Noook
JP00NOoonfX7o`0001_ooo]Z1?l0001noookJPGo0000EooonfX7o`0001kooo]Z1?l0002NoookJP00
NOoonfX8o`0001[ooo]Z1?l0001noookJPGo0000F?oonfX6o`0001kooo]Z1?l0002NoookJP00N_oo
nfX7o`0001[ooo]Z1?l0001noookJPGo0000FOoonfX6o`0001gooo]Z1?l0002NoookJP00N_oonfX8
o`0001Wooo]Z1?l0001noookJPGo0000F_oonfX6o`0001cooo]Z1?l0002NoookJP00OOoonfX5o`00
01Wooo]Z1?l0001PoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000F_oonfX7o`00
01_ooo]Z1?l0002NoookJP00OOoonfX8o`0001Kooo]Z1?l0001OoookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l9oookJPGo0000FooonfX7o`0001[ooo]Z1?l0002NoookJP00O_oonfX7o`0001Kooo]Z
1?l0001OoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o
001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005cooo]Z1ol0000IoookJPCo0000W_oonfX007ko
oo]Z2?l0000EoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`So
oo]Z1Ol0001MoookJPOo00006?oonfX4o`0009kooo]Z001ooookJPOo00005OoonfX4o`0005kooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001MoookJPOo00005ooonfX4o`0009kooo]Z
0021oookJPGo00005OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0
001OoookJPOo00005_oonfX4o`0009kooo]Z0022oookJPOo00004_oonfX4o`0005kooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000H?oonfX7o`0001Gooo]Z1?l0002N
oookJP00P_oonfX8o`00017ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oook
JPGo0000HOoonfX7o`0001Cooo]Z1?l0002NoookJP00P_oonfX8o`00017ooo]Z1?l0001NoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000H_oonfX6o`0001Cooo]Z1?l0002NoookJP00
PooonfX8o`00013ooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000
HooonfX6o`0001?ooo]Z1?l0002NoookJP00Q?oonfX7o`00013ooo]Z1?l0001OoookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001ToookJPKo00004_oonfX4o`0009kooo]Z
0026oookJPGo00004?oonfX4o`0005oooo]Z1ol007l9oookJPOo001o2?oonfX5o`0006Cooo]Z1ol0
000AoookJPCo0000W_oonfX008Oooo]Z1ol0000=oookJPCo0000H?oonfX5o`00O`[ooo]Z1ol007l8
oookJPGo0000IOoonfX7o`00013ooo]Z1?l0002NoookJP00QooonfX7o`0000gooo]Z1?l0001noook
JPGo0000I_oonfX7o`0000kooo]Z1Ol0002NoookJP00QooonfX7o`0000gooo]Z1?l0001noookJPGo
0000IooonfX7o`0000gooo]Z1Ol0002NoookJP00QooonfX8o`0000cooo]Z1?l0001noookJPGo0000
J?oonfX6o`0000gooo]Z1Ol0002NoookJP00R?oonfX7o`0000cooo]Z1?l0001noookJPGo0000JOoo
nfX6o`0000cooo]Z1?l0002OoookJP00R_oonfX5o`0000cooo]Z1?l0001noookJPGo0000J_oonfX6
o`0000_ooo]Z1?l0002OoookJP00RooonfX7o`0000Wooo]Z1?l0001noookJPGo0000J_oonfX7o`00
00[ooo]Z1?l0002OoookJP00RooonfX8o`0000Sooo]Z1?l0001noookJPGo0000JooonfX7o`0000Wo
oo]Z1?l0002OoookJP00RooonfX8o`0000Sooo]Z1?l0001noookJPGo0000K?oonfX7o`0000Sooo]Z
1?l0002OoookJP00RooonfX8o`0000Sooo]Z1?l0001noookJPGo0000KOoonfX6o`0000Sooo]Z1?l0
002OoookJP00RooonfX8o`0000Sooo]Z1?l0001noookJPGo0000K_oonfX5o`0000Sooo]Z1?l0002O
oookJP00S?oonfX7o`0000Sooo]Z1?l0001noookJPGo0000KooonfX5o`0000Oooo]Z1?l0002Ooook
JP00SooonfX8o`0000Cooo]Z1?l0001noookJPGo0000KooonfX8o`0000Cooo]Z1?l0002OoookJP00
SooonfX8o`0000Cooo]Z1?l0001noookJPGo0000KooonfX8o`0000Cooo]Z1?l0002OoookJP00Sooo
nfX8o`0000Cooo]Z1?l0001noookJPGo0000L?oonfX8o`0000?ooo]Z1?l0002OoookJP00T?oonfX7
o`0000Cooo]Z1?l0001noookJPGo0000L?oonfX8o`0000?ooo]Z1?l0002OoookJP00T?oonfX?o`00
07kooo]Z1Ol0001`oookJPoo0000WooonfX0093ooo]Z3ol0001noookJPGo0000L?oonfX?o`0009oo
oo]Z002AoookJPko0000O_oonfX5o`00073ooo]Z3ol0002OoookJP00TOoonfX>o`0007kooo]Z1Ol0
001aoookJPko0000WooonfX009Cooo]Z2ol0001noookJPGo0000M?oonfX;o`0009oooo]Z002Doook
JP_o0000O_oonfX5o`0007Cooo]Z2ol0002OoookJP00U?oonfX;o`0007kooo]Z1Ol0001doookJP_o
0000WooonfX009Cooo]Z2ol0001noookJPGo0000M?oonfX;o`0009oooo]Z002DoookJP_o0000O_oo
nfX5o`0007Cooo]Z2ol0002OoookJP00UOoonfX:o`0007kooo]Z1Ol0001eoookJP[o0000WooonfX0
09Gooo]Z2_l0001noookJPGo0000MOoonfX:o`0009oooo]Z002EoookJP[o0000O_oonfX5o`0007Go
oo]Z2_l0002OoookJP00UOoonfX:o`0007kooo]Z1Ol0001eoookJP[o0000WooonfX009Gooo]Z2_l0
001noookJPGo0000M_oonfX9o`0009oooo]Z002HoookJPOo0000LOoonfX3o`00O`[ooo]Z1Ol0001i
oookJPKo0000WooonfX009Wooo]Z1Ol0001boookJP?o001o2_oonfX5o`0007Wooo]Z1_l0002Ooook
JP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000
L_oonfX3o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001boookJP?o001o2_oo
nfX6o`0007Sooo]Z1Ol0002PoookJP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX5
o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wo
oo]Z1Ol0001boookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007;ooo]Z
0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000KooonfX6o`00O`[ooo]Z1Ol0
001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001_oookJPKo001o2_oonfX5o`0007Wooo]Z1Ol0002P
oookJP00V_oonfX4o`00077ooo]Z1?l007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002JoookJPCo
0000L_oonfX3o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009[ooo]Z1?l0001ooookJPGo0000
NOoonfX5o`000:3ooo]Z002JoookJPCo0000OooonfX5o`0007Wooo]Z1Ol0002PoookJP00V_oonfX4
o`0007oooo]Z1Ol0001joookJPCo0000X?oonfX009[ooo]Z1?l0001ooookJPGo0000N_oonfX4o`00
0:3ooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[o
oo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2?oo
nfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o3_oonfX3
o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooo
nfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2
o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooook
JQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z1?l007l=oookJPGo0000oooo
nfXOoookJP00oooonfX>oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3ooonfX5o`00
O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP00
oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z4ooonfX3o`00Oooooo]Z;?oo
nfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oook
JP?o001ooooonfX/oookJP00oooonfX=oookJPCo001o0_oonfX3o`00Oooooo]Z;?oonfX00?oooo]Z
3_oonfX7o`00Oooooo]Z;OoonfX00?oooo]Z3ooonfX5o`00Oooooo]Z;_oonfX00?oooo]ZoooonfY2
oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30835 L
.02605 .30819 L
.02729 .30865 L
.02846 .30938 L
.02954 .30982 L
.03053 .30977 L
.03163 .30923 L
.03279 .30852 L
.03395 .30819 L
.0352 .30854 L
.03638 .30927 L
.03746 .3098 L
.03873 .30979 L
.03944 .30946 L
.04011 .30906 L
.04132 .30839 L
.04262 .30831 L
.04327 .30856 L
.04396 .30898 L
.04519 .30974 L
.04588 .30996 L
.04652 .30997 L
.04722 .30976 L
.04797 .30935 L
.04862 .30894 L
.04933 .30857 L
.05061 .30841 L
.05186 .30899 L
.05302 .30975 L
.05414 .31018 L
.05519 .31005 L
.05634 .30943 L
.05759 .30876 L
.05882 .30869 L
.06012 .30936 L
.06124 .31012 L
.06244 .31055 L
.06315 .31047 L
.0638 .3102 L
.06509 .30944 L
.06625 .30904 L
.06748 .30932 L
.07287 .31022 L
.07401 .30969 L
.0751 .30972 L
.07635 .31043 L
.07749 .31129 L
.07874 .31181 L
.07945 .31176 L
Mistroke
.08011 .31151 L
.08139 .31079 L
.08257 .31045 L
.08324 .31056 L
.08395 .31092 L
.08467 .31147 L
.08545 .3121 L
.08613 .31255 L
.08685 .3128 L
.08816 .31258 L
.08882 .31224 L
.08953 .31185 L
.09081 .31154 L
.09207 .31205 L
.09323 .31302 L
.09388 .31355 L
.09458 .31396 L
.09585 .31406 L
.09658 .31377 L
.09736 .31336 L
.09802 .31306 L
.09874 .31291 L
.0995 .31307 L
.1002 .31349 L
.10101 .31419 L
.10177 .31489 L
.10247 .31542 L
.10312 .3157 L
.10383 .31573 L
.10458 .3155 L
.1058 .31489 L
.10648 .31466 L
.10712 .31465 L
.10829 .31523 L
.10953 .31642 L
.11063 .31738 L
.11167 .31775 L
.11281 .31749 L
.11404 .3169 L
.11527 .31676 L
.11597 .31706 L
.11662 .31758 L
.11735 .31834 L
.11804 .31908 L
.11934 .32003 L
.12046 .32009 L
.12168 .31959 L
.12299 .31921 L
.12419 .31967 L
.14252 .32877 L
Mistroke
.15232 .33454 L
.15357 .33448 L
.15427 .33421 L
.1549 .334 L
.15565 .33402 L
.15636 .3344 L
.15701 .33509 L
.15772 .33611 L
.15902 .33818 L
.15967 .33899 L
.16039 .33951 L
.16166 .33953 L
.16285 .3391 L
.16414 .33926 L
.16536 .3406 L
.16646 .34248 L
.16765 .34436 L
.16895 .34529 L
.1696 .34526 L
.17032 .34501 L
.1716 .34471 L
.1728 .34545 L
.17391 .34718 L
.17508 .34944 L
.17608 .35095 L
.17717 .35163 L
.17836 .35139 L
.17962 .35104 L
.18081 .35172 L
.18189 .35346 L
.18311 .35604 L
.18425 .35796 L
.18545 .3587 L
.18675 .35832 L
.18788 .35807 L
.18892 .35877 L
.19011 .3609 L
.19124 .36355 L
.19246 .36579 L
.19375 .36652 L
.19498 .36605 L
.19609 .36581 L
.19739 .36709 L
.19813 .36865 L
.19881 .37039 L
.20004 .37341 L
.20074 .37455 L
.20137 .37507 L
.2025 .37494 L
.20358 .37435 L
Mistroke
.20456 .37442 L
.20564 .37588 L
.20671 .37865 L
.20786 .38197 L
.20913 .38431 L
.21031 .38455 L
.21155 .3837 L
.21269 .38361 L
.21399 .38575 L
.21522 .38961 L
.21626 .39288 L
.21738 .39488 L
.21861 .39481 L
.21975 .39373 L
.23971 .42539 L
.24041 .42937 L
.24108 .43223 L
.24184 .43374 L
.24254 .43325 L
.2438 .42927 L
.24446 .42708 L
.24518 .4259 L
.24587 .42677 L
.24661 .43013 L
.24729 .43511 L
.24794 .44058 L
.24864 .44628 L
.24939 .45038 L
.25021 .45126 L
.25096 .44848 L
.2522 .43938 L
.25289 .43481 L
.25352 .43302 L
.25475 .43966 L
.25591 .45754 L
.25656 .46938 L
.25726 .47949 L
.2585 .4801 L
.25919 .4657 L
.25984 .44127 L
.26055 .40314 L
.26131 .35214 L
.26261 .25806 L
.26331 .2116 L
.26398 .17631 L
.26528 .13836 L
.26645 .13747 L
.26713 .14668 L
.26785 .15953 L
.26914 .17924 L
Mistroke
.26986 .18434 L
.27053 .18468 L
.27126 .18119 L
.27205 .1752 L
.27336 .16731 L
.2741 .16683 L
.27479 .16936 L
.27605 .17895 L
.27669 .18433 L
.27738 .18897 L
.27858 .19214 L
.27969 .18989 L
.28101 .18535 L
.28224 .18458 L
.28337 .18851 L
.28457 .19544 L
.28525 .19912 L
.2859 .2016 L
.28711 .20287 L
.28839 .20067 L
.28956 .19877 L
.29086 .2001 L
.29151 .20232 L
.29222 .2055 L
.2934 .2107 L
.2945 .21361 L
.29578 .21363 L
.29695 .21206 L
.29805 .21148 L
.29907 .21294 L
.30018 .21659 L
.30137 .22111 L
.3025 .22399 L
.30374 .22452 L
.30504 .22337 L
.30624 .22303 L
.30738 .22473 L
.30841 .22779 L
.30953 .23146 L
.31072 .23404 L
.31201 .23447 L
.3132 .23365 L
.31449 .23356 L
.31522 .23446 L
.3159 .23595 L
.31712 .23942 L
.31827 .24234 L
.3189 .24331 L
.31959 .24376 L
.32081 .24339 L
Mistroke
.32205 .24288 L
.32321 .24367 L
.32426 .24573 L
.32539 .24867 L
.32663 .25129 L
.32794 .25225 L
.32906 .25188 L
.33028 .25152 L
.33143 .25234 L
.33248 .25427 L
.3336 .25691 L
.33483 .25918 L
.33596 .25997 L
.33701 .25974 L
.33801 .25936 L
.33908 .2596 L
.34021 .26106 L
.34146 .26362 L
.34276 .26601 L
.34397 .26696 L
.3451 .26679 L
.34613 .26642 L
.34732 .26671 L
.34845 .26811 L
.35855 .2776 L
.36732 .28353 L
.36969 .28377 L
.371 .28341 L
.37224 .28395 L
.37339 .28535 L
.37464 .28718 L
.37578 .2883 L
.37683 .28853 L
.37797 .28816 L
.3792 .28783 L
.38036 .28828 L
.38142 .28943 L
.38267 .29112 L
.38398 .29231 L
.38509 .29243 L
.3863 .29197 L
.387 .29173 L
.38766 .29171 L
.3889 .29241 L
.3896 .29317 L
.39024 .29398 L
.39099 .29488 L
.39169 .29551 L
.39285 .29588 L
.39413 .29548 L
Mistroke
.39537 .29504 L
.39607 .29509 L
.39671 .2954 L
.39802 .29668 L
.39871 .29748 L
.39943 .29821 L
.40007 .29864 L
.40077 .29882 L
.40199 .29851 L
.40273 .29816 L
.40352 .29791 L
.40427 .29793 L
.40495 .29825 L
.4056 .29879 L
.40632 .29955 L
.40762 .30083 L
.40884 .30131 L
.40953 .30121 L
.41018 .30095 L
.41148 .30037 L
.41221 .30029 L
.41289 .30049 L
.41402 .30135 L
.41526 .30258 L
.41655 .30335 L
.41776 .30325 L
.41894 .30267 L
.42023 .30228 L
.42144 .30268 L
.42256 .30362 L
.42366 .30458 L
.42468 .30508 L
.42575 .30499 L
.42693 .30442 L
.42819 .30393 L
.42939 .30415 L
.43047 .30493 L
.43165 .30592 L
.43293 .30649 L
.43364 .30643 L
.43428 .30618 L
.43545 .30555 L
.43673 .30521 L
.43803 .30569 L
.43874 .30623 L
.4394 .30678 L
.44058 .30748 L
.44185 .30748 L
.44257 .30716 L
.44334 .30671 L
Mistroke
.44408 .30636 L
.44476 .30621 L
.44604 .30657 L
.44668 .307 L
.4474 .30756 L
.4487 .30831 L
.44989 .30832 L
.4512 .30766 L
.45187 .30728 L
.45258 .30701 L
.45379 .30709 L
.4549 .30775 L
.45622 .30866 L
.45744 .309 L
.45868 .30861 L
.45933 .30823 L
.46004 .30782 L
.46077 .30754 L
.46147 .3075 L
.46278 .30805 L
.46392 .30884 L
.46514 .30938 L
.46583 .30938 L
.46647 .30917 L
.4677 .30846 L
.4684 .30808 L
.46914 .30785 L
.47045 .3081 L
.47119 .30853 L
.47187 .309 L
.47262 .30943 L
.47343 .30965 L
.47412 .30959 L
.47488 .30928 L
.47559 .30885 L
.47625 .30845 L
.47749 .30804 L
.47881 .3084 L
.48006 .30919 L
.4812 .30973 L
.48251 .30964 L
.48376 .30894 L
.48491 .30831 L
.48598 .30815 L
.48715 .30859 L
.4884 .30938 L
.48912 .30972 L
.48977 .30985 L
.49049 .30974 L
.49126 .30939 L
Mistroke
.49193 .30897 L
.49265 .30853 L
.49394 .30817 L
.4952 .30856 L
.49634 .30928 L
.49699 .30963 L
.49769 .30984 L
.49897 .30962 L
.50011 .30895 L
.5013 .30831 L
.50261 .30826 L
.50382 .30885 L
.50487 .3095 L
.50599 .30986 L
.50722 .30957 L
.50837 .30888 L
.50902 .3085 L
.50971 .30824 L
.51046 .30821 L
.51116 .30842 L
.51242 .30917 L
.51314 .3096 L
.5138 .30984 L
.51503 .30975 L
.51635 .30902 L
.51758 .30837 L
.51874 .30829 L
.51942 .30855 L
.52007 .30893 L
.52127 .30968 L
.52256 .30999 L
.52329 .30981 L
.52395 .30947 L
.52517 .30873 L
.52631 .30838 L
.52749 .30866 L
.52879 .30949 L
.52947 .3099 L
.53021 .31017 L
.53091 .31017 L
.53156 .30998 L
.53278 .30927 L
.53408 .30867 L
.53475 .30864 L
.53547 .30886 L
.53678 .30969 L
.53753 .31018 L
.53833 .3105 L
.539 .31054 L
.53975 .31032 L
Mistroke
.54039 .30998 L
.54107 .30956 L
.54229 .30906 L
.5436 .30928 L
.54435 .30974 L
.54505 .31025 L
.54631 .31097 L
.54746 .31101 L
.54809 .31077 L
.54879 .31038 L
.55005 .30974 L
.55116 .30968 L
.5524 .31032 L
.5536 .31124 L
.5549 .31181 L
.55611 .3116 L
.55722 .31099 L
.55828 .31052 L
.55939 .31054 L
.5607 .31134 L
.5619 .31229 L
.56256 .31266 L
.56327 .31283 L
.56457 .31247 L
.56579 .31181 L
.56708 .31154 L
.56819 .312 L
.5694 .313 L
.57013 .31359 L
.57082 .31398 L
.57212 .31404 L
.57285 .31373 L
.57353 .31337 L
.57427 .31303 L
.57506 .31292 L
.57574 .31309 L
.57649 .31356 L
.57719 .31418 L
.57784 .31479 L
.57906 .31562 L
.58035 .31566 L
.58158 .31509 L
.58222 .3148 L
.5829 .31464 L
.58416 .315 L
.58532 .31601 L
.58635 .31702 L
.58747 .31768 L
.58869 .31761 L
.58984 .31708 L
Mistroke
.59107 .31672 L
.59177 .31686 L
.59242 .31725 L
.59374 .31855 L
.59441 .31926 L
.59514 .31984 L
.59645 .32013 L
.59769 .31967 L
.59889 .31923 L
.6 .31943 L
.60106 .3203 L
.6022 .32161 L
.60327 .32262 L
.60425 .323 L
.60539 .32276 L
.60664 .32224 L
.60782 .32226 L
.60891 .32305 L
.61834 .32828 L
.63719 .33965 L
.64709 .3448 L
.64774 .34471 L
.64843 .34495 L
.6497 .34647 L
.65047 .34788 L
.65117 .34925 L
.65186 .35041 L
.6525 .35118 L
.65366 .35164 L
.65495 .35123 L
.65619 .35112 L
.6569 .35161 L
.65754 .35247 L
.66288 .35835 L
.66357 .35809 L
.66423 .35811 L
.66499 .35863 L
.66567 .35963 L
.66643 .36121 L
.66726 .36316 L
.66796 .36468 L
.66873 .36589 L
.66942 .36644 L
.67006 .36651 L
.67074 .36626 L
.67147 .36591 L
.67279 .36608 L
.67399 .3679 L
.679 .37476 L
.68026 .37426 L
Mistroke
.68097 .37459 L
.68162 .37549 L
.68282 .37843 L
.68408 .38206 L
.68531 .38431 L
.686 .38466 L
.68665 .38447 L
.68737 .38396 L
.68802 .38355 L
.68877 .38355 L
.68949 .38429 L
.69066 .38715 L
.69191 .39127 L
.69297 .39405 L
.69414 .3951 L
.69549 .39414 L
.69678 .39343 L
.69793 .39489 L
.69919 .39898 L
.70038 .40349 L
.70165 .40635 L
.70285 .4062 L
.70394 .40474 L
.7052 .40412 L
.70591 .40519 L
.70657 .40719 L
.70785 .41287 L
.70904 .41765 L
.71007 .41933 L
.71118 .41827 L
.7123 .41592 L
.71353 .41528 L
.7148 .41916 L
.716 .426 L
.71718 .43192 L
.71826 .43377 L
.71945 .43126 L
.72073 .42686 L
.72194 .42645 L
.72305 .43177 L
.72428 .44189 L
.72498 .4473 L
.72562 .45052 L
.7263 .45137 L
.72703 .44916 L
.72833 .43984 L
.729 .43526 L
.7297 .43303 L
.73097 .44002 L
.73167 .45013 L
Mistroke
.73233 .46187 L
.7331 .475 L
.73383 .48268 L
.73514 .47219 L
.73633 .42649 L
.73762 .34414 L
.73902 .24276 L
.74023 .17365 L
.74134 .14018 L
.74256 .13676 L
.74385 .15601 L
.7449 .17383 L
.74602 .18422 L
.74725 .18247 L
.74839 .174 L
.74904 .16954 L
.74973 .16688 L
.75049 .16726 L
.75118 .17057 L
.75244 .18067 L
.75316 .18639 L
.75382 .19016 L
.75505 .19196 L
.75637 .18813 L
.75759 .18456 L
.75875 .18528 L
.76008 .19138 L
.76127 .19829 L
.76194 .20113 L
.76266 .20274 L
.76396 .20197 L
.76518 .19945 L
.76648 .19897 L
.76758 .20185 L
.76879 .20728 L
.76953 .21048 L
.77022 .21271 L
.77153 .21397 L
.77226 .21329 L
.77293 .21234 L
.77367 .21155 L
.77446 .21161 L
.77576 .21438 L
.77697 .21895 L
.77763 .22133 L
.77831 .22326 L
.77906 .22442 L
.77975 .22459 L
.78098 .2236 L
.78168 .22304 L
Mistroke
.78232 .22298 L
.7835 .22458 L
.78475 .22831 L
.78579 .23168 L
.78692 .23405 L
.78815 .23449 L
.7893 .23372 L
.7906 .23351 L
.79134 .23435 L
.79203 .23578 L
.79339 .23967 L
.79462 .24265 L
.79584 .24377 L
.79698 .2434 L
.79819 .24288 L
.79949 .2438 L
.80064 .24621 L
.80172 .24901 L
.80289 .25139 L
.80415 .25225 L
.80536 .25182 L
.80668 .25156 L
.80792 .25279 L
.80907 .25519 L
.81022 .25783 L
.8113 .2595 L
.81243 .25997 L
.81367 .25953 L
.81472 .25935 L
.81569 .26 L
.81675 .26171 L
.81786 .26407 L
.8191 .26621 L
.8198 .26683 L
.82044 .26699 L
.82163 .26665 L
.82288 .26641 L
.824 .26718 L
.82505 .26884 L
.82619 .27104 L
.82743 .27282 L
.82876 .27331 L
.83001 .2729 L
.83123 .27279 L
.83236 .27369 L
.83367 .27578 L
.83436 .27699 L
.83508 .27806 L
.83572 .27869 L
.83642 .27899 L
Mistroke
.83764 .27877 L
.8387 .27841 L
.83984 .27865 L
.84091 .27975 L
.84188 .28126 L
.84303 .283 L
.84428 .284 L
.84546 .28393 L
.84655 .28351 L
.84768 .28349 L
.84874 .28426 L
.8499 .28584 L
.85115 .28758 L
.85246 .2885 L
.8537 .28835 L
.85491 .28789 L
.85602 .28796 L
.85727 .289 L
.85793 .28986 L
.85862 .29081 L
.85978 .29207 L
.86106 .29246 L
.8622 .2921 L
.86342 .2917 L
.86457 .29199 L
.86562 .29297 L
.86684 .2945 L
.86814 .29567 L
.86881 .29588 L
.86956 .29579 L
.87087 .29524 L
.87211 .29505 L
.8728 .29533 L
.87344 .29584 L
.8746 .29714 L
.87585 .29839 L
.87701 .29882 L
.87807 .29856 L
.87914 .29807 L
.88013 .29788 L
.88129 .29836 L
.88254 .29957 L
.88371 .30075 L
.88481 .30129 L
.88586 .30117 L
.88699 .30063 L
.88825 .30029 L
.88939 .30067 L
.89058 .30172 L
.89188 .30293 L
Mistroke
.89311 .3034 L
.89424 .30313 L
.89553 .30248 L
.89619 .3023 L
.8969 .30234 L
.89816 .30308 L
.89934 .30417 L
.90006 .30473 L
.90073 .30505 L
.902 .30497 L
.90271 .30464 L
.90337 .30429 L
.90408 .30399 L
.90485 .30392 L
.90603 .30442 L
.9073 .30548 L
.9085 .30632 L
.90959 .30648 L
.91087 .30597 L
.91155 .30559 L
.91227 .30529 L
.91359 .30535 L
.91482 .30614 L
.91599 .30708 L
.91724 .30758 L
.91788 .30752 L
.9186 .30725 L
.91985 .30655 L
.92103 .30621 L
.9223 .30661 L
.9235 .30749 L
.92459 .3082 L
.92572 .30839 L
.92677 .30802 L
.92789 .30737 L
.92914 .30696 L
.93021 .3072 L
.93122 .30784 L
.93239 .30865 L
.93345 .309 L
.93462 .30874 L
.93588 .30801 L
.93704 .30752 L
.93814 .30761 L
.93942 .30835 L
.9406 .30912 L
.9419 .30939 L
.94255 .30922 L
.94327 .30885 L
.94459 .30808 L
Mistroke
.94585 .30785 L
.94654 .30805 L
.9473 .30848 L
.94862 .30933 L
.94987 .30966 L
.95058 .3095 L
.95121 .30919 L
.95238 .30848 L
.95362 .30804 L
.95476 .30827 L
.95601 .30903 L
.95714 .30965 L
.9582 .30977 L
.95945 .30926 L
.96059 .30855 L
.96191 .30814 L
.96315 .30849 L
.96423 .30916 L
.96524 .3097 L
.96629 .30983 L
.96745 .30939 L
.96862 .30865 L
.96988 .30818 L
.97105 .3084 L
.97212 .30902 L
.97306 .30958 L
.97407 .30986 L
.97517 .30961 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00W_oonfX4o`0007_ooo]Z1Ol0001noookJPCo
0000W?oonfX009kooo]Z1?l0001koookJPGo0000O_oonfX4o`0009cooo]Z002NoookJPCo0000Nooo
nfX5o`0007kooo]Z1?l0002LoookJP00W_oonfX5o`0007[ooo]Z1Ol0001noookJPCo0000W?oonfX0
09kooo]Z1Ol0001joookJPGo0000O_oonfX4o`0009cooo]Z002NoookJPGo0000N_oonfX5o`0007ko
oo]Z1?l0002LoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z
002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000VooonfX009kooo]Z1Ol0001]
oookJP?o001o2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0005gooo]Z2_l007l6oook
JP?o001o2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0005gooo]Z2_l007l6oookJP?o
001o2_oonfX6o`0007gooo]Z1Ol0002KoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000
O_oonfX5o`0009_ooo]Z002MoookJPKo0000KOoonfX3o`00O`[ooo]Z1Ol0001moookJPKo0000Vooo
nfX009gooo]Z1_l0001]oookJP?o001o2_oonfX5o`0007gooo]Z1_l0002KoookJP00WOoonfX6o`00
06gooo]Z0ol007l:oookJPGo0000OOoonfX6o`0009_ooo]Z002MoookJPKo0000J_oonfX6o`00O`[o
oo]Z1Ol0001moookJPKo0000VooonfX009gooo]Z2_l0001VoookJPKo001o2_oonfX5o`0007gooo]Z
2_l0002GoookJP00WOoonfX:o`0006Sooo]Z1?l007l:oookJPGo0000OOoonfX:o`0009Oooo]Z002M
oookJP[o0000JOoonfX3o`00O`[ooo]Z1Ol0001moookJP[o0000UooonfX009gooo]Z2_l0001foook
JPGo0000OOoonfX:o`0009Oooo]Z002MoookJP[o0000M_oonfX5o`0007gooo]Z2_l0002GoookJP00
WOoonfX;o`0007Gooo]Z1Ol0001moookJP_o0000U_oonfX009gooo]Z2ol0001eoookJPGo0000OOoo
nfX;o`0009Kooo]Z002MoookJP_o0000MOoonfX5o`0007gooo]Z2ol0002FoookJP00WOoonfX;o`00
07Gooo]Z1Ol0001moookJP_o0000U_oonfX009gooo]Z2ol0001eoookJPGo0000OOoonfX;o`0009Ko
oo]Z002MoookJPko0000L_oonfX5o`0007gooo]Z3_l0002CoookJP00WOoonfX>o`0007;ooo]Z1Ol0
001moookJPko0000TooonfX009gooo]Z3ol0001aoookJPGo0000OOoonfX?o`0009;ooo]Z002Moook
JPoo0000LOoonfX5o`0007gooo]Z1?l00003oookJPSo0000T_oonfX009gooo]Z1?l00003oookJPSo
0000LOoonfX5o`0007gooo]Z1?l00003oookJPSo0000T_oonfX009gooo]Z1?l00003oookJPSo0000
LOoonfX5o`0007gooo]Z1?l00003oookJPSo0000T_oonfX009gooo]Z1?l00003oookJPSo0000LOoo
nfX5o`0007gooo]Z1?l00004oookJPSo0000TOoonfX009gooo]Z1?l00004oookJP[o0000K_oonfX5
o`0007gooo]Z1?l00004oookJP[o0000SooonfX009gooo]Z1?l00007oookJPSo0000KOoonfX5o`00
07gooo]Z1?l00007oookJPOo0000SooonfX009gooo]Z1?l00007oookJPSo0000KOoonfX5o`0007go
oo]Z1?l00008oookJPOo0000S_oonfX009gooo]Z1?l00008oookJPOo0000KOoonfX5o`0007gooo]Z
1?l00008oookJPOo0000S_oonfX009gooo]Z1?l00008oookJPOo0000KOoonfX5o`0007gooo]Z1?l0
0008oookJPSo0000SOoonfX009gooo]Z1?l00008oookJPOo0000KOoonfX5o`0007gooo]Z1?l00008
oookJPSo0000SOoonfX009gooo]Z1?l00009oookJPOo0000K?oonfX5o`0007gooo]Z1?l0000;oook
JPGo0000SOoonfX009gooo]Z1?l0000;oookJPSo0000JOoonfX5o`0007gooo]Z1?l0000<oookJPOo
0000R_oonfX009gooo]Z1?l0000;oookJPSo0000JOoonfX5o`0007gooo]Z1?l0000<oookJPOo0000
R_oonfX009gooo]Z1?l0000<oookJPOo0000JOoonfX5o`0007gooo]Z1?l0000<oookJPOo0000R_oo
nfX009gooo]Z1?l0000<oookJPSo0000J?oonfX5o`0007gooo]Z1?l0000<oookJPOo0000R_oonfX0
09gooo]Z1?l0000=oookJPOo0000J?oonfX5o`0007gooo]Z1?l0000<oookJPSo0000ROoonfX009go
oo]Z1?l0000?oookJPGo0000J?oonfX5o`0007gooo]Z1?l0000=oookJPOo0000ROoonfX009gooo]Z
1?l0000@oookJPOo0000IOoonfX5o`0007gooo]Z1?l0000?oookJPSo0000Q_oonfX009gooo]Z1?l0
000@oookJPSo0000I?oonfX5o`0007gooo]Z1?l0000@oookJPSo0000QOoonfX009gooo]Z1?l0000@
oookJPSo0000A_oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`0007gooo]Z1?l0000@
oookJPSo0000QOoonfX009gooo]Z1?l0000@oookJPSo0000AOoonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o2OoonfX5o`0007gooo]Z1?l0000@oookJPSo0000QOoonfX009gooo]Z1?l0000AoookJPOo
0000AOoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001moookJPCo00004OoonfX7o`0008Gooo]Z002Moook
JPCo00005?oonfX5o`0003Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o2?oonfX5o`0007gooo]Z1?l0000DoookJPGo0000Q?oonfX009gooo]Z1?l0000DoookJPOo
0000=OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001loookJPCo
00005?oonfX7o`0008;ooo]Z002LoookJPGo00005?oonfX8o`00043ooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Sooo]Z1Ol0001moookJPCo00005?oonfX8o`00087ooo]Z002LoookJPGo00005Ooo
nfX7o`00043ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000OOoo
nfX4o`0001Gooo]Z1ol00021oookJP00W?oonfX5o`0001Gooo]Z2?l0000ooookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l9oookJPGo0000OOoonfX4o`0001Gooo]Z2?l00020oookJP00W?oonfX4o`00
01Oooo]Z1ol0000ooookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000OOoonfX4o`00
01Kooo]Z1ol00020oookJP00W?oonfX4o`0001Wooo]Z2?l0000loookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l>oookJPGo0000OOoonfX4o`0001Sooo]Z2?l0001moookJP00W?oonfX4o`0001[ooo]Z
1ol0000moookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001moookJPCo
00006OoonfX7o`0007gooo]Z002LoookJPCo00006_oonfX8o`0003cooo]Z1ol007l9oookJPOo001o
2?oonfX5o`0007gooo]Z1?l0000IoookJPSo0000O?oonfX009cooo]Z1?l0000KoookJPOo0000?Ooo
nfX5o`00O`[ooo]Z1ol007l8oookJPGo0000OOoonfX4o`0001[ooo]Z1ol0001loookJP00W?oonfX4
o`0001_ooo]Z1ol0001KoookJPGo0000OOoonfX4o`0001[ooo]Z2?l0001koookJP00W?oonfX4o`00
01kooo]Z2?l0001GoookJPGo0000OOoonfX4o`0001gooo]Z1ol0001ioookJP00W?oonfX4o`0001ko
oo]Z2?l0001GoookJPGo0000OOoonfX4o`0001gooo]Z2?l0001hoookJP00W?oonfX4o`0001kooo]Z
2?l0001GoookJPGo0000OOoonfX4o`0001kooo]Z1ol0001hoookJP00W?oonfX4o`0001oooo]Z2?l0
001FoookJPGo0000OOoonfX4o`0001kooo]Z2?l0001goookJP00W?oonfX4o`0002;ooo]Z2?l0001C
oookJPGo0000OOoonfX4o`00027ooo]Z2?l0001doookJP00W?oonfX4o`0002;ooo]Z2?l0001Coook
JPGo0000OOoonfX4o`00027ooo]Z2Ol0001coookJP00W?oonfX4o`0002?ooo]Z2?l0001BoookJPGo
0000OOoonfX4o`0002;ooo]Z2?l0001coookJP00W?oonfX4o`0002?ooo]Z2?l0001BoookJPGo0000
OOoonfX4o`0002?ooo]Z1ol0001coookJP00W?oonfX4o`0002Kooo]Z2?l0001?oookJPGo0000OOoo
nfX4o`0002Kooo]Z2?l0001_oookJP00W?oonfX4o`0002Oooo]Z2?l0001>oookJPGo0000OOoonfX4
o`0002Kooo]Z2?l0001_oookJP00W?oonfX4o`0002Oooo]Z2Ol0001=oookJPGo0000OOoonfX4o`00
02Kooo]Z2Ol0001^oookJP008_oonfX3o`00OgGooo]Z0_l007l4o`0000?ooo]Z0ol007l3oookJPGo
001o6_oonfX9o`0004cooo]Z1Ol0001doookJPGo001o1?oonfX4o`0000;ooo]Z1Ol007lPoookJP_o
0000BooonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`Co00000ooonfX3o`00O`;ooo]Z
1ol007lLoookJPOo0000BooonfX5o`0007?ooo]Z1ol007l3oookJPCo000000?ooo]Zo`00Ool007l0
1Ol007lRoookJPSo0000BooonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`Co00000ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o7OoonfX7o`0004[ooo]Z
1Ol0001coookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`0000Co001o00Cooo]Zo`00Ool0
07oo001o8ooonfX8o`0004[ooo]Z0ol007lMoookJP004ooonfX:o`00O`Gooo]Z0ol007mWoookJP[o
001o0_oonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01?oonfX3o`00O`?o
oo]Z0ol007lMoookJPSo0000B?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`0000?o
001o0ooonfX3o`00Ob;ooo]Z2ol00017oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001o
IooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00[ooo]Z
0ol007lNoookJPWo0000A_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`0000Kooo]Z
0ol007lSoookJP_o0000A_oonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00O`03oookJ_l0
003o000000;o000000?o001ooookJ_oonfX02_oonfX3o`00Oaoooo]Z2Ol00015oookJPGo0000L_oo
nfX3o`00O`?ooo]Z0ol007l2oookJPCo00001_oonfX3o`00ObKooo]Z2?l00016oookJP?o001o7Ooo
nfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP05
oookJP;o001o0_oonfX4o`00Ob3ooo]Z3?l00011oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l2
oookJPCo000000?ooo]Zo`00Ool007l00_oonfX4o`00ObKooo]Z2ol00013oookJP?o001o7OoonfX0
02;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP05oook
JPOo001o8ooonfX:o`00047ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooo
nf[o001oo`00O`05o`00ObSooo]Z3?l00011oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o
001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP05oookJPKo001o9_oonfX9o`00043o
oo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`04o`00Obco
oo]Z2Ol00011oookJP?o001o7OoonfX001oooo]Z1_l007mcoookJP?o001o00?ooo]Zo`000?l00000
0_l000000ol007oooo]ZoookJP05oookJP;o001o:ooonfX<o`0003cooo]Z1Ol0001boookJP?o001o
0ooonfX3o`00O`;ooo]Z1?l000000ooonf[o001oo`00O`0aoookJPco0000>_oonfX6o`00Oagooo]Z
000OoookJPKo001oM?oonfX3o`00O`Co00002?oonfX2o`00Obkooo]Z2Ol0000loookJPGo0000Looo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1?l000000ooonf[o001oo`00O`0doookJPWo0000
>_oonfX6o`00Oagooo]Z000QoookJPCo001oM?oonfX3o`00O`Co00002OoonfX7o`00ObWooo]Z3?l0
000hoookJPGo0000LooonfX7o`00O`?ooo]Z1?l00002oookJPOo001o;ooonfX<o`0003Sooo]Z1?l0
07lMoookJP008_oonfX3o`00OgGooo]Z0_l007l4o`0000Wooo]Z1ol007lZoookJPoo0000=?oonfX5
o`0007Cooo]Z1Ol007l3oookJPGo00000_oonfX7o`00Oc3ooo]Z3ol0000eoookJP?o001o7OoonfX0
09cooo]Z1?l0000moookJPgo0000<ooonfX5o`0007cooo]Z1Ol0000loookJPco0000EOoonfX009co
oo]Z1?l0000noookJQ3o0000;ooonfX5o`0007cooo]Z1Ol0000moookJQ3o0000D?oonfX009cooo]Z
1?l00012oookJQ3o0000:ooonfX5o`0007cooo]Z1?l00012oookJPoo0000COoonfX009cooo]Z1?l0
0012oookJQCo00009ooonfX5o`0007cooo]Z1?l00013oookJQ?o0000B?oonfX009cooo]Z1?l00016
oookJQGo00008_oonfX5o`0007cooo]Z1?l00016oookJQCo0000A?oonfX009cooo]Z1?l00017oook
JQSo00007_oonfX5o`0007cooo]Z1?l00017oookJQWo0000?_oonfX000kooo]Zool0003oo`0002Go
00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooo
nfX000kooo]Zool0003oo`0002Go00003ooonfX000kooo]Zool0003oo`0002Go00003ooonfX001go
oo]Z00?o0000oookJ_oonfX01ooonfX>o`000003oookJ_l0003o000001Wo0000BooonfX4o`0007go
oo]Z1Ol00007oookJR[o0000BooonfX4o`0007oooo]Z00?o0000oookJ_oonfX07?oonfX003Wooo]Z
6Ol0001:oookJPCo0000OOoonfX5o`0001Wooo]Z6Ol0001:oookJPCo0000W_oonfX0047ooo]Z5Ol0
0016oookJPCo0000OOoonfX5o`00027ooo]Z5Ol00016oookJPCo0000W_oonfX004Kooo]Z4_l00014
oookJPCo0000OOoonfX5o`0002Kooo]Z4ol00013oookJPCo0000W_oonfX004[ooo]Z4?l00012oook
JPCo0000OOoonfX5o`0002[ooo]Z4Ol00011oookJPCo0000W_oonfX004oooo]Z3Ol00010oookJPCo
0000OOoonfX5o`0002kooo]Z4?l0000noookJPCo0000W_oonfX005?ooo]Z2ol0000noookJPCo0000
OOoonfX5o`0003;ooo]Z3_l0000loookJPCo0000W_oonfX005Gooo]Z2ol0000loookJPCo0000OOoo
nfX5o`0003?ooo]Z3_l0000koookJPCo0000W_oonfX005Oooo]Z2ol0000joookJPCo0000OOoonfX5
o`0003Sooo]Z2ol0000ioookJPCo0000W_oonfX005Wooo]Z2ol0000hoookJPCo0000OOoonfX5o`00
03_ooo]Z2Ol0000hoookJPCo0000W_oonfX005_ooo]Z3?l0000eoookJPCo0000OOoonfX5o`0003go
oo]Z2?l0000goookJPCo0000W_oonfX005gooo]Z2ol0000doookJPCo0000OOoonfX5o`0003kooo]Z
2Ol0000eoookJPCo0000W_oonfX005oooo]Z3?l0000aoookJPCo0000OOoonfX5o`00043ooo]Z2?l0
000doookJPCo0000W_oonfX0067ooo]Z2ol0000`oookJPCo0000OOoonfX5o`00047ooo]Z2_l0000a
oookJPCo0000W_oonfX006Cooo]Z2?l0000`oookJPCo0000OOoonfX5o`0004;ooo]Z3?l0000^oook
JPCo0000W_oonfX006Cooo]Z2ol0000]oookJPCo0000OOoonfX5o`0004Cooo]Z2ol0000]oookJPCo
0000W_oonfX006Gooo]Z2ol0000/oookJPCo0000OOoonfX5o`0004Gooo]Z2ol0000/oookJPCo0000
W_oonfX006Sooo]Z2?l0000/oookJPCo0000OOoonfX5o`0004Sooo]Z2Ol0000[oookJPCo0000W_oo
nfX006Wooo]Z2?l0000[oookJPCo0000OOoonfX5o`0004_ooo]Z1_l0000[oookJPCo0000W_oonfX0
06[ooo]Z2_l0000XoookJPCo0000OOoonfX5o`0004_ooo]Z2Ol0000XoookJPCo0000W_oonfX006co
oo]Z2Ol0000WoookJPCo0000OOoonfX5o`0004gooo]Z1ol0000XoookJPCo0000W_oonfX006gooo]Z
2?l0000WoookJPCo0000OOoonfX5o`0004gooo]Z2?l0000WoookJPCo0000W_oonfX006gooo]Z2?l0
000WoookJPCo0000OOoonfX5o`0004kooo]Z2?l0000VoookJPCo0000W_oonfX0077ooo]Z1ol0000T
oookJPCo0000OOoonfX5o`00053ooo]Z2Ol0000SoookJPCo0000W_oonfX0077ooo]Z2?l0000Soook
JPCo0000OOoonfX5o`00057ooo]Z2?l0000SoookJPCo0000W_oonfX0077ooo]Z2?l0000SoookJPCo
0000OOoonfX5o`0005;ooo]Z2?l0000RoookJPCo0000W_oonfX007;ooo]Z2?l0000RoookJPCo0000
OOoonfX5o`0005?ooo]Z1ol0000RoookJPCo0000W_oonfX007Gooo]Z1ol0000PoookJPCo0000OOoo
nfX5o`0005Gooo]Z2?l0000OoookJPCo0000W_oonfX007Gooo]Z2?l0000OoookJPCo0000OOoonfX5
o`0005Kooo]Z1ol0000OoookJPCo0000W_oonfX007Kooo]Z2?l0000NoookJPCo0000OOoonfX5o`00
05Kooo]Z1ol0000OoookJPCo0000W_oonfX007Kooo]Z2?l0000NoookJPCo0000OOoonfX5o`0005Ko
oo]Z2?l0000NoookJPCo0000W_oonfX007Wooo]Z2?l0000KoookJPCo0000OOoonfX5o`0005Wooo]Z
2?l0000KoookJPCo0000W_oonfX007[ooo]Z1ol0000KoookJPCo0000OOoonfX5o`0005Wooo]Z2?l0
000KoookJPCo0000W_oonfX007[ooo]Z1ol0000KoookJPCo0000OOoonfX5o`0005[ooo]Z1ol0000K
oookJPCo0000W_oonfX007[ooo]Z2?l0000IoookJPGo0000OOoonfX5o`0005_ooo]Z1ol0000Joook
JPCo0000W_oonfX007_ooo]Z1ol0000IoookJPGo0000GooonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o2_oonfX5o`0005cooo]Z1_l0000JoookJPCo0000W_oonfX007gooo]Z2?l0000FoookJPGo0000
G_oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0005gooo]Z2?l0000GoookJPCo0000
W_oonfX007kooo]Z1ol0000FoookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001NoookJPSo
00005_oonfX4o`0009kooo]Z001noookJPSo00005OoonfX4o`0005kooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000G_oonfX8o`0001Gooo]Z1Ol0002NoookJP00Oooo
nfX7o`0001Gooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l8oookJPKo0000G_oo
nfX7o`0001Gooo]Z1Ol0002NoookJP00OooonfX8o`0001Cooo]Z1?l0001NoookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l8oookJPGo0000GooonfX8o`0001Cooo]Z1Ol0002NoookJP00P_oonfX5o`00
01Cooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX5o`00
06;ooo]Z1Ol0000DoookJPCo0000WooonfX008;ooo]Z1ol0000BoookJPCo0000G_oonfX3o`00O`?o
oo]Z0ol007l7oookJPOo001o2OoonfX5o`0006;ooo]Z2?l0000AoookJPCo0000WooonfX008?ooo]Z
1_l0000BoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2_oonfX5o`0006?ooo]Z
1ol0000AoookJPCo0000WooonfX008?ooo]Z1ol0000AoookJPCo0000G_oonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o3_oonfX5o`0006?ooo]Z1ol0000AoookJPCo0000WooonfX008?ooo]Z2?l0000@
oookJPCo0000GooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000I?oo
nfX7o`00013ooo]Z1?l0002OoookJP00Q?oonfX7o`00013ooo]Z1?l0001OoookJPOo001o2OoonfX7
o`00O`Sooo]Z1Ol0001ToookJPOo00004?oonfX4o`0009oooo]Z0026oookJPKo00003ooonfX4o`00
063ooo]Z1Ol007l:oookJPOo001o2?oonfX5o`0006Kooo]Z1_l0000?oookJPCo0000WooonfX008Oo
oo]Z1_l0000>oookJPCo0000O_oonfX5o`0006Oooo]Z2?l0000<oookJPCo0000WooonfX008Oooo]Z
1_l0000>oookJPCo0000O_oonfX5o`0006Oooo]Z2?l0000<oookJPCo0000WooonfX008Sooo]Z1_l0
000=oookJPCo0000O_oonfX5o`0006Sooo]Z1ol0000<oookJPCo0000WooonfX008Wooo]Z1_l0000<
oookJPCo0000O_oonfX5o`0006Sooo]Z2?l0000;oookJPCo0000WooonfX008Wooo]Z1_l0000<oook
JPCo0000O_oonfX5o`0006Sooo]Z2?l0000;oookJPCo0000WooonfX008[ooo]Z1_l0000;oookJPCo
0000O_oonfX5o`0006_ooo]Z1Ol0000;oookJPCo0000WooonfX008_ooo]Z1Ol0000;oookJPCo0000
O_oonfX5o`0006cooo]Z1ol00008oookJPCo0000WooonfX008_ooo]Z1_l0000:oookJPCo0000O_oo
nfX5o`0006cooo]Z1ol00008oookJPCo0000WooonfX008cooo]Z1_l00009oookJPCo0000O_oonfX5
o`0006cooo]Z1ol00008oookJPCo0000WooonfX008cooo]Z1_l00009oookJPCo0000O_oonfX5o`00
06cooo]Z1ol00008oookJPCo0000WooonfX008gooo]Z1_l00008oookJPCo0000O_oonfX5o`0006co
oo]Z2?l00007oookJPCo0000WooonfX008kooo]Z2Ol00004oookJPCo0000O_oonfX5o`0006gooo]Z
1ol00007oookJPCo0000WooonfX008kooo]Z2Ol00004oookJPCo0000O_oonfX5o`0006oooo]Z2?l0
0004oookJPCo0000WooonfX008oooo]Z2?l00004oookJPCo0000O_oonfX5o`00073ooo]Z1ol00004
oookJPCo0000WooonfX0093ooo]Z2?l00003oookJPCo0000O_oonfX5o`00073ooo]Z2?l00003oook
JPCo0000WooonfX0093ooo]Z3ol0001noookJPGo0000L?oonfX?o`0009oooo]Z002@oookJPoo0000
O_oonfX5o`00073ooo]Z3ol0002OoookJP00T?oonfX?o`0007kooo]Z1Ol0001aoookJPko0000Wooo
nfX0097ooo]Z3_l0001noookJPGo0000LOoonfX>o`0009oooo]Z002AoookJPko0000O_oonfX5o`00
077ooo]Z3_l0002OoookJP00U?oonfX;o`0007kooo]Z1Ol0001doookJP_o0000WooonfX009Cooo]Z
2ol0001noookJPGo0000MOoonfX:o`0009oooo]Z002DoookJP_o0000O_oonfX5o`0007Gooo]Z2_l0
002OoookJP00U?oonfX;o`0007kooo]Z1Ol0001eoookJP[o0000WooonfX009Gooo]Z2_l0001noook
JPGo0000MOoonfX:o`0009oooo]Z002EoookJP[o0000O_oonfX5o`0007Gooo]Z2_l0002OoookJP00
UOoonfX:o`0007kooo]Z1Ol0001eoookJP[o0000WooonfX009Gooo]Z2_l0001noookJPGo0000MOoo
nfX:o`0009oooo]Z002EoookJP[o0000O_oonfX5o`0007Gooo]Z2Ol0002PoookJP00VOoonfX6o`00
077ooo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[o
oo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001boookJP?o001o2_oonfX5o`0007Wooo]Z
1Ol0002PoookJP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002I
oookJPGo0000L_oonfX3o`00O`[ooo]Z1_l0001hoookJPGo0000X?oonfX009Wooo]Z1Ol0001boook
JP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo
0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z1Ol0001ioookJPGo0000
X?oonfX009Wooo]Z1Ol0001boookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5
o`0006oooo]Z1_l007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000KooonfX6o`00
O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001aoookJPCo001o2_oonfX5o`0007Wo
oo]Z1Ol0002PoookJP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z
002IoookJPGo0000OooonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0007oooo]Z1Ol0001i
oookJPGo0000X?oonfX009[ooo]Z1?l0001ooookJPGo0000N_oonfX4o`000:3ooo]Z003ooookJQko
oo]Z1Ol0001joookJPCo0000X?oonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003o
oookJP;ooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`ko
oo]Z0ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z
1?l007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0
003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX0
0?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o
001o3_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfX2oookJP?o001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000
oooonfXOoookJP00oooonfX=oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4
o`00O`gooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoook
JP00oooonfX?oookJPGo001o2_oonfX6o`000?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXC
oookJP?o001ooooonfX/oookJP00oooonfX=oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oo
oo]Z3OoonfX3o`00O`?ooo]Z0ol007oooookJRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001o
oooonfX/oookJP00oooonfX>oookJPOo001ooooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^
oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30968 L
.02605 .30983 L
.02729 .30935 L
.02846 .30862 L
.02954 .30821 L
.03053 .30832 L
.03163 .3089 L
.03279 .3096 L
.03395 .30985 L
.0352 .30942 L
.03638 .30868 L
.03746 .30825 L
.03873 .30843 L
.03944 .30882 L
.04011 .30925 L
.04132 .30985 L
.04262 .30977 L
.04327 .30945 L
.04396 .30902 L
.04519 .30839 L
.04588 .30831 L
.04652 .30844 L
.04722 .30878 L
.04797 .30928 L
.04862 .30969 L
.04933 .30998 L
.05061 .30992 L
.05186 .30924 L
.05302 .30862 L
.05414 .30852 L
.05519 .30897 L
.05644 .30981 L
.05759 .31029 L
.05873 .31015 L
.05993 .30949 L
.06113 .30888 L
.06244 .30892 L
.06315 .30929 L
.06381 .30974 L
.06451 .31023 L
.06529 .31062 L
.06659 .31062 L
.06731 .3103 L
.06797 .3099 L
.06924 .30932 L
.0704 .30939 L
.07103 .30972 L
.07173 .31021 L
.073 .31107 L
Mistroke
.07376 .31132 L
.07448 .31127 L
.07513 .31102 L
.07583 .31063 L
.0766 .3102 L
.0774 .30995 L
.07809 .30998 L
.07885 .31031 L
.07956 .31081 L
.0802 .31133 L
.08095 .31184 L
.08166 .31211 L
.08291 .31197 L
.08362 .31161 L
.08427 .31124 L
.08544 .31084 L
.08669 .31116 L
.08787 .31206 L
.08896 .31289 L
.09016 .31324 L
.09148 .31282 L
.09219 .31242 L
.09287 .31212 L
.09413 .3121 L
.09538 .31289 L
.09603 .31348 L
.09675 .31407 L
.09746 .31448 L
.0982 .31463 L
.0989 .31449 L
.09954 .3142 L
.10081 .31359 L
.10197 .31354 L
.10261 .31384 L
.10331 .31439 L
.10458 .31558 L
.10579 .31629 L
.10691 .31623 L
.10813 .31566 L
.10942 .31527 L
.11054 .31565 L
.11159 .31657 L
.11273 .3177 L
.11396 .3184 L
.11467 .3184 L
.11531 .31819 L
.11659 .3176 L
.11775 .31749 L
.11897 .31824 L
.12029 .31965 L
Mistroke
.12152 .3207 L
.12223 .32092 L
.12288 .32086 L
.12362 .32058 L
.12433 .32025 L
.12501 .32005 L
.12565 .32006 L
.12685 .3208 L
.12814 .32227 L
.12881 .32301 L
.12954 .32359 L
.13076 .32384 L
.13206 .32335 L
.13326 .32304 L
.13437 .32347 L
.13505 .32413 L
.13579 .32505 L
.13645 .32589 L
.13714 .32664 L
.13845 .32727 L
.13966 .32698 L
.14033 .3267 L
.14105 .32653 L
.14236 .32702 L
.14311 .32782 L
.14391 .3289 L
.14465 .32991 L
.14533 .33065 L
.14657 .3312 L
.14722 .3311 L
.14791 .33084 L
.14906 .33052 L
.15034 .33106 L
.15147 .33247 L
.15269 .33429 L
.15384 .33544 L
.15488 .33567 L
.15618 .33524 L
.15739 .33509 L
.15871 .3361 L
.15945 .33718 L
.16012 .33829 L
.16135 .34004 L
.16204 .34059 L
.16268 .34075 L
.16385 .34046 L
.16509 .34015 L
.16623 .34075 L
.16728 .34221 L
.1684 .34422 L
Mistroke
.16962 .34593 L
.17075 .34645 L
.1718 .34618 L
.1728 .34587 L
.17385 .34618 L
.17499 .34761 L
.17621 .34997 L
.17737 .35191 L
.17842 .35275 L
.17966 .35259 L
.18036 .35232 L
.181 .35221 L
.18219 .35291 L
.18346 .35508 L
.18411 .3565 L
.1848 .35793 L
.18606 .35961 L
.18737 .35976 L
.18812 .35943 L
.18881 .35923 L
.19002 .35979 L
.19134 .36212 L
.19258 .36505 L
.19374 .36708 L
.19438 .36758 L
.19507 .36764 L
.19583 .36732 L
.19654 .367 L
.19723 .36696 L
.19799 .3675 L
.19878 .3688 L
.19951 .37056 L
.20015 .37227 L
.20084 .37401 L
.2021 .376 L
.20285 .37626 L
.20354 .37601 L
.20486 .37536 L
.20602 .376 L
.20727 .37866 L
.20835 .38186 L
.20952 .38469 L
.21024 .38555 L
.2109 .38568 L
.2122 .38486 L
.21339 .38456 L
.21465 .38641 L
.22503 .40502 L
.22628 .40737 L
.22698 .40729 L
Mistroke
.22762 .40657 L
.22887 .40497 L
.23004 .40552 L
.23125 .40937 L
.23257 .41547 L
.23326 .41815 L
.234 .41979 L
.23464 .42001 L
.23533 .41916 L
.23609 .41756 L
.23678 .41622 L
.23753 .41577 L
.23833 .41711 L
.23902 .4199 L
.23967 .42348 L
.24042 .42802 L
.24114 .43169 L
.24179 .43378 L
.24249 .43428 L
.24372 .43126 L
.24441 .42865 L
.24515 .42668 L
.24647 .42843 L
.24772 .43708 L
.24887 .44667 L
.25019 .45178 L
.25144 .4469 L
.25259 .43791 L
.25366 .43328 L
.25484 .43953 L
.25608 .45919 L
.25733 .47958 L
.25803 .4836 L
.25867 .47862 L
.25986 .44223 L
.2611 .36798 L
.26238 .27331 L
.26309 .22431 L
.26375 .18564 L
.26454 .15329 L
.26525 .13782 L
.26592 .13455 L
.26665 .14053 L
.26785 .16124 L
.269 .1788 L
.27032 .18456 L
.27153 .17774 L
.27258 .16972 L
.27371 .16626 L
.27495 .17139 L
Mistroke
.27609 .18101 L
.27675 .1862 L
.27744 .19004 L
.2782 .19166 L
.2789 .19087 L
.28016 .18652 L
.28088 .18438 L
.28155 .18371 L
.2828 .1869 L
.28393 .19332 L
.28525 .20014 L
.28649 .20229 L
.2877 .20053 L
.28839 .19902 L
.28903 .19812 L
.2897 .19813 L
.29042 .19951 L
.29173 .20479 L
.29295 .21023 L
.29408 .21297 L
.29527 .21275 L
.29657 .21098 L
.29725 .21059 L
.298 .21116 L
.2987 .21276 L
.29934 .21496 L
.30065 .22 L
.30187 .22314 L
.30317 .22351 L
.30387 .22287 L
.30461 .22217 L
.30539 .22202 L
.30613 .22277 L
.3068 .22423 L
.30752 .22646 L
.30877 .23059 L
.31009 .23324 L
.31078 .23354 L
.31153 .23322 L
.31222 .2327 L
.31286 .23236 L
.31412 .23308 L
.31528 .23565 L
.31593 .23759 L
.31663 .23961 L
.31787 .24215 L
.31897 .24267 L
.32018 .24207 L
.32147 .24188 L
.32269 .24343 L
Mistroke
.32374 .24599 L
.32486 .24887 L
.3261 .25081 L
.32724 .25104 L
.32797 .25071 L
.32866 .25042 L
.32995 .25082 L
.33118 .25287 L
.33252 .25603 L
.33374 .25819 L
.33503 .2588 L
.33614 .2584 L
.33735 .25822 L
.33808 .25871 L
.33877 .25967 L
.34006 .26233 L
.34074 .26374 L
.34146 .26492 L
.34225 .26567 L
.34297 .26582 L
.34426 .2654 L
.34547 .26531 L
.34616 .2658 L
.3468 .26663 L
.3475 .26787 L
.34823 .26932 L
.34946 .27136 L
.35016 .27199 L
.3508 .27217 L
.35197 .27187 L
.35322 .2716 L
.35434 .27226 L
.35538 .27377 L
.35652 .27581 L
.35776 .27746 L
.35908 .27786 L
.36033 .27743 L
.36154 .27735 L
.36267 .27824 L
.36795 .28267 L
.36911 .28235 L
.37035 .28287 L
.37153 .28434 L
.37262 .28597 L
.3736 .28708 L
.37467 .28752 L
.37579 .28724 L
.37684 .28687 L
.37807 .28708 L
.37923 .28822 L
Mistroke
.38029 .28968 L
.38141 .29099 L
.38263 .29151 L
.38376 .29122 L
.38498 .29078 L
.38567 .2908 L
.38631 .29111 L
.39616 .29636 L
.3968 .29708 L
.39749 .29767 L
.39875 .29799 L
.39951 .29777 L
.40021 .29745 L
.40153 .29711 L
.40268 .29759 L
.40395 .29886 L
.40459 .29955 L
.40528 .30016 L
.40652 .30059 L
.40765 .30025 L
.40889 .2997 L
.41006 .29969 L
.41114 .30038 L
.41219 .30143 L
.41332 .30242 L
.41438 .30276 L
.41536 .30253 L
.41656 .30194 L
.41782 .30171 L
.41888 .30218 L
.42004 .30322 L
.42129 .30425 L
.42199 .30453 L
.42262 .30454 L
.42386 .30405 L
.42503 .3035 L
.42618 .30349 L
.42741 .30424 L
.42848 .30518 L
.42964 .30592 L
.43035 .30603 L
.431 .3059 L
.43229 .30524 L
.43347 .30481 L
.43472 .30507 L
.44001 .30652 L
.44128 .30594 L
.44191 .30588 L
.44261 .30607 L
.44384 .30689 L
Mistroke
.445 .30775 L
.44617 .3081 L
.44724 .30782 L
.44847 .30712 L
.44964 .30671 L
.45089 .307 L
.45205 .3078 L
.45332 .3086 L
.45396 .30877 L
.45467 .30869 L
.4558 .30815 L
.45684 .30756 L
.45799 .30731 L
.45919 .30774 L
.46018 .30842 L
.46123 .30906 L
.46238 .30922 L
.46344 .30881 L
.46466 .30808 L
.46536 .30779 L
.46601 .30772 L
.46718 .30811 L
.46844 .30895 L
.46965 .30951 L
.47081 .30941 L
.47185 .30886 L
.47298 .3082 L
.47367 .308 L
.47432 .30801 L
.47554 .30856 L
.47623 .30902 L
.47696 .30945 L
.47827 .30971 L
.47939 .30929 L
.48063 .30854 L
.48195 .30812 L
.48318 .30846 L
.48432 .30918 L
.48556 .30976 L
.48673 .30968 L
.48782 .30911 L
.48888 .30847 L
.48987 .30818 L
.4909 .30838 L
.49204 .30904 L
.49321 .30969 L
.49443 .30979 L
.49548 .30935 L
.49662 .30863 L
.49785 .3082 L
Mistroke
.49917 .30852 L
.50041 .30928 L
.50154 .30979 L
.50274 .30971 L
.50386 .30911 L
.50509 .3084 L
.5064 .30823 L
.50706 .30847 L
.50778 .30888 L
.50909 .30965 L
.51037 .30982 L
.51155 .30933 L
.51257 .30868 L
.51367 .30825 L
.51488 .30841 L
.51601 .30907 L
.51722 .30975 L
.51849 .30986 L
.51957 .30938 L
.52076 .30865 L
.52143 .30838 L
.52216 .30831 L
.52285 .30849 L
.52349 .30883 L
.52477 .30966 L
.52597 .31006 L
.52725 .30972 L
.52794 .30931 L
.52867 .30887 L
.52944 .30855 L
.53017 .30849 L
.53082 .30867 L
.53154 .30907 L
.53283 .30993 L
.53406 .31032 L
.53473 .31021 L
.53546 .30988 L
.53674 .30912 L
.53796 .30879 L
.53926 .30923 L
.54036 .31 L
.54157 .31065 L
.54288 .31059 L
.54408 .30995 L
.54477 .30956 L
.54541 .30932 L
.54608 .30927 L
.54682 .30949 L
.54808 .31033 L
.54877 .31083 L
Mistroke
.54941 .31117 L
.55054 .3113 L
.55178 .31077 L
.5529 .31015 L
.55395 .30993 L
.55516 .31039 L
.55626 .31123 L
.55747 .312 L
.55858 .31213 L
.5598 .31162 L
.56109 .31096 L
.56239 .31093 L
.56357 .31165 L
.56485 .31269 L
.56557 .3131 L
.56624 .31324 L
.56744 .31293 L
.56871 .31226 L
.56994 .31201 L
.57105 .31249 L
.58201 .31629 L
.58332 .31615 L
.58456 .31554 L
.58524 .31531 L
.58598 .31531 L
.58728 .31608 L
.58852 .31733 L
.58983 .3183 L
.59096 .31838 L
.59219 .31786 L
.59347 .31745 L
.59418 .31757 L
.59484 .31796 L
.59611 .31924 L
.59732 .32044 L
.59799 .32082 L
.59871 .32092 L
.6 .32049 L
.60079 .32015 L
.60154 .32002 L
.60221 .32019 L
.60293 .32069 L
.62214 .33107 L
.66076 .35748 L
.68069 .37547 L
.68188 .37563 L
.68317 .3779 L
.6844 .38145 L
.68553 .38436 L
.68685 .3857 L
Mistroke
.68751 .38551 L
.68825 .38497 L
.68953 .38454 L
.69073 .38613 L
.69643 .39487 L
.69711 .39438 L
.69776 .39449 L
.6985 .39557 L
.69918 .39745 L
.70052 .40254 L
.70175 .4064 L
.70284 .40744 L
.704 .4063 L
.70516 .40491 L
.70644 .40595 L
.70772 .4106 L
.70842 .41394 L
.70909 .41686 L
.71039 .41997 L
.71157 .41908 L
.71281 .41646 L
.71351 .41574 L
.71414 .41622 L
.71537 .42067 L
.71652 .42746 L
.71718 .43102 L
.71787 .43355 L
.71911 .43367 L
.71981 .43163 L
.72045 .4292 L
.72116 .42702 L
.72192 .42644 L
.72316 .4312 L
.7243 .44047 L
.72556 .44974 L
.72619 .45169 L
.72689 .45087 L
.72806 .44363 L
.72932 .43466 L
.73051 .43507 L
.7316 .44733 L
.73266 .46638 L
.73365 .48096 L
.73474 .48033 L
.7359 .44881 L
.73712 .38023 L
.73827 .29607 L
.73939 .21697 L
.74042 .1641 L
.74158 .13637 L
Mistroke
.74282 .14022 L
.74397 .15981 L
.74506 .17729 L
.74633 .18476 L
.7475 .17943 L
.74816 .17417 L
.74887 .16915 L
.75016 .1666 L
.75139 .17336 L
.75253 .18307 L
.7538 .19065 L
.75445 .19167 L
.75515 .19073 L
.75584 .18844 L
.75648 .18608 L
.75721 .18411 L
.7579 .18379 L
.75913 .18757 L
.75982 .19146 L
.76046 .19532 L
.76152 .20043 L
.76266 .2023 L
.76374 .20086 L
.76472 .19877 L
.76588 .19812 L
.76713 .20129 L
.76832 .20671 L
.76942 .21118 L
.77066 .2132 L
.77183 .21226 L
.7729 .21085 L
.77402 .21093 L
.77525 .21391 L
.77637 .21826 L
.77759 .22224 L
.77828 .22341 L
.77892 .22369 L
.78018 .22274 L
.78087 .22213 L
.78152 .222 L
.78266 .22343 L
.78393 .22718 L
.7852 .23126 L
.78585 .23266 L
.78655 .23344 L
.78731 .23346 L
.78802 .233 L
.78867 .23253 L
.78937 .23234 L
.79066 .23368 L
Mistroke
.79188 .23686 L
.79297 .24001 L
.79416 .24226 L
.79545 .24259 L
.79616 .2422 L
.79682 .24185 L
.798 .24212 L
.79927 .2443 L
.80897 .2566 L
.81783 .26515 L
.8277 .27205 L
.83686 .27733 L
.84754 .28407 L
.84886 .28604 L
.85009 .28729 L
.85138 .28745 L
.85205 .28721 L
.85278 .28693 L
.85408 .28698 L
.8553 .28806 L
.8564 .28957 L
.8576 .29098 L
.85878 .29151 L
.86009 .29116 L
.86075 .29089 L
.86145 .29076 L
.86273 .29129 L
.86394 .29264 L
.86521 .29419 L
.8663 .29492 L
.86748 .29487 L
.8682 .29456 L
.86889 .29428 L
.87016 .29429 L
.87087 .29474 L
.87153 .29539 L
.8723 .2963 L
.87302 .29711 L
.87421 .29793 L
.87552 .29784 L
.87679 .29728 L
.87751 .29711 L
.87816 .2972 L
.87931 .29797 L
.88054 .2993 L
.88158 .30024 L
.88274 .30058 L
.88397 .30019 L
.88462 .29987 L
.88531 .29964 L
Mistroke
.88656 .29983 L
.88772 .30075 L
.8888 .30185 L
.88996 .30265 L
.89105 .3027 L
.89204 .30229 L
.89321 .30177 L
.89448 .30184 L
.89568 .30268 L
.89678 .30373 L
.89803 .3045 L
.89922 .30444 L
.90028 .30392 L
.90144 .30345 L
.9027 .30362 L
.90341 .30408 L
.90405 .30463 L
.90529 .30565 L
.90646 .30603 L
.90756 .30574 L
.90873 .30511 L
.90972 .3048 L
.91081 .30502 L
.91199 .30586 L
.91325 .30684 L
.91444 .3072 L
.91552 .3069 L
.9168 .30619 L
.91745 .30594 L
.91816 .30589 L
.91942 .30643 L
.9206 .30734 L
.92128 .30779 L
.92199 .30807 L
.92326 .3079 L
.92397 .30753 L
.92462 .30714 L
.92535 .30682 L
.92612 .30671 L
.92742 .3072 L
.92815 .30773 L
.92883 .30823 L
.93007 .30876 L
.93138 .30849 L
.93255 .30781 L
.93365 .30735 L
.93486 .30747 L
.93615 .30827 L
.93745 .30907 L
.93863 .30921 L
Mistroke
.93928 .30899 L
.93998 .3086 L
.94126 .30789 L
.94246 .30775 L
.94372 .30833 L
.94491 .30912 L
.94599 .30953 L
.94726 .30929 L
.94797 .3089 L
.94863 .30849 L
.94981 .308 L
.9511 .30821 L
.95177 .30858 L
.95251 .30908 L
.95328 .30952 L
.95401 .30972 L
.9553 .30944 L
.95603 .30902 L
.9567 .3086 L
.9579 .30814 L
.95917 .30837 L
.96038 .3091 L
.96147 .30968 L
.96276 .30973 L
.96349 .30942 L
.96416 .30901 L
.96539 .30833 L
.96669 .30824 L
.96782 .30877 L
.96903 .30952 L
.97018 .30984 L
.97122 .30959 L
.97244 .30885 L
.97309 .30848 L
.97377 .30823 L
.97503 .30836 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00W_oonfX4o`0007_ooo]Z1Ol0003o
oookJQoooo]Z002NoookJPCo0000NooonfX5o`0007kooo]Z1?l0002LoookJP00W_oonfX4o`0007_o
oo]Z1Ol0001noookJPCo0000W?oonfX009kooo]Z1Ol0001joookJPGo0000O_oonfX5o`0009_ooo]Z
002NoookJPGo0000N_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0007[ooo]Z1Ol0001n
oookJPGo0000VooonfX009kooo]Z1Ol0001joookJPGo0000O_oonfX5o`0009_ooo]Z002MoookJPKo
0000N_oonfX5o`0007kooo]Z1Ol0002KoookJP00WOoonfX6o`0006gooo]Z0ol007l:oookJPGo0000
O_oonfX5o`0009_ooo]Z002MoookJPKo0000KOoonfX3o`00O`[ooo]Z1Ol0001moookJPKo0000Vooo
nfX009gooo]Z1_l0001]oookJP?o001o2_oonfX5o`0007gooo]Z1_l0002KoookJP00WOoonfX6o`00
05gooo]Z2_l007l6oookJP?o001o2_oonfX5o`0007gooo]Z1_l0002KoookJP00WOoonfX6o`0005go
oo]Z2_l007l6oookJP?o001o2_oonfX6o`0007cooo]Z1_l0002KoookJP00WOoonfX6o`0006gooo]Z
0ol007l:oookJPGo0000OOoonfX6o`0009_ooo]Z002MoookJPKo0000KOoonfX3o`00O`[ooo]Z1Ol0
001moookJPKo0000VooonfX009gooo]Z1_l0001]oookJP?o001o2_oonfX5o`0007gooo]Z1_l0002K
oookJP00WOoonfX6o`0006gooo]Z0ol007l:oookJPGo0000OOoonfX6o`0009_ooo]Z002MoookJPKo
0000J_oonfX6o`00O`[ooo]Z1Ol0001moookJPKo0000VooonfX009gooo]Z2Ol0001WoookJPKo001o
2_oonfX5o`0007gooo]Z2_l0002GoookJP00WOoonfX9o`0006Wooo]Z1?l007l:oookJPGo0000OOoo
nfX:o`0009Oooo]Z002MoookJP[o0000JOoonfX3o`00O`[ooo]Z1Ol0001moookJP[o0000UooonfX0
09gooo]Z2_l0001foookJPGo0000OOoonfX:o`0009Oooo]Z002MoookJP[o0000M_oonfX5o`0007go
oo]Z2_l0002GoookJP00WOoonfX:o`0007Kooo]Z1Ol0001moookJP[o0000UooonfX009gooo]Z2ol0
001eoookJPGo0000OOoonfX:o`0009Oooo]Z002MoookJP_o0000MOoonfX5o`0007gooo]Z2ol0002F
oookJP00WOoonfX;o`0007Gooo]Z1Ol0001moookJP_o0000U_oonfX009gooo]Z3_l0001boookJPGo
0000OOoonfX>o`0009?ooo]Z002MoookJPko0000L_oonfX5o`0007gooo]Z3_l0002CoookJP00WOoo
nfX>o`0007;ooo]Z1Ol0001moookJPko0000TooonfX009gooo]Z3_l0001boookJPGo0000OOoonfX>
o`0009?ooo]Z002MoookJPoo0000LOoonfX5o`0007gooo]Z3ol0002BoookJP00WOoonfX4o`0000?o
oo]Z2?l0001aoookJPGo0000OOoonfX4o`0000?ooo]Z2?l0002BoookJP00WOoonfX4o`0000?ooo]Z
2?l0001aoookJPGo0000OOoonfX4o`0000Cooo]Z1ol0002BoookJP00WOoonfX4o`0000?ooo]Z2?l0
001aoookJPGo0000OOoonfX4o`0000Cooo]Z1ol0002BoookJP00WOoonfX4o`0000Oooo]Z1ol0001^
oookJPGo0000OOoonfX4o`0000Oooo]Z1ol0002?oookJP00WOoonfX4o`0000Oooo]Z1ol0001^oook
JPGo0000OOoonfX4o`0000Oooo]Z1ol0002?oookJP00WOoonfX4o`0000Oooo]Z1ol0001^oookJPGo
0000OOoonfX4o`0000Oooo]Z2?l0002>oookJP00WOoonfX4o`0000Sooo]Z1ol0001]oookJPGo0000
OOoonfX4o`0000Sooo]Z1ol0002>oookJP00WOoonfX4o`0000Sooo]Z1ol0001]oookJPGo0000OOoo
nfX4o`0000Sooo]Z1ol0002>oookJP00WOoonfX4o`0000Sooo]Z1ol0001]oookJPGo0000OOoonfX4
o`0000Sooo]Z1ol0002>oookJP00WOoonfX4o`0000_ooo]Z1Ol0001/oookJPGo0000OOoonfX4o`00
00_ooo]Z1?l0002>oookJP00WOoonfX4o`0000_ooo]Z2?l0001YoookJPGo0000OOoonfX4o`0000_o
oo]Z2?l0002:oookJP00WOoonfX4o`0000_ooo]Z2?l0001YoookJPGo0000OOoonfX4o`0000_ooo]Z
2?l0002:oookJP00WOoonfX4o`0000cooo]Z1ol0001YoookJPGo0000OOoonfX4o`0000_ooo]Z2?l0
002:oookJP00WOoonfX4o`0000cooo]Z1ol0001YoookJPGo0000OOoonfX4o`0000cooo]Z2?l00029
oookJP00WOoonfX4o`0000cooo]Z2?l0001XoookJPGo0000OOoonfX4o`0000gooo]Z1ol00029oook
JP00WOoonfX4o`0000oooo]Z1Ol0001XoookJPGo0000OOoonfX4o`0000oooo]Z1Ol00029oookJP00
WOoonfX4o`0000oooo]Z2?l0001UoookJPGo0000OOoonfX4o`00013ooo]Z1ol00026oookJP00WOoo
nfX4o`00013ooo]Z1ol0001UoookJPGo0000OOoonfX4o`00013ooo]Z1ol00026oookJP00WOoonfX4
o`00013ooo]Z2?l00016oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000OOoonfX4
o`00013ooo]Z1ol00026oookJP00WOoonfX4o`00017ooo]Z1ol00015oookJPOo001o0ooonfX3o`00
O`;ooo]Z1ol007l9oookJPGo0000OOoonfX4o`00013ooo]Z2?l00025oookJP00WOoonfX4o`00017o
oo]Z1ol00015oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0007gooo]Z1?l0000AoookJPOo0000QOoonfX0
09gooo]Z1?l0000DoookJPOo0000=OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l8oookJPGo0000OOoonfX4o`0001?ooo]Z2?l00022oookJP00WOoonfX4o`0001Co
oo]Z1ol0000eoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2?oonfX6o`0007co
oo]Z1?l0000DoookJPSo0000POoonfX009gooo]Z1?l0000DoookJPSo0000@?oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o2?oonfX5o`0007gooo]Z1?l0000DoookJPSo0000POoonfX009gooo]Z1?l0
000DoookJPSo0000@?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0
001moookJPCo00005OoonfX7o`00087ooo]Z002MoookJPCo00005OoonfX8o`0003oooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`Wooo]Z1Ol0001moookJPCo00005OoonfX7o`00087ooo]Z002Moook
JPCo00006?oonfX5o`0003oooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0001moook
JPCo00006?oonfX5o`00083ooo]Z002MoookJPCo00006?oonfX8o`0003cooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`kooo]Z1Ol0001moookJPCo00006?oonfX7o`0007kooo]Z002MoookJPCo0000
6OoonfX7o`0003gooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3_oonfX5o`0007go
oo]Z1?l0000HoookJPSo0000OOoonfX009gooo]Z1?l0000IoookJPOo0000?OoonfX7o`00O`Wooo]Z
1ol007l8oookJPGo0000OOoonfX4o`0001Wooo]Z1ol0001moookJP00WOoonfX4o`0001Wooo]Z2?l0
000moookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0001moookJPCo00006OoonfX8o`0007cooo]Z002L
oookJPGo00007?oonfX8o`0005Sooo]Z1Ol0001moookJPCo00007?oonfX6o`0007_ooo]Z002Loook
JPGo00007?oonfX8o`0005Sooo]Z1Ol0001moookJPCo00007?oonfX7o`0007[ooo]Z002LoookJPGo
00007OoonfX8o`0005Oooo]Z1Ol0001moookJPCo00007OoonfX6o`0007[ooo]Z002LoookJPCo0000
7ooonfX7o`0005Oooo]Z1Ol0001moookJPCo00007_oonfX6o`0007Wooo]Z002LoookJPCo00007ooo
nfX8o`0005Kooo]Z1Ol0001loookJPGo00007ooonfX7o`0007Oooo]Z002LoookJPCo00008_oonfX8
o`0005?ooo]Z1Ol0001loookJPGo00007ooonfX8o`0007Kooo]Z002LoookJPCo00008_oonfX8o`00
05?ooo]Z1Ol0001loookJPGo00008?oonfX8o`0007Gooo]Z002LoookJPCo00008ooonfX8o`0005;o
oo]Z1Ol0001loookJPCo00008_oonfX8o`0007Cooo]Z002LoookJPCo00009?oonfX9o`00053ooo]Z
1Ol0001loookJPCo00009?oonfX8o`0007;ooo]Z002LoookJPCo00009_oonfX8o`0004oooo]Z1Ol0
001loookJPCo00009OoonfX8o`00077ooo]Z002LoookJPCo00009_oonfX8o`0004oooo]Z1Ol0001l
oookJPCo00009_oonfX9o`0006oooo]Z002LoookJPCo00009ooonfX8o`0004kooo]Z1Ol0001loook
JPCo00009ooonfX9o`0006kooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00000ooonfX3o`00O`?o
oo]Z1Ol007lJoookJP[o0000BooonfX5o`0007Cooo]Z1Ol007l3oookJPCo00000ooonfX5o`00Ob7o
oo]Z2Ol0001<oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o1?l00003oookJP?o001o
0_oonfX7o`00Oa_ooo]Z2Ol0001:oookJPGo0000LooonfX7o`00O`;ooo]Z1?l00002oookJPOo001o
8OoonfX:o`0004[ooo]Z0ol007lMoookJP008_oonfX3o`00OgCooo]Z0ol007l4o`0000?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Oacooo]Z2?l0001:oookJPGo0000
LooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l000000ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00Ob?ooo]Z2Ol00019oookJP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o
001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Co
oo]Z0ol007l3oookJP?o001o6ooonfX<o`0004Kooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03
oookJ_l0003o000000;o000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ob?ooo]Z2_l00017oook
JP?o001o7OoonfX001?ooo]Z2_l007l5oookJP?o001oIooonfX:o`00O`;ooo]Z0ol007l00ooonf[o
0000o`000002o`000003o`00Oooonf[ooo]Z00[ooo]Z0ol007lOoookJPSo0000A_oonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00007oookJP?o001o9OoonfX9o`0004Ko
oo]Z0ol007lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00
Oooonf[ooo]Z00[ooo]Z0ol007lOoookJPWo0000AOoonfX5o`0007;ooo]Z0ol007l3oookJP?o001o
00?ooo]Zo`000?l000000_l00007oookJP?o001o9ooonfX8o`0004Gooo]Z0ol007lMoookJP008_oo
nfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l0
07l2oookJPCo001o8?oonfX;o`0004;ooo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0
003o000000;o00000_oonfX2o`00O`;ooo]Z1?l007lXoookJPSo0000A?oonfX3o`00Oagooo]Z000R
oookJP?o001oLooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX7
o`00ObCooo]Z2?l00012oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002
o`0000;ooo]Z1ol007l[oookJPOo0000@ooonfX3o`00Oagooo]Z000RoookJP?o001oLooonfX3o`00
O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01OoonfX6o`00ObKooo]Z2ol0000noook
JPGo0000L_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z1_l007l]oook
JP[o0000?ooonfX3o`00Oagooo]Z000OoookJPKo001oLooonfX3o`00O`03oookJ_l0003o000000;o
000000?o001ooookJ_oonfX01OoonfX2o`00Ob_ooo]Z2ol0000moookJPGo0000L_oonfX3o`00O`?o
oo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0_l007lboookJP[o0000>ooonfX6o`00Oago
oo]Z000OoookJPKo001oM?oonfX3o`00O`Co00002?oonfX2o`00Obgooo]Z3Ol0000ioookJPGo0000
LooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l00002oookJP;o001o<ooonfX=o`0003Oo
oo]Z1_l007lMoookJP008OoonfX4o`00OgCooo]Z0ol007l4o`0000Wooo]Z1ol007lXoookJPko0000
=ooonfX5o`0007?ooo]Z1ol007l2oookJPCo00000ooonfX7o`00Obkooo]Z3?l0000ioookJPCo001o
7OoonfX002;ooo]Z0ol007meoookJP;o001o1?l00009oookJPOo001o;?oonfX<o`0003Gooo]Z1Ol0
001doookJPGo001o0ooonfX4o`0000?ooo]Z1ol007lboookJPco0000=_oonfX3o`00Oagooo]Z002L
oookJPCo0000??oonfX=o`0003Cooo]Z1Ol0001loookJPCo0000?OoonfX<o`0005Gooo]Z002Loook
JPCo0000?OoonfX?o`00037ooo]Z1Ol0001loookJPCo0000?OoonfX@o`00057ooo]Z002LoookJPCo
0000@ooonfX>o`0002cooo]Z1Ol0001loookJPCo0000@OoonfX?o`0004kooo]Z002LoookJPCo0000
AOoonfX@o`0002Sooo]Z1Ol0001loookJPCo0000A?oonfXAo`0004Wooo]Z002LoookJPCo0000AOoo
nfXEo`0002?ooo]Z1Ol0001loookJPCo0000AOoonfXEo`0004Cooo]Z002LoookJPCo0000BOoonfXI
o`0001_ooo]Z1Ol0001loookJPCo0000BOoonfXIo`0003cooo]Z000>oookJ_oo0000ool0000Uo`00
00oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z
000>oookJ_oo0000ool0000Uo`0000oooo]Z000>oookJ_oo0000ool0000Uo`0000oooo]Z000Moook
JP03o`000?oonf[ooo]Z00Wooo]Z9_l0001=oookJPCo0000OOoonfX5o`0000Wooo]Z9Ol0001>oook
JPCo0000OooonfX00ol0003ooo]ZoookJP0LoookJP00>_oonfXIo`0004Wooo]Z1?l0001moookJPGo
00006_oonfXHo`0004[ooo]Z1?l0002NoookJP00@_oonfXEo`0004Gooo]Z1?l0001moookJPGo0000
9?oonfXDo`0004Cooo]Z1?l0002NoookJP00AooonfX@o`0004Gooo]Z1?l0001moookJPGo00009ooo
nfXCo`0004;ooo]Z1?l0002NoookJP00BooonfX@o`00047ooo]Z1?l0001moookJPGo0000:ooonfX@
o`00047ooo]Z1?l0002NoookJP00CooonfX=o`00043ooo]Z1?l0001moookJPGo0000;ooonfX>o`00
03oooo]Z1?l0002NoookJP00DooonfX=o`0003cooo]Z1?l0001moookJPGo0000=OoonfX:o`0003go
oo]Z1?l0002NoookJP00E?oonfX<o`0003cooo]Z1?l0001moookJPGo0000=ooonfX9o`0003cooo]Z
1?l0002NoookJP00F?oonfX<o`0003Sooo]Z1?l0001moookJPGo0000>?oonfX:o`0003[ooo]Z1?l0
002NoookJP00F?oonfX<o`0003Sooo]Z1?l0001moookJPGo0000>_oonfX9o`0003Wooo]Z1?l0002N
oookJP00G?oonfX;o`0003Gooo]Z1?l0001moookJPGo0000??oonfX9o`0003Oooo]Z1?l0002Noook
JP00GOoonfX;o`0003Cooo]Z1?l0001moookJPGo0000?OoonfX9o`0003Kooo]Z1?l0002NoookJP00
H?oonfX9o`0003?ooo]Z1?l0001moookJPGo0000?ooonfX9o`0003Cooo]Z1?l0002NoookJP00HOoo
nfX;o`00033ooo]Z1?l0001moookJPGo0000@?oonfX9o`0003?ooo]Z1?l0002NoookJP00I?oonfX9
o`0002oooo]Z1?l0001moookJPGo0000@_oonfX9o`00037ooo]Z1?l0002NoookJP00IOoonfX8o`00
02oooo]Z1?l0001moookJPGo0000@ooonfX9o`00033ooo]Z1?l0002NoookJP00IOoonfX;o`0002co
oo]Z1?l0001moookJPGo0000AOoonfX9o`0002kooo]Z1?l0002NoookJP00JOoonfX8o`0002_ooo]Z
1?l0001moookJPGo0000A_oonfX9o`0002gooo]Z1?l0002NoookJP00JOoonfX9o`0002[ooo]Z1?l0
001moookJPGo0000B?oonfX9o`0002_ooo]Z1?l0002NoookJP00J_oonfX:o`0002Sooo]Z1?l0001m
oookJPGo0000BOoonfX9o`0002[ooo]Z1?l0002NoookJP00KOoonfX8o`0002Oooo]Z1?l0001moook
JPGo0000BooonfX9o`0002Sooo]Z1?l0002NoookJP00K_oonfX7o`0002Oooo]Z1?l0001moookJPGo
0000C?oonfX9o`0002Oooo]Z1?l0002NoookJP00K_oonfX8o`0002Kooo]Z1?l0001moookJPGo0000
C_oonfX9o`0002Gooo]Z1?l0002NoookJP00KooonfX9o`0002Cooo]Z1?l0001moookJPGo0000Cooo
nfX9o`0002Cooo]Z1?l0002NoookJP00LOoonfX8o`0002?ooo]Z1?l0001moookJPGo0000DOoonfX8
o`0002?ooo]Z1?l0002NoookJP00L_oonfX8o`0002;ooo]Z1?l0001moookJPGo0000D_oonfX8o`00
02;ooo]Z1?l0002NoookJP00L_oonfX8o`0002;ooo]Z1?l0001moookJPGo0000E?oonfX7o`00027o
oo]Z1?l0002NoookJP00M?oonfX9o`0001oooo]Z1?l0001moookJPGo0000EOoonfX7o`00023ooo]Z
1?l0002NoookJP00M_oonfX8o`0001kooo]Z1?l0001moookJPGo0000E_oonfX7o`0001oooo]Z1?l0
002NoookJP00M_oonfX8o`0001kooo]Z1?l0001moookJPGo0000EooonfX7o`0001kooo]Z1?l0002N
oookJP00MooonfX8o`0001gooo]Z1?l0001moookJPGo0000F?oonfX7o`0001gooo]Z1?l0002Noook
JP00MooonfX8o`0001gooo]Z1?l0001moookJPGo0000FOoonfX7o`0001cooo]Z1?l0002NoookJP00
N_oonfX8o`0001[ooo]Z1?l0001moookJPGo0000F_oonfX8o`0001[ooo]Z1?l0002NoookJP00Nooo
nfX7o`0001[ooo]Z1?l0001moookJPGo0000FooonfX7o`0001[ooo]Z1?l0002NoookJP00NooonfX7
o`0001[ooo]Z1?l0001moookJPGo0000G?oonfX6o`0001[ooo]Z1?l0002NoookJP00O?oonfX6o`00
01[ooo]Z1?l0001OoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000GOoonfX6o`00
01Wooo]Z1?l0002NoookJP00O_oonfX5o`0001Wooo]Z1?l0001NoookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l9oookJPGo0000G_oonfX5o`0001Wooo]Z1?l0002NoookJP00O_oonfX8o`0001Kooo]Z
1?l0001NoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o
001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`0005kooo]Z2?l0000FoookJPCo0000W_oonfX007ko
oo]Z2?l0000FoookJPCo0000GOoonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`So
oo]Z1Ol0001OoookJPOo00005_oonfX4o`0009kooo]Z001ooookJPOo00005_oonfX4o`0005gooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1_l0001NoookJPOo00005_oonfX4o`0009kooo]Z
0020oookJPOo00005OoonfX4o`0005gooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0
001PoookJPOo00005OoonfX4o`0009kooo]Z0020oookJPSo00005?oonfX4o`0005gooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000H?oonfX8o`0001Cooo]Z1?l0002N
oookJP00P_oonfX6o`0001Cooo]Z1?l0001MoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oook
JPGo0000H_oonfX8o`0001;ooo]Z1?l0002NoookJP00PooonfX6o`0001?ooo]Z1?l0001MoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000HooonfX8o`00017ooo]Z1?l0002NoookJP00
Q?oonfX5o`0001?ooo]Z1?l0001MoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000
I?oonfX7o`00017ooo]Z1?l0002NoookJP00Q?oonfX6o`0001;ooo]Z1?l0001NoookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z1Ol0001ToookJPOo00004OoonfX4o`0009kooo]Z
0025oookJPKo00004OoonfX4o`0005kooo]Z1ol007l9oookJPOo001o2?oonfX5o`0006Gooo]Z1ol0
000@oookJPCo0000W_oonfX008Gooo]Z1_l0000AoookJPCo0000GooonfX5o`00O`[ooo]Z1ol007l8
oookJPGo0000IooonfX5o`00013ooo]Z1?l0002NoookJP00Q_oonfX9o`0000gooo]Z1?l0001moook
JPGo0000IooonfX7o`0000kooo]Z1?l0002NoookJP00QooonfX8o`0000cooo]Z1Ol0001moookJPGo
0000J?oonfX7o`0000gooo]Z1?l0002NoookJP00QooonfX8o`0000cooo]Z1Ol0001moookJPGo0000
J?oonfX7o`0000gooo]Z1?l0002NoookJP00R?oonfX7o`0000cooo]Z1Ol0001moookJPGo0000J?oo
nfX8o`0000cooo]Z1?l0002NoookJP00ROoonfX6o`0000cooo]Z1?l0001noookJPGo0000J?oonfX8
o`0000cooo]Z1?l0002NoookJP00RooonfX5o`0000_ooo]Z1?l0001noookJPGo0000JooonfX5o`00
00cooo]Z1?l0002NoookJP00RooonfX8o`0000Sooo]Z1?l0001noookJPGo0000K?oonfX7o`0000So
oo]Z1Ol0002NoookJP00RooonfX8o`0000Sooo]Z1?l0001noookJPGo0000K?oonfX7o`0000Sooo]Z
1Ol0002NoookJP00S?oonfX8o`0000Oooo]Z1?l0001noookJPGo0000K?oonfX8o`0000Oooo]Z1Ol0
002NoookJP00S?oonfX8o`0000Oooo]Z1?l0001noookJPGo0000K?oonfX8o`0000Oooo]Z1?l0002O
oookJP00S?oonfX8o`0000Oooo]Z1?l0001noookJPGo0000K?oonfX8o`0000Oooo]Z1?l0002Ooook
JP00SOoonfX7o`0000Oooo]Z1?l0001noookJPGo0000KOoonfX7o`0000Oooo]Z1?l0002OoookJP00
T?oonfX7o`0000Cooo]Z1?l0001noookJPGo0000L?oonfX7o`0000Cooo]Z1?l0002OoookJP00T?oo
nfX8o`0000?ooo]Z1?l0001noookJPGo0000L?oonfX7o`0000Cooo]Z1?l0002OoookJP00T?oonfX8
o`0000?ooo]Z1?l0001noookJPGo0000L?oonfX8o`0000?ooo]Z1?l0002OoookJP00T?oonfX?o`00
07kooo]Z1Ol0001`oookJPSo00000ooonfX4o`0009oooo]Z002@oookJPoo0000O_oonfX5o`00073o
oo]Z3ol0002OoookJP00T?oonfX?o`0007kooo]Z1Ol0001aoookJPko0000WooonfX0097ooo]Z3_l0
001noookJPGo0000LOoonfX>o`0009oooo]Z002AoookJPko0000O_oonfX5o`00077ooo]Z3_l0002O
oookJP00U?oonfX;o`0007kooo]Z1Ol0001eoookJP[o0000WooonfX009Cooo]Z2ol0001noookJPGo
0000MOoonfX:o`0009oooo]Z002DoookJP_o0000O_oonfX5o`0007Gooo]Z2_l0002OoookJP00U?oo
nfX;o`0007kooo]Z1Ol0001eoookJP[o0000WooonfX009Gooo]Z2_l0001noookJPGo0000MOoonfX:
o`0009oooo]Z002EoookJP[o0000O_oonfX5o`0007Gooo]Z2_l0002OoookJP00UOoonfX:o`0007ko
oo]Z1Ol0001eoookJP[o0000WooonfX009Gooo]Z2_l0001noookJPGo0000MOoonfX:o`0009oooo]Z
002FoookJPWo0000O_oonfX5o`0007Kooo]Z2Ol0002OoookJP00VOoonfX6o`00077ooo]Z0ol007l:
oookJPGo0000NOoonfX6o`0009oooo]Z002IoookJPKo0000LOoonfX3o`00O`[ooo]Z1Ol0001ioook
JPKo0000WooonfX009Wooo]Z1_l0001aoookJP?o001o2_oonfX5o`0007Wooo]Z1_l0002OoookJP00
VOoonfX6o`00077ooo]Z0ol007l:oookJPGo0000NOoonfX6o`0009oooo]Z002IoookJPKo0000LOoo
nfX3o`00O`[ooo]Z1_l0001hoookJPKo0000WooonfX009Wooo]Z1Ol0001boookJP?o001o2_oonfX5
o`0007Wooo]Z1_l0002OoookJP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000NOoonfX6o`00
09oooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z
1Ol0001boookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX5o`0006oooo]Z1_l0
07l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000KooonfX6o`00O`[ooo]Z1Ol0001i
oookJPGo0000X?oonfX009Wooo]Z1Ol0001aoookJPCo001o2_oonfX5o`0007Wooo]Z1Ol0002Poook
JP00VOoonfX5o`0007;ooo]Z0ol007l:oookJPGo0000N_oonfX4o`000:3ooo]Z002IoookJPGo0000
OooonfX5o`0007[ooo]Z1?l0002PoookJP00VOoonfX5o`0007oooo]Z1Ol0001joookJPCo0000X?oo
nfX009Wooo]Z1Ol0001ooookJPGo0000N_oonfX4o`000:3ooo]Z002JoookJPCo0000OooonfX5o`00
0?oooo]Z7ooonfX009[ooo]Z1?l0001ooookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`?o
oo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`;ooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o1?oonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oo
nfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3
o`00O`kooo]Z0ol007l8oookJPKo0000oooonfXNoookJP00oooonfX2oookJP?o001o3_oonfX3o`00
O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJP;o001o0_oonfX4o`00O`So
oo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l9oookJPOo001o2OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z1_l007l:oookJPGo0000oooonfXOoookJP00o_oonfX6
o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00o_oonfX6o`00O`Wooo]Z0_l007l>oook
JPGo0000oooonfXOoookJP00oooonfX1oookJPCo001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoo
oo]Z003ooookJP;ooo]Z0ol007l:oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX9o`00O`Sooo]Z1Ol0003ooookJQoo
oo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPCo001o3Ooo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3_oonfX4o`00O`cooo]Z1Ol0003ooookJQoooo]Z003ooook
JPoooo]Z1Ol007l:oookJPKo0000oooonfXNoookJP00oooonfXAoookJPCo001o2OoonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z4_oonfX3o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ?ooo]Z0ol0
07oooookJRcooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001ooooonfX/oookJP00oooonfX=oook
JP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z0ol007oooookJRco
oo]Z003ooookJPkooo]Z1ol007oooookJRgooo]Z003ooookJPoooo]Z1Ol007oooookJRkooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.154508 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 0 -26.9375 -10 ]
[.4875 0 0 10 ]
[.4875 .07725 -41.9375 -10 ]
[.4875 .07725 0 10 ]
[.4875 .15451 -26.9375 -10 ]
[.4875 .15451 0 10 ]
[.4875 .23176 -41.9375 -10 ]
[.4875 .23176 0 10 ]
[.4875 .38627 -29 -10 ]
[.4875 .38627 0 10 ]
[.4875 .46353 -14 -10 ]
[.4875 .46353 0 10 ]
[.4875 .54078 -29 -10 ]
[.4875 .54078 0 10 ]
[.4875 .61803 -14 -10 ]
[.4875 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 0 m
.50625 0 L
s
gsave
.4875 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .30902 m
.02499 .30836 L
.02605 .30822 L
.02729 .30873 L
.02846 .30946 L
.02954 .30982 L
.03053 .30967 L
.03163 .30906 L
.03279 .3084 L
.03395 .30824 L
.0352 .30877 L
.03628 .30945 L
.03746 .30986 L
.03818 .30978 L
.03884 .30949 L
.04016 .30869 L
.04135 .30827 L
.04262 .30857 L
.04327 .30896 L
.04396 .30941 L
.04519 .30993 L
.04588 .30992 L
.04652 .30969 L
.04722 .3093 L
.04797 .30883 L
.04862 .30852 L
.04933 .30838 L
.05061 .30877 L
.05186 .30959 L
.05302 .31011 L
.05414 .31 L
.05519 .30944 L
.05634 .30879 L
.05759 .30865 L
.05882 .30924 L
.06012 .31011 L
.06123 .31045 L
.06244 .31013 L
.06315 .30972 L
.06381 .30933 L
.06453 .30904 L
.06529 .309 L
.06657 .30957 L
.06729 .31009 L
.06797 .31055 L
.06924 .31093 L
.0704 .31059 L
.07166 .30986 L
.07236 .30958 L
.073 .30952 L
Mistroke
.07374 .30973 L
.07443 .31015 L
.07508 .31064 L
.07577 .31114 L
.07652 .31151 L
.07722 .3116 L
.07796 .31143 L
.07878 .311 L
.07949 .3106 L
.08015 .31033 L
.08092 .31028 L
.08162 .31051 L
.08289 .31142 L
.08356 .31194 L
.08427 .31235 L
.08553 .31245 L
.08671 .31191 L
.08739 .31154 L
.08811 .31128 L
.08939 .31147 L
.09004 .31189 L
.09074 .31247 L
.09199 .31342 L
.09276 .31367 L
.09348 .31361 L
.09413 .31336 L
.09483 .31298 L
.096 .31251 L
.0973 .31278 L
.09795 .31324 L
.09864 .31386 L
.0999 .31487 L
.10116 .31514 L
.10235 .31468 L
.10342 .31417 L
.10458 .31411 L
.10579 .31485 L
.10691 .31593 L
.10813 .31681 L
.10942 .31687 L
.11055 .31636 L
.11161 .31596 L
.11285 .3162 L
.11396 .31713 L
.11519 .31839 L
.11589 .31889 L
.11653 .31912 L
.11768 .31892 L
.11891 .31836 L
.11955 .3182 L
Mistroke
.12024 .31827 L
.12149 .31915 L
.1222 .31993 L
.12296 .32077 L
.12368 .32137 L
.12433 .32167 L
.125 .32169 L
.12572 .32146 L
.12702 .32092 L
.12776 .32086 L
.12855 .32119 L
.12922 .32177 L
.12995 .32262 L
.13064 .32345 L
.13129 .32412 L
.13204 .3246 L
.13272 .32472 L
.13396 .32435 L
.13465 .32406 L
.1353 .32393 L
.1365 .3244 L
.13714 .32503 L
.13783 .32589 L
.13851 .32679 L
.13923 .32758 L
.14051 .32821 L
.1417 .32792 L
.14281 .32752 L
.14403 .32776 L
.14533 .32913 L
.16526 .34165 L
.18685 .3603 L
.22685 .40819 L
.22807 .40755 L
.22875 .40653 L
.22939 .40578 L
.23056 .40628 L
.23181 .41033 L
.23256 .41389 L
.23327 .41713 L
.23459 .42061 L
.23581 .41977 L
.23713 .41696 L
.23829 .41675 L
.23957 .42136 L
.24081 .42877 L
.24149 .4323 L
.24214 .43436 L
.24339 .43384 L
.24452 .42981 L
Mistroke
.24558 .42694 L
.24674 .42893 L
.24794 .43736 L
.24864 .44346 L
.24927 .44834 L
.24994 .45153 L
.25065 .45183 L
.25195 .44461 L
.25313 .43567 L
.25442 .43515 L
.25564 .4495 L
.25677 .4702 L
.25746 .4803 L
.25821 .48351 L
.25891 .47534 L
.25956 .45623 L
.2608 .39023 L
.2621 .29411 L
.26341 .20293 L
.26414 .16597 L
.26481 .14457 L
.2656 .13453 L
.26635 .13771 L
.26704 .14774 L
.26779 .16165 L
.269 .17986 L
.27012 .18441 L
.27134 .17765 L
.27263 .16811 L
.27376 .16623 L
.2748 .17157 L
.27595 .18143 L
.27718 .18958 L
.27788 .19118 L
.27852 .19063 L
.27923 .18846 L
.27998 .1856 L
.28123 .18318 L
.28195 .18436 L
.28261 .18714 L
.28384 .19435 L
.285 .2 L
.28563 .20144 L
.28633 .20152 L
.28755 .19922 L
.28824 .19785 L
.28898 .19729 L
.28968 .19811 L
.29032 .20003 L
.29154 .20556 L
Mistroke
.29283 .21077 L
.2935 .21213 L
.29422 .21238 L
.29551 .21081 L
.2963 .20989 L
.29705 .20991 L
.29772 .21094 L
.29845 .21309 L
.29977 .21823 L
.301 .2219 L
.30228 .22272 L
.30297 .22217 L
.3037 .22141 L
.30494 .22124 L
.30624 .22379 L
.30735 .22749 L
.30856 .23107 L
.3092 .23215 L
.30988 .23254 L
.3111 .23191 L
.31241 .23133 L
.31316 .23191 L
.31386 .2332 L
.31885 .24122 L
.32336 .24662 L
.32466 .24929 L
.32589 .24999 L
.32699 .24954 L
.3282 .24929 L
.32949 .25064 L
.3307 .25333 L
.33141 .25502 L
.33215 .25648 L
.33278 .25729 L
.33347 .25766 L
.33415 .25759 L
.33487 .25728 L
.33617 .2571 L
.33695 .25772 L
.33769 .25888 L
.33908 .26186 L
.3403 .26398 L
.34159 .26468 L
.3427 .26434 L
.34391 .26412 L
.34522 .26522 L
.34595 .26648 L
.34662 .26782 L
.34792 .27011 L
.34916 .27102 L
Mistroke
.3692 .28254 L
.37792 .28811 L
.38251 .28996 L
.38363 .28988 L
.38482 .29069 L
.38613 .29234 L
.38736 .29368 L
.38804 .29404 L
.38878 .29407 L
.38947 .29385 L
.39012 .29357 L
.39134 .29332 L
.39264 .29402 L
.39384 .2954 L
.39514 .29676 L
.39637 .29719 L
.39749 .29685 L
.39855 .29641 L
.3997 .29644 L
.40091 .29733 L
.40203 .29858 L
.4033 .29965 L
.40445 .29981 L
.40509 .2996 L
.40578 .29926 L
.40704 .2989 L
.40834 .29942 L
.40956 .30061 L
.41025 .3013 L
.4109 .3018 L
.41165 .30209 L
.41234 .30205 L
.41301 .3018 L
.41373 .30143 L
.41502 .30107 L
.41582 .30128 L
.41656 .3018 L
.41722 .30242 L
.41795 .30312 L
.41918 .30391 L
.42047 .30383 L
.42167 .30324 L
.42279 .30288 L
.42411 .30329 L
.42531 .30431 L
.42598 .30489 L
.4267 .30535 L
.42801 .30547 L
.43737 .30597 L
.43856 .30553 L
Mistroke
.43984 .30583 L
.44057 .30634 L
.44123 .30688 L
.44253 .30767 L
.44374 .30768 L
.44506 .30701 L
.4463 .30647 L
.44744 .30658 L
.44813 .30696 L
.44878 .30743 L
.44955 .308 L
.45025 .30838 L
.45098 .30852 L
.45168 .30838 L
.45241 .30803 L
.45321 .30756 L
.45384 .30725 L
.45454 .3071 L
.45527 .30722 L
.45595 .30756 L
.45717 .30842 L
.45785 .30883 L
.45849 .30903 L
.45976 .30882 L
.4604 .30847 L
.46109 .30805 L
.46234 .30759 L
.46348 .30781 L
.46417 .30822 L
.4648 .30866 L
.46549 .3091 L
.46624 .30938 L
.46751 .30922 L
.4682 .30886 L
.46885 .30845 L
.47011 .30792 L
.47128 .30808 L
.47257 .30885 L
.47322 .30927 L
.47393 .30958 L
.47523 .3095 L
.47646 .30882 L
.47766 .30819 L
.47875 .30813 L
.47984 .30861 L
.48085 .30927 L
.48197 .30974 L
.48316 .30959 L
.48441 .30888 L
.48559 .30827 L
Mistroke
.48665 .30822 L
.48781 .30875 L
.48898 .30948 L
.49025 .30982 L
.49097 .30966 L
.49164 .30932 L
.49294 .30852 L
.49421 .3082 L
.49493 .30838 L
.4956 .30872 L
.49629 .30916 L
.49704 .30959 L
.49774 .30981 L
.49839 .3098 L
.4996 .30927 L
.50087 .30849 L
.50195 .3082 L
.50313 .30853 L
.50439 .3093 L
.50509 .30967 L
.50574 .30983 L
.50699 .30955 L
.50818 .30882 L
.50943 .30825 L
.51014 .30824 L
.51078 .30844 L
.51198 .30915 L
.51323 .30978 L
.51436 .30978 L
.51542 .30927 L
.51656 .30857 L
.51781 .30827 L
.5185 .30843 L
.51914 .30876 L
.5204 .30956 L
.52154 .30995 L
.52275 .30967 L
.52405 .30889 L
.52527 .3084 L
.52597 .30843 L
.52661 .30867 L
.52735 .30912 L
.52805 .30959 L
.5292 .31011 L
.53025 .31002 L
.53147 .30938 L
.53261 .30876 L
.53367 .30863 L
.53464 .30901 L
.53572 .30974 L
Mistroke
.53685 .31035 L
.53799 .31039 L
.53921 .3098 L
.54027 .3092 L
.54143 .30899 L
.54213 .3092 L
.54278 .30958 L
.54406 .31048 L
.54522 .31093 L
.54645 .31066 L
.54759 .31 L
.54883 .30953 L
.55013 .30983 L
.55134 .31069 L
.55247 .31142 L
.55351 .3116 L
.5547 .31116 L
.55582 .31053 L
.55705 .31027 L
.55834 .31083 L
.55945 .31171 L
.56067 .31243 L
.56197 .31237 L
.56271 .31202 L
.56338 .31164 L
.56468 .31124 L
.56592 .31167 L
.5842 .31676 L
.59454 .31861 L
.59581 .31819 L
.597 .31856 L
.59825 .31976 L
.59895 .32055 L
.59961 .32118 L
.60078 .32171 L
.60186 .32148 L
.60303 .32097 L
.60427 .32094 L
.6053 .32166 L
.60644 .32299 L
.60749 .32413 L
.60845 .32468 L
.60958 .32458 L
.6108 .32407 L
.61187 .32397 L
.613 .32467 L
.62244 .33044 L
.64215 .34138 L
.64335 .34138 L
.64464 .34269 L
Mistroke
.64587 .34485 L
.647 .34667 L
.64832 .34757 L
.64898 .34749 L
.64971 .34722 L
.65099 .34705 L
.65218 .34806 L
.65785 .35347 L
.66313 .36041 L
.702 .40639 L
.71216 .41945 L
.71281 .41799 L
.71349 .41672 L
.71423 .41646 L
.71492 .41777 L
.71616 .42366 L
.71687 .428 L
.71752 .43155 L
.71819 .43406 L
.71892 .43485 L
.72022 .4317 L
.72096 .42889 L
.72176 .42695 L
.72252 .42746 L
.72322 .43043 L
.72448 .44039 L
.72517 .44629 L
.72583 .45043 L
.72711 .45106 L
.72828 .44345 L
.72951 .43474 L
.7302 .43364 L
.73084 .43678 L
.73156 .4452 L
.7322 .45625 L
.73291 .46941 L
.73366 .48041 L
.7349 .4789 L
.73605 .44369 L
.73728 .36968 L
.73864 .26791 L
.73981 .191 L
.74106 .1432 L
.74225 .13525 L
.74333 .14949 L
.74443 .16961 L
.74562 .18308 L
.74692 .18209 L
.74814 .1727 L
.74944 .16605 L
Mistroke
.75009 .16659 L
.75081 .1702 L
.75207 .1808 L
.75325 .18905 L
.75444 .19107 L
.75557 .18786 L
.7566 .18424 L
.75769 .18338 L
.75887 .18747 L
.75996 .19395 L
.76113 .19982 L
.76242 .20159 L
.78319 .22628 L
.80428 .24926 L
.82354 .26923 L
.82469 .27071 L
.82592 .271 L
.82709 .27058 L
.82816 .27053 L
.82942 .27167 L
.83005 .27269 L
.83074 .27396 L
.83195 .2759 L
.83308 .27673 L
.83378 .27673 L
.83444 .27651 L
.83568 .27618 L
.83638 .27639 L
.83702 .27694 L
.83773 .27789 L
.83847 .27913 L
.8397 .281 L
.84085 .28186 L
.84211 .28171 L
.84282 .28144 L
.84347 .2813 L
.84463 .28172 L
.84587 .28324 L
.84695 .28488 L
.8481 .28617 L
.84882 .28648 L
.84947 .28644 L
.85076 .28597 L
.85193 .2859 L
.85316 .28683 L
.86238 .29242 L
.86351 .29365 L
.86471 .2941 L
.86603 .2937 L
.86724 .29331 L
Mistroke
.86837 .29365 L
.86943 .29467 L
.87061 .29609 L
.87185 .29707 L
.87249 .29719 L
.87318 .29705 L
.87441 .29652 L
.8751 .29633 L
.87583 .29642 L
.87653 .29681 L
.87716 .29739 L
.87836 .29873 L
.87965 .29972 L
.88088 .29975 L
.88201 .29925 L
.88306 .29891 L
.8842 .29919 L
.88527 .30009 L
.88625 .30111 L
.88739 .30196 L
.88864 .30202 L
.88982 .30149 L
.89091 .30109 L
.89214 .30136 L
.8933 .30231 L
.89436 .30331 L
.89547 .30394 L
.89669 .30382 L
.89781 .30327 L
.89902 .30288 L
.90034 .30332 L
.90559 .30482 L
.90684 .30436 L
.90747 .30441 L
.90817 .30471 L
.9094 .30569 L
.91056 .30654 L
.91168 .30679 L
.91271 .30645 L
.91391 .30579 L
.91502 .30552 L
.91615 .3059 L
.91739 .30685 L
.91859 .30762 L
.91987 .3077 L
.92109 .30711 L
.9224 .30649 L
.92363 .30658 L
.92475 .30727 L
.92593 .30813 L
Mistroke
.92721 .30852 L
.92793 .30836 L
.9286 .30803 L
.92992 .3073 L
.93122 .30715 L
.93196 .30745 L
.93266 .30791 L
.93335 .30841 L
.93407 .30884 L
.93486 .30905 L
.93558 .30896 L
.93687 .3083 L
.93807 .30768 L
.93939 .3077 L
.94013 .30807 L
.9408 .30852 L
.94193 .30922 L
.94313 .3094 L
.94416 .309 L
.94529 .30831 L
.9465 .3079 L
.9478 .30824 L
.94903 .30904 L
.95016 .30959 L
.95129 .30955 L
.95233 .30902 L
.95357 .3083 L
.9547 .30809 L
.95577 .30846 L
.95679 .30911 L
.95785 .30966 L
.95901 .30971 L
.96008 .3092 L
.96109 .30858 L
.96218 .30818 L
.96336 .3084 L
.96449 .30907 L
.96572 .30972 L
.96688 .30975 L
.96796 .30924 L
.96904 .30857 L
.97005 .30822 L
.9711 .30837 L
.97226 .30902 L
.97319 .30957 L
.97415 .30983 L
.97522 .30959 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfX=oookJPWo001ooooonfX/oook
JP00oooonfX=oookJPWo001ooooonfX/oookJP00oooonfX=oookJPCo001o3OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0OoonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX1
oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0003ooookJQkooo]Z003ooookJQ7ooo]Z1?l007l9oook
JPGo0000oooonfXOoookJP00oooonfXBoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z
4ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPgooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP00oooonfX=oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z
0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003aoookJP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?7ooo]Z2_l007l6oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJQkooo]Z003ooook
JP;ooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wo
oo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z003noookJPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003noook
JPKo001o2OoonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z003ooookJP7ooo]Z1?l007l:oookJPOo
001o2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00W_oonfX4o`0007_ooo]Z1Ol0003o
oookJQoooo]Z002NoookJPCo0000NooonfX5o`0007kooo]Z1?l0002LoookJP00W_oonfX4o`0007_o
oo]Z1Ol0001noookJPCo0000W?oonfX009kooo]Z1?l0001koookJPGo0000O_oonfX4o`0009cooo]Z
002NoookJPCo0000NooonfX5o`0007kooo]Z1?l0002LoookJP00W_oonfX4o`0007_ooo]Z1Ol0001n
oookJPCo0000W?oonfX009kooo]Z1Ol0001joookJPGo0000O_oonfX5o`0009_ooo]Z002NoookJPGo
0000N_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0006gooo]Z0ol007l:oookJPGo0000
O_oonfX5o`0009_ooo]Z002NoookJPGo0000KOoonfX3o`00O`[ooo]Z1Ol0001noookJPGo0000Vooo
nfX009kooo]Z1Ol0001]oookJP?o001o2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`00
05gooo]Z2_l007l6oookJP?o001o2_oonfX5o`0007kooo]Z1Ol0002KoookJP00W_oonfX5o`0005go
oo]Z2_l007l6oookJP?o001o2_oonfX6o`0007gooo]Z1Ol0002KoookJP00WOoonfX6o`0006gooo]Z
0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z002MoookJPKo0000KOoonfX3o`00O`[ooo]Z1Ol0
001noookJPGo0000VooonfX009gooo]Z1_l0001]oookJP?o001o2_oonfX5o`0007kooo]Z1Ol0002K
oookJP00WOoonfX6o`0006gooo]Z0ol007l:oookJPGo0000O_oonfX5o`0009_ooo]Z002MoookJPKo
0000J_oonfX6o`00O`[ooo]Z1Ol0001noookJPGo0000VooonfX009gooo]Z2Ol0001WoookJPKo001o
2_oonfX5o`0007kooo]Z2Ol0002GoookJP00WOoonfX9o`0006Wooo]Z1?l007l:oookJPGo0000OOoo
nfX:o`0009Oooo]Z002MoookJP[o0000JOoonfX3o`00O`[ooo]Z1Ol0001moookJP[o0000UooonfX0
09gooo]Z2_l0001foookJPGo0000OOoonfX:o`0009Oooo]Z002MoookJP[o0000M_oonfX5o`0007go
oo]Z2_l0002GoookJP00WOoonfX:o`0007Kooo]Z1Ol0001moookJP[o0000UooonfX009gooo]Z2ol0
001eoookJPGo0000OOoonfX;o`0009Kooo]Z002MoookJP_o0000MOoonfX5o`0007gooo]Z2ol0002F
oookJP00WOoonfX;o`0007Gooo]Z1Ol0001moookJP_o0000U_oonfX009gooo]Z3_l0001boookJPGo
0000OOoonfX>o`0009?ooo]Z002MoookJPko0000L_oonfX5o`0007gooo]Z3_l0002CoookJP00WOoo
nfX>o`0007;ooo]Z1Ol0001moookJPko0000TooonfX009gooo]Z3_l0001boookJPGo0000OOoonfX>
o`0009?ooo]Z002MoookJPko0000L_oonfX5o`0007gooo]Z1?l00003oookJPOo0000TooonfX009go
oo]Z1?l00003oookJPSo0000LOoonfX5o`0007gooo]Z1?l00003oookJPSo0000T_oonfX009gooo]Z
1?l00003oookJPSo0000LOoonfX5o`0007gooo]Z1?l00003oookJPSo0000T_oonfX009gooo]Z1?l0
0004oookJP[o0000K_oonfX5o`0007gooo]Z1?l00004oookJPOo0000T_oonfX009gooo]Z1?l00007
oookJPOo0000K_oonfX5o`0007gooo]Z1?l00007oookJPGo0000TOoonfX009gooo]Z1?l00007oook
JPOo0000K_oonfX5o`0007gooo]Z1?l00007oookJPGo0000TOoonfX009gooo]Z1?l00007oookJPOo
0000K_oonfX5o`0007gooo]Z1?l00007oookJPGo0000TOoonfX009gooo]Z1?l00007oookJPSo0000
KOoonfX5o`0007gooo]Z1?l00008oookJPCo0000TOoonfX009gooo]Z1?l00007oookJPSo0000KOoo
nfX5o`0007gooo]Z1?l00008oookJPGo0000T?oonfX009gooo]Z1?l00008oookJPOo0000KOoonfX5
o`0007gooo]Z1?l00008oookJPKo0000SooonfX009gooo]Z1?l0000;oookJPOo0000J_oonfX5o`00
07gooo]Z1?l00008oookJPOo0000S_oonfX009gooo]Z1?l0000;oookJPOo0000J_oonfX5o`0007go
oo]Z1?l00009oookJPOo0000SOoonfX009gooo]Z1?l0000;oookJPSo0000JOoonfX5o`0007gooo]Z
1?l0000:oookJPOo0000S?oonfX009gooo]Z1?l0000<oookJPOo0000JOoonfX5o`0007gooo]Z1?l0
000;oookJPOo0000RooonfX009gooo]Z1?l0000<oookJPOo0000JOoonfX5o`0007gooo]Z1?l0000<
oookJPKo0000RooonfX009gooo]Z1?l0000<oookJPOo0000JOoonfX5o`0007gooo]Z1?l0000=oook
JPKo0000R_oonfX009gooo]Z1?l0000?oookJPOo0000I_oonfX5o`0007gooo]Z1?l0000>oookJPKo
0000ROoonfX009gooo]Z1?l0000?oookJPOo0000I_oonfX5o`0007gooo]Z1?l0000>oookJPOo0000
R?oonfX009gooo]Z1?l0000?oookJPSo0000IOoonfX5o`0007gooo]Z1?l0000?oookJPOo0000Qooo
nfX009gooo]Z1?l0000?oookJPSo0000AooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5
o`0007gooo]Z1?l0000@oookJPOo0000Q_oonfX009gooo]Z1?l0000@oookJPSo0000AOoonfX7o`00
O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`0007gooo]Z1?l0000AoookJPKo0000Q_oonfX009go
oo]Z1?l0000CoookJPGo0000AOoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooo
nf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0001moookJPCo00004_oonfX6
o`0008Gooo]Z002MoookJPCo00004ooonfX8o`0003Gooo]Z2_l007l2oookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0007cooo]Z1Ol0000CoookJPKo0000Q?oonfX009go
oo]Z1?l0000DoookJPOo0000=OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`So
oo]Z1_l0001koookJPGo00004ooonfX7o`0008?ooo]Z002MoookJPCo00005?oonfX7o`00047ooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001loookJPGo00005?oonfX7o`0008;ooo]Z
002MoookJPCo00005?oonfX8o`00043ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l8oookJPGo0000O?oonfX4o`0001Kooo]Z1ol00021oookJP00WOoonfX4o`0001Gooo]Z2?l0000o
oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000O?oonfX4o`0001Oooo]Z1ol00020
oookJP00WOoonfX4o`0001Oooo]Z1ol0000noookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oook
JPGo0000O?oonfX4o`0001Sooo]Z1ol0001ooookJP00WOoonfX4o`0001Sooo]Z1_l0000noookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000O?oonfX4o`0001Wooo]Z1ol0001noookJP00
WOoonfX4o`0001Wooo]Z1_l0000noookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`ko
oo]Z1Ol0001loookJPCo00006_oonfX7o`0007gooo]Z002MoookJPCo00006_oonfX6o`0003gooo]Z
1ol007l9oookJPOo001o2?oonfX5o`0007cooo]Z1?l0000KoookJPOo0000O?oonfX009gooo]Z1?l0
000JoookJPKo0000?_oonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000O?oonfX4o`0001cooo]Z1ol0
001koookJP00W?oonfX5o`0001_ooo]Z2Ol0001HoookJPGo0000O?oonfX4o`0001gooo]Z1ol0001j
oookJP00W?oonfX5o`0001cooo]Z2?l0001HoookJPGo0000O?oonfX4o`0001kooo]Z1ol0001ioook
JP00W?oonfX5o`0001cooo]Z2?l0001HoookJPGo0000O?oonfX4o`0001oooo]Z1ol0001hoookJP00
W?oonfX4o`0001kooo]Z2?l0001GoookJPGo0000O?oonfX4o`00023ooo]Z1ol0001goookJP00W?oo
nfX4o`00027ooo]Z2?l0001DoookJPGo0000O?oonfX4o`00027ooo]Z1ol0001foookJP00W?oonfX4
o`00027ooo]Z2?l0001DoookJPGo0000O?oonfX4o`0002;ooo]Z1ol0001eoookJP00W?oonfX4o`00
02;ooo]Z2?l0001CoookJPGo0000O?oonfX4o`0002?ooo]Z1ol0001doookJP00W?oonfX4o`0002;o
oo]Z2?l0001CoookJPGo0000O?oonfX4o`0002Cooo]Z1ol0001coookJP00W?oonfX4o`0002Gooo]Z
2?l0001@oookJPGo0000O?oonfX4o`0002Gooo]Z1ol0001boookJP00W?oonfX4o`0002Kooo]Z2?l0
001?oookJPGo0000O?oonfX4o`0002Kooo]Z1ol0001aoookJP00W?oonfX4o`0002Kooo]Z2?l0001?
oookJPGo0000O?oonfX4o`0002Oooo]Z1ol0001`oookJP00W?oonfX4o`0002Kooo]Z2_l0001=oook
JPGo0000O?oonfX4o`0002Sooo]Z2Ol0001]oookJP008_oonfX3o`00OgGooo]Z0_l007l4o`0000?o
oo]Z0ol007l3oookJPGo001o7?oonfX7o`0004cooo]Z1Ol0001doookJPGo001o0ooonfX4o`0000?o
oo]Z1Ol007lQoookJPWo0000C?oonfX3o`00Oagooo]Z000RoookJP?o001oM?oonfX3o`00O`Co0000
0ooonfX3o`00O`;ooo]Z1ol007lKoookJPWo0000B_oonfX5o`0007?ooo]Z1ol007l2oookJPCo0000
0_oonfX7o`00Ob7ooo]Z2?l0001<oookJP?o001o7OoonfX002;ooo]Z0ol007mdoookJP?o001o1?l0
0003oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lLoookJP[o0000
B?oonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo000000?ooo]Zo`00Ool0
07l00_l007l01?oonf[o001oo`00Ool007lRoookJP[o0000BOoonfX3o`00Oagooo]Z000CoookJP[o
001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oo
oo]ZoookJP04oookJP?o001o0ooonfX3o`00Oagooo]Z2Ol00017oookJPGo0000L_oonfX3o`00O`?o
oo]Z0ol007l00ooonf[o0000o`000002o`000004oookJ_l007oo001oo`00O`?ooo]Z0ol007lToook
JPSo0000B?oonfX3o`00Oagooo]Z000CoookJP[o001o1OoonfX3o`00OfOooo]Z2_l007l2oookJP?o
001o00?ooo]Zo`000?l000000_l000000ol007oooo]ZoookJP0:oookJP?o001o7_oonfX:o`0004Go
oo]Z1Ol0001boookJP?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00001ooonfX3o`00ObCo
oo]Z2?l00018oookJP?o001o7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l00000
0_l000000ol007oooo]ZoookJP0:oookJP?o001o8?oonfX9o`0004Cooo]Z1Ol0001boookJP?o001o
0ooonfX3o`00O`03oookJ_l0003o000000;o00001ooonfX3o`00ObGooo]Z2ol00014oookJP?o001o
7OoonfX002;ooo]Z0ol007mcoookJP?o001o00?ooo]Zo`000?l000000_l000000ol007oooo]Zoook
JP05oookJP;o001o0_oonfX4o`00Ob;ooo]Z2Ol00012oookJPGo0000L_oonfX3o`00O`?ooo]Z0ol0
07l00ooonf[o0000o`000002o`0000;ooo]Z0_l007l2oookJPCo001o9_oonfX:o`0004Cooo]Z0ol0
07lMoookJP008_oonfX3o`00Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[o
oo]Z00Gooo]Z1ol007lToookJP[o0000@?oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Z
o`000?l000000_l00002oookJPOo001o:OoonfX9o`0004?ooo]Z0ol007lMoookJP008_oonfX3o`00
Og?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z1_l007lWoook
JPWo0000?ooonfX5o`0007;ooo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oook
JPKo001o:ooonfX<o`0003oooo]Z0ol007lMoookJP007ooonfX6o`00Og?ooo]Z0ol007l00ooonf[o
0000o`000002o`000003o`00Oooonf[ooo]Z00Gooo]Z0_l007l/oookJP[o0000?OoonfX5o`0007;o
oo]Z0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP;o001o<_oonfX;o`0003[o
oo]Z1_l007lMoookJP007ooonfX6o`00OgCooo]Z0ol007l4o`0000Sooo]Z0_l007l^oookJP_o0000
>_oonfX5o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo00000_oonfX2o`00Oc?o
oo]Z2ol0000ioookJPKo001o7OoonfX0027ooo]Z1?l007mdoookJP?o001o1?l00009oookJPOo001o
:_oonfX9o`0003[ooo]Z1Ol0001coookJPOo001o0_oonfX4o`0000?ooo]Z1ol007l^oookJP_o0000
>_oonfX4o`00Oagooo]Z000RoookJP?o001oMOoonfX2o`00O`Co00002OoonfX7o`00Ob_ooo]Z3?l0
000foookJPGo0000M?oonfX5o`00O`?ooo]Z1?l00003oookJPOo001o<_oonfX;o`0003Oooo]Z0ol0
07lMoookJP00W?oonfX4o`0003gooo]Z3_l0000boookJPGo0000O?oonfX4o`0003kooo]Z3Ol0001C
oookJP00W?oonfX4o`0003oooo]Z3Ol0000aoookJPGo0000O?oonfX4o`0003oooo]Z3Ol0001Boook
JP00W?oonfX4o`00043ooo]Z4?l0000]oookJPGo0000O?oonfX4o`00043ooo]Z4?l0001>oookJP00
W?oonfX4o`0004?ooo]Z4Ol0000YoookJPGo0000O?oonfX4o`0004Cooo]Z4?l0001:oookJP00W?oo
nfX4o`0004Gooo]Z5?l0000ToookJPGo0000O?oonfX4o`0004Gooo]Z5Ol00014oookJP00W?oonfX4
o`0004Wooo]Z5ol0000MoookJPGo0000O?oonfX4o`0004Wooo]Z6?l0000moookJP003_oonf[oo`00
0?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo0000
9Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?oookJP003_oonf[oo`000?oo00009Ol0000?
oookJP007OoonfX00ol0003ooo]ZoookJP07oookJRWo0000C?oonfX4o`0007gooo]Z1Ol00007oook
JRWo0000C?oonfX4o`0007oooo]Z00?o0000oookJ_oonfX07?oonfX003_ooo]Z6?l00019oookJPCo
0000OOoonfX5o`0001cooo]Z1Ol000000ooonf[o0000o`00000@o`0004Sooo]Z1?l0002NoookJP00
@?oonfXGo`0004Gooo]Z1?l0001moookJPGo00009OoonfXCo`0004Cooo]Z1?l0002NoookJP00B?oo
nfX@o`0004Cooo]Z1?l0001moookJPGo0000:?oonfX@o`0004Cooo]Z1?l0002NoookJP00C?oonfX@
o`00043ooo]Z1?l0001moookJPGo0000;OoonfX?o`00043ooo]Z1?l0002NoookJP00COoonfX@o`00
03oooo]Z1?l0001moookJPGo0000<?oonfX=o`0003oooo]Z1?l0002NoookJP00DOoonfX?o`0003co
oo]Z1?l0001moookJPGo0000<OoonfX>o`0003gooo]Z1?l0002NoookJP00EOoonfX=o`0003[ooo]Z
1?l0001moookJPGo0000=OoonfX;o`0003cooo]Z1?l0002NoookJP00E_oonfX=o`0003Wooo]Z1?l0
001moookJPGo0000=_oonfX<o`0003[ooo]Z1?l0002NoookJP00FOoonfX<o`0003Oooo]Z1?l0001m
oookJPGo0000>_oonfX:o`0003Sooo]Z1?l0002NoookJP00GOoonfX:o`0003Gooo]Z1?l0001moook
JPGo0000??oonfX:o`0003Kooo]Z1?l0002NoookJP00GooonfX9o`0003Cooo]Z1?l0001moookJPGo
0000?OoonfX:o`0003Gooo]Z1?l0002NoookJP00H?oonfX:o`0003;ooo]Z1?l0001moookJPGo0000
?ooonfX:o`0003?ooo]Z1?l0002NoookJP00H_oonfX9o`00037ooo]Z1?l0001moookJPGo0000@Ooo
nfX:o`00037ooo]Z1?l0002NoookJP00I?oonfX9o`0002oooo]Z1?l0001moookJPGo0000@ooonfX:
o`0002oooo]Z1?l0002NoookJP00IOoonfX9o`0002gooo]Z1Ol0001moookJPGo0000A?oonfX:o`00
02kooo]Z1?l0002NoookJP00IooonfX8o`0002cooo]Z1Ol0001moookJPGo0000A_oonfX9o`0002go
oo]Z1?l0002NoookJP00J?oonfX8o`0002_ooo]Z1Ol0001moookJPGo0000B?oonfX:o`0002[ooo]Z
1?l0002NoookJP00J_oonfX7o`0002[ooo]Z1?l0001noookJPGo0000B_oonfX9o`0002Wooo]Z1?l0
002NoookJP00JooonfX7o`0002Wooo]Z1?l0001noookJPGo0000BooonfX9o`0002Sooo]Z1?l0002N
oookJP00K?oonfX7o`0002Sooo]Z1?l0001noookJPGo0000BooonfX:o`0002Oooo]Z1?l0002Noook
JP00KOoonfX7o`0002Oooo]Z1?l0001noookJPGo0000CooonfX6o`0002Oooo]Z1?l0002NoookJP00
K_oonfX7o`0002Kooo]Z1?l0001noookJPGo0000D?oonfX6o`0002Kooo]Z1?l0002NoookJP00Kooo
nfX7o`0002Gooo]Z1?l0001noookJPGo0000DOoonfX5o`0002Kooo]Z1?l0002NoookJP00L?oonfX7
o`0002Cooo]Z1?l0001noookJPGo0000DOoonfX6o`0002Gooo]Z1?l0002NoookJP00LOoonfX6o`00
02Cooo]Z1?l0001noookJPGo0000D_oonfX5o`0002Gooo]Z1?l0002NoookJP00L_oonfX6o`0002?o
oo]Z1?l0001noookJPGo0000D_oonfX6o`0002Cooo]Z1?l0002NoookJP00LooonfX6o`0002;ooo]Z
1?l0001noookJPGo0000DooonfX6o`0002?ooo]Z1?l0002NoookJP00LooonfX7o`00027ooo]Z1?l0
001noookJPGo0000DooonfX7o`0002;ooo]Z1?l0002NoookJP00M?oonfX7o`00023ooo]Z1?l0001n
oookJPGo0000E?oonfX7o`00027ooo]Z1?l0002NoookJP00MOoonfX7o`0001oooo]Z1?l0001noook
JPGo0000EOoonfX7o`00023ooo]Z1?l0002NoookJP00M_oonfX7o`0001kooo]Z1?l0001noookJPGo
0000E_oonfX6o`00023ooo]Z1?l0002NoookJP00MooonfX6o`0001kooo]Z1?l0001noookJPGo0000
EooonfX6o`0001oooo]Z1?l0002NoookJP00N?oonfX6o`0001gooo]Z1?l0001noookJPGo0000F?oo
nfX6o`0001kooo]Z1?l0002NoookJP00NOoonfX6o`0001cooo]Z1?l0001noookJPGo0000F?oonfX7
o`0001gooo]Z1?l0002NoookJP00NOoonfX7o`0001_ooo]Z1?l0001PoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPGo0000FOoonfX7o`0001cooo]Z1?l0002NoookJP00N_oonfX7o`0001[o
oo]Z1?l0001OoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000F_oonfX7o`0001_o
oo]Z1?l0002NoookJP00NooonfX7o`0001Wooo]Z1?l0001OoookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`00
05_ooo]Z1ol0000JoookJPCo0000W_oonfX007cooo]Z1_l0000IoookJPCo0000G_oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0001LoookJPKo00006_oonfX4o`0009ko
oo]Z001moookJPKo00006?oonfX4o`0005kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z
1_l0001LoookJPKo00006OoonfX4o`0009kooo]Z001noookJPKo00005ooonfX4o`0005kooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1Ol0001NoookJPKo00006?oonfX4o`0009kooo]Z001n
oookJPOo00005_oonfX4o`0005kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8
oookJPGo0000G_oonfX7o`0001Oooo]Z1?l0002NoookJP00OooonfX7o`0001Gooo]Z1?l0001Noook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000GooonfX7o`0001Kooo]Z1?l0002Noook
JP00P?oonfX7o`0001Cooo]Z1?l0001NoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo
0000H?oonfX7o`0001Gooo]Z1?l0002NoookJP00POoonfX7o`0001?ooo]Z1?l0001NoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000HOoonfX6o`0001Gooo]Z1?l0002NoookJP00P_oo
nfX6o`0001?ooo]Z1?l0001OoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`kooo]Z
1Ol0001RoookJPKo00005?oonfX4o`0009kooo]Z0023oookJPKo00004_oonfX4o`0005oooo]Z1ol0
07l9oookJPOo001o2?oonfX5o`0006?ooo]Z1_l0000CoookJPCo0000W_oonfX008Cooo]Z1_l0000A
oookJPCo0000H?oonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000HooonfX7o`0001;ooo]Z1?l0002N
oookJP00Q?oonfX:o`0000gooo]Z1?l0001noookJPGo0000I?oonfX7o`00017ooo]Z1?l0002Noook
JP00QOoonfX:o`0000cooo]Z1?l0001noookJPGo0000IOoonfX7o`00013ooo]Z1?l0002NoookJP00
Q_oonfX9o`0000cooo]Z1?l0001noookJPGo0000I_oonfX6o`0000oooo]Z1Ol0002NoookJP00Qooo
nfX9o`0000_ooo]Z1?l0001noookJPGo0000IooonfX6o`0000kooo]Z1Ol0002NoookJP00R?oonfX8
o`0000_ooo]Z1?l0001noookJPGo0000J?oonfX6o`0000gooo]Z1Ol0002NoookJP00ROoonfX7o`00
00_ooo]Z1?l0001noookJPGo0000J?oonfX7o`0000cooo]Z1?l0002OoookJP00S?oonfX7o`0000So
oo]Z1?l0001noookJPGo0000JOoonfX:o`0000Sooo]Z1?l0002OoookJP00S?oonfX7o`0000Sooo]Z
1?l0001noookJPGo0000J_oonfX9o`0000Sooo]Z1?l0002OoookJP00S?oonfX8o`0000Oooo]Z1?l0
001noookJPGo0000JooonfX8o`0000Sooo]Z1?l0002OoookJP00S?oonfX8o`0000Oooo]Z1?l0001n
oookJPGo0000K?oonfX8o`0000Oooo]Z1?l0002OoookJP00S?oonfX8o`0000Oooo]Z1?l0001noook
JPGo0000KOoonfX7o`0000Oooo]Z1?l0002OoookJP00S?oonfX8o`0000Oooo]Z1?l0001noookJPGo
0000K_oonfX6o`0000Oooo]Z1?l0002OoookJP00SOoonfX:o`0000Cooo]Z1?l0001noookJPGo0000
L?oonfX8o`0000?ooo]Z1?l0002OoookJP00T?oonfX8o`0000?ooo]Z1?l0001noookJPGo0000L?oo
nfX8o`0000?ooo]Z1?l0002OoookJP00T?oonfX8o`0000?ooo]Z1?l0001noookJPGo0000L?oonfX8
o`0000?ooo]Z1?l0002OoookJP00TOoonfX7o`0000?ooo]Z1?l0001noookJPGo0000LOoonfX7o`00
00?ooo]Z1?l0002OoookJP00TOoonfX>o`0007kooo]Z1Ol0001aoookJPko0000WooonfX0097ooo]Z
3_l0001noookJPGo0000LOoonfX>o`0009oooo]Z002AoookJPko0000O_oonfX5o`00077ooo]Z3_l0
002OoookJP00TOoonfX>o`0007kooo]Z1Ol0001aoookJPko0000WooonfX009Cooo]Z2ol0001noook
JPGo0000MOoonfX:o`0009oooo]Z002DoookJP_o0000O_oonfX5o`0007Gooo]Z2_l0002OoookJP00
U?oonfX;o`0007kooo]Z1Ol0001eoookJP[o0000WooonfX009Gooo]Z2_l0001noookJPGo0000MOoo
nfX:o`0009oooo]Z002EoookJP[o0000O_oonfX5o`0007Gooo]Z2_l0002OoookJP00UOoonfX:o`00
07kooo]Z1Ol0001eoookJP[o0000WooonfX009Gooo]Z2_l0001noookJPGo0000MOoonfX:o`0009oo
oo]Z002EoookJP[o0000O_oonfX5o`0007Gooo]Z2_l0002OoookJP00UOoonfX:o`0007kooo]Z1Ol0
001eoookJP[o0000WooonfX009Wooo]Z1_l0001aoookJP?o001o2_oonfX5o`0007Wooo]Z1_l0002O
oookJP00VOoonfX6o`00077ooo]Z0ol007l:oookJPGo0000NOoonfX6o`0009oooo]Z002IoookJPKo
0000LOoonfX3o`00O`[ooo]Z1Ol0001ioookJPKo0000WooonfX009Wooo]Z1_l0001aoookJP?o001o
2_oonfX5o`0007Wooo]Z1_l0002OoookJP00VOoonfX6o`00077ooo]Z0ol007l:oookJPKo0000N?oo
nfX6o`0009oooo]Z002IoookJPKo0000LOoonfX3o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX0
09Wooo]Z1_l0001aoookJP?o001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00VOoonfX6o`00077o
oo]Z0ol007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002IoookJPGo0000L_oonfX3o`00O`[ooo]Z
1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001_oookJPKo001o2_oonfX5o`0007Wooo]Z1Ol0
002PoookJP00VOoonfX5o`0006oooo]Z1_l007l:oookJPGo0000NOoonfX5o`000:3ooo]Z002Ioook
JPGo0000LOoonfX4o`00O`[ooo]Z1Ol0001ioookJPGo0000X?oonfX009Wooo]Z1Ol0001boookJP?o
001o2_oonfX5o`0007Wooo]Z1Ol0002PoookJP00V_oonfX4o`0007oooo]Z1Ol0001joookJPCo0000
X?oonfX009[ooo]Z1?l0001ooookJPGo0000N_oonfX4o`000:3ooo]Z002JoookJPCo0000OooonfX5
o`0007[ooo]Z1?l0002PoookJP00V_oonfX4o`0007oooo]Z1Ol0003ooookJQoooo]Z002JoookJPCo
0000OooonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z
7ooonfX00?oooo]Z0_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l8oookJP?o001o0ooo
nfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol007l>oookJP?o001o2?oonfX6
o`000?oooo]Z7_oonfX00?oooo]Z0_oonfX3o`00O`kooo]Z0ol007l8oookJPGo0000oooonfXOoook
JP00oooonfX2oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfXOoookJP00
oooonfX2oookJP?o001o2OoonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJP;ooo]Z0ol0
07l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5
o`000?oooo]Z7ooonfX00?kooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z0OoonfX4o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfXOoookJP00oooonfX2oookJP?o001o
2_oonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJPgooo]Z2Ol007l8oookJPGo0000oooonfXOoookJP00oooonfX=oookJPWo001o
2?oonfX5o`000?oooo]Z7ooonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooookJQoooo]Z003o
oookJPkooo]Z1?l007l<oookJPGo0000oooonfXOoookJP00oooonfX?oookJPGo001o2_oonfX6o`00
0?oooo]Z7_oonfX00?oooo]Z4OoonfX4o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003ooookJQ;ooo]Z
0ol007l9oookJPGo0000oooonfXOoookJP00oooonfXCoookJP?o001ooooonfX/oookJP00oooonfX=
oookJP?o001o0ooonfX3o`00Oooooo]Z;?oonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007oooook
JRcooo]Z003ooookJPgooo]Z1?l007l2oookJP?o001ooooonfX/oookJP00oooonfX>oookJPOo001o
oooonfX]oookJP00oooonfX?oookJPGo001ooooonfX^oookJP00oooonf[ooookJT;ooo]Z003ooook
J_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11406, -2.11945, \
0.00387498, 0.0119426}},
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}]
}, Closed]]
}, Open  ]],

Cell["Recall the definition used above for myfunction", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(myfunction[x]\)], "Input"],

Cell[BoxData[
    \(\((1 - x)\)\^2\ \((2 - x)\)\ x\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Reduce myfunction to a domain so that we can use ",
  StyleBox["Mathematica'",
    FontSlant->"Italic"],
  "s Fourier Package on it."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReducedMyFunction\  = \ 
      ReduceHalfHalf[myfunction, x, 2] // Simplify\)], "Input"],

Cell[BoxData[
    \(4\ x\^2 - 16\ x\^4\)], "Output"]
}, Open  ]],

Cell["General form of the even amplitudes", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(myfunccos\  = 
      FourierCosCoefficient[4\ x\^2 - 16\ x\^4, x, n]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(4\ \((\(-1\))\)\^n\ \((\(-12\) + 
                n\^2\ \[Pi]\^2)\)\)\/\(n\^4\ \[Pi]\^4\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FourierSinCoefficient[4\ x\^2 - 16\ x\^4, x, n]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell["\<\
Illustrate how amplitude of each term behaves. This plot indicates \
that the short wavelength contributions are smaller and smaller. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Table[myfunccos, {n, 1, 50}]]\)], "Input",
  CellTags->"mmtag:17:ListPlot[]"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.321488 54.6113 [
[.21429 .30899 -12 -20 ]
[.21429 .30899 12 0 ]
[.40476 .30899 -12 -20 ]
[.40476 .30899 12 0 ]
[.59524 .30899 -12 -20 ]
[.59524 .30899 12 0 ]
[.78571 .30899 -12 -20 ]
[.78571 .30899 12 0 ]
[.97619 .30899 -12 -20 ]
[.97619 .30899 12 0 ]
[.01131 .10304 -61.9375 -10 ]
[.01131 .10304 0 10 ]
[.01131 .21227 -61.9375 -10 ]
[.01131 .21227 0 10 ]
[.01131 .43071 -49 -10 ]
[.01131 .43071 0 10 ]
[.01131 .53993 -49 -10 ]
[.01131 .53993 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .32149 m
.21429 .32774 L
s
gsave
.21429 .30899 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.40476 .32149 m
.40476 .32774 L
s
gsave
.40476 .30899 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.59524 .32149 m
.59524 .32774 L
s
gsave
.59524 .30899 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.78571 .32149 m
.78571 .32774 L
s
gsave
.78571 .30899 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.97619 .32149 m
.97619 .32774 L
s
gsave
.97619 .30899 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 .32149 m
.0619 .32524 L
s
.1 .32149 m
.1 .32524 L
s
.1381 .32149 m
.1381 .32524 L
s
.17619 .32149 m
.17619 .32524 L
s
.25238 .32149 m
.25238 .32524 L
s
.29048 .32149 m
.29048 .32524 L
s
.32857 .32149 m
.32857 .32524 L
s
.36667 .32149 m
.36667 .32524 L
s
.44286 .32149 m
.44286 .32524 L
s
.48095 .32149 m
.48095 .32524 L
s
.51905 .32149 m
.51905 .32524 L
s
.55714 .32149 m
.55714 .32524 L
s
.63333 .32149 m
.63333 .32524 L
s
.67143 .32149 m
.67143 .32524 L
s
.70952 .32149 m
.70952 .32524 L
s
.74762 .32149 m
.74762 .32524 L
s
.82381 .32149 m
.82381 .32524 L
s
.8619 .32149 m
.8619 .32524 L
s
.9 .32149 m
.9 .32524 L
s
.9381 .32149 m
.9381 .32524 L
s
.01 w
0 .32149 m
1 .32149 L
s
.25 Mabswid
.02381 .10304 m
.03006 .10304 L
s
gsave
.01131 .10304 -122.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.004) show
1.000 setlinewidth
grestore
.02381 .21227 m
.03006 .21227 L
s
gsave
.01131 .21227 -122.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.002) show
1.000 setlinewidth
grestore
.02381 .43071 m
.03006 .43071 L
s
gsave
.01131 .43071 -110 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.002) show
1.000 setlinewidth
grestore
.02381 .53993 m
.03006 .53993 L
s
gsave
.01131 .53993 -110 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.004) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .13035 m
.02756 .13035 L
s
.02381 .15765 m
.02756 .15765 L
s
.02381 .18496 m
.02756 .18496 L
s
.02381 .23957 m
.02756 .23957 L
s
.02381 .26688 m
.02756 .26688 L
s
.02381 .29418 m
.02756 .29418 L
s
.02381 .34879 m
.02756 .34879 L
s
.02381 .3761 m
.02756 .3761 L
s
.02381 .40341 m
.02756 .40341 L
s
.02381 .45802 m
.02756 .45802 L
s
.02381 .48532 m
.02756 .48532 L
s
.02381 .51263 m
.02756 .51263 L
s
.02381 .07574 m
.02756 .07574 L
s
.02381 .04843 m
.02756 .04843 L
s
.02381 .02113 m
.02756 .02113 L
s
.02381 .56724 m
.02756 .56724 L
s
.02381 .59454 m
.02756 .59454 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.19524 .59064 Mdot
.21429 .10285 Mdot
.23333 .50257 Mdot
.25238 .16908 Mdot
.27143 .45151 Mdot
.29048 .20926 Mdot
.30952 .41933 Mdot
.32857 .23544 Mdot
.34762 .39775 Mdot
.36667 .25343 Mdot
.38571 .38259 Mdot
.40476 .26632 Mdot
.42381 .37154 Mdot
.44286 .27587 Mdot
.4619 .36323 Mdot
.48095 .28314 Mdot
.5 .35683 Mdot
.51905 .28881 Mdot
.5381 .3518 Mdot
.55714 .2933 Mdot
.57619 .34777 Mdot
.59524 .29693 Mdot
.61429 .34449 Mdot
.63333 .2999 Mdot
.65238 .34179 Mdot
.67143 .30236 Mdot
.69048 .33954 Mdot
.70952 .30443 Mdot
.72857 .33764 Mdot
.74762 .30617 Mdot
.76667 .33603 Mdot
.78571 .30767 Mdot
.80476 .33465 Mdot
.82381 .30895 Mdot
.84286 .33345 Mdot
.8619 .31006 Mdot
.88095 .33241 Mdot
.9 .31103 Mdot
.91905 .3315 Mdot
.9381 .31189 Mdot
.95714 .3307 Mdot
.97619 .31264 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo
0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012
oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[o
oo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003o
oookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z
1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX0
04;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Z
n_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`00
0?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oo
nfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joook
JP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooo
nf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo
0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012
oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[o
oo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003o
oookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z
1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX0
04;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Z
n_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`00
0?oooo]Zn_oonfX0017ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Gooo]Z1Ol007l8oookJP?o
001o2?oonfX5o`000?oooo]Zn_oonfX0013ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`?ooo]Z
1ol007l7oookJP?o001o2?oonfX5o`000?oooo]Zn_oonfX0013ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l7oookJP?o001o2?oonfX5o`0005oooo]Z0_l0003ooookJYWooo]Z0003oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Oooo]Z1Ol0001NoookJPCo0000oooonfZHoook
JP000ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l7oookJPKo0000GOoonfX4o`00
0?oooo]ZV?oonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00ooonfX3o`00O`Sooo]Z1Ol0001Ooook
JP;o0000oooonfZIoookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJP;o001o0_oonfX3o`00O`Sooo]Z1Ol0003ooook
J_[ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000oooonf[j
oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l3oookJP;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]Zn_oo
nfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o1?oonfX5o`00O`Sooo]Z1Ol0003ooookJ_[ooo]Z000@oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l5oookJPGo001o2?oonfX5o`000?oooo]Zn_oonfX0013ooo]Z1ol007l8oookJPOo001o
0ooonfX7o`00O`Kooo]Z1?l007l8oookJPGo0000oooonf[joookJP004OoonfX5o`00O`[ooo]Z1Ol0
07l5oookJPGo001o2?oonfX3o`00O`Sooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[j
oookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000
oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oook
JPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z
0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooook
J_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0
003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;o
oo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oo
nfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oo
oo]Zn_oonfX004;ooo]Z1Ol0001boookJP;o0000oooonfZ6oookJP00@_oonfX5o`00077ooo]Z1?l0
003ooookJXGooo]Z0012oookJPGo0000LOoonfX4o`000?oooo]ZQOoonfX004;ooo]Z1Ol0001boook
JP;o0000oooonfZ6oookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z
0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooook
J_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0
003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;o
oo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oo
nfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oo
oo]Zn_oonfX0017ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Gooo]Z1Ol007l3oookJPWo001o
1ooonfX5o`000?oooo]Zn_oonfX0013ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`?ooo]Z1ol0
07l2oookJPWo001o1ooonfX5o`0008Kooo]Z0_l0003ooookJW;ooo]Z000@oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0_oonfX4o`00O`cooo]Z1Ol00025oookJPCo0000oooonfYaoookJP00
0ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o0_oonfX4o`00O`_ooo]Z1Ol00025oookJPCo0000oooonfYaoookJP00
0ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o0ooonfX5o`00O`Wooo]Z1_l00025oookJP;o0000oooonfYboookJP00
3ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l5oookJPCo001o2?oonfX5o`000?oooo]Zn_oonfX000oooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`So
oo]Z1Ol0003ooookJ_[ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z0ol007l7oookJPGo0000oooonf[joookJP00
3ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`000?oooo]Zn_oonfX000oo
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJ_[ooo]Z000@oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l2oookJPCo001o0_oonfX3o`00O`Oooo]Z1Ol0003ooookJ_[ooo]Z
000@oookJPOo001o2?oonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o2?oonfX5o`000?oooo]Zn_oo
nfX0017ooo]Z1Ol007l:oookJPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l9oookJPGo0000oooonf[j
oookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000
V_oonfX2o`000?oooo]ZG_oonfX004;ooo]Z1Ol0002IoookJPCo0000oooonfYMoookJP00@_oonfX5
o`0009Wooo]Z1?l0003ooookJUgooo]Z0012oookJPGo0000V_oonfX2o`000?oooo]ZG_oonfX004;o
oo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oo
nfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000:go
oo]Z0_l0003ooookJT_ooo]Z0012oookJPGo0000[?oonfX4o`000?oooo]ZB_oonfX004;ooo]Z1Ol0
002/oookJPCo0000oooonfY:oookJP00@_oonfX5o`000:gooo]Z0_l0003ooookJT_ooo]Z0012oook
JPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z
0012oookJPGo0000`OoonfX2o`000?oooo]Z=ooonfX004;ooo]Z1Ol00030oookJPCo0000oooonfXf
oookJP00@_oonfX5o`000<3ooo]Z1?l0003ooookJSKooo]Z0012oookJPGo0000`OoonfX2o`000?oo
oo]Z=ooonfX004;ooo]Z1Ol0003EoookJP;o0000oooonfXSoookJP00@_oonfX5o`000=Cooo]Z1?l0
003ooookJR;ooo]Z0012oookJPGo0000e?oonfX4o`000?oooo]Z8_oonfX004;ooo]Z1Ol0003Eoook
JP;o0000oooonfXSoookJP00@_oonfX5o`000>Sooo]Z0_l0003ooookJQ3ooo]Z0012oookJPGo0000
FOoonfX3o`00O`Gooo]Z1Ol007mBoookJPWo001o0ooonfX5o`00Oakooo]Z1?l0000aoookJPGo001o
1OoonfX5o`00OeKooo]Z0ol007l4oookJPGo001oE?oonfX5o`00O`Gooo]Z1Ol007l9oookJP00@_oo
nfX5o`0005Wooo]Z0ol007l4oookJPOo001oDOoonfX9o`00O`;ooo]Z1ol007lMoookJPCo0000<?oo
nfX7o`00O`?ooo]Z1ol007mEoookJP?o001o0ooonfX7o`00Oe;ooo]Z1ol007l3oookJPOo001o2?oo
nfX004;ooo]Z1Ol0001IoookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00Oe7ooo]Z1?l0
07l7oookJP?o001o00Cooo]Zo`00Ool007oo001o7_oonfX2o`0001;ooo]Z0_l0000LoookJP?o001o
0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007mEoookJP?o001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00Oe7ooo]Z1?l007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX004;ooo]Z1Ol0001IoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007mA
oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007l`oookJPCo00006ooonfX3o`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001oCooonfX9o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007m@oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJP00
@_oonfX5o`0005Wooo]Z0ol007l3oookJP?o001o0ooonfX3o`00Oe;ooo]Z1Ol007l3oookJP?o001o
0ooonfX3o`00Oc3ooo]Z1?l0000AoookJP;o00003_oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007m?oookJPWo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OeKooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o1ooonfX004;ooo]Z1Ol0001IoookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007mDoookJPCo001o0_oonfX3o`00O`?ooo]Z0ol007laoookJP;o00004OoonfX4o`00
00gooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001oCooonfX2o`00O`?ooo]Z0ol007l2
oookJP?o001o0ooonfX3o`00OeKooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooo
nfX004;ooo]Z1Ol0001IoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007mEoookJP?o001o0_oonfX3
o`00O`?ooo]Z0ol007m4oookJPCo00002ooonfX4o`00O`03oookJ_l0003o000000;o001o0ooonfX3
o`00Oe3ooo]Z0_l007l2oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007mAoookJP;o001o0_oonfX4
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJP00@_oonfX5o`0005Wooo]Z0ol007l3
oookJP?o001o0ooonfX3o`00OeKooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001oAOoo
nfX2o`0000cooo]Z0ol007l00ooonf[o0000o`000002o`000004o`00Oooonf[ooo]ZoookJP?o001o
D?oonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001oDOoonfX7o`00O`;o
oo]Z0ol007l3oookJP?o001o1ooonfX004;ooo]Z1Ol0001IoookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007m@oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007mEoookJP;o
001o1?l000001?l007oooo]ZoookJ_oonfX3o`00O`[ooo]Z0_l00015oookJP;o001o00Cooo]Zo`00
Ool007oo001o0_oonfX3o`00O`?ooo]Z0ol007mAoookJPKo001o0ooonfX3o`00O`?ooo]Z0ol007l7
oookJP00@_oonfX5o`0005Kooo]Z1_l007l3oookJP?o001o0ooonfX3o`00Oe3ooo]Z0ol007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Odoooo]Z0ol007l3oookJP?o001o0_l00002
o`00O`?ooo]Z0ol007l9oookJPCo00004OoonfX2o`0003;ooo]Z1Ol007l2oookJP?o001o0ooonfX3
o`00Oe7ooo]Z0_l007l7oookJP?o001o0ooonfX3o`00O`Oooo]Z0012oookJPGo0000E_oonfX6o`00
O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007mAoookJPCo001o0_oonfX3o`00O`;ooo]Z0ol007l0
1?oonf[o001oo`00Ool007m@oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00
Ool007l:oookJPCo00004?oonfX4o`00013ooo]Z0_l0000OoookJPGo001o0ooonfX3o`00O`04oook
J_l007oo001oo`00Oe;ooo]Z0_l007l8oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX004;o
oo]Z1Ol0001HoookJPCo001o1?oonfX7o`00Oe;ooo]Z1ol007l3oookJPOo001oDOoonfX7o`00O`?o
oo]Z1ol007l;oookJP;o00004OoonfX4o`0000oooo]Z1?l0000AoookJP;o00003?oonfX4o`00O`?o
oo]Z1ol007mCoookJPOo001o0_oonfX7o`00O`Sooo]Z0012oookJPGo0000FOoonfX3o`00O`Gooo]Z
1Ol007mDoookJPGo001o1OoonfX5o`00Oe?ooo]Z1Ol007l5oookJPGo001o8?oonfX2o`00013ooo]Z
1?l0000@oookJPCo00003?oonfX3o`00O`;ooo]Z0_l00005o`00OeCooo]Z1ol007l3oookJPGo001o
2OoonfX004;ooo]Z1Ol0003ooookJUoooo]Z0_l0000AoookJPCo00004?oonfX4o`00013ooo]Z0_l0
000BoookJP;o0000B_oonfX004;ooo]Z1Ol0003ooookJW?ooo]Z0_l0000AoookJPCo00003ooonfX4
o`00013ooo]Z1?l0000AoookJP;o00004OoonfX2o`0001;ooo]Z0_l0000?oookJP00@_oonfX5o`00
0?oooo]ZQooonfX2o`00013ooo]Z1?l0000@oookJPCo00004?oonfX4o`0000oooo]Z1?l0000@oook
JPCo00003_oonfX004;ooo]Z1Ol0003ooookJY[ooo]Z0_l0000BoookJP;o00004OoonfX4o`0000oo
oo]Z1?l0000@oookJPCo00003_oonfX004;ooo]Z1Ol0003ooookJ/;ooo]Z0_l0000AoookJP;o0000
4_oonfX2o`0000oooo]Z000foookJ_oo0000ool0000;o`00007ooo]Z000foookJ_oo0000ool0000;
o`00007ooo]Z000foookJ_oo0000ool0000;o`00007ooo]Z000foookJ_oo0000ool0000;o`00007o
oo]Z000foookJ_oo0000ool0000;o`00007ooo]Z0012oookJPGo0000GooonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z00gooo]Z0012oookJPGo0000GooonfX00ol0003ooo]ZoookJP1P
oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP12
oookJP;o00004OoonfX2o`0000Wooo]Z00?o0000oookJ_oonfX03OoonfX004;ooo]Z1Ol0003ooook
JZCooo]Z0_l0000BoookJP;o00004OoonfX4o`0000oooo]Z1?l0000HoookJP00@_oonfX5o`000?oo
oo]ZTOoonfX2o`00013ooo]Z1?l0000@oookJPCo00004?oonfX4o`0000oooo]Z1?l0000HoookJP00
@_oonfX5o`000?oooo]ZJOoonfX2o`0001;ooo]Z0_l0000AoookJPCo00003ooonfX4o`00013ooo]Z
1?l0000AoookJP;o00004OoonfX2o`0001Wooo]Z0012oookJPGo0000oooonfYFoookJP;o00004?oo
nfX4o`00013ooo]Z1?l0000@oookJPCo00004?oonfX2o`0001;ooo]Z0_l00010oookJP00@_oonfX5
o`000?oooo]ZEOoonfX4o`0000oooo]Z1?l0000@oookJPCo00004OoonfX2o`0006Oooo]Z0012oook
JPGo0000oooonfY2oookJP;o00004OoonfX4o`00013ooo]Z0_l0000BoookJP;o0000NooonfX004;o
oo]Z1Ol0003ooookJRkooo]Z0_l0000AoookJPCo00004OoonfX2o`000:;ooo]Z0012oookJPGo0000
oooonfX]oookJPCo00004?oonfX4o`000;Gooo]Z0012oookJPGo0000oooonfXKoookJP;o00004?oo
nfX4o`00017ooo]Z0_l0002foookJP00@_oonfX5o`000?oooo]Z6_oonfX4o`00013ooo]Z0_l0003:
oookJP00@_oonfX5o`000?oooo]Z1ooonfX2o`00017ooo]Z1?l0003LoookJP00@_oonfX5o`000?oo
oo]Z1_oonfX4o`00017ooo]Z0_l0003MoookJP00@_oonfX5o`000?;ooo]Z0_l0000AoookJPCo0000
l?oonfX004;ooo]Z1Ol0003aoookJPCo00004OoonfX2o`000?7ooo]Z0012oookJPGo0000lOoonfX4
o`000?oooo]Z1OoonfX004;ooo]Z1Ol0003boookJP;o0000oooonfX6oookJP00@_oonfX5o`000=oo
oo]Z0_l0003ooookJQWooo]Z0012oookJPGo0000g_oonfX4o`000?oooo]Z6?oonfX004;ooo]Z1Ol0
003NoookJPCo0000oooonfXHoookJP00@_oonfX5o`000=oooo]Z0_l0003ooookJQWooo]Z0012oook
JPGo0000booonfX2o`000?oooo]Z;OoonfX004;ooo]Z1Ol0003:oookJPCo0000oooonfX/oookJP00
@_oonfX5o`000<[ooo]Z1?l0003ooookJRcooo]Z0012oookJPGo0000booonfX2o`000?oooo]Z;Ooo
nfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000;Oo
oo]Z0_l0003ooookJT7ooo]Z0012oookJPGo0000]_oonfX4o`000?oooo]Z@?oonfX004;ooo]Z1Ol0
002foookJPCo0000oooonfY0oookJP00@_oonfX5o`000;Oooo]Z0_l0003ooookJT7ooo]Z0012oook
JPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z
0012oookJPGo0000Y?oonfX2o`000?oooo]ZE?oonfX004;ooo]Z1Ol0002SoookJPCo0000oooonfYC
oookJP00@_oonfX5o`000:?ooo]Z1?l0003ooookJU?ooo]Z0012oookJPGo0000Y?oonfX2o`000?oo
oo]ZE?oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5
o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00
@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[j
oookJP00@_oonfX5o`00093ooo]Z0_l0003ooookJVSooo]Z0012oookJPGo0000SooonfX4o`000?oo
oo]ZIooonfX004;ooo]Z1Ol0002?oookJPCo0000oooonfYWoookJP004OoonfX5o`00O`Cooo]Z0ol0
07l3oookJPGo001o1OoonfX5o`00O`?ooo]Z2Ol007l7oookJPGo0000T?oonfX2o`000?oooo]ZJ?oo
nfX0013ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`?ooo]Z1ol007l2oookJPWo001o1ooonfX5
o`000?oooo]Zn_oonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo001o
3?oonfX5o`000?oooo]Zn_oonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX4o`00O`_ooo]Z1Ol0003ooookJ_[ooo]Z
000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`?ooo]Z1Ol007l9oookJPKo0000oooonf[ioookJP003ooonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJPCo001o
2?oonfX5o`000?oooo]Zn_oonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`Sooo]Z1Ol0003ooookJ_[ooo]Z
000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`Oooo]Z0ol007l7oookJPGo0000oooonf[joookJP003ooonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o1ooonfX5o`000?oooo]Zn_oonfX000oooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJ_[ooo]Z000@oookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l2oookJPCo001o0_oonfX3o`00O`Oooo]Z1Ol0003ooookJ_[ooo]Z000@oookJPOo001o2?oonfX7
o`00O`?ooo]Z1ol007l3oookJPOo001o2?oonfX5o`000?oooo]Zn_oonfX0017ooo]Z1Ol007l:oook
JPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l9oookJPGo0000oooonf[joookJP00@_oonfX5o`0007co
oo]Z0_l0003ooookJWcooo]Z0012oookJPGo0000NooonfX4o`000?oooo]ZNooonfX004;ooo]Z1Ol0
001koookJPCo0000oooonfYkoookJP00@_oonfX5o`0007cooo]Z0_l0003ooookJWcooo]Z0012oook
JPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z
0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooook
J_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0
003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;o
oo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oo
nfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oo
oo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5
o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00
@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0001YoookJP;o0000oooonfZ?oookJP00@_oonfX5
o`0006Sooo]Z1?l0003ooookJXkooo]Z0012oookJPGo0000J?oonfX4o`000?oooo]ZS_oonfX004;o
oo]Z1Ol0001YoookJP;o0000oooonfZ?oookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0
003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;o
oo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oo
nfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oo
oo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP004OoonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o1OoonfX5o`00O`Sooo]Z0ol007l8oookJPGo0000oooonf[j
oookJP004?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0ooonfX7o`00O`Oooo]Z0ol007l8oook
JPGo0000oooonf[joookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z0ol0
07l8oookJPGo0000oooonf[joookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Oooo]Z1Ol0
003ooookJ_[ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001o1ooonfX6o`000?oooo]ZnOoo
nfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00ooonfX3o`00O`Sooo]Z1Ol0003ooookJ_[ooo]Z000?
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`;ooo]Z0_l007l2oookJP?o001o2?oonfX5o`000?oooo]Zn_oonfX000oooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_[ooo]Z000?oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z
0_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000oooonf[joookJP003ooonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l4oookJPGo
001o2?oonfX5o`000?oooo]Zn_oonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Gooo]Z1Ol007l8
oookJPGo0000oooonf[joookJP004?oonfX7o`00O`Sooo]Z1ol007l3oookJPOo001o1_oonfX4o`00
O`Sooo]Z1Ol0003ooookJ_[ooo]Z000AoookJPGo001o2_oonfX5o`00O`Gooo]Z1Ol007l8oookJP?o
001o2?oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooo
nf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo
0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012
oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[o
oo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003o
oookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z
1Ol0003ooookJ_[ooo]Z0012oookJPGo0000EOoonfX2o`000?oooo]ZXooonfX004;ooo]Z1Ol0001D
oookJPCo0000oooonfZRoookJP00@_oonfX5o`0005Cooo]Z1?l0003ooookJZ;ooo]Z0012oookJPGo
0000EOoonfX2o`000?oooo]ZXooonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo0000oooo
nf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012oookJPGo
0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[ooo]Z0012
oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003ooookJ_[o
oo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX004;ooo]Z1Ol0003o
oookJ_[ooo]Z0012oookJPGo0000oooonf[joookJP00@_oonfX5o`000?oooo]Zn_oonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-6.95442, -0.00652236, \
0.101682, 3.54652*^-5}},
  CellTags->"mmtag:17:ListPlot[]"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->"mmtag:17:ListPlot[]"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Table[myfunccos, {n, 1, 10}], PlotJoined \[Rule] True, 
      PlotRange \[Rule] All]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0820106 0.10582 0.421994 4.65555 [
[.34127 .40949 -7 -20 ]
[.34127 .40949 7 0 ]
[.55291 .40949 -7 -20 ]
[.55291 .40949 7 0 ]
[.76455 .40949 -7 -20 ]
[.76455 .40949 7 0 ]
[.97619 .40949 -12 -20 ]
[.97619 .40949 12 0 ]
[.11713 .04955 -51.9375 -10 ]
[.11713 .04955 0 10 ]
[.11713 .14266 -51.9375 -10 ]
[.11713 .14266 0 10 ]
[.11713 .23577 -51.9375 -10 ]
[.11713 .23577 0 10 ]
[.11713 .32888 -51.9375 -10 ]
[.11713 .32888 0 10 ]
[.11713 .51511 -39 -10 ]
[.11713 .51511 0 10 ]
[.11713 .60822 -39 -10 ]
[.11713 .60822 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.34127 .42199 m
.34127 .42824 L
s
gsave
.34127 .40949 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.55291 .42199 m
.55291 .42824 L
s
gsave
.55291 .40949 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.76455 .42199 m
.76455 .42824 L
s
gsave
.76455 .40949 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 .42199 m
.97619 .42824 L
s
gsave
.97619 .40949 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.18254 .42199 m
.18254 .42574 L
s
.23545 .42199 m
.23545 .42574 L
s
.28836 .42199 m
.28836 .42574 L
s
.39418 .42199 m
.39418 .42574 L
s
.44709 .42199 m
.44709 .42574 L
s
.5 .42199 m
.5 .42574 L
s
.60582 .42199 m
.60582 .42574 L
s
.65873 .42199 m
.65873 .42574 L
s
.71164 .42199 m
.71164 .42574 L
s
.81746 .42199 m
.81746 .42574 L
s
.87037 .42199 m
.87037 .42574 L
s
.92328 .42199 m
.92328 .42574 L
s
.07672 .42199 m
.07672 .42574 L
s
.02381 .42199 m
.02381 .42574 L
s
.01 w
0 .42199 m
1 .42199 L
s
.25 Mabswid
.12963 .04955 m
.13588 .04955 L
s
gsave
.11713 .04955 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.08) show
1.000 setlinewidth
grestore
.12963 .14266 m
.13588 .14266 L
s
gsave
.11713 .14266 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.06) show
1.000 setlinewidth
grestore
.12963 .23577 m
.13588 .23577 L
s
gsave
.11713 .23577 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
.12963 .32888 m
.13588 .32888 L
s
gsave
.11713 .32888 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
.12963 .51511 m
.13588 .51511 L
s
gsave
.11713 .51511 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
.12963 .60822 m
.13588 .60822 L
s
gsave
.11713 .60822 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
.125 Mabswid
.12963 .07283 m
.13338 .07283 L
s
.12963 .09611 m
.13338 .09611 L
s
.12963 .11938 m
.13338 .11938 L
s
.12963 .16594 m
.13338 .16594 L
s
.12963 .18922 m
.13338 .18922 L
s
.12963 .21249 m
.13338 .21249 L
s
.12963 .25905 m
.13338 .25905 L
s
.12963 .28233 m
.13338 .28233 L
s
.12963 .30561 m
.13338 .30561 L
s
.12963 .35216 m
.13338 .35216 L
s
.12963 .37544 m
.13338 .37544 L
s
.12963 .39872 m
.13338 .39872 L
s
.12963 .44527 m
.13338 .44527 L
s
.12963 .46855 m
.13338 .46855 L
s
.12963 .49183 m
.13338 .49183 L
s
.12963 .53838 m
.13338 .53838 L
s
.12963 .56166 m
.13338 .56166 L
s
.12963 .58494 m
.13338 .58494 L
s
.12963 .02627 m
.13338 .02627 L
s
.12963 .00299 m
.13338 .00299 L
s
.01 w
.12963 0 m
.12963 .61803 L
s
.5 Mabswid
.02381 .01472 m
.12963 .09367 L
.23545 .60332 L
.34127 .31303 L
.44709 .4938 L
.55291 .37135 L
.65873 .45955 L
.76455 .39307 L
.87037 .44494 L
.97619 .40336 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003oCOoonfX5
o`000?oooo]ZkooonfX004gooo]Z1Ol0003ooookJ^oooo]Z001=oookJPGo0000oooonf[_oookJP00
COoonfX5o`000?oooo]ZkooonfX004gooo]Z1Ol0003ooookJ^oooo]Z001=oookJPGo0000oooonf[_
oookJP00COoonfX5o`000?oooo]ZkooonfX004gooo]Z1Ol0003ooookJ^oooo]Z001=oookJPGo0000
oooonf[_oookJP00COoonfX5o`000?oooo]ZkooonfX004gooo]Z1Ol0003ooookJ^oooo]Z000Coook
JP;o0000>?oonfX5o`000?oooo]ZkooonfX001Gooo]Z00?o0000oookJ_oonfX0=OoonfX5o`000?oo
oo]ZkooonfX001Kooo]Z00?o0000oookJ_oonfX0=?oonfX5o`000?oooo]ZkooonfX001Oooo]Z0_l0
000doookJPGo0000oooonf[_oookJP006OoonfX00ol0003ooo]ZoookJP0aoookJPGo0000oooonf[_
oookJP006_oonfX2o`00037ooo]Z1Ol0003ooookJ^oooo]Z000LoookJP03o`000?oonf[ooo]Z02ko
oo]Z1Ol0003ooookJ^oooo]Z000MoookJP03o`000?oonf[ooo]Z02gooo]Z1Ol0003ooookJ^oooo]Z
000NoookJP;o0000;OoonfX5o`000?oooo]ZkooonfX0023ooo]Z00?o0000oookJ_oonfX0:_oonfX5
o`000?oooo]ZkooonfX0027ooo]Z00?o0000oookJ_oonfX0:OoonfX5o`000?oooo]ZkooonfX002;o
oo]Z0_l0000YoookJPGo0000oooonf[_oookJP009?oonfX00ol0003ooo]ZoookJP0VoookJPGo0000
oooonf[_oookJP009OoonfX00ol0003ooo]ZoookJP0UoookJPGo0000oooonf[_oookJP009_oonfX2
o`0002Gooo]Z1Ol0003ooookJ^oooo]Z000UoookJP?o001o00?o0000o`00OooonfX00ooonfX3o`00
O`?ooo]Z1Ol007l5oookJPGo001o2_oonfX5o`000?oooo]ZkooonfX002Cooo]Z1Ol007l2o`0000?o
oo]Z0ol007l2oookJPOo001o0ooonfX7o`00O`Wooo]Z1Ol0003ooookJ^oooo]Z000ToookJP?o001o
00Gooo]Zo`00Ool007oo001oo`000002oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00
O`;ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]ZkooonfX001Oooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`03o`000?oonf[ooo]Z00?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJ^oooo]Z000GoookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l00ooonf[o0000o`000003oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l8oookJPKo0000oooonf[^oookJP008ooonfX3o`00O`?ooo]Z0ol007l3oookJP03
o`000?oonf[ooo]Z00?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l8oook
JPGo0000oooonf[_oookJP008ooonfX3o`00O`?ooo]Z0ol007l4oookJP03o`000?oonf[o001o00;o
001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonf[_oookJP008ooonfX3o`00O`?ooo]Z
0ol007l5oookJP;o00000_l007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJ^oooo]Z
000SoookJP?o001o0ooonfX3o`00O`Kooo]Z00?o001oo`000?l007l00ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l8oookJPGo0000oooonf[_oookJP008ooonfX3o`00O`?ooo]Z0ol0
07l6oookJP;o001o00Co0000oookJ_oonf[ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o2?oonfX5o`000?oooo]ZkooonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o0_l00003o`00O`;ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]ZkooonfX002Cooo]Z
1ol007l8oookJPCo001o00?o0000o`00Ool007l00ooonfX7o`00O`Wooo]Z1Ol0003ooookJ^oooo]Z
000UoookJPGo001o2_oonfX4o`00O`;o00001?oonfX5o`00O`[ooo]Z1Ol0003ooookJ^oooo]Z000j
oookJP03o`000?oonf[ooo]Z013ooo]Z1Ol0003ooookJ^oooo]Z000koookJP03o`000?oonf[ooo]Z
00oooo]Z1Ol0003ooookJ^oooo]Z000loookJP;o00003ooonfX5o`000?oooo]ZkooonfX003kooo]Z
00?o0000oookJ_oonfX03?oonfX5o`000?oooo]ZkooonfX003oooo]Z00?o0000oookJ_oonfX02ooo
nfX5o`000?oooo]ZkooonfX0043ooo]Z0_l0000;oookJPGo0000oooonf[_oookJP00@_oonfX00ol0
003ooo]ZoookJP08oookJPGo0000oooonf[_oookJP00@ooonfX00ol0003ooo]ZoookJP07oookJPGo
0000oooonf[_oookJP00A?oonfX2o`0000Oooo]Z1Ol0003ooookJ^oooo]Z0016oookJP03o`000?oo
nf[ooo]Z00Cooo]Z1Ol0003ooookJ^oooo]Z0017oookJP;o00001?oonfX5o`000?oooo]ZkooonfX0
04Wooo]Z00Co0000oookJ_oonf[ooo]Z1Ol0003ooookJ^oooo]Z001:oookJP03o`000?oonf[ooo]Z
00Go0000oooonf[_oookJP00BooonfX7o`000?oooo]ZkooonfX004gooo]Z1Ol0003ooookJ^oooo]Z
001=oookJPGo0000oooonf[_oookJP00COoonfX5o`000?oooo]ZkooonfX004gooo]Z1Ol0003ooook
J^oooo]Z001=oookJPGo0000oooonf[_oookJP00COoonfX5o`000?oooo]ZkooonfX004gooo]Z1Ol0
003ooookJ^oooo]Z001=oookJPGo0000oooonf[_oookJP00COoonfX5o`000?oooo]ZkooonfX004go
oo]Z1Ol0003ooookJ^oooo]Z001=oookJPGo0000oooonf[_oookJP00COoonfX5o`000?oooo]Zkooo
nfX004gooo]Z1Ol0003ooookJ^oooo]Z001=oookJPGo0000oooonf[_oookJP00COoonfX5o`000?oo
oo]ZkooonfX004gooo]Z1_l0003ooookJ^kooo]Z001=oookJPKo0000oooonf[^oookJP00COoonfX6
o`000?oooo]Zk_oonfX004gooo]Z1_l0003ooookJ^kooo]Z001=oookJPKo0000oooonf[^oookJP00
COoonfX5o`000003oookJ_l0003ooo]Z0?oooo]Zk?oonfX004gooo]Z1Ol000000ooonf[o0000oook
JP3ooookJ^cooo]Z001=oookJPGo000000?ooo]Zo`000?oonfX0oooonf[/oookJP00COoonfX5o`00
0003oookJ_l0003ooo]Z0?oooo]Zk?oonfX004gooo]Z1Ol000000ooonf[o0000oookJP3ooookJ^co
oo]Z001=oookJPGo00000_oonfX00ol0003ooo]ZoookJP3ooookJ^[ooo]Z000UoookJPGo001o1?oo
nfX3o`00O`?ooo]Z1Ol007l5oookJPGo001o2_oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooo
nf[ZoookJP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0ooonfX7o`00O`Wooo]Z1Ol00002
oookJP03o`000?oonf[ooo]Z0?oooo]Zj_oonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJP?o001o2?oo
nfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonf[ZoookJP005ooonfX:o`00O`;ooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o2?oo
nfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonf[ZoookJP005ooonfX:o`00O`;ooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o2?oo
nfX6o`0000;ooo]Z00?o0000oookJ_oonfX0oooonf[YoookJP008ooonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o0_oonfX3o`00O`Sooo]Z1Ol00003
oookJP03o`000?oonf[ooo]Z0?oooo]ZjOoonfX002?ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`06o`00O`Wooo]Z1Ol00003oookJP03o`000?oonf[ooo]Z
0?oooo]ZjOoonfX002?ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01Ooonf[o
001oo`00Ool007oooo]Z00?o001o2_oonfX5o`0000?ooo]Z00?o0000oookJ_oonfX0oooonf[Yoook
JP008ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`kooo]Z1Ol00003oookJP03o`000?oonf[ooo]Z0?oooo]ZjOoonfX002?ooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l>oookJPGo00001?oonfX00ol0
003ooo]ZoookJP3ooookJ^Sooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJP?o001o2?oonfX5o`0000Cooo]Z00?o0000
oookJ_oonfX0oooonf[XoookJP009?oonfX7o`00O`Sooo]Z1ol007l3oookJPOo001o2OoonfX5o`00
00Cooo]Z00?o0000oookJ_oonfX0oooonf[XoookJP009OoonfX5o`00O`[ooo]Z1Ol007l6oookJPCo
001o2_oonfX5o`0000Cooo]Z00?o0000oookJ_oonfX0oooonf[XoookJP00COoonfX5o`0000Gooo]Z
00?o0000oookJ_oonfX0oooonf[WoookJP00COoonfX5o`0000Gooo]Z00?o0000oookJ_oonfX0oooo
nf[WoookJP00COoonfX5o`0000Gooo]Z00?o0000oookJ_oonfX0oooonf[WoookJP00COoonfX5o`00
00Gooo]Z00?o0000oookJ_oonfX0oooonf[WoookJP00COoonfX5o`0000Gooo]Z00?o0000oookJ_oo
nfX0oooonf[WoookJP00COoonfX5o`0000Kooo]Z00?o0000oookJ_oonfX0oooonf[VoookJP00COoo
nfX5o`0000Kooo]Z00?o0000oookJ_oonfX0oooonf[VoookJP00COoonfX5o`0000Kooo]Z00?o0000
oookJ_oonfX0oooonf[VoookJP00COoonfX5o`0000Kooo]Z00?o0000oookJ_oonfX0oooonf[Voook
JP00COoonfX5o`0000Kooo]Z00?o0000oookJ_oonfX0oooonf[VoookJP00COoonfX5o`0000Oooo]Z
00?o0000oookJ_oonfX0oooonf[UoookJP00COoonfX5o`0000Oooo]Z00?o0000oookJ_oonfX0oooo
nf[UoookJP00COoonfX5o`0000Oooo]Z00?o0000oookJ_oonfX0oooonf[UoookJP00COoonfX5o`00
00Oooo]Z00?o0000oookJ_oonfX0oooonf[UoookJP00COoonfX5o`0000Oooo]Z00?o0000oookJ_oo
nfX0oooonf[UoookJP00COoonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonf[ToookJP00COoo
nfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonf[ToookJP00COoonfX5o`0000Sooo]Z00?o0000
oookJ_oonfX0oooonf[ToookJP00COoonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonf[Toook
JP00COoonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonf[ToookJP00COoonfX5o`0000Wooo]Z
00?o0000oookJ_oonfX0oooonf[SoookJP00COoonfX5o`0000Wooo]Z00?o0000oookJ_oonfX0oooo
nf[SoookJP00COoonfX5o`0000Wooo]Z00?o0000oookJ_oonfX0oooonf[SoookJP00COoonfX5o`00
00Wooo]Z00?o0000oookJ_oonfX0oooonf[SoookJP00COoonfX5o`0000Wooo]Z00?o0000oookJ_oo
nfX0oooonf[SoookJP00COoonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0oooonf[RoookJP00COoo
nfX5o`0000[ooo]Z00?o0000oookJ_oonfX0oooonf[RoookJP00COoonfX5o`0000[ooo]Z00?o0000
oookJ_oonfX0oooonf[RoookJP00COoonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0oooonf[Roook
JP00COoonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0oooonf[RoookJP00COoonfX5o`0000_ooo]Z
00?o0000oookJ_oonfX0oooonf[QoookJP00COoonfX5o`0000_ooo]Z00?o0000oookJ_oonfX0oooo
nf[QoookJP00COoonfX5o`0000_ooo]Z00?o0000oookJ_oonfX0oooonf[QoookJP00COoonfX5o`00
00_ooo]Z00?o0000oookJ_oonfX0oooonf[QoookJP00COoonfX5o`0000_ooo]Z00?o0000oookJ_oo
nfX0oooonf[QoookJP00COoonfX5o`0000cooo]Z00?o0000oookJ_oonfX0oooonf[PoookJP00COoo
nfX5o`0000cooo]Z00?o0000oookJ_oonfX0oooonf[PoookJP00COoonfX5o`0000cooo]Z00?o0000
oookJ_oonfX0oooonf[PoookJP00COoonfX5o`0000cooo]Z00?o0000oookJ_oonfX0oooonf[Poook
JP009OoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2?oonfX3o`00O`Wooo]Z1Ol0000=oookJP03
o`000?oonf[ooo]Z0?oooo]ZgooonfX002Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z
0ol007l9oookJPGo00003OoonfX00ol0003ooo]ZoookJP3ooookJ]oooo]Z000ToookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJP?o
001o2OoonfX5o`0000gooo]Z00?o0000oookJ_oonfX0oooonf[OoookJP005ooonfX:o`00O`;ooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Sooo]Z
1Ol0000=oookJP03o`000?oonf[ooo]Z0?oooo]ZgooonfX001Oooo]Z2_l007l2oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l8oookJPKo00003?oo
nfX00ol0003ooo]ZoookJP3ooookJ]oooo]Z000SoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o00?ooo]Zo`00Ool007l00ooonfX3o`00O`Wooo]Z1Ol0000>oookJP03o`000?oonf[o
oo]Z0?oooo]Zg_oonfX002?ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oook
JP;o001o0_oonfX3o`00O`Wooo]Z1Ol0000>oookJP03o`000?oonf[ooo]Z0?oooo]Zg_oonfX002?o
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool0
07oo001o2OoonfX5o`0000kooo]Z00?o0000oookJ_oonfX0oooonf[NoookJP008ooonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0_l007l01?oonf[o001oo`00Ool007l9oook
JPGo00003_oonfX00ol0003ooo]ZoookJP3ooookJ]kooo]Z000SoookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o1?oonfX5o`00O`Wooo]Z1Ol0000>oookJP03o`000?oonf[ooo]Z0?oo
oo]Zg_oonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o00Cooo]Zo`00Ool0
07oo001o1OoonfX5o`00O`Wooo]Z1Ol0000?oookJP03o`000?oonf[ooo]Z0?oooo]ZgOoonfX002Co
oo]Z1ol007l8oookJPOo001o1_oonfX4o`00O`Wooo]Z1Ol0000?oookJP03o`000?oonf[ooo]Z0?oo
oo]ZgOoonfX002Gooo]Z1Ol007l:oookJPGo001o2?oonfX3o`00O`Wooo]Z1Ol0000?oookJP03o`00
0?oonf[ooo]Z0?oooo]ZgOoonfX004gooo]Z1Ol0000?oookJP03o`000?oonf[ooo]Z0?oooo]ZgOoo
nfX004gooo]Z1Ol0000?oookJP03o`000?oonf[ooo]Z0?oooo]ZgOoonfX004gooo]Z1Ol0000@oook
JP03o`000?oonf[ooo]Z0?oooo]Zg?oonfX004gooo]Z1Ol0000@oookJP03o`000?oonf[ooo]Z0?oo
oo]Zg?oonfX004gooo]Z1Ol0000@oookJP03o`000?oonf[ooo]Z0?oooo]Zg?oonfX004gooo]Z1Ol0
000@oookJP03o`000?oonf[ooo]Z0?oooo]Zg?oonfX004gooo]Z1Ol0000@oookJP03o`000?oonf[o
oo]Z0?oooo]Zg?oonfX004gooo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z0?oooo]ZfooonfX004go
oo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z0?oooo]ZfooonfX004gooo]Z1Ol0000AoookJP03o`00
0?oonf[ooo]Z0?oooo]ZfooonfX004gooo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z0?oooo]Zfooo
nfX004gooo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z0?oooo]ZfooonfX004gooo]Z1Ol0000Boook
JP03o`000?oonf[ooo]Z0?oooo]Zf_oonfX004gooo]Z1Ol0000BoookJP03o`000?oonf[ooo]Z0?oo
oo]Zf_oonfX004gooo]Z1Ol0000BoookJP03o`000?oonf[ooo]Z0?oooo]Zf_oonfX004gooo]Z1Ol0
000BoookJP03o`000?oonf[ooo]Z0?oooo]Zf_oonfX004gooo]Z1Ol0000BoookJP03o`000?oonf[o
oo]Z0?oooo]Zf_oonfX004gooo]Z1Ol0000CoookJP03o`000?oonf[ooo]Z0?oooo]ZfOoonfX004go
oo]Z1Ol0000CoookJP03o`000?oonf[ooo]Z0?oooo]ZfOoonfX004gooo]Z1Ol0000CoookJP03o`00
0?oonf[ooo]Z0?oooo]ZfOoonfX004gooo]Z1Ol0000CoookJP03o`000?oonf[ooo]Z0?oooo]ZfOoo
nfX004gooo]Z1Ol0000DoookJP03o`000?oonf[ooo]Z0?oooo]Zf?oonfX004gooo]Z1Ol0000Doook
JP03o`000?oonf[ooo]Z0?oooo]Zf?oonfX004gooo]Z1Ol0000DoookJP03o`000?oonf[ooo]Z0?oo
oo]Zf?oonfX004gooo]Z1Ol0000DoookJP03o`000?oonf[ooo]Z0?oooo]Zf?oonfX004gooo]Z1Ol0
000DoookJP03o`000?oonf[ooo]Z0?oooo]Zf?oonfX004gooo]Z1Ol0000EoookJP03o`000?oonf[o
oo]Z0?oooo]ZeooonfX004gooo]Z1Ol0000EoookJP03o`000?oonf[ooo]Z0?oooo]ZeooonfX004go
oo]Z1Ol0000EoookJP03o`000?oonf[ooo]Z0?oooo]ZeooonfX004gooo]Z1Ol0000EoookJP03o`00
0?oonf[ooo]Z0?oooo]ZeooonfX004gooo]Z1Ol0000EoookJP03o`000?oonf[ooo]Z0?oooo]Zeooo
nfX004gooo]Z1Ol0000FoookJP03o`000?oonf[ooo]Z0?oooo]Ze_oonfX004gooo]Z1Ol0000Foook
JP03o`000?oonf[ooo]Z0?oooo]Ze_oonfX004gooo]Z1Ol0000FoookJP03o`000?oonf[ooo]Z0?oo
oo]Ze_oonfX004gooo]Z1Ol0000FoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0
oooonfYhoookJP00COoonfX5o`0001Kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]Zoook
JP3ooookJWSooo]Z001=oookJPGo00005ooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[o
00000?oooo]ZNOoonfX004gooo]Z1Ol0000GoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oook
J_l00000oooonfYioookJP00COoonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0FOoonfX01?l0003o
oo]ZoookJ_l0003ooookJWSooo]Z000UoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l3oookJPWo
001o2?oonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z0?oooo]ZMOoonfX002Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z
2Ol007l8oookJPGo00005ooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX0oooonfYeoookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`00O`gooo]Z1Ol0000HoookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP3ooookJWCo
oo]Z000GoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z
1?l007l<oookJPGo00006?oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX0oooonfYdoookJP005ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l3oookJPGo001o2_oonfX6o`0001Oooo]Z00?o0000oookJ_oonfX0E_oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0?oooo]ZLooonfX002?ooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l5oookJPCo001o2OoonfX5o`0001Sooo]Z00?o0000
oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0?oooo]ZLooonfX0
02?ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o2OoonfX5o`00
01Sooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
0?oooo]ZL_oonfX002?ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJP?o
001o2?oonfX5o`0001Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z0?oooo]ZLOoonfX002?ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o2?oonfX5o`0001Wooo]Z00?o0000oookJ_oo
nfX0DooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0?oooo]ZLOoonfX002?ooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o2?oonfX5o`0001Wooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z0?oooo]ZL?oonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o
001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`00O`;ooo]Z0ol007l8oookJPGo00006OoonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0oooonfY`oook
JP009?oonfX7o`00O`Sooo]Z1ol007l3oookJPOo001o2OoonfX5o`0001Wooo]Z00?o0000oookJ_oo
nfX0D_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z0?oooo]ZKooonfX002Gooo]Z
1Ol007l:oookJPGo001o1OoonfX5o`00O`[ooo]Z1Ol0000JoookJP03o`000?oonf[ooo]Z057ooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP3ooookJVkooo]Z001=oookJPGo00006_oo
nfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0oooo
nfY^oookJP00COoonfX5o`0001[ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z0?oooo]ZKOoonfX004gooo]Z1Ol0000JoookJP03o`000?oonf[ooo]Z
053ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP3ooookJVgooo]Z001=oookJPGo
00006ooonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX0oooonfY/oookJP00COoonfX5o`0001_ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z0?oooo]ZK?oonfX004gooo]Z1Ol0000KoookJP03o`000?oo
nf[ooo]Z04kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP3ooookJV_ooo]Z001=
oookJPGo00006ooonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX0oooonfYZoookJP00COoonfX5o`0001_ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z0?oooo]ZJ_oonfX004gooo]Z1Ol0000LoookJP03
o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP3ooookJVWo
oo]Z001=oookJPGo00007?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX0oooonfYYoookJP00COoonfX5o`0001cooo]Z00?o0000oookJ_oonfX0Booo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0?oooo]ZJ?oonfX004gooo]Z1Ol0000L
oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP3o
oookJVSooo]Z001=oookJPGo00007?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP00COoonfX5o`0001gooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0?oooo]ZI_oonfX004gooo]Z
1Ol0000MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Z
oookJP3ooookJVKooo]Z001=oookJPGo00007OoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oo
nf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0HOoonfX2o`000?oooo]Z0_oonfX004gooo]Z1Ol0000M
oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP1Q
oookJP03o`000?oonf[o00000?oooo]Z0OoonfX004gooo]Z1Ol0000MoookJP03o`000?oonf[ooo]Z
04Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP1OoookJP05o`000?oonf[ooo]Z
oookJ_l00000oooonfX004gooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX0o?oonfX004gooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX0nooonfX004gooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0
8OoonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0
n_oonfX004gooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00Wooo]Z0_l0003joookJP00COoonfX5
o`0001kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z05Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP3goookJP00COoonfX5o`00
01oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0<oookJP?o001o5?oonfX00ol0
003ooo]ZoookJP1FoookJP04o`000?oonf[ooo]ZoookJPGo001o2?oonfX00ol0003ooo]ZoookJP1W
oookJPGo001oKooonfX3o`00O`Gooo]Z1Ol007l>oookJP00COoonfX5o`0001oooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP0<oookJP?o001o5OoonfX00ol0003ooo]ZoookJP1Eoook
JP03o`000?oonf[ooo]Z00Oo001o2?oonfX00ol0003ooo]ZoookJP1UoookJPOo001oK_oonfX3o`00
O`Cooo]Z1ol007l=oookJP00COoonfX5o`0001oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP0=oookJP?o001o5_oonfX00ol0003ooo]ZoookJP1CoookJP04o`000?oonf[ooo]Zoook
JP?o001o0_oonfX3o`00O`Sooo]Z00?o0000oookJ_oonfX0HooonfX3o`00O`?ooo]Z0ol007m]oook
JP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`gooo]Z001=oookJPGo00007ooonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z00Sooo]Z2Ol007lEoookJP03o`000?oonf[ooo]Z
05;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol007l3oookJP?o001o2OoonfX2o`0006?ooo]Z0ol007l3
oookJP?o001oKOoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o3?oonfX004gooo]Z1Ol0000Ooook
JP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX02?oonfX9o`00OaKooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP02oookJP?o001o0ooonfX3o`00O`_ooo]Z00?o0000oook
J_oonfX0H?oonfX3o`00O`04oookJ_l0003o0000o`0000;o001oKOoonfX3o`00O`?ooo]Z0ol007l3
oookJP?o001o3?oonfX004gooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX02OoonfX2o`00O`?ooo]Z0ol007lGoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX00ooonfX4o`00O`;ooo]Z0ol007l<oookJP03o`000?oonf[ooo]Z05oooo]Z0ol007l01?l0
003ooo]ZoookJ_l007l2o`0006gooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`cooo]Z001=oook
JPGo00008?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l007l2oook
JP?o001o6?oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z00Cooo]Z2?l007l>oook
JP03o`000?oonf[ooo]Z05oooo]Z0_l00005o`00O`03oookJ_l0003o000006_ooo]Z0ol007l3oook
JP?o001o0ooonfX3o`00O`cooo]Z001=oookJPGo00008?oonfX00ol0003ooo]ZoookJP10oookJP03
o`000?oonf[ooo]Z00[ooo]Z0ol007l01?oonf[o001oo`00Ool007lHoookJP03o`000?oonf[ooo]Z
04cooo]Z00?o0000oookJ_oonfX01OoonfX3o`00O`04oookJ_l007oo001oo`00Oa3ooo]Z00?o0000
oookJ_oonfX0G?oonfX2o`0000Oo001o0ooonfX2o`0006Wooo]Z0ol007l3oookJP?o001o0ooonfX3
o`00O`cooo]Z001=oookJPGo00008?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
00cooo]Z0_l007l01?oonf[o001oo`00Ool007lIoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000
oookJ_oonfX01OoonfX3o`00OaGooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]Zo`00O`02
o`00O`?ooo]Z0ol007l4oookJP;o0000IooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o3?oonfX0
04gooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX03OoonfX5o`00
Oa[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP06oookJP?o001o5_oonfX2o`00
05Sooo]Z0_l00002oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l0001RoookJPKo001o0ooonfX3o`00
O`?ooo]Z0ol007l<oookJP00COoonfX5o`00027ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP0=oookJPGo001o6_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z00So
oo]Z0ol007l2oookJP?o001o4_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z00;o
oo]Z0ol007l3oookJP?o001o2?oonfX2o`00063ooo]Z1_l007l2oookJP;o00000ol007l01?oonf[o
001oo`00Ool007l=oookJP00COoonfX5o`00027ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003o
oo]ZoookJP0?oookJPCo001o6ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z00Wo
oo]Z1ol007lDoookJP03o`000?oonf[ooo]Z057ooo]Z0_l00006oookJPOo001o2ooonfX2o`00063o
oo]Z0ol007l3o`0000;ooo]Z1ol007l=oookJP00COoonfX5o`00027ooo]Z00?o0000oookJ_oonfX0
?OoonfX00ol0003ooo]ZoookJP0@oookJP?o001o6ooonfX00ol0003ooo]ZoookJP15oookJP03o`00
0?oonf[ooo]Z00cooo]Z1?l007lFoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
1ooonfX5o`00O`kooo]Z0_l0001OoookJP;o000000?o001ooookJ_oonfX00ooonfX5o`00O`kooo]Z
001=oookJPGo00008OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z04cooo]Z0_l0
000OoookJP;o0000F_oonfX3o`0001_ooo]Z001=oookJPGo00008OoonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0Z
oookJP;o0000B_oonfX2o`0002?ooo]Z0_l0001FoookJP;o00007_oonfX004gooo]Z1Ol0000Roook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0Uoook
JP;o0000DOoonfX3o`00023ooo]Z001=oookJPGo00008_oonfX00ol0003ooo]ZoookJP0joookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z04?ooo]Z0_l0000ZoookJP;o0000COoonfX2o`0002?ooo]Z001=oookJPGo0000
8_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
?_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
;?oonfX2o`0004Sooo]Z0ol0000UoookJP00COoonfX5o`0002;ooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP0noookJP;o0000<OoonfX2o`0004Cooo]Z0_l0000XoookJP001?oonf[o
o`000?oo0000>Ol00005oookJP001?oonf[oo`000?oo0000>Ol00005oookJP001?oonf[oo`000?oo
0000>Ol00005oookJP001?oonf[oo`000?oo0000>Ol00005oookJP001?oonf[oo`000?oo0000>Ol0
0005oookJP00COoonfX5o`0002Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l0000ZoookJP;o00008_oonfX00ol0003ooo]ZoookJP0B
oookJP00COoonfX5o`0002Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0koook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0@?oonfX2o`0002cooo]Z0_l00019oook
JP;o00009OoonfX3o`0003Wooo]Z001=oookJPGo00009?oonfX00ol0003ooo]ZoookJP0eoookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Oooo]Z0_l0001=oookJP;o00008OoonfX2o`0003cooo]Z001=oookJPGo0000
9?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
CooonfX2o`0001cooo]Z0ol0000noookJP00COoonfX5o`0002Cooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP0RoookJP;o0000E?oonfX2o`0001Sooo]Z0_l00011oookJP00COoonfX5
o`0002Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z05Kooo]Z0_l0000CoookJP?o0000@ooonfX004gooo]Z1Ol0000UoookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
04_ooo]Z00?o0000oookJ_oonfX07OoonfX2o`0005_ooo]Z0_l0000?oookJP;o0000A_oonfX004go
oo]Z1Ol0000UoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z04cooo]Z0_l0000LoookJP03o`000?oonf[ooo]Z05go
oo]Z0_l0000:oookJP?o0000B?oonfX004gooo]Z1Ol0000UoookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX05ooonfX2o`0006;ooo]Z0_l00006oookJP;o0000BooonfX004gooo]Z1Ol0
000UoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX05?oonfX2o`0006Kooo]Z0_l0
00001?oonf[o0000o`000?l0001=oookJP00COoonfX5o`0002Kooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0Dooo
nfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0C_oo
nfX004gooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX03ooonfX2
o`000;cooo]Z001=oookJPGo00009_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP1GoookJP;o00003_oonfX00ol0
003ooo]ZoookJP2loookJP00COoonfX5o`0002Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003o
oo]ZoookJP09oookJP;o0000_ooonfX004gooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z05cooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP2ooookJP00COoonfX5o`0002Oooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP04oookJP;o0000`_oonfX004gooo]Z1Ol0000W
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z05oooo]Z00Co0000oookJ_oonf[ooo]Z0_l00034oookJP00COoonfX5
o`0002Oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[o
oo]Z01_ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Zo`000036oookJP00COoonfX5o`00
02Oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP35oookJP00COoonfX5o`0002Oo
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX0oooonfX]oookJP00COoonfX5o`0002Sooo]Z00?o0000oookJ_oonfX0
:_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
oooonfX^oookJP00COoonfX5o`0002Sooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP1=oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0oooonfX_oookJP00COoonfX5
o`0002Sooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX0oooonfX`oookJP00COoonfX5o`0002Sooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX0oooonfX`oookJP00COoonfX5o`0002Sooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP1@oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0oooonfXaoookJP00
COoonfX5o`0002Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP1BoookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0oooonfXboookJP00COoonfX5o`0002Wooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX0oooonfXcoookJP00COoonfX5o`0002Wooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0oooonfXd
oookJP00COoonfX5o`0002Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP1Eoook
JP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0oooonfXeoookJP00COoonfX5o`0002[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0oooonfXfoookJP00COoonfX5o`0002[ooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
oooonfXfoookJP00COoonfX5o`0002[ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP1GoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0oooonfXgoookJP00COoonfX5
o`0002[ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX0oooonfXhoookJP00COoonfX5o`0002[ooo]Z00?o0000oook
J_oonfX08ooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX0oooonfXioookJP00COoonfX5o`0002_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP1JoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0oooonfXjoookJP00
COoonfX5o`0002_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP1KoookJP04o`00
0?oonf[ooo]Zo`000?oooo]Z?OoonfX004gooo]Z1Ol0000[oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]Zo`00003ooookJSkooo]Z001=oookJPGo0000:ooo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0oooo
nfXmoookJP00COoonfX5o`0002_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP3o
oookJYkooo]Z001=oookJPGo0000;?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
0?oooo]ZW_oonfX004gooo]Z1Ol0000/oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0oooonfZNoookJP00COoonfX5o`0002cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP3ooookJYoooo]Z001=oookJPGo0000;?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z0?oooo]ZWooonfX004gooo]Z1Ol0000/oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX0oooonfZOoookJP00COoonfX5o`0002gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0
003ooo]ZoookJP3ooookJZ3ooo]Z000UoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l3oookJPWo
001o2?oonfX5o`0002gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP3ooookJZ3o
oo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo001o2?oonfX5o`0002gooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP3ooookJZ3ooo]Z000ToookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo
001o3OoonfX5o`0002gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP3ooookJZ7o
oo]Z000SoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX4o`00O`cooo]Z
1Ol0000]oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0oooonfZQoookJP008ooo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z1Ol007l:oookJPKo0000;Ooo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z0?oooo]ZX_oonfX002?ooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l5oookJPCo001o2OoonfX5o`0002kooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP3ooookJZ;ooo]Z000SoookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`Wooo]Z1Ol0000^oookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX0oooonfZRoookJP008ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Oooo]Z0ol007l8oookJPGo0000;_oonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z0?oooo]ZXooonfX002?ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o2?oonfX5o`0002kooo]Z00?o0000oookJ_oo
nfX06?oonfX00ol0003ooo]ZoookJP3ooookJZ?ooo]Z000SoookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Sooo]Z1Ol0000_oookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0oooonfZSoookJP009?oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo001o0_oonfX3o`00
O`Sooo]Z1Ol0000_oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0oooonfZToook
JP009?oonfX7o`00O`Sooo]Z1ol007l3oookJPOo001o2OoonfX5o`0002oooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP3ooookJZCooo]Z000UoookJPGo001o2_oonfX5o`00O`Gooo]Z
1Ol007l:oookJPGo0000;ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z0?oooo]Z
Y?oonfX004gooo]Z1Ol0000_oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0oooo
nfZUoookJP00COoonfX5o`00033ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP3o
oookJZGooo]Z001=oookJPGo0000<?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
0?oooo]ZY_oonfX004gooo]Z1Ol0000`oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oo
nfX0oooonfZVoookJP00COoonfX5o`00033ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP3ooookJZKooo]Z001=oookJPGo0000<?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oo
nf[ooo]Z0?oooo]ZYooonfX004gooo]Z1Ol0000aoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX0oooonfZWoookJP00COoonfX5o`00037ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP3ooookJZOooo]Z001=oookJPGo0000<OoonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z0?oooo]ZZ?oonfX004gooo]Z1Ol0000aoookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX0oooonfZXoookJP00COoonfX5o`0003;ooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP3ooookJZSooo]Z001=oookJPGo0000<_oonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z0?oooo]ZZOoonfX004gooo]Z1Ol0000boookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX0oooonfZYoookJP00COoonfX5o`0003;ooo]Z00?o0000oookJ_oo
nfX03OoonfX00ol0003ooo]ZoookJP3ooookJZ[ooo]Z001=oookJPGo0000<_oonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z0?oooo]ZZ_oonfX004gooo]Z1Ol0000coookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0oooonfZZoookJP00COoonfX5o`0003?ooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP3ooookJZ_ooo]Z001=oookJPGo0000<ooonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0?oooo]ZZooonfX004gooo]Z1Ol0000coookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0oooonfZ[oookJP00COoonfX5o`0003?ooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP3ooookJZcooo]Z001=oookJPGo0000=?oo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0?oooo]Z[?oonfX004gooo]Z1Ol0000d
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0oooonfZ]oookJP00COoonfX5o`00
03Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP3ooookJZgooo]Z001=oookJPGo
0000=?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0?oooo]Z[OoonfX004gooo]Z
1Ol0000doookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0oooonfZ^oookJP00COoo
nfX5o`0003Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP3ooookJZkooo]Z001=
oookJPGo0000=OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z0?oooo]Z[_oonfX0
04gooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0oooonfZ_oook
JP00COoonfX5o`0003Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP3ooookJZoo
oo]Z001=oookJPGo0000=OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0?oooo]Z
[ooonfX004gooo]Z1Ol0000foookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0oooo
nfZ`oookJP00COoonfX5o`0003Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP3o
oookJ[3ooo]Z001=oookJPGo0000=_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
0?oooo]Z/OoonfX004gooo]Z1Ol0000foookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX0oooonfZaoookJP00COoonfX5o`0003Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP3ooookJ[7ooo]Z001=oookJPGo0000=ooonfX01?l0003ooo]ZoookJ_l0003ooookJ[Cooo]Z
001=oookJPGo0000=ooonfX01?l0003ooo]ZoookJ_l0003ooookJ[Cooo]Z001=oookJPGo0000=ooo
nfX01?l0003ooo]ZoookJ_l0003ooookJ[Cooo]Z001=oookJPGo0000=ooonfX00ol0003ooo]Zo`00
003ooookJ[Gooo]Z000UoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l8oookJP?o001o2OoonfX5
o`0003Oooo]Z00?o0000oookJ_l00000oooonfZeoookJP009?oonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o1ooonfX3o`00O`Wooo]Z1Ol0000hoookJP;o0000oooonfZeoookJP009?oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX3
o`00O`Wooo]Z1Ol0000hoookJP03o`000?oonf[ooo]Z0?oooo]Z]?oonfX002?ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Sooo]Z1Ol0003ooook
J^oooo]Z000SoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00?ooo]Zo`00Ool0
07l01ol007l8oookJPKo0000oooonf[^oookJP008ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`03oookJ_l007oo001o00?ooo]Z0ol007l9oookJPGo0000oooonf[_oookJP008ooo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007l2oookJP?o001o2Ooo
nfX5o`000?oooo]ZkooonfX002?ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2
oookJP?o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]ZkooonfX002?ooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP;o001o00Cooo]Zo`00Ool007oo001o2Ooo
nfX5o`000?oooo]ZkooonfX002?ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4
oookJPGo001o2OoonfX5o`000?oooo]ZkooonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJP?o001o00Cooo]Zo`00Ool007oo001o1OoonfX5o`00O`Wooo]Z1Ol0003ooookJ^oooo]Z000T
oookJPOo001o2?oonfX7o`00O`Kooo]Z1?l007l9oookJPGo0000oooonf[_oookJP009OoonfX5o`00
O`[ooo]Z1Ol007l8oookJP?o001o2OoonfX5o`000?oooo]ZkooonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {0.66997, -0.0917179, \
0.0168001, 0.000381864}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{4, 1920}, {0, 1178}},
WindowSize->{1523, 955},
WindowMargins->{{109, Automatic}, {Automatic, 91}},
WindowTitle->"Lecture 17 MIT 3.016 (Fall 2005)   \[Copyright] W. Craig Carter \
2003-2005",
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "mmtag:17:notes_and_frequencies"->{
    Cell[1902, 60, 1187, 22, 356, "Input",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}],
    Cell[3092, 84, 395576, 5037, 364, 67135, 906, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}],
    Cell[398671, 5123, 252, 6, 68, "Output",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}]},
  "mmtag:17:middle_c"->{
    Cell[1902, 60, 1187, 22, 356, "Input",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}],
    Cell[3092, 84, 395576, 5037, 364, 67135, 906, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}],
    Cell[398671, 5123, 252, 6, 68, "Output",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}]},
  "mmtag:17:Play[]"->{
    Cell[1902, 60, 1187, 22, 356, "Input",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}],
    Cell[3092, 84, 395576, 5037, 364, 67135, 906, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}],
    Cell[398671, 5123, 252, 6, 68, "Output",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}]},
  "mmtag:17:sound_generation"->{
    Cell[1902, 60, 1187, 22, 356, "Input",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}],
    Cell[3092, 84, 395576, 5037, 364, 67135, 906, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}],
    Cell[398671, 5123, 252, 6, 68, "Output",
      CellTags->{
      "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", 
        "mmtag:17:Play[]", "mmtag:17:sound_generation"}]},
  "mmtag:17:ode_to_joy"->{
    Cell[541657, 6989, 186343, 2611, 100, "Text",
      CellTags->"mmtag:17:ode_to_joy"]},
  "mmtag:17:periodicity__constraining_a_function_to_be_periodic"->{
    Cell[4001736, 52523, 240, 6, 59, "Text",
      CellTags->{
      "mmtag:17:periodicity__constraining_a_function_to_be_periodic", 
        "mmtag:17:Mod[]"}]},
  "mmtag:17:Mod[]"->{
    Cell[4001736, 52523, 240, 6, 59, "Text",
      CellTags->{
      "mmtag:17:periodicity__constraining_a_function_to_be_periodic", 
        "mmtag:17:Mod[]"}]},
  "mmtag:17:Fourier_series"->{
    Cell[4054631, 53793, 73, 1, 61, "Subtitle",
      CellTags->"mmtag:17:Fourier_series"]},
  "mmtag:17:orthogonality_of_trignometric_functions"->{
    Cell[4054729, 53798, 158, 4, 78, "Section",
      CellTags->"mmtag:17:orthogonality_of_trignometric_functions"]},
  "mmtag:17:Assuming[]"->{
    Cell[4056272, 53844, 329, 6, 63, "Input",
      CellTags->{"mmtag:17:Assuming[]", "mmtag:17:Limit[]__and_Assuming[]"}],
    Cell[4056604, 53852, 119, 2, 94, "Output",
      CellTags->{
      "mmtag:17:Assuming[]", "mmtag:17:Limit[]__and_Assuming[]"}]},
  "mmtag:17:Limit[]__and_Assuming[]"->{
    Cell[4056272, 53844, 329, 6, 63, "Input",
      CellTags->{"mmtag:17:Assuming[]", "mmtag:17:Limit[]__and_Assuming[]"}],
    Cell[4056604, 53852, 119, 2, 94, "Output",
      CellTags->{
      "mmtag:17:Assuming[]", "mmtag:17:Limit[]__and_Assuming[]"}]},
  "mmtag:17:Fourier_series__example_function_for_calculating_cosine_terms"->{
    Cell[4061141, 53995, 409, 8, 94, "Input",
      CellTags->
      "mmtag:17:Fourier_series__example_function_for_calculating_cosine_\
terms"]},
  "mmtag:17:Fourier_series__example_function_for_calculating_sine_terms"->{
    Cell[4061734, 54013, 405, 8, 94, "Input",
      CellTags->
      "mmtag:17:Fourier_series__example_function_for_calculating_sine_terms"]}\
,
  "mmtag:17:Fourier_series__basis_functions"->{
    Cell[4107778, 55102, 232, 4, 94, "Input",
      CellTags->"mmtag:17:Fourier_series__basis_functions"]},
  "mmtag:17:Fourier_series__function_to_create_truncated_series"->{
    Cell[4108824, 55138, 416, 7, 80, "Input",
      CellTags->
      "mmtag:17:Fourier_series__function_to_create_truncated_series"]},
  "mmtag:17:Fourier_series__example_plot"->{
    Cell[4268835, 58715, 181, 4, 63, "Input",
      CellTags->"mmtag:17:Fourier_series__example_plot"],
    Cell[4269019, 58721, 76122, 1627, 377, 18109, 906, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"mmtag:17:Fourier_series__example_plot"],
    Cell[4345144, 60350, 183, 4, 80, "Output",
      CellTags->"mmtag:17:Fourier_series__example_plot"]},
  "mmtag:17:FourierTransform_Package"->{
    Cell[4444987, 62383, 154, 3, 63, "Input",
      CellTags->{
      "mmtag:17:FourierTransform_Package", 
        "mmtag:17:Package__FourierTransform"}]},
  "mmtag:17:Package__FourierTransform"->{
    Cell[4444987, 62383, 154, 3, 63, "Input",
      CellTags->{
      "mmtag:17:FourierTransform_Package", 
        "mmtag:17:Package__FourierTransform"}]},
  "mmtag:17:Fourier_series__changing_domain_of_periodicity"->{
    Cell[4479395, 63304, 325, 7, 59, "Text",
      CellTags->"mmtag:17:Fourier_series__changing_domain_of_periodicity"]},
  "mmtag:17:FourierCosCoefficient[]"->{
    Cell[4511960, 64159, 125, 2, 63, "Input",
      CellTags->"mmtag:17:FourierCosCoefficient[]"],
    Cell[4512088, 64163, 83, 2, 68, "Output",
      CellTags->"mmtag:17:FourierCosCoefficient[]"]},
  "mmtag:17:FourierSinCoefficient[]"->{
    Cell[4512208, 64170, 125, 2, 63, "Input",
      CellTags->"mmtag:17:FourierSinCoefficient[]"],
    Cell[4512336, 64174, 152, 3, 102, "Output",
      CellTags->"mmtag:17:FourierSinCoefficient[]"]},
  "mmtag:17:FourierTrigSeries[]"->{
    Cell[4512525, 64182, 117, 2, 63, "Input",
      CellTags->"mmtag:17:FourierTrigSeries[]"],
    Cell[4512645, 64186, 417, 6, 102, "Output",
      CellTags->"mmtag:17:FourierTrigSeries[]"]},
  "mmtag:17:Fourier_series__example_function_for_calculating_and_efficiency"->{\

    Cell[4513467, 64204, 402, 8, 91, "Text",
      CellTags->
      "mmtag:17:Fourier_series__example_function_for_calculating_and_\
efficiency"]},
  "mmtag:17:Module[]"->{
    Cell[4513894, 64216, 1003, 20, 182, "Input",
      CellTags->{
      "mmtag:17:Module[]", "mmtag:17:Fourier_series__example_animation"}],
    Cell[4514900, 64238, 444, 7, 24, "Message",
      CellTags->{
      "mmtag:17:Module[]", "mmtag:17:Fourier_series__example_animation"}]},
  "mmtag:17:Fourier_series__example_animation"->{
    Cell[4513894, 64216, 1003, 20, 182, "Input",
      CellTags->{
      "mmtag:17:Module[]", "mmtag:17:Fourier_series__example_animation"}],
    Cell[4514900, 64238, 444, 7, 24, "Message",
      CellTags->{
      "mmtag:17:Module[]", "mmtag:17:Fourier_series__example_animation"}]},
  "mmtag:17:Fourier_series__Gibbs_phenomena"->{
    Cell[4515541, 64255, 256, 5, 63, "Input",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4515822, 64264, 36793, 1084, 377, 17754, 843, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4552618, 65350, 40193, 1196, 377, 19121, 930, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4592814, 66548, 42155, 1269, 377, 20083, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4634972, 67819, 44245, 1349, 377, 21124, 1058, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4679220, 69170, 45227, 1403, 377, 21907, 1109, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4724450, 70575, 46210, 1452, 377, 22660, 1156, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4770663, 72029, 47043, 1491, 377, 23185, 1191, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4817709, 73522, 47949, 1526, 377, 23641, 1220, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4865661, 75050, 47935, 1526, 377, 23639, 1220, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4913599, 76578, 49120, 1585, 377, 24504, 1275, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4962722, 78165, 50091, 1641, 377, 25370, 1330, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5012816, 79808, 50602, 1662, 377, 25675, 1349, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5063421, 81472, 49789, 1614, 377, 24918, 1301, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5113213, 83088, 51419, 1702, 377, 26249, 1386, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5164635, 84792, 50205, 1639, 377, 25302, 1326, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5214843, 86433, 51802, 1714, 377, 26401, 1395, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5266648, 88149, 51763, 1731, 377, 26657, 1415, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5318414, 89882, 52760, 1784, 377, 27500, 1466, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5371177, 91668, 53485, 1815, 377, 27946, 1494, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5424665, 93485, 50680, 1676, 377, 25927, 1365, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5475348, 95163, 51789, 1745, 377, 27007, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5527140, 96910, 52194, 1744, 377, 26882, 1426, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5579337, 98656, 53729, 1844, 377, 28429, 1526, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5633069, 100502, 51890, 1738, 377, 26788, 1422, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5684962, 102242, 53390, 1826, 377, 28199, 1509, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5738355, 104070, 51966, 1762, 377, 27265, 1451, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5790324, 105834, 51971, 1765, 377, 27315, 1455, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5842298, 107601, 52457, 1788, 377, 27655, 1476, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5894758, 109391, 52929, 1811, 377, 27998, 1498, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5947690, 111204, 52615, 1788, 377, 27647, 1474, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6000308, 112994, 54100, 1895, 377, 29347, 1584, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6054411, 114891, 53614, 1888, 377, 29335, 1583, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6108028, 116781, 53302, 1859, 377, 28836, 1551, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6161333, 118642, 53438, 1863, 377, 28826, 1553, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6214774, 120507, 51414, 1761, 377, 27426, 1459, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6266191, 122270, 52443, 1826, 377, 28374, 1523, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6318637, 124098, 54308, 1935, 377, 30065, 1630, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6372948, 126035, 51983, 1806, 377, 28125, 1506, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6424934, 127843, 53068, 1857, 377, 28841, 1552, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6478005, 129702, 51297, 1759, 377, 27358, 1458, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6529305, 131463, 52649, 1836, 377, 28532, 1533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6581957, 133301, 52710, 1839, 377, 28568, 1535, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6634670, 135142, 48158, 1551, 377, 24081, 1248, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6682831, 136695, 49715, 1662, 377, 25877, 1362, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6732549, 138359, 49294, 1633, 377, 25371, 1332, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6781846, 139994, 50244, 1694, 377, 26353, 1393, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6832093, 141690, 50771, 1727, 377, 26864, 1426, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6882867, 143419, 50540, 1713, 377, 26657, 1412, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6933410, 145134, 50778, 1730, 377, 26883, 1429, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6984191, 146866, 48766, 1598, 377, 24863, 1297, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7032960, 148466, 48916, 1608, 377, 25013, 1307, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7081879, 150076, 51669, 1791, 377, 27867, 1491, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7133551, 151869, 52868, 1867, 377, 29066, 1567, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7186422, 153738, 50521, 1707, 377, 26566, 1406, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7236946, 155447, 50914, 1737, 377, 27068, 1437, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7287863, 157186, 52640, 1849, 377, 28778, 1549, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7340506, 159037, 51605, 1792, 377, 27933, 1494, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7392114, 160831, 52594, 1850, 377, 28817, 1551, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7444711, 162683, 51999, 1808, 377, 28153, 1508, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7496713, 164493, 49823, 1667, 377, 25920, 1366, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}]},
  "mmtag:17:Gibbs_phenomena"->{
    Cell[4515541, 64255, 256, 5, 63, "Input",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4515822, 64264, 36793, 1084, 377, 17754, 843, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4552618, 65350, 40193, 1196, 377, 19121, 930, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4592814, 66548, 42155, 1269, 377, 20083, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4634972, 67819, 44245, 1349, 377, 21124, 1058, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4679220, 69170, 45227, 1403, 377, 21907, 1109, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4724450, 70575, 46210, 1452, 377, 22660, 1156, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4770663, 72029, 47043, 1491, 377, 23185, 1191, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4817709, 73522, 47949, 1526, 377, 23641, 1220, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4865661, 75050, 47935, 1526, 377, 23639, 1220, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4913599, 76578, 49120, 1585, 377, 24504, 1275, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4962722, 78165, 50091, 1641, 377, 25370, 1330, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5012816, 79808, 50602, 1662, 377, 25675, 1349, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5063421, 81472, 49789, 1614, 377, 24918, 1301, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5113213, 83088, 51419, 1702, 377, 26249, 1386, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5164635, 84792, 50205, 1639, 377, 25302, 1326, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5214843, 86433, 51802, 1714, 377, 26401, 1395, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5266648, 88149, 51763, 1731, 377, 26657, 1415, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5318414, 89882, 52760, 1784, 377, 27500, 1466, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5371177, 91668, 53485, 1815, 377, 27946, 1494, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5424665, 93485, 50680, 1676, 377, 25927, 1365, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5475348, 95163, 51789, 1745, 377, 27007, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5527140, 96910, 52194, 1744, 377, 26882, 1426, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5579337, 98656, 53729, 1844, 377, 28429, 1526, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5633069, 100502, 51890, 1738, 377, 26788, 1422, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5684962, 102242, 53390, 1826, 377, 28199, 1509, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5738355, 104070, 51966, 1762, 377, 27265, 1451, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5790324, 105834, 51971, 1765, 377, 27315, 1455, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5842298, 107601, 52457, 1788, 377, 27655, 1476, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5894758, 109391, 52929, 1811, 377, 27998, 1498, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5947690, 111204, 52615, 1788, 377, 27647, 1474, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6000308, 112994, 54100, 1895, 377, 29347, 1584, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6054411, 114891, 53614, 1888, 377, 29335, 1583, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6108028, 116781, 53302, 1859, 377, 28836, 1551, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6161333, 118642, 53438, 1863, 377, 28826, 1553, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6214774, 120507, 51414, 1761, 377, 27426, 1459, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6266191, 122270, 52443, 1826, 377, 28374, 1523, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6318637, 124098, 54308, 1935, 377, 30065, 1630, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6372948, 126035, 51983, 1806, 377, 28125, 1506, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6424934, 127843, 53068, 1857, 377, 28841, 1552, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6478005, 129702, 51297, 1759, 377, 27358, 1458, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6529305, 131463, 52649, 1836, 377, 28532, 1533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6581957, 133301, 52710, 1839, 377, 28568, 1535, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6634670, 135142, 48158, 1551, 377, 24081, 1248, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6682831, 136695, 49715, 1662, 377, 25877, 1362, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6732549, 138359, 49294, 1633, 377, 25371, 1332, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6781846, 139994, 50244, 1694, 377, 26353, 1393, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6832093, 141690, 50771, 1727, 377, 26864, 1426, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6882867, 143419, 50540, 1713, 377, 26657, 1412, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6933410, 145134, 50778, 1730, 377, 26883, 1429, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6984191, 146866, 48766, 1598, 377, 24863, 1297, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7032960, 148466, 48916, 1608, 377, 25013, 1307, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7081879, 150076, 51669, 1791, 377, 27867, 1491, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7133551, 151869, 52868, 1867, 377, 29066, 1567, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7186422, 153738, 50521, 1707, 377, 26566, 1406, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7236946, 155447, 50914, 1737, 377, 27068, 1437, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7287863, 157186, 52640, 1849, 377, 28778, 1549, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7340506, 159037, 51605, 1792, 377, 27933, 1494, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7392114, 160831, 52594, 1850, 377, 28817, 1551, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7444711, 162683, 51999, 1808, 377, 28153, 1508, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7496713, 164493, 49823, 1667, 377, 25920, 1366, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}]},
  "mmtag:17:Fourier_series__visualization_of_convergence"->{
    Cell[4515541, 64255, 256, 5, 63, "Input",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4515822, 64264, 36793, 1084, 377, 17754, 843, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4552618, 65350, 40193, 1196, 377, 19121, 930, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4592814, 66548, 42155, 1269, 377, 20083, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4634972, 67819, 44245, 1349, 377, 21124, 1058, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4679220, 69170, 45227, 1403, 377, 21907, 1109, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4724450, 70575, 46210, 1452, 377, 22660, 1156, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4770663, 72029, 47043, 1491, 377, 23185, 1191, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4817709, 73522, 47949, 1526, 377, 23641, 1220, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4865661, 75050, 47935, 1526, 377, 23639, 1220, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4913599, 76578, 49120, 1585, 377, 24504, 1275, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[4962722, 78165, 50091, 1641, 377, 25370, 1330, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5012816, 79808, 50602, 1662, 377, 25675, 1349, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5063421, 81472, 49789, 1614, 377, 24918, 1301, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5113213, 83088, 51419, 1702, 377, 26249, 1386, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5164635, 84792, 50205, 1639, 377, 25302, 1326, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5214843, 86433, 51802, 1714, 377, 26401, 1395, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5266648, 88149, 51763, 1731, 377, 26657, 1415, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5318414, 89882, 52760, 1784, 377, 27500, 1466, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5371177, 91668, 53485, 1815, 377, 27946, 1494, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5424665, 93485, 50680, 1676, 377, 25927, 1365, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5475348, 95163, 51789, 1745, 377, 27007, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5527140, 96910, 52194, 1744, 377, 26882, 1426, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5579337, 98656, 53729, 1844, 377, 28429, 1526, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5633069, 100502, 51890, 1738, 377, 26788, 1422, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5684962, 102242, 53390, 1826, 377, 28199, 1509, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5738355, 104070, 51966, 1762, 377, 27265, 1451, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5790324, 105834, 51971, 1765, 377, 27315, 1455, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5842298, 107601, 52457, 1788, 377, 27655, 1476, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5894758, 109391, 52929, 1811, 377, 27998, 1498, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[5947690, 111204, 52615, 1788, 377, 27647, 1474, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6000308, 112994, 54100, 1895, 377, 29347, 1584, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6054411, 114891, 53614, 1888, 377, 29335, 1583, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6108028, 116781, 53302, 1859, 377, 28836, 1551, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6161333, 118642, 53438, 1863, 377, 28826, 1553, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6214774, 120507, 51414, 1761, 377, 27426, 1459, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6266191, 122270, 52443, 1826, 377, 28374, 1523, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6318637, 124098, 54308, 1935, 377, 30065, 1630, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6372948, 126035, 51983, 1806, 377, 28125, 1506, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6424934, 127843, 53068, 1857, 377, 28841, 1552, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6478005, 129702, 51297, 1759, 377, 27358, 1458, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6529305, 131463, 52649, 1836, 377, 28532, 1533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6581957, 133301, 52710, 1839, 377, 28568, 1535, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6634670, 135142, 48158, 1551, 377, 24081, 1248, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6682831, 136695, 49715, 1662, 377, 25877, 1362, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6732549, 138359, 49294, 1633, 377, 25371, 1332, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6781846, 139994, 50244, 1694, 377, 26353, 1393, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6832093, 141690, 50771, 1727, 377, 26864, 1426, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6882867, 143419, 50540, 1713, 377, 26657, 1412, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6933410, 145134, 50778, 1730, 377, 26883, 1429, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[6984191, 146866, 48766, 1598, 377, 24863, 1297, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7032960, 148466, 48916, 1608, 377, 25013, 1307, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7081879, 150076, 51669, 1791, 377, 27867, 1491, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7133551, 151869, 52868, 1867, 377, 29066, 1567, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7186422, 153738, 50521, 1707, 377, 26566, 1406, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7236946, 155447, 50914, 1737, 377, 27068, 1437, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7287863, 157186, 52640, 1849, 377, 28778, 1549, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7340506, 159037, 51605, 1792, 377, 27933, 1494, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7392114, 160831, 52594, 1850, 377, 28817, 1551, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7444711, 162683, 51999, 1808, 377, 28153, 1508, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}],
    Cell[7496713, 164493, 49823, 1667, 377, 25920, 1366, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
        "mmtag:17:Fourier_series__visualization_of_convergence"}]},
  "mmtag:17:ListPlot[]"->{
    Cell[7547813, 166221, 106, 2, 63, "Input",
      CellTags->"mmtag:17:ListPlot[]"],
    Cell[7547922, 166225, 33652, 838, 377, 12296, 569, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"mmtag:17:ListPlot[]"],
    Cell[7581577, 167065, 165, 4, 80, "Output",
      CellTags->"mmtag:17:ListPlot[]"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"mmtag:17:notes_and_frequencies", 7632163, 168140},
  {"mmtag:17:middle_c", 7632788, 168154},
  {"mmtag:17:Play[]", 7633411, 168168},
  {"mmtag:17:sound_generation", 7634044, 168182},
  {"mmtag:17:ode_to_joy", 7634671, 168196},
  {"mmtag:17:periodicity__constraining_a_function_to_be_periodic", 7634830, \
168199},
  {"mmtag:17:Mod[]", 7635015, 168204},
  {"mmtag:17:Fourier_series", 7635209, 168209},
  {"mmtag:17:orthogonality_of_trignometric_functions", 7635358, 168212},
  {"mmtag:17:Assuming[]", 7635503, 168215},
  {"mmtag:17:Limit[]__and_Assuming[]", 7635800, 168221},
  {"mmtag:17:Fourier_series__example_function_for_calculating_cosine_terms", \
7636135, 168227},
  {"mmtag:17:Fourier_series__example_function_for_calculating_sine_terms", \
7636358, 168232},
  {"mmtag:17:Fourier_series__basis_functions", 7636551, 168237},
  {"mmtag:17:Fourier_series__function_to_create_truncated_series", 7636727, \
168240},
  {"mmtag:17:Fourier_series__example_plot", 7636907, 168244},
  {"mmtag:17:FourierTransform_Package", 7637318, 168252},
  {"mmtag:17:Package__FourierTransform", 7637517, 168257},
  {"mmtag:17:Fourier_series__changing_domain_of_periodicity", 7637737, \
168262},
  {"mmtag:17:FourierCosCoefficient[]", 7637899, 168265},
  {"mmtag:17:FourierSinCoefficient[]", 7638138, 168270},
  {"mmtag:17:FourierTrigSeries[]", 7638375, 168275},
  {"mmtag:17:Fourier_series__example_function_for_calculating_and_efficiency",\
 7638648, 168280},
  {"mmtag:17:Module[]", 7638823, 168286},
  {"mmtag:17:Fourier_series__example_animation", 7639157, 168293},
  {"mmtag:17:Fourier_series__Gibbs_phenomena", 7639489, 168300},
  {"mmtag:17:Gibbs_phenomena", 7655786, 168605},
  {"mmtag:17:Fourier_series__visualization_of_convergence", 7672112, 168910},
  {"mmtag:17:ListPlot[]", 7688404, 169215}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 35, 0, 64, "Title"],
Cell[1792, 53, 85, 3, 78, "Text"],

Cell[CellGroupData[{
Cell[1902, 60, 1187, 22, 356, "Input",
  CellTags->{
  "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", "mmtag:17:Play[]", 
    "mmtag:17:sound_generation"}],
Cell[3092, 84, 395576, 5037, 364, 67135, 906, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{
  "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", "mmtag:17:Play[]", 
    "mmtag:17:sound_generation"}],
Cell[398671, 5123, 252, 6, 68, "Output",
  CellTags->{
  "mmtag:17:notes_and_frequencies", "mmtag:17:middle_c", "mmtag:17:Play[]", 
    "mmtag:17:sound_generation"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[398960, 5134, 71, 1, 50, "Input"],
Cell[399034, 5137, 142478, 1844, 364, 17335, 259, "GraphicsData", \
"PostScript", "Graphics"],
Cell[541515, 6983, 127, 3, 68, "Output"]
}, Open  ]],
Cell[541657, 6989, 186343, 2611, 100, "Text",
  CellTags->"mmtag:17:ode_to_joy"],
Cell[728003, 9602, 272, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[728300, 9610, 152, 2, 50, "Input"],
Cell[728455, 9614, 409, 6, 90, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[728901, 9625, 92, 1, 50, "Input"],
Cell[728996, 9628, 2546408, 33415, 364, 2391077, 31087, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3275407, 43045, 127, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3275571, 43053, 118, 3, 50, "Input"],
Cell[3275692, 43058, 725144, 9437, 364, 166732, 2199, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4000839, 52497, 280, 4, 44, "Message"],
Cell[4001122, 52503, 313, 5, 24, "Message"],
Cell[4001438, 52510, 127, 3, 68, "Output"]
}, Open  ]],
Cell[4001580, 52516, 31, 0, 64, "Title"],
Cell[4001614, 52518, 119, 3, 48, "Subtitle"],
Cell[4001736, 52523, 240, 6, 59, "Text",
  CellTags->{
  "mmtag:17:periodicity__constraining_a_function_to_be_periodic", 
    "mmtag:17:Mod[]"}],
Cell[4001979, 52531, 107, 2, 50, "Input"],

Cell[CellGroupData[{
Cell[4002111, 52537, 78, 1, 50, "Input"],
Cell[4002192, 52540, 365, 5, 24, "Message"]
}, Open  ]],
Cell[4002572, 52548, 276, 11, 46, "Text"],
Cell[4002851, 52561, 365, 5, 24, "Message"],

Cell[CellGroupData[{
Cell[4003241, 52570, 113, 2, 50, "Input"],
Cell[4003357, 52574, 51126, 1211, 364, 14890, 759, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4054486, 53787, 130, 3, 55, "Output"]
}, Open  ]],
Cell[4054631, 53793, 73, 1, 61, "Subtitle",
  CellTags->"mmtag:17:Fourier_series"],

Cell[CellGroupData[{
Cell[4054729, 53798, 158, 4, 78, "Section",
  CellTags->"mmtag:17:orthogonality_of_trignometric_functions"],

Cell[CellGroupData[{
Cell[4054912, 53806, 363, 7, 78, "Input"],
Cell[4055278, 53815, 777, 14, 185, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4056092, 53834, 105, 2, 50, "Input"],
Cell[4056200, 53838, 35, 1, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4056272, 53844, 329, 6, 63, "Input",
  CellTags->{"mmtag:17:Assuming[]", "mmtag:17:Limit[]__and_Assuming[]"}],
Cell[4056604, 53852, 119, 2, 94, "Output",
  CellTags->{"mmtag:17:Assuming[]", "mmtag:17:Limit[]__and_Assuming[]"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4056760, 53859, 365, 7, 78, "Input"],
Cell[4057128, 53868, 789, 14, 185, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4057954, 53887, 121, 3, 50, "Input"],
Cell[4058078, 53892, 35, 1, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4058150, 53898, 256, 5, 50, "Input"],
Cell[4058409, 53905, 35, 1, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4058481, 53911, 363, 7, 78, "Input"],
Cell[4058847, 53920, 789, 14, 185, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4059673, 53939, 105, 2, 50, "Input"],
Cell[4059781, 53943, 35, 1, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4059853, 53949, 256, 5, 50, "Input"],
Cell[4060112, 53956, 46, 1, 81, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4060207, 53963, 67, 0, 65, "Section"],
Cell[4060277, 53965, 342, 10, 46, "Text"],
Cell[4060622, 53977, 99, 3, 46, "Text"],
Cell[4060724, 53982, 34, 0, 46, "Text"],
Cell[4060761, 53984, 191, 3, 81, "Input"],
Cell[4060955, 53989, 183, 4, 46, "Text"],
Cell[4061141, 53995, 409, 8, 94, "Input",
  CellTags->
  "mmtag:17:Fourier_series__example_function_for_calculating_cosine_terms"],
Cell[4061553, 54005, 94, 3, 46, "Text"],
Cell[4061650, 54010, 81, 1, 50, "Input"],
Cell[4061734, 54013, 405, 8, 94, "Input",
  CellTags->
  "mmtag:17:Fourier_series__example_function_for_calculating_sine_terms"],
Cell[4062142, 54023, 114, 3, 46, "Text"],
Cell[4062259, 54028, 200, 3, 67, "Input"],
Cell[4062462, 54033, 202, 3, 67, "Input"],
Cell[4062667, 54038, 55, 0, 46, "Text"],
Cell[4062725, 54040, 88, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[4062838, 54045, 142, 3, 50, "Input"],
Cell[4062983, 54050, 43779, 1010, 364, 12781, 623, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4106765, 55062, 130, 3, 68, "Output"]
}, Open  ]],
Cell[4106910, 55068, 87, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[4107022, 55075, 86, 1, 50, "Input"],
Cell[4107111, 55078, 309, 5, 102, "Output"]
}, Open  ]],
Cell[4107435, 55086, 174, 5, 62, "Text"],

Cell[CellGroupData[{
Cell[4107634, 55095, 71, 1, 50, "Input"],
Cell[4107708, 55098, 55, 1, 68, "Output"]
}, Open  ]],
Cell[4107778, 55102, 232, 4, 94, "Input",
  CellTags->"mmtag:17:Fourier_series__basis_functions"],

Cell[CellGroupData[{
Cell[4108035, 55110, 56, 1, 50, "Input"],
Cell[4108094, 55113, 149, 2, 68, "Output"]
}, Open  ]],
Cell[4108258, 55118, 177, 3, 81, "Input"],

Cell[CellGroupData[{
Cell[4108460, 55125, 57, 1, 50, "Input"],
Cell[4108520, 55128, 149, 2, 68, "Output"]
}, Open  ]],
Cell[4108684, 55133, 137, 3, 46, "Text"],
Cell[4108824, 55138, 416, 7, 80, "Input",
  CellTags->"mmtag:17:Fourier_series__function_to_create_truncated_series"],
Cell[4109243, 55147, 141, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[4109409, 55156, 72, 1, 50, "Input"],
Cell[4109484, 55159, 424, 6, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4109945, 55170, 128, 3, 50, "Input"],
Cell[4110076, 55175, 71092, 1607, 364, 18963, 959, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4181171, 56784, 130, 3, 68, "Output"]
}, Open  ]],
Cell[4181316, 56790, 296, 6, 66, "Text"],

Cell[CellGroupData[{
Cell[4181637, 56800, 64, 1, 50, "Input"],
Cell[4181704, 56803, 86716, 1893, 364, 20728, 1074, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4268423, 58698, 130, 3, 68, "Output"]
}, Open  ]],
Cell[4268568, 58704, 242, 7, 46, "Text"],

Cell[CellGroupData[{
Cell[4268835, 58715, 181, 4, 63, "Input",
  CellTags->"mmtag:17:Fourier_series__example_plot"],
Cell[4269019, 58721, 76122, 1627, 377, 18109, 906, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"mmtag:17:Fourier_series__example_plot"],
Cell[4345144, 60350, 183, 4, 80, "Output",
  CellTags->"mmtag:17:Fourier_series__example_plot"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4345364, 60359, 64, 1, 50, "Input"],
Cell[4345431, 60362, 99270, 2006, 364, 19877, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4444704, 62370, 130, 3, 68, "Output"]
}, Open  ]],
Cell[4444849, 62376, 135, 5, 46, "Text"],
Cell[4444987, 62383, 154, 3, 63, "Input",
  CellTags->{
  "mmtag:17:FourierTransform_Package", 
    "mmtag:17:Package__FourierTransform"}],
Cell[4445144, 62388, 71, 1, 78, "Input"],

Cell[CellGroupData[{
Cell[4445240, 62393, 62, 1, 50, "Input"],
Cell[4445305, 62396, 33942, 900, 364, 13653, 645, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4479250, 63298, 130, 3, 68, "Output"]
}, Open  ]],
Cell[4479395, 63304, 325, 7, 59, "Text",
  CellTags->"mmtag:17:Fourier_series__changing_domain_of_periodicity"],
Cell[4479723, 63313, 120, 2, 50, "Input"],

Cell[CellGroupData[{
Cell[4479868, 63319, 105, 2, 50, "Input"],
Cell[4479976, 63323, 41, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4480054, 63329, 104, 2, 50, "Input"],
Cell[4480161, 63333, 31629, 816, 364, 11993, 569, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4511793, 64151, 130, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4511960, 64159, 125, 2, 63, "Input",
  CellTags->"mmtag:17:FourierCosCoefficient[]"],
Cell[4512088, 64163, 83, 2, 68, "Output",
  CellTags->"mmtag:17:FourierCosCoefficient[]"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4512208, 64170, 125, 2, 63, "Input",
  CellTags->"mmtag:17:FourierSinCoefficient[]"],
Cell[4512336, 64174, 152, 3, 102, "Output",
  CellTags->"mmtag:17:FourierSinCoefficient[]"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4512525, 64182, 117, 2, 63, "Input",
  CellTags->"mmtag:17:FourierTrigSeries[]"],
Cell[4512645, 64186, 417, 6, 102, "Output",
  CellTags->"mmtag:17:FourierTrigSeries[]"]
}, Open  ]],
Cell[4513077, 64195, 387, 7, 67, "Input"],
Cell[4513467, 64204, 402, 8, 91, "Text",
  CellTags->
  "mmtag:17:Fourier_series__example_function_for_calculating_and_efficiency"],\


Cell[CellGroupData[{
Cell[4513894, 64216, 1003, 20, 182, "Input",
  CellTags->{
  "mmtag:17:Module[]", "mmtag:17:Fourier_series__example_animation"}],
Cell[4514900, 64238, 444, 7, 24, "Message",
  CellTags->{
  "mmtag:17:Module[]", "mmtag:17:Fourier_series__example_animation"}]
}, Open  ]],
Cell[4515359, 64248, 157, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[4515541, 64255, 256, 5, 63, "Input",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],

Cell[CellGroupData[{
Cell[4515822, 64264, 36793, 1084, 377, 17754, 843, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[4552618, 65350, 40193, 1196, 377, 19121, 930, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[4592814, 66548, 42155, 1269, 377, 20083, 991, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[4634972, 67819, 44245, 1349, 377, 21124, 1058, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[4679220, 69170, 45227, 1403, 377, 21907, 1109, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[4724450, 70575, 46210, 1452, 377, 22660, 1156, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[4770663, 72029, 47043, 1491, 377, 23185, 1191, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[4817709, 73522, 47949, 1526, 377, 23641, 1220, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[4865661, 75050, 47935, 1526, 377, 23639, 1220, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[4913599, 76578, 49120, 1585, 377, 24504, 1275, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[4962722, 78165, 50091, 1641, 377, 25370, 1330, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5012816, 79808, 50602, 1662, 377, 25675, 1349, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5063421, 81472, 49789, 1614, 377, 24918, 1301, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5113213, 83088, 51419, 1702, 377, 26249, 1386, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5164635, 84792, 50205, 1639, 377, 25302, 1326, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5214843, 86433, 51802, 1714, 377, 26401, 1395, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5266648, 88149, 51763, 1731, 377, 26657, 1415, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5318414, 89882, 52760, 1784, 377, 27500, 1466, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5371177, 91668, 53485, 1815, 377, 27946, 1494, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5424665, 93485, 50680, 1676, 377, 25927, 1365, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5475348, 95163, 51789, 1745, 377, 27007, 1433, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5527140, 96910, 52194, 1744, 377, 26882, 1426, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5579337, 98656, 53729, 1844, 377, 28429, 1526, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5633069, 100502, 51890, 1738, 377, 26788, 1422, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5684962, 102242, 53390, 1826, 377, 28199, 1509, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5738355, 104070, 51966, 1762, 377, 27265, 1451, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5790324, 105834, 51971, 1765, 377, 27315, 1455, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5842298, 107601, 52457, 1788, 377, 27655, 1476, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5894758, 109391, 52929, 1811, 377, 27998, 1498, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[5947690, 111204, 52615, 1788, 377, 27647, 1474, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6000308, 112994, 54100, 1895, 377, 29347, 1584, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6054411, 114891, 53614, 1888, 377, 29335, 1583, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6108028, 116781, 53302, 1859, 377, 28836, 1551, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6161333, 118642, 53438, 1863, 377, 28826, 1553, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6214774, 120507, 51414, 1761, 377, 27426, 1459, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6266191, 122270, 52443, 1826, 377, 28374, 1523, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6318637, 124098, 54308, 1935, 377, 30065, 1630, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6372948, 126035, 51983, 1806, 377, 28125, 1506, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6424934, 127843, 53068, 1857, 377, 28841, 1552, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6478005, 129702, 51297, 1759, 377, 27358, 1458, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6529305, 131463, 52649, 1836, 377, 28532, 1533, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6581957, 133301, 52710, 1839, 377, 28568, 1535, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6634670, 135142, 48158, 1551, 377, 24081, 1248, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6682831, 136695, 49715, 1662, 377, 25877, 1362, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6732549, 138359, 49294, 1633, 377, 25371, 1332, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6781846, 139994, 50244, 1694, 377, 26353, 1393, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6832093, 141690, 50771, 1727, 377, 26864, 1426, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6882867, 143419, 50540, 1713, 377, 26657, 1412, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6933410, 145134, 50778, 1730, 377, 26883, 1429, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[6984191, 146866, 48766, 1598, 377, 24863, 1297, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[7032960, 148466, 48916, 1608, 377, 25013, 1307, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[7081879, 150076, 51669, 1791, 377, 27867, 1491, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[7133551, 151869, 52868, 1867, 377, 29066, 1567, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[7186422, 153738, 50521, 1707, 377, 26566, 1406, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[7236946, 155447, 50914, 1737, 377, 27068, 1437, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[7287863, 157186, 52640, 1849, 377, 28778, 1549, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[7340506, 159037, 51605, 1792, 377, 27933, 1494, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[7392114, 160831, 52594, 1850, 377, 28817, 1551, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[7444711, 162683, 51999, 1808, 377, 28153, 1508, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}],
Cell[7496713, 164493, 49823, 1667, 377, 25920, 1366, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "mmtag:17:Fourier_series__Gibbs_phenomena", "mmtag:17:Gibbs_phenomena", 
    "mmtag:17:Fourier_series__visualization_of_convergence"}]
}, Closed]]
}, Open  ]],
Cell[7546563, 166164, 63, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[7546651, 166168, 46, 1, 50, "Input"],
Cell[7546700, 166171, 64, 1, 70, "Output"]
}, Open  ]],
Cell[7546779, 166175, 164, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[7546968, 166184, 108, 2, 50, "Input"],
Cell[7547079, 166188, 52, 1, 70, "Output"]
}, Open  ]],
Cell[7547146, 166192, 51, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[7547222, 166196, 101, 2, 57, "Input"],
Cell[7547326, 166200, 134, 2, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7547497, 166207, 80, 1, 57, "Input"],
Cell[7547580, 166210, 35, 1, 68, "Output"]
}, Open  ]],
Cell[7547630, 166214, 158, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[7547813, 166221, 106, 2, 63, "Input",
  CellTags->"mmtag:17:ListPlot[]"],
Cell[7547922, 166225, 33652, 838, 377, 12296, 569, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"mmtag:17:ListPlot[]"],
Cell[7581577, 167065, 165, 4, 80, "Output",
  CellTags->"mmtag:17:ListPlot[]"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7581779, 167074, 126, 2, 50, "Input"],
Cell[7581908, 167078, 49353, 1035, 364, 13040, 582, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7631264, 168115, 130, 3, 68, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

